CREATE SCHEMA ethereal AUTHORIZATION erealms_ethereal;
CREATE SEQUENCE ethereal.seqComment  MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqFeed     MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqFortune  MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqGallery  MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqLayer    MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqLink     MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqMail     MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqOption   MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqPoll     MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqVanity   MAXVALUE 2147483647;
CREATE SEQUENCE ethereal.seqWork     MAXVALUE 2147483647 START 15;
CREATE SEQUENCE ethereal.seqAudit    MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE ethereal.seqBoard    MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE ethereal.seqFaq      MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE ethereal.seqOffline  MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE ethereal.seqPost     MAXVALUE 2147483647 CYCLE;
CREATE SEQUENCE ethereal.seqWeblog   MAXVALUE 2147483647 CYCLE;
CREATE TABLE ethereal.Astrology (
  AstroSign          VARCHAR(15)   NOT NULL,
  AstroStart         DATE          NOT NULL,
  AstroEnd           DATE          NOT NULL,
  CONSTRAINT pkAstrology           PRIMARY KEY (AstroSign, AstroStart)
);
CREATE INDEX idxAstrology ON ethereal.Astrology
(
  AstroStart,
  AstroEnd
);
CREATE TABLE ethereal.Contact (
  ContactName          VARCHAR(25)   NOT NULL,
  ContactType          VARCHAR(10),
  ContactFilter        VARCHAR(10)   NOT NULL DEFAULT 'none',
  CONSTRAINT pkContact               PRIMARY KEY (ContactName),
  CONSTRAINT enumContactFilter       CHECK (ContactFilter IN ('email','http','none','numeric'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Exif (
  ExifTag              VARCHAR(20)   NOT NULL,
  ExifMacro            VARCHAR(10)   NOT NULL,
  CONSTRAINT pkExif                  PRIMARY KEY (ExifTag)
) WITHOUT OIDS;
CREATE TABLE ethereal.Faq (
  FaqNum               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqFaq'),
  FaqQuestion          VARCHAR(255)  NOT NULL,
  Faqgroup             VARCHAR(25),
  FaqAnswer            TEXT,
  CONSTRAINT pkFaq                   PRIMARY KEY(FaqNum)
) WITHOUT OIDS;
CREATE INDEX idxFaq ON ethereal.Faq
(
  FaqGroup,
  FaqQuestion
);
CREATE TABLE ethereal.Font (
  FontName             VARCHAR(25)   NOT NULL,
  FontType             VARCHAR(5)    NOT NULL,
  FontCode             VARCHAR(35),
  CONSTRAINT pkFont                  PRIMARY KEY(FontName, FontType),
  CONSTRAINT enumFontType            CHECK (FontType in ('color','face','size'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Fortune (
  FortuneNum           INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqFortune'),
  FortuneType          VARCHAR(15)   NOT NULL,
  FortuneMsg           TEXT,
  CONSTRAINT pkFortune               PRIMARY KEY (FortuneNum)
) WITHOUT OIDS;
CREATE INDEX idxFortune ON ethereal.Fortune
(
  FortuneType
);
CREATE TABLE ethereal.Genre (
  GenreName            VARCHAR(25)  NOT NULL,
  GenreType            VARCHAR(5)   NOT NULL DEFAULT 'realm',
  GenreSub             VARCHAR(25)  NOT NULL DEFAULT '<root>',
  GenreDescription     VARCHAR(250),
  CONSTRAINT pkGenre                PRIMARY KEY (GenreName, GenreType, GenreSub),
  CONSTRAINT enumGenreOrder         CHECK (GenreType IN ('realm','image','text'))
) WITHOUT OIDS;
CREATE TABLE PGSHCMEA.Sign (
  SignAnimal           VARCHAR(10)   NOT NULL,
  SignElement          VARCHAR(10)   NOT NULL,
  SignStart            DATE          NOT NULL,
  SignEnd              DATE          NOT NULL,
  CONSTRAINT pkSign                  PRIMARY KEY (SignAnimal, SignElement, SignStart, SignEnd)
);
CREATE TABLE ethereal.Tag (
  TagName              VARCHAR(25)    NOT NULL,
  TagType              VARCHAR(15)    NOT NULL DEFAULT 'system',
  TagData              TEXT,
  CONSTRAINT pkTag                    PRIMARY KEY (TagName, TagType),
  CONSTRAINT enumTagType              CHECK (TagType IN ('admin','board','bio','configuration','contrib','faq','gallery','gummy','login','mail','poll','portal','realm','system','template','user','vanity','vcodes'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Rotate (
  RotateName           VARCHAR(25)    NOT NULL,
  RotateZone           VARCHAR(10)    NOT NULL DEFAULT 'banner',
  RotateConduct        VARCHAR(8)     NOT NULL DEFAULT 'static',
  RotateTimestamp      TIMESTAMP      NOT NULL DEFAULT LOCALTIMESTAMP,
  RotateData           TEXT,
  CONSTRAINT pkRotate                 PRIMARY KEY (RotateName, RotateZone),
  CONSTRAINT enumRotateZone           CHECK (RotateZone IN ('banner','gallery','javascript','portal','ssi')),
  CONSTRAINT enumRotateConduct        CHECK (RotateConduct IN ('image','static','text'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Poll (
  PollID               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqPoll'),
  RealmName            VARCHAR       NOT NULL DEFAULT 'system',      
  PollName             VARCHAR(20)   NOT NULL,
  PollQuestion         VARCHAR(255)  NOT NULL,
  CONSTRAINT pkPoll                  PRIMARY KEY (PollID),
  CONSTRAINT fkPoll                  FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.PollOption (
  PollID               INT           NOT NULL,
  OptionID             INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqOption'),
  OptionName           VARCHAR(50)   NOT NULL,
  CONSTRAINT pkPollOption            PRIMARY KEY (PollID, OptionID),
  CONSTRAINT fkPollOption            FOREIGN KEY (PollID)
    REFERENCES ethereal.Poll (PollID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.PollVote (
  PollID               INT           NOT NULL,
  VoteHostname         INET          NOT NULL,
  OptionID             INT           NOT NULL,
  CONSTRAINT pkPollVote              PRIMARY KEY (PollID, VoteHostname),
  CONSTRAINT fkPollVote_PollID       FOREIGN KEY (PollID, OptionID)
    REFERENCES ethereal.PollOption (PollID, OptionID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Puppeteer (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  PuppeteerPassword    VARCHAR(13)   NOT NULL,
  PuppeteerName        VARCHAR(30)   NOT NULL,
  PuppeteerAlias       VARCHAR(10),
  PuppeteerEMail       VARCHAR(45)   NOT NULL,
  PuppeteerMailer      CHAR(3)       NOT NULL DEFAULT 'int',
  PuppeteerTimestamp   TIMESTAMP,
  PuppeteerHostname    INET,
  PuppeteerBan         VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerVerified    VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerChatPref    VARCHAR(10)   NOT NULL DEFAULT 'stream',
  PuppeteerFormatting  VARCHAR(9)    NOT NULL DEFAULT 'complete',
  PuppeteerJavascript  VARCHAR(3)    NOT NULL DEFAULT 'yes',
  PuppeteerPrivacy     VARCHAR(6)    NOT NULL DEFAULT 'no',
  PuppeteerAdminPrivs  VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerSuperPrivs  VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerModPrivs    VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerIgnore      VARCHAR(3)    NOT NULL DEFAULT 'yes',
  PuppeteerSnub        VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppeteerContact     VARCHAR(5)    NOT NULL DEFAULT 'yes',
  PuppeteerHome        VARCHAR(200),
  PuppeteerHomeSpan    TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  PuppeteerRealm       VARCHAR(30),
  CONSTRAINT pkPuppeteer             PRIMARY KEY(PuppeteerLogin),
  CONSTRAINT enumPuppeteerBan        CHECK (PuppeteerBan        IN ('yes','no')),
  CONSTRAINT enumPuppeteerVerified   CHECK (PuppeteerVerified   IN ('yes','no')),
  CONSTRAINT enumPuppeteerChatPref   CHECK (PuppeteerChatPref   IN ('basic','framed','stream','autoscroll')),
  CONSTRAINT enumPuppeteerFormatting CHECK (PuppeteerFormatting IN ('complete','imageless','spartan')),
  CONSTRAINT enumPuppeteerJavascript CHECK (PuppeteerJavascript IN ('yes','no')),
  CONSTRAINT enumPuppeteerPrivacy    CHECK (PuppeteerPrivacy    IN ('yes','no','global')),
  CONSTRAINT enumPuppeteerAdminPrivs CHECK (PuppeteerAdminPrivs IN ('yes','no')),
  CONSTRAINT enumPuppeteerSuperPrivs CHECK (PuppeteerSuperPrivs IN ('yes','no')),
  CONSTRAINT enumPuppeteerModPrivs   CHECK (PuppeteerModPrivs   IN ('yes','no')),
  CONSTRAINT enumPuppeteerIgnore     CHECK (PuppeteerIgnore     IN ('yes','no')),
  CONSTRAINT enumPuppeteerSnub       CHECK (PuppeteerSnub       IN ('yes','no')),
  CONSTRAINT enumPuppeteerContact    CHECK (PuppeteerContact    IN ('yes','no','limit')),
  CONSTRAINT enumPuppeteerMailer     CHECK (PuppeteerMailer     IN ('int','ext'))
) WITHOUT OIDS;
CREATE UNIQUE INDEX fncPuppeteer_Login ON ethereal.Puppeteer
(
  lower(PuppeteerLogin)
);
CREATE INDEX fncPuppeteer_Name ON ethereal.Puppeteer
(
  lower(PuppeteerName)
);
CREATE INDEX fncPuppeteer_Home ON ethereal.Puppeteer
(
  lower(PuppeteerHome)
);
CREATE INDEX fncPuppeteer_Email ON ethereal.Puppeteer
(
  lower(PuppeteerEmail)
);
CREATE INDEX idxPuppeteer_Ident_Name ON ethereal.Puppeteer
(
  PuppeteerName
);
CREATE INDEX idxPuppeteer_Ident_Home ON ethereal.Puppeteer
(
  PuppeteerHome
);
CREATE INDEX idxPuppeteer_Ident_Email ON ethereal.Puppeteer
(
  PuppeteerEMail
);
CREATE INDEX idxPuppeteer_Time ON ethereal.Puppeteer
(
  PuppeteerTimestamp
);
CREATE INDEX idxPuppeteer_Privs_Admin ON ethereal.Puppeteer
(
  PuppeteerAdminPrivs
);
CREATE INDEX idxPuppeteer_Privs_Mod ON ethereal.Puppeteer
(
  PuppeteerModPrivs
);
CREATE INDEX idxPuppeteer_Privs_Super ON ethereal.Puppeteer
(
  PuppeteerSuperPrivs
);
CREATE INDEX idxPuppeteer_Privs_Verified ON ethereal.Puppeteer
(
  PuppeteerVerified
);
CREATE TABLE ethereal.Social (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  LocateCity           VARCHAR(45)   NOT NULL,
  LocateRegion         VARCHAR(45)   NOT NULL,
  LocateCountry        VARCHAR(45)   NOT NULL,
  LocateLat            REAL          NOT NULL,
  LocateLong           REAL          NOT NULL,
  PhysicalGender       VARCHAR(10),
  PhysicalBirthDate    DATE,
  PhysicalHeight       VARCHAR(15),
  PhysicalBodyType     VARCHAR(15),
  PhysicalEyeColour    VARCHAR(15),
  PhysicalHairColour   VARCHAR(15),
  PhysicalEthnicity    VARCHAR(15),
  IntroCatchPhrase     VARCHAR(150),
  IntroDescription     TEXT,
  IntroFirstDate       TEXT,
  SocialLooking        VARCHAR(15),
  SocialSeeking        VARCHAR(10),
  SocialAgeMin         SMALLINT      NOT NULL DEFAULT 18,
  SocialAgeMax         SMALLINT      NOT NULL DEFAULT 99,
  SocialMarital        VARCHAR(10),
  SocialChildrenHave   VARCHAR(10),
  SocialChildrenWant   VARCHAR(10),
  SocialInterests      TEXT,
  SocialReligion       VARCHAR(30),
  SocialProfession     VARCHAR(30),
  ViceSmoke            VARCHAR(10),
  ViceDrink            VARCHAR(10),
  CONSTRAINT pkSocial                PRIMARY KEY (PuppeteerLogin),
  CONSTRAINT valLocateLat            CHECK (LocateLat  <= 90  AND LocateLat  >= -90),
  CONSTRAINT valLocateLong           CHECK (LocateLong <= 180 AND LocateLong >= -180),
  CONSTRAINT valSocialAgeMin         CHECK (SocialAgeMin > 17 AND SocialAgeMin < 100),
  CONSTRAINT valSocialAgeMax         CHECK (SocialAgeMax > 17 AND SocialAgeMax < 100),
  CONSTRAINT fkSocial                FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Liason (
  LiasonOwner          VARCHAR(10)   NOT NULL,
  LiasonTarget         VARCHAR(10)   NOT NULL,
  LiasonSource         VARCHAR(6)    NOT NULL DEFAULT 'owner',
  LiasonRelation       VARCHAR(7)    NOT NULL DEFAULT 'neutral',
  CONSTRAINT PkLiason                PRIMARY KEY (LiasonOwner, LiasonTarget),
  CONSTRAINT enumLiasonSource        CHECK (LiasonSource   IN ('owner','target','nil')),
  CONSTRAINT enumLiasonRelation      CHECK (LiasonRelation IN ('neutral','friend','foe')),
  CONSTRAINT FkLiasonOwner           FOREIGN KEY (LiasonOwner)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT FkLiasonTarget          FOREIGN KEY (LiasonTarget)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Vanity (
  VanityID             INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqVanity'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  VanityPath           VARCHAR(200)  NOT NULL,
  VanityThumb          VARCHAR(200)  NOT NULL,
  VanityWidth          SMALLINT      NOT NULL,
  VanityHeight         SMALLINT      NOT NULL,
  VanityDefault        VARCHAR(3)    NOT NULL DEFAULT 'no',
  VanityPublic         VARCHAR(3)    NOT NULL DEFAULT 'yes',
  VanityVote           VARCHAR(3)    NOT NULL DEFAULT 'no',
  CONSTRAINT pkVanity                PRIMARY KEY (VanityID),
  CONSTRAINT enumVanityDefault       CHECK (VanityDefault IN ('yes','no')),
  CONSTRAINT enumVanityPublic        CHECK (VanityPublic  IN ('yes','no')),
  CONSTRAINT enumVanityVote          CHECK (VanityVote    IN ('yes','no')),
  CONSTRAINT fkVanity                FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);
CREATE TABLE ethereal.VanityVotes (
  VanityID             INT           NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  VoteLevel            SMALLINT      NOT NULL,
  CONSTRAINT fkVanityVote_Login      FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkVanityVote_VanityID   FOREIGN KEY (VanityID)
    REFERENCES ethereal.Vanity (VanityID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);
CREATE TABLE ethereal.Param (
  ParamNumber          INTEGER       NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  ParamValue           TEXT          NOT NULL,
  ParamTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT PkParam                 PRIMARY KEY (ParamNumber, PuppeteerLogin),
  CONSTRAINT FkParam                 FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE INDEX idxParam_Timestamp ON ethereal.Param
(
  ParamTimestamp
);
CREATE TABLE ethereal.PuppeteerContact (
  ContactName          VARCHAR(25)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  ContactData          VARCHAR(200),
  CONSTRAINT pkPuppeteerContact      PRIMARY KEY (ContactName, PuppeteerLogin),
  CONSTRAINT fkPuppetContact_Name    FOREIGN KEY (ContactName)
    REFERENCES ethereal.Contact (ContactName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkPuppetContact_Login   FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.PuppeteerRegistration (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  PuppeteerConfCode    VARCHAR(10)   NOT NULL,
  PuppeteerTimeStamp   TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkPuppeteerRegistration PRIMARY KEY (PuppeteerLogin),
  CONSTRAINT fkPuppeteerRegistration FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Association (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  AssociationName      VARCHAR(10)   NOT NULL,
  CONSTRAINT pkAssociation PRIMARY KEY (PuppeteerLogin, AssociationName),
  CONSTRAINT fkAssociation FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Audit (
  AuditNumber          INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqAudit'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  PuppeteerHostname    INET,
  AuditAction          VARCHAR(6)    NOT NULL DEFAULT 'auth',
  AuditCode            SMALLINT      NOT NULL DEFAULT '1000',
  AuditAdditional      VARCHAR(50),
  AuditRealm           VARCHAR(30)   NOT NULL DEFAULT 'system',
  AuditTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkAudit                 PRIMARY KEY (AuditNumber),
  CONSTRAINT enumAction CHECK (AuditAction IN ('action','auth','delete','insert','update')),
  CONSTRAINT numCode    CHECK (AuditCode >= 1000 AND AuditCode < 10000 )
) WITHOUT OIDS;
CREATE INDEX idxAudit_Action ON ethereal.Audit
(
  AuditAction
);
CREATE INDEX idxAudit_Hostname ON ethereal.Audit
(
  PuppeteerHostname
);
CREATE INDEX idxAudit_Realm ON ethereal.Audit
(
  AuditRealm
);
CREATE INDEX idxAudit_Timestamp ON ethereal.Audit
(
  AuditTimestamp
);
CREATE INDEX idxAudit_CodeTimestamp ON ethereal.Audit
(
  AuditCode,
  AuditTimestamp
);
CREATE TABLE ethereal.Transaction (
  TransIdentifier      VARCHAR(20)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  TransGross           NUMERIC(9,2)  NOT NULL,
  TransCur             CHAR(3)       NOT NULL,
  TransTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkTrans                 PRIMARY KEY (TransIdentifier),
  CONSTRAINT fkTrans                 FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Gallery (
  GalleryID            INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqGallery'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  GalleryPenName       VARCHAR(30)   NOT NULL,
  GalleryName          VARCHAR(30)   NOT NULL,
  GalleryRating        VARCHAR(5)    NOT NULL,
  GalleryDescription   VARCHAR(250),
  GalleryWork          INT,
  GalleryHighlight     VARCHAR(30),
  GalleryThumbnail     VARCHAR(200),
  GalleryComments      VARCHAR(7)    NOT NULL DEFAULT 'combo',
  GallerySort          VARCHAR(7)    NOT NULL DEFAULT 'alpha',
  GalleryType          VARCHAR(7)    NOT NULL DEFAULT 'initial',
  GallerySub           VARCHAR(25),
  GalleryPrivacy       VARCHAR(3)    NOT NULL DEFAULT 'no',
  GalleryDisplay       SMALLINT,
  GalleryCreated       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  GalleryUpdated       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkGallery               PRIMARY KEY (GalleryID),
  CONSTRAINT fkGallery_Login         FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumGalleryComments     CHECK (GalleryComments IN ('combo','comment','none','rating')),
  CONSTRAINT enumGalleryPrivacy      CHECK (GalleryPrivacy IN ('yes','no')),
  CONSTRAINT enumGallerySort         CHECK (GallerySort IN ('alpha','date','manual','rating')),
  CONSTRAINT enumGalleryType         CHECK (GalleryType IN ('comic','image','initial','journal','text'))
) WITHOUT OIDS;
CREATE INDEX fncGallery_Pen ON ethereal.Gallery
(
  lower(GalleryPenName)
);
CREATE INDEX fncGallery_Name ON ethereal.Gallery
(
  lower(GalleryName)
);
CREATE INDEX fncGallery_Rating ON ethereal.Gallery
(
  lower(GalleryRating)
);
CREATE INDEX idxGallery_Name ON ethereal.Gallery
(
  GalleryName
);
CREATE INDEX idxGallery_Pen ON ethereal.Gallery
(
  GalleryPenName
);
CREATE INDEX idxGallery_Rating ON ethereal.Gallery
(
  GalleryRating
);
CREATE TABLE ethereal.Layer (
  LayerID              INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqLayer'),
  GalleryID            INT           NOT NULL,
  LayerShort           VARCHAR(16),
  LayerFull            VARCHAR(100),
  LayerDescription     VARCHAR(250),
  LayerWork            INT,
  LayerHighlight       VARCHAR(30),
  LayerThumbnail       VARCHAR(200),
  LayerLevel           SMALLINT      NOT NULL DEFAULT '0',
  LevelZero            VARCHAR(16)   NOT NULL DEFAULT '0',
  LevelOne             VARCHAR(16)   NOT NULL DEFAULT '0',
  LevelTwo             VARCHAR(16)   NOT NULL DEFAULT '0',
  LevelThree           VARCHAR(16)   NOT NULL DEFAULT '0',
  LevelFour            VARCHAR(16)   NOT NULL DEFAULT '0',
  LevelFive            VARCHAR(16)   NOT NULL DEFAULT '0',
  CONSTRAINT pkLayer                 PRIMARY KEY (LayerID, GalleryID),
  CONSTRAINT fkLayer                 FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE UNIQUE INDEX idxLayer_ID ON ethereal.Layer
(
  LayerID
);
CREATE UNIQUE INDEX idxLayer_Short ON ethereal.Layer
(
  GalleryID,
  LayerShort
);
CREATE INDEX idxLayer_Levels ON ethereal.Layer
(
  LayerLevel,
  LevelZero,
  LevelOne,
  LevelTwo,
  LevelThree,
  LevelFour,
  LevelFive
);
CREATE TABLE ethereal.Work (
  GalleryID            INT           NOT NULL,
  WorkID               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqWork'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  WorkName             VARCHAR(30)   NOT NULL,
  WorkLayer            INT,
  WorkDescription      VARCHAR(250),
  WorkSort             SMALLINT,
  WorkImage            VARCHAR(200),
  WorkImageThumbnail   VARCHAR(200),
  WorkImageSize        SMALLINT,
  WorkImageExif        TEXT,
  WorkImageHeight      SMALLINT,
  WorkImageWidth       SMALLINT,
  WorkImageView        VARCHAR(30),
  WorkImageFull        VARCHAR(30),
  WorkText             TEXT,
  WorkTextPreserve     VARCHAR(3)    NOT NULL DEFAULT 'no',
  WorkTimestamp        TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  WorkRating           SMALLINT      NOT NULL DEFAULT '0',
  CONSTRAINT pkWork                  PRIMARY KEY (GalleryID, WorkID),
  CONSTRAINT fkWork                  FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWork_Owner            FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWork_Layer            FOREIGN KEY (WorkLayer)
    REFERENCES ethereal.Layer (LayerID)
      ON DELETE SET NULL
      ON UPDATE CASCADE,
  CONSTRAINT enumWorkTextPreserve    CHECK (WorkTextPreserve IN ('yes','no'))
) WITHOUT OIDS;
CREATE UNIQUE INDEX idxWork_Highlight ON ethereal.Work
(
  WorkId,
  WorkName,
  WorkImageThumbnail
)
CREATE INDEX fncWork_Name ON ethereal.Work
(
  lower(WorkName)
);
CREATE INDEX idxWork_Name ON ethereal.Work
(
  WorkName,
  GalleryID
);
ALTER TABLE ethereal.Gallery ADD CONSTRAINT fkGallery_Highlight
FOREIGN KEY (GalleryWork, GalleryHighlight, GalleryThumbnail)
    REFERENCES ethereal.Work (WorkID, WorkName, WorkImageThumbnail)
      ON DELETE SET NULL
      ON UPDATE CASCADE;
ALTER TABLE ethereal.Layer ADD CONSTRAINT fkLayer_Highlight
FOREIGN KEY (LayerWork, LayerHighlight, LayerThumbnail)
    REFERENCES ethereal.Work (WorkID, WorkName, WorkImageThumbnail)
      ON DELETE SET NULL
      ON UPDATE CASCADE;
CREATE TABLE ethereal.GalleryAccess (
  GalleryID            INT           NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  PuppetName           VARCHAR(30)   NOT NULL,
  AccessOwner          VARCHAR(3)    NOT NULL DEFAULT 'no',
  AccessEditor         VARCHAR(3)    NOT NULL DEFAULT 'no',
  AccessJanitor        VARCHAR(3)    NOT NULL DEFAULT 'no',
  CONSTRAINT pkGalleryAccess         PRIMARY KEY (GalleryID, PuppeteerLogin),
  CONSTRAINT fkAccess_ID             FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkAccess_Login          FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumAccessOwner         CHECK (AccessOwner       IN ('yes','no')),
  CONSTRAINT enumAccessEditor        CHECK (AccessEditor      IN ('yes','no')),
  CONSTRAINT enumAccessJanitor       CHECK (AccessJanitor     IN ('yes','no'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Revision (
  GalleryID            INT           NOT NULL,
  WorkID               INT           NOT NULL,
  RevisionTimestamp    TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  RevisionName         VARCHAR(30)   NOT NULL,
  RevisionText         TEXT,
  CONSTRAINT pkRevision              PRIMARY KEY (GalleryID, WorkID, RevisionTimestamp),
  CONSTRAINT fkRevision_Work         FOREIGN KEY (GalleryID, WorkID)
    REFERENCES ethereal.Work (GalleryID, WorkID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkRevision_Owner        FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Comment (
  GalleryID            INT           NOT NULL,
  WorkID               INT           NOT NULL,
  CommentID            INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqComment'),
  PuppetName           VARCHAR(30)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  CommentTimestamp     TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CommentPost          TEXT,
  CommentRating        SMALLINT      NOT NULL,
  CONSTRAINT pkComment               PRIMARY KEY (GalleryID, WorkID, CommentID),
  CONSTRAINT fkComment               FOREIGN KEY (GalleryID, WorkID)
    REFERENCES ethereal.Work (GalleryID, WorkID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.GalleryGenre (
  GalleryID            INT          NOT NULL,
  GenreName            VARCHAR(25)  NOT NULL,
  GenreType            VARCHAR(7)   NOT NULL,
  GenreSub             VARCHAR(25)  NOT NULL,
  CONSTRAINT pkGalleryGenre         PRIMARY KEY (GalleryID, GenreName, GenreType, GenreSub),
  CONSTRAINT fkGenre_Gallery        FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkGenre_Genre          FOREIGN KEY (GenreName, GenreType, GenreSub)
    REFERENCES ethereal.Genre (GenreName, GenreType, GenreSub)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.GalleryNotify (
  GalleryID            INT           NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  CONSTRAINT pkGalleryNotify         PRIMARY KEY (GalleryID, PuppeteerLogin),
  CONSTRAINT fkNotify_Gallery        FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkComment_Puppeteer     FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Link (
  LinkID               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqLink'),
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  GalleryID            INT,
  LinkName             VARCHAR(20)   NOT NULL,
  LinkAddress          VARCHAR(250)  NOT NULL,
  CONSTRAINT pkLink                  PRIMARY KEY (LinkID),
  CONSTRAINT fkComment_Gallery       FOREIGN KEY (GalleryID)
    REFERENCES ethereal.Gallery (GalleryID)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkLinkPuppeteer         FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE INDEX idxLink_PuppeteerLogin ON ethereal.Link
(
  PuppeteerLogin
);
CREATE INDEX idxLink_GalleryId ON ethereal.Link
(
  GalleryID
);
CREATE TABLE ethereal.Index (
  IndexWord            VARCHAR(50)   NOT NULL,
  GalleryID            INT           NOT NULL,
  WorkID               INT           NOT NULL,
  IndexScore           SMALLINT,
  CONSTRAINT pkIndex                 PRIMARY KEY (IndexWord, GalleryID, WorkID),
  CONSTRAINT fkIndex                 FOREIGN KEY (GalleryID, WorkID)
    REFERENCES ethereal.Work (GalleryID, WorkID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Realm (
  RealmName            VARCHAR(30)   NOT NULL,
  RealmAlias           VARCHAR(30),
  RealmDescription     TEXT,
  RealmHomepage        VARCHAR(255),
  RealmRating          VARCHAR(5)    NOT NULL DEFAULT 'PG',
  RealmGenre           VARCHAR(25)   NOT NULL DEFAULT 'General',
  RealmPassword        VARCHAR(13),
  RealmArchive         VARCHAR(45),
  RealmAccess          VARCHAR(10)   NOT NULL DEFAULT 'relaxed',
  RealmVerified        VARCHAR(3)    NOT NULL DEFAULT 'no',
  RealmBanner          VARCHAR(7)    NOT NULL DEFAULT 'display',
  RealmDateLoc         VARCHAR(7)    NOT NULL DEFAULT 'bottom',
  RealmDateFormat      VARCHAR(30)   NOT NULL DEFAULT 'DD-Mon-YYYY, HH24:MI:SS TZ',
  RealmPublic          VARCHAR(6)    NOT NULL DEFAULT 'no',
  RealmLocale          VARCHAR(8)    NOT NULL DEFAULT 'none',
  RealmTags            VARCHAR(10)   NOT NULL DEFAULT 'relaxed',
  RealmLanguage        VARCHAR(10)   NOT NULL DEFAULT 'relaxed',
  RealmHarass          VARCHAR(3)    NOT NULL DEFAULT 'no',
  RealmFilter          VARCHAR(10)   NOT NULL DEFAULT '****',
  RealmFontColor       TEXT,
  RealmFontFace        TEXT ,
  RealmFontSize        TEXT,
  RealmTextColour      VARCHAR(25)   NOT NULL DEFAULT 'White',
  RealmImageHeight     SMALLINT      NOT NULL DEFAULT '0',
  RealmImageWidth      SMALLINT      NOT NULL DEFAULT '0',
  RealmImageSize       SMALLINT      NOT NULL DEFAULT '0',
  RealmBoard           VARCHAR(45),
  RealmAltBoard        VARCHAR(255),
  RealmICAO            VARCHAR(4),
  RealmMETAR           VARCHAR(250),
  RealmTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkRealm                 PRIMARY KEY (RealmName),
  CONSTRAINT enumRealmAccess         CHECK (RealmAccess   IN ('relaxed','restricted','list')),
  CONSTRAINT enumRealmVerified       CHECK (RealmVerified IN ('yes','no')),
  CONSTRAINT enumRealmHarass         CHECK (RealmHarass   IN ('yes','no')),
  CONSTRAINT enumRealmBanner         CHECK (RealmBanner   IN ('display','exempt')),
  CONSTRAINT enumRealmDateLoc        CHECK (RealmDateLoc  IN ('bottom','top','removed')),
  CONSTRAINT enumRealmLocale         CHECK (RealmLocale   IN ('none','strict','variable')),
  CONSTRAINT enumRealmPublic         CHECK (RealmPublic   IN ('yes','no','hybrid','alias')),
  CONSTRAINT enumRealmTags           CHECK (RealmTags     IN ('relaxed','restricted')),
  CONSTRAINT enumRealmLanguage       CHECK (RealmLanguage IN ('relaxed','restricted'))
) WITHOUT OIDS;
CREATE INDEX fncRealm ON ethereal.Realm
(
  lower(RealmName)
);
CREATE INDEX idxRealm_Alias ON ethereal.Realm
(
  RealmAlias
);
CREATE INDEX idxRealm_Public ON ethereal.Realm
(
  RealmPublic
);
CREATE INDEX idxRealm_Timestamp ON ethereal.Realm
(
  RealmTimestamp
);
CREATE INDEX idxRealm_Verified ON ethereal.Realm
(
  RealmVerified
);
CREATE INDEX idxRealm_NamePublicVerified ON ethereal.Realm
(
  RealmName, 
  RealmPublic, 
  RealmVerified
);
CREATE TABLE ethereal.BoardTopic (
  RealmName            VARCHAR(30)   NOT NULL,
  BoardTopic           VARCHAR(25)   NOT NULL,
  BoardDescription     TEXT,
  CONSTRAINT pkBoardTopic            PRIMARY KEY (RealmName, BoardTopic),
  CONSTRAINT fkBoardTopic            FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Feed (
  FeedID               INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqFeed'),
  RealmName            VARCHAR(30)   NOT NULL,
  FeedTitle            VARCHAR(30)   NOT NULL,
  FeedLink             VARCHAR(250)  NOT NULL,
  FeedSource           VARCHAR(250)  NOT NULL,
  FeedMax              SMALLINT      NOT NULL DEFAULT 0,
  FeedCompactView      VARCHAR(3)    NOT NULL DEFAULT 'yes',
  FeedShowDate         VARCHAR(3)    NOT NULL DEFAULT 'yes',
  FeedNewWindow        VARCHAR(3)    NOT NULL DEFAULT 'yes',
  FeedArchive          TEXT,
  FeedTimestamp        TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT enumFeedCompactView     CHECK (FeedCompactView IN ('yes','no')),
  CONSTRAINT enumFeedShowDate        CHECK (FeedShowDate    IN ('yes','no')),
  CONSTRAINT enumFeedNewWindow       CHECK (FeedNewWindow   IN ('yes','no')),
  CONSTRAINT pkFeed                  PRIMARY KEY (FeedID),
  CONSTRAINT fkFeed                  FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE INDEX idxFeed_Realm ON ethereal.Feed
(
  RealmName
);
CREATE TABLE ethereal.Gummy (
  GummyName            VARCHAR(20)   NOT NULL,
  GummyClass           VARCHAR(12)   NOT NULL DEFAULT 'general',
  RealmName            VARCHAR(30)   NOT NULL DEFAULT 'system',
  GummyIdent           VARCHAR(25),
  GummyPath            VARCHAR(200)  NOT NULL,
  GummyMacro           VARCHAR(10),
  CONSTRAINT pkGummy                 PRIMARY KEY (GummyName),
  CONSTRAINT fkGummy                 FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumGummyClass          CHECK (GummyClass IN ('admin','default','canon','contributor','general','inject','mod','super'))
) WITHOUT OIDS;
CREATE INDEX idxGummy_Class ON ethereal.Gummy
(
       GummyClass
);
CREATE INDEX idxGummy_Ident ON ethereal.Gummy
(
       GummyIdent
);
CREATE INDEX idxGummy_Macro ON ethereal.Gummy
(
       GummyMacro
);
CREATE INDEX idxGummy_Name ON ethereal.Gummy
(
       GummyName
);
CREATE INDEX idxGummy_Path ON ethereal.Gummy
(
       GummyPath
);
CREATE TABLE ethereal.RealmDesign (
  RealmName            VARCHAR(30)   NOT NULL,
  TagName              VARCHAR(20)   NOT NULL,
  DesignContent        TEXT,
  CONSTRAINT pkRealmDesign           PRIMARY KEY (RealmName, TagName),
  CONSTRAINT fkRealmDesign           FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.RealmLocale (
  RealmName            VARCHAR(30)   NOT NULL,
  RealmLocale          VARCHAR(50)   NOT NULL,
  CONSTRAINT pkRealmLocale           PRIMARY KEY (RealmName, RealmLocale),
  CONSTRAINT fkRealmLocale           FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Restriction (
  RealmName            VARCHAR(30)   NOT NULL DEFAULT 'system',
  RestrictionType      VARCHAR(8)    NOT NULL DEFAULT 'picture',
  RestrictionValue     VARCHAR(255)  NOT NULL,
  CONSTRAINT pkRestriction           PRIMARY KEY (RealmName, RestrictionType, RestrictionValue),
  CONSTRAINT fkRestriction           FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumRestrictionType     CHECK (RestrictionType IN ('picture','word'))
) WITHOUT OIDS;
CREATE TABLE ethereal.Statistics (
  RealmName            VARCHAR(30)   NOT NULL DEFAULT 'system',
  StatTimestamp        TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  StatHits             INT           NOT NULL DEFAULT '0',
  StatPosts            INT           NOT NULL DEFAULT '0',
  CONSTRAINT pkStatistics            PRIMARY KEY (RealmName, StatTimestamp),
  CONSTRAINT fkRealmLocale           FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.PuppeteerRestriction (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  RealmName            VARCHAR(30)   NOT NULL,
  RestrictionTimestamp TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  CONSTRAINT pkPuppeteerRestr             PRIMARY KEY (PuppeteerLogin, RealmName),
  CONSTRAINT fkPuppeteerRestr_Realm       FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkPuppeteerRestr_Puppeteer   FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.RealmSupervisor (
  RealmName            VARCHAR(30)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  RealmACL             SMALLINT      NOT NULL DEFAULT '16',
  CONSTRAINT pkRealmSupervisor           PRIMARY KEY (RealmName, PuppeteerLogin),
  CONSTRAINT fkRealmSupervisor_Realm     FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkRealmSupervisor_Puppeteer FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.Puppet (
  PuppetName           VARCHAR(30)   NOT NULL,
  PuppetPool           VARCHAR(30)   NOT NULL DEFAULT 'system',
  PuppeteerLogin       VARCHAR(10),
  PuppetShort          VARCHAR(30),
  RealmLocale          VARCHAR(25),
  PuppetActive         TIMESTAMP,
  RealmName            VARCHAR(30),
  PuppetAssociation    VARCHAR(10),
  PuppetDefault        VARCHAR(3)    NOT NULL DEFAULT 'no',
  PuppetBio            TEXT,
  PuppetTag            TEXT,
  PuppetTitle          TEXT,
  PuppetGummy          VARCHAR(200),
  PuppetLocale         VARCHAR(50),
  PuppetPic            VARCHAR(200),
  PuppetPicHeight      SMALLINT,
  PuppetPicWidth       SMALLINT,
  PuppetPicSize        SMALLINT,
  PuppetTextSize       SMALLINT      NOT NULL DEFAULT '1',
  PuppetTextColour     VARCHAR(25)   NOT NULL DEFAULT 'White',
  PuppetTextFace       VARCHAR(15)   NOT NULL DEFAULT 'Times New Roman',
  CONSTRAINT pkPuppet                PRIMARY KEY (PuppetName, PuppetPool),
  CONSTRAINT fkPuppetRealm           FOREIGN KEY (PuppetPool)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkPuppetPuppeteer       FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumPuppetDefault       CHECK (PuppetDefault IN ('yes','no'))
) WITHOUT OIDS;
CREATE INDEX fncPuppet ON ethereal.Puppet
(
  lower(PuppetName)
);
CREATE INDEX idxPuppet_PuppetName ON ethereal.Puppet
(
  PuppetName
);
CREATE INDEX idxPuppet_Active ON ethereal.Puppet
(
  PuppetActive
);
CREATE INDEX idxPuppet_Default ON ethereal.Puppet
(
  PuppetDefault
);
CREATE INDEX idxPuppet_Association ON ethereal.Puppet
(
  PuppetAssociation
);
CREATE UNIQUE INDEX idxPuppet_Short ON PSCHEMA.Puppet
(
  PuppetShort
) WHERE PuppetPool='system';
CREATE TABLE ethereal.Board (
  BoardIDNumber        INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqBoard'),
  RealmName            VARCHAR(30),
  BoardTopic           VARCHAR(25),
  PuppetName           VARCHAR(30),
  BoardSubject         VARCHAR(255),
  BoardTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  BoardUpdate          TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  BoardMessage         TEXT,
  BoardLevel           SMALLINT      NOT NULL DEFAULT '0',
  LevelZero            INT           NOT NULL DEFAULT '0',
  LevelOne             INT           NOT NULL DEFAULT '0',
  LevelTwo             INT           NOT NULL DEFAULT '0',
  LevelThree           INT           NOT NULL DEFAULT '0',
  LevelFour            INT           NOT NULL DEFAULT '0',
  LevelFive            INT           NOT NULL DEFAULT '0',
  CONSTRAINT pkBoard                 PRIMARY KEY (BoardIDNumber),
  CONSTRAINT fkBoard                 FOREIGN KEY (RealmName, BoardTopic)
    REFERENCES ethereal.BoardTopic (RealmName, BoardTopic)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE INDEX idxBoard_Topic ON ethereal.Board
(
  BoardTopic
);
CREATE INDEX idxBoard_Timestamp ON ethereal.Board
(
  BoardTimestamp
);
CREATE INDEX idxBoard_Update ON ethereal.Board
(
  BoardUpdate
);
CREATE INDEX idxBoard_Levels ON ethereal.Board
(
  BoardLevel,
  LevelZero,
  LevelOne,
  LevelTwo,
  LevelThree,
  LevelFour,
  LevelFive
);
CREATE TABLE ethereal.Mail (
  MailIDNumber         INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqMail'),
  MailFrom             VARCHAR(30),
  MailFromLogin        VARCHAR(10),
  MailFromDel          VARCHAR(3)    NOT NULL DEFAULT 'no',
  MailRcpt             VARCHAR(30),
  MailRcptLogin        VARCHAR(10)   NOT NULL,
  MailRcptRead         VARCHAR(3)    NOT NULL DEFAULT 'no',
  MailRcptDel          VARCHAR(3)    NOT NULL DEFAULT 'no',
  MailSubject          VARCHAR(250),
  MailTimestamp        TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  MailRead             TIMESTAMP,
  MailContents         TEXT,
  CONSTRAINT pkMail                  PRIMARY KEY (MailIDNumber),
  CONSTRAINT enumMailFromDel         CHECK (MailFromDel  IN ('yes','no')),
  CONSTRAINT enumMailRcptRead        CHECK (MailRcptRead IN ('yes','no')),
  CONSTRAINT enumMailRcptDel         CHECK (MailRcptDel  IN ('yes','no'))
) WITHOUT OIDS;
CREATE INDEX idxMail_Rcpt ON ethereal.Mail
(
       MailRcptLogin,
       MailRcptDel
);
CREATE INDEX idxMail_From ON ethereal.Mail
(
       MailFromLogin,
       MailFromDel
);
CREATE TABLE ethereal.MailVanity (
  MailIDNumber         INT           NOT NULL,
  VanityID             INT           NOT NULL,
  CONSTRAINT pkMailVanity             PRIMARY KEY (MailIDNumber, VanityID),
  CONSTRAINT fkMailVanity_Mail       FOREIGN KEY (MailIDNumber)
    REFERENCES ethereal.Mail (MailIDNumber)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkMailVanity_Vanity     FOREIGN KEY (VanityID)
    REFERENCES ethereal.Vanity (VanityID)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;
CREATE TABLE ethereal.PuppetIgnore (
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  PuppetName           VARCHAR(30)   NOT NULL,
  PuppetLogin          VARCHAR(10),
  PuppetIgnore         VARCHAR(6)    NOT NULL,
  CONSTRAINT pkPuppetIgnore          PRIMARY KEY (PuppeteerLogin, PuppetName),
  CONSTRAINT fkPuppetIgnorePuppeteer FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumPuppetIgnore        CHECK (PuppetIgnore IN ('behead','single','global','visual','optics'))
) WITHOUT OIDS;
CREATE INDEX idxIgnore_Ignore ON ethereal.PuppetIgnore
(
       PuppetIgnore
);
CREATE INDEX idxIgnore_LoginIgnore ON ethereal.PuppetIgnore
(
       Puppeteerlogin,
       PuppetIgnore
);
CREATE TABLE ethereal.Weblog (
  LogIDNumber          INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqWeblog'),
  PuppetName           VARCHAR(30)   NOT NULL,
  LogTitle             VARCHAR(100)  NOT NULL,
  LogTopic             VARCHAR(25)   NOT NULL,
  LogTimestamp         TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  LogPost              TEXT          NOT NULL,
  CONSTRAINT pkWeblog                PRIMARY KEY (LogIDNumber)
) WITHOUT OIDS;
CREATE INDEX idxWeblog_Title ON ethereal.Weblog
(
  LogTitle
);
CREATE INDEX idxWeblog_Timestamp ON ethereal.Weblog
(
  LogTimestamp
);
CREATE INDEX idxWeblog_Topic ON ethereal.Weblog
(
  LogTopic
);
CREATE TABLE ethereal.Post (
  PostIDNumber         INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqPost'),
  RealmName            VARCHAR(30)   NOT NULL,
  PuppetName           VARCHAR(30),
  PuppeteerLogin       VARCHAR(10),
  PostTo               VARCHAR(30),
  PostTimestamp        TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  PostClass            VARCHAR(10)   NOT NULL DEFAULT 'general',
  PostCmd              VARCHAR(10)   NOT NULL DEFAULT 'none',
  PostFullFormat       TEXT,
  PostImagelessFormat  TEXT,
  PostPartialFormat    TEXT,
  CONSTRAINT pkPost                  PRIMARY KEY (PostIDNumber),
  CONSTRAINT enumPostClass           CHECK (PostCLass IN ('banner','dice','duplicate','general','play','private','special','system')),
  CONSTRAINT enumPostCmd             CHECK (PostCmd IN ('general','none','play','stream'))
) WITHOUT OIDS;
CREATE INDEX idxPost_Class ON ethereal.Post
(
  PostClass
);
CREATE INDEX idxPost_Login ON ethereal.Post
(
  PuppeteerLogin
);
CREATE INDEX idxPost_Puppet ON ethereal.Post
(
  PuppetName
);
CREATE INDEX idxPost_Realm ON ethereal.Post
(
  RealmName
);
CREATE INDEX idxPost_Timestamp ON ethereal.Post
(
  PostTimestamp
);
CREATE INDEX idxPost_RealmClassTo ON ethereal.Post
(
  RealmName,
  PostClass,
  PostTo
);
CREATE INDEX idxPost_NumberRealm ON ethereal.Post
(
  PostIDNumber,
  RealmName
);
CREATE INDEX idxPost_TimestampPuppet ON ethereal.Post
(
  PostTimestamp,
  PuppetName
);
CREATE TABLE ethereal.Offline (
  OfflineIDNumber        INT           NOT NULL DEFAULT NEXTVAL('ethereal.seqOffline'),
  RealmName              VARCHAR(30)   NOT NULL,
  PuppetName             VARCHAR(30),
  PuppeteerLogin         VARCHAR(10),
  OfflineTimestamp       TIMESTAMP     NOT NULL DEFAULT LOCALTIMESTAMP,
  OfflineFullFormat      TEXT,
  OfflineImagelessFormat TEXT,
  OfflinePartialFormat   TEXT,
  CONSTRAINT pkOffline                 PRIMARY KEY (OfflineIDNumber)
) WITHOUT OIDS;
CREATE INDEX idxOffline_Login ON ethereal.Offline
(
  PuppeteerLogin
);
CREATE INDEX idxOffline_Puppet ON ethereal.Offline
(
  PuppetName
);
CREATE INDEX idxOffline_Realm ON ethereal.Offline
(
  RealmName
);
CREATE INDEX idxOffline_Timestamp ON ethereal.Offline
(
  OfflineTimestamp
);
CREATE INDEX idxOffline_NumberRealm ON ethereal.Offline
(
  OfflineIDNumber,
  RealmName
);
CREATE INDEX idxOffline_TimestampPuppet ON ethereal.Offline
(
  OfflineTimestamp,
  PuppetName
);
ALTER TABLE ethereal.Association           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Audit                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Board                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.BoardTopic            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Comment               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Contact               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Exif                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Faq                   OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Feed                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Font                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Fortune               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Gallery               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.GalleryAccess         OWNER TO erealms_ethereal;
ALTER TABLE ethereal.GalleryGenre          OWNER TO erealms_ethereal;
ALTER TABLE ethereal.GalleryNotify         OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Genre                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Gummy                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Layer                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Liason                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Mail                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.MailVanity            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Param                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Poll                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PollOption            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PollVote              OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Post                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Puppet                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PuppetIgnore          OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Puppeteer             OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PuppeteerContact      OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PuppeteerRegistration OWNER TO erealms_ethereal;
ALTER TABLE ethereal.PuppeteerRestriction  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Index                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Link                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Realm                 OWNER TO erealms_ethereal;
ALTER TABLE ethereal.RealmDesign           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.RealmLocale           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.RealmSupervisor       OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Restriction           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Revision              OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Rotate                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Statistics            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Tag                   OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Transaction           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Vanity                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.VanityVotes           OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Weblog                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Work                  OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqAudit              OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqBoard              OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqComment            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqFaq                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqFeed               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqFortune            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqGallery            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqLayer              OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqLink               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqMail               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqOffline            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqOption             OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqPoll               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqPost               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqVanity             OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqWeblog             OWNER TO erealms_ethereal;
ALTER TABLE ethereal.seqWork               OWNER TO erealms_ethereal;
CREATE OR REPLACE FUNCTION ethereal.getInterval(interval) RETURNS TIMESTAMP WITHOUT TIME ZONE AS'
  SELECT LOCALTIMESTAMP - $1
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getInterval_Hour(interval) RETURNS TIMESTAMP WITHOUT TIME ZONE AS'
  SELECT DATE_TRUNC(''hour'', LOCALTIMESTAMP - $1)
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getInterval_Day(interval) RETURNS TIMESTAMP WITHOUT TIME ZONE AS'
  SELECT DATE_TRUNC(''day'', LOCALTIMESTAMP - $1)
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getAge(TIMESTAMP) RETURNS INT AS'
    SELECT EXTRACT(YEAR FROM AGE($1))::INT
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getBirthDay(TIMESTAMP) RETURNS INT AS'
  SELECT EXTRACT(DAY FROM $1)::INT
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getBirthMonth(TIMESTAMP) RETURNS INT AS'
  SELECT EXTRACT(MONTH FROM $1)::INT
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getBirthYear(TIMESTAMP) RETURNS INT AS'
  SELECT EXTRACT(YEAR FROM $1)::INT
 ' LANGUAGE SQL IMMUTABLE STRICT;
CREATE OR REPLACE FUNCTION ethereal.getCurrent(TIME WITHOUT TIME ZONE) RETURNS INTEGER AS'
  DECLARE
    -- Alias
    varTimestamp ALIAS FOR $1;			-- Puppeteer Login
    -- Declarations
    varCurrent TIMESTAMP WITH TIME ZONE;
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is newer
    IF varTimestamp > (varCurrent - INTERVAL ''20 Minutes'') THEN
      -- Expired
      RETURN 1;
    ELSE
      -- Active
      RETURN 0;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getCurrent(TIMESTAMP WITH TIME ZONE) RETURNS INTEGER AS'
  DECLARE
    -- Alias
    varTimestamp ALIAS FOR $1;			-- Puppeteer Login
    -- Declarations
    varCurrent TIMESTAMP WITH TIME ZONE;
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is newer
    IF (varTimestamp > varCurrent - INTERVAL ''20 Minutes'') THEN
      -- Expired
      RETURN 1;
    ELSE
      -- Active
      RETURN 0;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDate(TIMESTAMP) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''DD-Mon-YYYY'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDate(TIMESTAMP WITH TIME ZONE) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''DD-Mon-YYYY'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDateRSS(TIMESTAMP) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''Dy, DD Mon YYYY HH24:MM:SS'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDateRSS(TIMESTAMP WITH TIME ZONE) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''Dy, DD Mon YYYY HH24:MM:SS TZ'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDateTime(TIMESTAMP) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''DD-Mon-YYYY, HH24:MI:SS'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getDateTime(TIMESTAMP WITH TIME ZONE) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''DD-Mon-YYYY, HH24:MI:SS'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getExpire(VARCHAR) RETURNS VARCHAR AS'
  DECLARE
    -- Alias
    varPuppeteer ALIAS FOR $1;			-- Puppeteer Login
    -- Declarations
    varSpan    TIMESTAMP WITH TIME ZONE;
    varCurrent TIMESTAMP WITH TIME ZONE;
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Pull expiry for homepage
    SELECT INTO varSpan PuppeteerHomeSpan
         FROM ethereal.Puppeteer
         WHERE LOWER(PuppeteerLogin)=LOWER(varPuppeteer);
    -- Which is greater
    IF varCurrent > varSpan then
      -- Expired
      RETURN ''yes'';
    ELSE
      -- Active
      RETURN ''no'';
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getFile(TIMESTAMP) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''YYYYMMDD_HHMM'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getFile(TIMESTAMP WITH TIME ZONE) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''YYYYMMDD_HHMM'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getNew(TIME WITHOUT TIME ZONE) RETURNS INTEGER AS'
  DECLARE
    -- Alias
    varTimestamp ALIAS FOR $1;			-- Puppeteer Login
    -- Declarations
    varCurrent TIMESTAMP WITH TIME ZONE;
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is newer
    IF varTimestamp > (varCurrent - INTERVAL ''7 days'') THEN
      -- Expired
      RETURN 1;
    ELSE
      -- Active
      RETURN 0;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getNew(TIMESTAMP WITH TIME ZONE) RETURNS INTEGER AS'
  DECLARE
    -- Alias
    varTimestamp ALIAS FOR $1;			-- Puppeteer Login
    -- Declarations
    varCurrent TIMESTAMP WITH TIME ZONE;
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is newer
    IF (varTimestamp > varCurrent - INTERVAL ''7 days'') THEN
      -- Expired
      RETURN 1;
    ELSE
      -- Active
      RETURN 0;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getSort(INTEGER) RETURNS INTEGER AS'
  SELECT (COUNT(*) - 1)::INT FROM ethereal.Work WHERE GalleryID = $1::INT
 ' LANGUAGE SQL;
CREATE OR REPLACE FUNCTION ethereal.getTime(TIMESTAMP) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''HH24:MI'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getTime(TIMESTAMP WITH TIME ZONE) RETURNS VARCHAR AS'
  DECLARE
    varTimestamp ALIAS FOR $1;				-- Timestamp
  BEGIN
    -- Quick and simple
    RETURN TO_CHAR(varTimestamp, ''HH24:MI'');
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getTimestamp(TIMESTAMP WITH TIME ZONE) RETURNS TIMESTAMP WITH TIME ZONE AS'
  DECLARE
    varPassed  ALIAS FOR $1;				-- Passed timestamp
    varCurrent TIMESTAMP WITH TIME ZONE;		-- Current timestamp
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is biggest
    IF varCurrent < varPassed THEN
       -- Passed value will do
       RETURN varPassed;
    ELSE
       -- Use current timestamp instead
       RETURN varCurrent;
    END IF;
    
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getTimestamp(TIMESTAMP) RETURNS TIMESTAMP AS'
  DECLARE
    varPassed  ALIAS FOR $1;				-- Passed timestamp
    varCurrent TIMESTAMP;		                -- Current timestamp
  BEGIN
    -- Pull current time
    varCurrent := ''now'';
    -- Which is biggest
    IF varCurrent < varPassed THEN
       -- Passed value will do
       RETURN varPassed;
    ELSE
       -- Use current timestamp instead
       RETURN varCurrent;
    END IF;
    
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getPuppet(VARCHAR, VARCHAR) RETURNS VARCHAR AS'
  DECLARE
    varPuppeteer ALIAS FOR $1;				-- Puppeteer handle
    varPuppet    ALIAS FOR $2;                          -- Puppet name
    varDefault   VARCHAR(30);				-- Puppet default
  BEGIN
    -- Check for a proper default
    SELECT INTO varDefault PuppetName
      FROM ethereal.Puppet
      WHERE PuppetDefault=''yes''
        AND PuppeteerLogin=varPuppeteer
        AND PuppetName <> varPuppet;
    -- No proper default available
    IF varDefault IS NULL THEN
       -- First in the list
       SELECT INTO varDefault PuppetName
         FROM ethereal.Puppet
         WHERE PuppeteerLogin=varPuppeteer
           AND PuppetName <> varPuppet
           AND PuppetPool=''system''
         ORDER BY PuppetName LIMIT 1;
    END IF;
    -- Return default handle
    RETURN varDefault;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getPuppet(VARCHAR) RETURNS VARCHAR AS'
  DECLARE
    varPuppeteer ALIAS FOR $1;				-- Puppeteer handle
    varDefault   VARCHAR(30);				-- Puppet default
  BEGIN
    -- Check for a proper default
    SELECT INTO varDefault PuppetName
      FROM ethereal.Puppet
      WHERE PuppetDefault=''yes''
        AND PuppeteerLogin=varPuppeteer;
    -- No proper default available
    IF varDefault IS NULL THEN
       -- First in the list
       SELECT INTO varDefault PuppetName
         FROM ethereal.Puppet
         WHERE PuppeteerLogin=varPuppeteer
           AND PuppetPool=''system''
         ORDER BY PuppetName LIMIT 1;
    END IF;
    -- Return default handle
    RETURN varDefault;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.getWarning(VARCHAR, VARCHAR) RETURNS VARCHAR AS'
  DECLARE
    varRealm     ALIAS FOR $1;				-- Puppeteer Login
    varPuppeteer ALIAS FOR $2;				-- Realm Name
    varOne       TIMESTAMP;                             -- Day one
    VarTwo       TIMESTAMP;                             -- Day two
    VarThree     TIMESTAMP;                             -- Day three
    varOccur     RECORD;				-- Occurences seen
    varWeight    NUMERIC(6,2);                          -- Weight calculated
  BEGIN
    -- Pull times
    SELECT INTO varOne   DATE_TRUNC(''day'', CURRENT_TIMESTAMP);
    SELECT INTO varTwo   DATE_TRUNC(''day'', CURRENT_TIMESTAMP - INTERVAL ''1 days'');
    SELECT INTO varThree DATE_TRUNC(''day'', CURRENT_TIMESTAMP - INTERVAL ''2 days'');
    -- Initial assignment
    varWeight := 0;
     -- Loop through results
     FOR VarOccur IN SELECT WarnTimestamp AS When, COUNT(*) AS Times FROM ethereal.Warning WHERE RealmName=varRealm AND PuppeteerLogin=varPuppeteer GROUP BY WarnTimestamp LOOP
       -- Calculate Weights
       -- Today at full weight
       IF varOccur.When = varOne THEN
          varWeight := varWeight + varOccur.Times;
       -- Yesterday at half weight
       ELSIF varOccur.When = varTwo THEN
          varWeight := varWeight + (varOccur.Times * 0.50);
       -- Day before yesterday at one fourth weight
       ELSIF varOccur.When = varThree THEN
          varWeight := varWeight + (varOccur.Times * 0.25);
       END IF;
    END LOOP;
    -- Speed things up
    varWeight := varWeight * 5;
    -- At most 100%
    IF varWeight > 100 THEN
       -- Set back to 100
       varWeight := 100;
    END IF;
    -- What to return
    IF varWeight = 0 THEN
      -- Empty string
      RETURN '''';
    ELSE
      -- Return warning level
      RETURN varWeight::VARCHAR || ''%'';
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.trigPuppet () RETURNS TRIGGER AS '
  DECLARE
    varPuppet VARCHAR(30);				-- Puppet Default
  BEGIN
    --
    -- REMOVE
    IF TG_OP = ''DELETE'' THEN
      -- Removing root handles
      IF OLD.PuppetPool = ''system'' THEN
         -- Cleanup sattelite tables
         -- Ignore table
         EXECUTE ''DELETE FROM ethereal.PuppetIgnore ''
            || '' WHERE PuppetName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
         -- Determine default handle
         SELECT INTO varPuppet * FROM ethereal.getPuppet(OLD.PuppeteerLogin, OLD.PuppetName);
         -- Update tables
         -- Something to replace with
         IF varPuppet IS NOT NULL THEN
            -- Board
            EXECUTE ''UPDATE ethereal.Board SET PuppetName = ''
               || QUOTE_LITERAL(varPuppet)
               || '' WHERE PuppetName = ''
               || QuOTE_LITERAL(OLD.PuppetName);
            -- Comment
            EXECUTE ''UPDATE ethereal.Comment SET PuppetName = ''
               || QUOTE_LITERAL(varPuppet)
               || '' WHERE PuppetName = ''
               || QuOTE_LITERAL(OLD.PuppetName);
            -- Gallery
            EXECUTE ''UPDATE ethereal.Gallery SET GalleryPenName = ''
               || QUOTE_LITERAL(varPuppet)
               || '' WHERE GalleryPenName = ''
               || QuOTE_LITERAL(OLD.PuppetName);
            -- Gallery Access
            EXECUTE ''UPDATE ethereal.GalleryAccess SET PuppetName = ''
               || QUOTE_LITERAL(varPuppet)
               || '' WHERE Puppetname = ''
               || QuOTE_LITERAL(OLD.PuppetName);
            -- Weblog
            EXECUTE ''UPDATE ethereal.Weblog SET PuppetName = ''
               || QUOTE_LITERAL(varPuppet)
               || '' WHERE PuppetName = ''
               || QuOTE_LITERAL(OLD.PuppetName);
         -- Time to remove
         ELSE
            -- Board
            EXECUTE ''DELETE FROM ethereal.Board ''
               || '' WHERE PuppetName = ''
               || QUOTE_LITERAL(OLD.PuppetName);
            -- Comment
            EXECUTE ''DELETE FROM ethereal.Comment ''
               || '' WHERE PuppetName = ''
               || QUOTE_LITERAL(OLD.PuppetName);
            -- Gallery
            EXECUTE ''DELETE FROM ethereal.Gallery ''
               || '' WHERE GalleryPenName = ''
               || QUOTE_LITERAL(OLD.PuppetName);
            -- Gallery
            EXECUTE ''DELETE FROM ethereal.GalleryAccess ''
               || '' WHERE PuppetName = ''
               || QUOTE_LITERAL(OLD.PuppetName);
            -- Weblog
            EXECUTE ''DELETE FROM ethereal.Weblog ''
               || '' WHERE PuppetName = ''
               || QUOTE_LITERAL(OLD.PuppetName);
         END IF;
      END IF;
      -- Return row unmodified
      RETURN OLD;
    --
    -- UPDATE
    ELSIF TG_OP = ''UPDATE'' THEN
      -- Handle rename
      IF OLD.PuppetName <> NEW.PuppetName AND NEW.PuppetPool = ''system'' THEN
         -- Board
         EXECUTE ''UPDATE ethereal.Board SET PuppetName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE PuppetName = ''
            || QuOTE_LITERAL(OLD.PuppetName);
         -- Comment
         EXECUTE ''UPDATE ethereal.Comment SET PuppetName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE PuppetName = ''
            || QuOTE_LITERAL(OLD.PuppetName);
         -- Gallery
         EXECUTE ''UPDATE ethereal.Gallery SET GalleryPenName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE GalleryPenName = ''
            || QuOTE_LITERAL(OLD.PuppetName);
         -- Gallery Access
         EXECUTE ''UPDATE ethereal.GalleryAccess SET PuppetName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE Puppetname = ''
            || QuOTE_LITERAL(OLD.PuppetName);
         -- Puppet Ignore
         EXECUTE ''UPDATE ethereal.PuppetIgnore SET PuppetName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE PuppetName = ''
            || QuOTE_LITERAL(OLD.PuppetName);
         -- Weblog
         EXECUTE ''UPDATE ethereal.Weblog SET PuppetName = ''
            || QUOTE_LITERAL(NEW.PuppetName)
            || '' WHERE PuppetName = ''
            || QuOTE_LITERAL(OLD.PuppetName);
      -- Banned handles
      ELSIF NEW.PuppetPool = ''banned'' AND OLD.PuppetPool <> ''banned'' THEN
         -- Board
         EXECUTE ''DELETE FROM ethereal.Board ''
            || '' WHERE PuppetName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
         -- Comment
         EXECUTE ''DELETE FROM ethereal.Comment ''
            || '' WHERE PuppetName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
         -- Gallery
         EXECUTE ''DELETE FROM ethereal.Gallery ''
            || '' WHERE GalleryPenName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
         -- Gallery Access
         EXECUTE ''DELETE FROM ethereal.GalleryAccess ''
            || '' WHERE PuppetName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
         -- Weblog
         EXECUTE ''DELETE FROM ethereal.Weblog ''
            || '' WHERE PuppetName = ''
            || QUOTE_LITERAL(OLD.PuppetName);
      END IF;
      -- Return row unmodified
      RETURN NEW;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.trigPuppeteer () RETURNS TRIGGER AS '
  BEGIN
    --
    -- REMOVE
    IF TG_OP = ''DELETE'' THEN
      -- This is a root handle
      IF OLD.PuppeteerAlias ISNULL THEN
         -- Remove associated handles
         EXECUTE ''DELETE FROM ethereal.Puppeteer WHERE PuppeteerAlias = ''
            || QUOTE_LITERAL(OLD.PuppeteerLogin);
      END IF;
      -- Return row unmodified
      RETURN OLD;
    --
    -- UPDATE
    ELSIF TG_OP = ''UPDATE'' THEN
      -- This user is banned
      IF OLD.PuppeteerBan = ''no'' AND NEW.PuppeteerBan = ''yes'' THEN
         -- Remove canon handles
         EXECUTE ''DELETE FROM ethereal.Puppet WHERE PuppeteerLogin = ''
            || QUOTE_LITERAL(NEW.PuppeteerLogin)
            || '' AND PuppetPool NOT IN (''''system'''', ''''banned'''')'';
         -- Remove duplicate handles
         EXECUTE ''DELETE FROM ethereal.Puppet ''
            || '' WHERE PuppeteerLogin = ''
            || QUOTE_LITERAL(NEW.PuppeteerLogin)
            || '' AND PuppetName IN (''
            || '' SELECT PuppetName FROM ethereal.Puppet WHERE PuppetPool = ''
            || QUOTE_LITERAL(''banned'')
            || '')'';
         -- Transfer remaining handles
         EXECUTE ''UPDATE ethereal.Puppet SET PuppetPool = ''
            || QUOTE_LITERAL(''banned'')
            || '' WHERE PuppeteerLogin = ''
            || QuOTE_LITERAL(NEW.PuppeteerLogin);
      -- Someone has opted to rename
      ELSIF OLD.PuppeteerLogin <> NEW.PuppeteerLogin THEN
         -- Transfer remaining handles
         EXECUTE ''UPDATE ethereal.Puppeteer SET PuppeteerAlias = ''
            || QUOTE_LITERAL(NEW.PuppeteerLogin)
            || '' WHERE PuppeteerAlias = ''
            || QuOTE_LITERAL(OLD.PuppeteerLogin);
      END IF;
      -- Return row unmodified
      RETURN NEW;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.trigRealm () RETURNS TRIGGER AS '
  DECLARE
    varRealm VARCHAR(30);				-- Realm existence
  BEGIN
    --
    -- REMOVE
    IF TG_OP = ''DELETE'' THEN
       -- This is a root realm
       IF OLD.RealmAlias IS NULL THEN
         -- Transfer remaining handles
         EXECUTE ''DELETE FROM ethereal.Realm WHERE RealmAlias = ''
            || QUOTE_LITERAL(OLD.RealmName);
       END IF;
      -- Return row unmodified
      RETURN OLD;
    --
    -- INSERT
    ELSIF TG_OP = ''INSERT'' THEN
       -- This is a child realm
       IF NEW.RealmAlias IS NOT NULL THEN
          -- Verification
          SELECT INTO varRealm RealmName FROM ethereal.Realm WHERE RealmName=NEW.RealmAlias;
          -- No match
          IF varRealm IS NULL THEN
             -- Raise a notification
             RAISE NOTICE ''The Realm % does not exist, and cannot be used in an alias.'', NEW.RealmAlias;
             -- Cancel operation
             RETURN NULL;
          END IF;
       END IF;
       -- Just pass it along
       RETURN NEW;
    --
    -- UPDATE
    ELSIF TG_OP = ''UPDATE'' THEN
      -- Someone has opted to rename
      IF OLD.RealmName <> NEW.RealmName THEN
         -- Transfer remaining handles
         EXECUTE ''UPDATE ethereal.Realm SET RealmAlias = ''
            || QUOTE_LITERAL(NEW.RealmName)
            || '' WHERE RealmAlias = ''
            || QuOTE_LITERAL(OLD.RealmName);
      END IF;
      -- Return row unmodified
      RETURN NEW;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE OR REPLACE FUNCTION ethereal.trigWork () RETURNS TRIGGER AS '
  BEGIN
    --
    -- REMOVE
    IF TG_OP = ''DELETE'' THEN
       -- Update Gallery
       EXECUTE ''UPDATE ethereal.Gallery''
            || '' SET GalleryHighlight=NULL,''
            || ''     GalleryThumbnail=NULL''
            || '' WHERE GalleryID = '' || QUOTE_LITERAL(OLD.GalleryID);
      -- Return row unmodified
      RETURN OLD;
    --
    -- UPDATE
    ELSIF TG_OP = ''UPDATE''  THEN
       -- This should be for image works only
       IF NEW.WorkImage IS NOT NULL THEN
         -- This is a child realm
         IF NEW.WorkName <> OLD.WorkName OR NEW.WorkImageThumbnail <> OLD.WorkImageThumbnail THEN
             -- Make sure nothing is highlighted
             IF OLD.WorkLayer IS NOT NULL AND NEW.WorkLayer IS NOT NULL THEN
                -- Update Layers
                EXECUTE ''UPDATE ethereal.Layer''
                     || '' SET LayerHighlight='' || QUOTE_LITERAL(NEW.WorkName) || '',''
                     || ''     LayerThumbnail='' || QUOTE_LITERAL(NEW.WorkImageThumbnail)
                     || '' WHERE LayerHighlight = '' || QUOTE_LITERAL(OLD.WorkName)
                     || ''   AND LayerThumbnail  = '' || QUOTE_LITERAL(OLD.WorkImageThumbnail)
                     || ''   AND LayerID = '' || QUOTE_LITERAL(NEW.WorkLayer)
                     || ''   AND GalleryID = '' || QUOTE_LITERAL(NEW.GalleryID);
             END IF;
             -- Update Gallery
             EXECUTE ''UPDATE ethereal.Gallery''
                  || '' SET GalleryHighlight = '' || QUOTE_LITERAL(NEW.WorkName) || '',''
                  || ''     GalleryThumbnail = '' || QUOTE_LITERAL(NEW.WorkImageThumbnail)
                  || '' WHERE GalleryHighlight = '' || QUOTE_LITERAL(OLD.WorkName)
                  || ''   AND GalleryThumbnail  = '' || QUOTE_LITERAL(OLD.WorkImageThumbnail)
                  || ''   AND GalleryID = '' || QUOTE_LITERAL(NEW.GalleryID);
   
         END IF;
       END IF;
       -- Just pass it along
       RETURN NEW;
    END IF;
  END;
 ' LANGUAGE 'plpgsql';
CREATE TRIGGER trig_on_Puppet
  BEFORE UPDATE OR DELETE
  ON ethereal.Puppet
  FOR EACH ROW EXECUTE PROCEDURE ethereal.trigPuppet();
CREATE TRIGGER trig_on_Puppeteer
  BEFORE UPDATE OR DELETE
  ON ethereal.Puppeteer
  FOR EACH ROW EXECUTE PROCEDURE ethereal.trigPuppeteer();
CREATE TRIGGER trig_on_Realm
  BEFORE UPDATE OR DELETE OR INSERT
  ON ethereal.Realm
  FOR EACH ROW EXECUTE PROCEDURE ethereal.trigRealm();
CREATE TRIGGER trig_on_Work
  BEFORE UPDATE OR DELETE
  ON ethereal.Work
  FOR EACH ROW EXECUTE PROCEDURE ethereal.trigWork();
ALTER TABLE ethereal.Realm                   OWNER TO erealms_ethereal;
CREATE VIEW ethereal.Exhibition AS
   SELECT
     gal.GalleryID          AS GalleryID,
     gal.PuppeteerLogin     AS PuppeteerLogin,
     gal.GalleryPenName     AS GalleryPenName,
     gal.GalleryName        AS GalleryName,
     gal.GalleryRating      AS GalleryRating,
     gal.GalleryDescription AS GalleryDescription,
     gal.GalleryHighlight   AS GalleryHighlight,
     gal.GalleryThumbnail   AS GalleryThumbnail,
     gal.GalleryType        AS GalleryType,
     gal.GallerySub         AS GallerySub,
     gre.GenreName          AS GalleryGenre,
     gal.GalleryCreated     AS GalleryCreated,
     gal.GalleryUpdated     AS GalleryUpdated,
     (COUNT(wrk.WorkID)-2)  AS WorkCount
   FROM ethereal.Gallery gal, ethereal.Work wrk, ethereal.GalleryGenre gre
   WHERE gal.GalleryID = wrk.GalleryID
     AND gal.GalleryID = gre.GalleryID
     AND gal.GalleryPrivacy = 'no'
   GROUP BY gal.GalleryID,
            gal.PuppeteerLogin,
            gal.GalleryPenName,
            gal.GalleryName,
            gal.GalleryRating,
            gal.GalleryDescription,
            gal.GalleryHighlight,
            gal.GalleryThumbnail,
            gal.GalleryType,
            gal.GallerySub,
            gal.GalleryCreated,
            gal.GalleryUpdated,
            gre.GenreName
   HAVING COUNT(wrk.WorkID) > 2::INT;
CREATE VIEW ethereal.Network AS
   SELECT
     p.PuppeteerLogin       AS PuppeteerLogin,
     p.PuppeteerTimestamp   AS PuppeteerTimestamp,
     h.PuppetName           AS PuppetName,
     h.PuppetShort          AS PuppetShort,
     s.LocateCity           AS LocateCity,
     s.LocateRegion         AS LocateRegion,
     s.LocateCountry        AS LocateCountry,
     s.LocateLat            AS LocateLat,
     s.LocateLong           AS LocateLong,
     s.PhysicalGender       AS PhysicalGender,
     s.PhysicalBirthDate    AS PhysicalBirthDate,
     s.PhysicalHeight       AS PhysicalHeight,
     s.PhysicalBodyType     AS PhysicalBodyType,
     s.PhysicalEyeColour    AS PhysicalEyeColour,
     s.PhysicalHairColour   AS PhysicalHairColour,
     s.PhysicalEthnicity    AS PhysicalEthnicity,
     s.IntroCatchPhrase     AS IntroCatchPhrase,
     s.IntroDescription     AS IntroDescription,
     s.IntroFirstDate       AS IntroFirstDate,
     s.SocialLooking        AS SocialLooking,
     s.SocialSeeking        AS SocialSeeking,
     s.SocialAgeMin         AS SocialAgeMin,
     s.SocialAgeMax         AS SocialAgeMax,
     s.SocialMarital        AS SocialMarital,
     s.SocialChildrenHave   AS SocialChildrenHave,
     s.SocialChildrenWant   AS SocialChildrenWant,
     s.SocialInterests      AS SocialInterests,
     s.SocialReligion       AS SocialReligion,
     s.SocialProfession     AS SocialProfession,
     s.ViceSmoke            AS ViceSmoke,
     s.ViceDrink            AS ViceDrink,
     ethereal.getBirthDay(s.PhysicalBirthDate)   AS PhysicalBirthDay,
     ethereal.getBirthMonth(s.PhysicalBirthDate) AS PhysicalBirthMonth,
     ethereal.getBirthYear(s.PhysicalBirthDate)  AS PhysicalBirthYear,
     ethereal.getAge(s.PhysicalBirthDate)        AS PhysicalAge
  FROM ethereal.Social s, ethereal.Puppeteer p, ethereal.Puppet h
  WHERE (h.PuppetDefault  = 'yes'
     AND h.PuppetPool     = 'system'
     AND s.PuppeteerLogin = h.PuppeteerLogin)
    AND s.PuppeteerLogin = P.PuppeteerLogin;
CREATE VIEW ethereal.Portal AS
   SELECT
     Po.PuppetName AS PuppetName,
     Po.RealmName  AS RealmName
   FROM ethereal.Post Po, ethereal.Realm Re
   WHERE Po.RealmName = Re.RealmName
     AND (Re.RealmPublic='yes'
      OR Re.RealmVerified='yes')
    AND Po.PostTimestamp > ethereal.GetInterval('10 Minutes')
    AND Po.PuppetName IS NOT NULL
  GROUP BY Po.RealmName, Po.PuppetName;
CREATE VIEW ethereal.Warning AS
   SELECT
      AuditRealm            AS RealmName,
      AuditAdditional       AS PuppeteerLogin,
      DATE_TRUNC('day', AuditTimestamp) AS WarnTimestamp
   FROM ethereal.Audit
   WHERE AuditCode=2007::INT
     AND AuditTimestamp > (LOCALTIMESTAMP - INTERVAL '3 days');
CREATE VIEW ethereal.Who AS
 SELECT
    Po.PuppetName     AS PuppetName,
    Po.PuppeteerLogin AS PuppeteerLogin,
    Po.RealmName      AS RealmName,
    Re.RealmPublic    AS RealmPublic,
    Re.RealmVerified  AS RealmVerified
  FROM ethereal.Post Po, ethereal.Puppet Ch, ethereal.Realm Re
  WHERE Po.PuppeteerLogin = Ch.PuppeteerLogin
    AND Po.RealmName = Re.RealmName
    AND Po.PostTimestamp > ethereal.getInterval('10 minutes')
    AND Po.PuppetName IS NOT NULL
  GROUP BY Po.PuppeteerLogin, Po.PuppetName, Po.RealmName, Re.RealmPublic, Re.RealmVerified;
ALTER TABLE ethereal.Exhibition            OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Portal                OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Warning               OWNER TO erealms_ethereal;
ALTER TABLE ethereal.Who                   OWNER TO erealms_ethereal;
INSERT INTO ethereal.Puppeteer (PuppeteerLogin,PuppeteerPassword,PuppeteerName,PuppeteerEmail,PuppeteerAdminPrivs,PuppeteerSuperPrivs) VALUES('admin','2d/SWwLlVvQEE','Default Administrator','postmaster@ethereal-realms.org','yes','yes');
INSERT INTO ethereal.Puppeteer (PuppeteerLogin,PuppeteerPassword,PuppeteerName,PuppeteerEmail) VALUES('system','*************','Default User','postmaster@ethereal-realms.org');
INSERT INTO ethereal.Realm (RealmName, RealmPassword) VALUES ('system','*************');
INSERT INTO ethereal.Realm (RealmName, RealmPassword) VALUES ('banned','*************');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('OfflineInfo','system','  <!- Ethereal Realms Online Realms Splash Page -->\r\n  <!- Outer border -->\r\n  <div class=\"ermedium\" style=\"width: 325px; margin: 0px; float: right;\">\r\n\r\n   <!- Title field -->\r\n   <div class=\"rowdark\">Quick Notes!</div>\r\n\r\n   <!- Wrapper Table -->\r\n   <div class=\"erlight\" style=\"width: auto; text-align: justify; padding: 3px;\">\r\n    You are now entering a realm in \'Offline Mode.\'<br><br>   \r\n\r\n    Offline mode is a different take on realms, addressing the\r\n    concerns of those who cannot interact quickly or often play\r\n    within the realm but still wish to carry on with threads and\r\n    extended plays with other players.   The use of modes permits\r\n    a coexistence of both methods of access providing you with a\r\n    consistent atmosphere in which to play with.<br><br>\r\n\r\n    The biggest difference in Offline mode is the simplified\r\n    interface.   There are no frames, no streaming of posts and\r\n    you certainly have no need for constant refreshing; posts\r\n    simply will not arrive at that fast a pace.  Instead you, as\r\n    the user, will be able to browse posts which are days, weeks\r\n    and even months old through the use of pages, permitting you\r\n    to move back and forth in time to keep tabs on the longest\r\n    running plays.<br><br>\r\n\r\n    Posting is as simple as ever.    The Comm panel is simpler\r\n    as there is no need for private messaging when within the\r\n    confines of an offline realm.    However posting a new message\r\n    will work as it always has and are always located at the\r\n    bottom of every page viewed.<br><br>\r\n\r\n    Additional points of note are as follows:<br><br>\r\n\r\n    <ul>\r\n     <li>\r\n      Normal realms expire posts at a rapid rate in order to keep\r\n      information and speed to an acceptable level.   Offline realms\r\n      are the exact opposite and will instead keep posts for weeks\r\n      and months at a time, however they will in time also expire.\r\n     </li>\r\n\r\n     <li>\r\n      Gummies provide an additional capability and that is to\r\n      watch the user as they make posts.  When they post you will be\r\n      notified in order to keep track of a thread and respond\r\n      accordingly.\r\n     </li>\r\n\r\n     <li>\r\n      When you post in an offline realm, a copy of that post will\r\n      be made to the online half of the realm.   This permits users\r\n      actively playing to see activity working below.    Fortunately\r\n      the opposit is not true cutting out the chance for post\r\n      floods.\r\n     </li>\r\n    </ul>\r\n\r\n    Offline realms exist for every realm created on the site.    If\r\n    you have any additional questions on Offline Realms feel free\r\n    to contact us directly.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('OfflinePage','system','<!- Navigational bar -->\r\n<br>\r\n <div align=\"center\">MNAVBAR</div>\r\n<br>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('OfflinePanel','system','<!- Offline Panel -->\r\n<div align=\"center\">\r\n <!- Top wrapper table -->\r\n <table width=\"550\" border=\"0\" align=\"center\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#CCCCCC\">\r\n  <tr> \r\n   <td align=\"center\" bgcolor=\"#999999\">\r\n\r\n    <!- Inner wrapper table -->\r\n    <table width=\"100%\" border=\"0\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#FFFFFF\">\r\n     <tr> \r\n      <!- Character Select -->\r\n      <td width=\"30%\" bgcolor=\"#666666\">WCHARSLCT</td>\r\n\r\n      <!- Top bar links -->\r\n      <td width=\"70%\" align=\"center\" bgcolor=\"#666666\">\r\n       <font face=\"Verdana\">\r\n        <a class=\"NAV\" HREF=\"/erealms/config/puppet.plGENPARAM\" TARGET=\"CONFIG\" TABINDEX=\"4\" GENJSCODE>Config</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/portal.plBASEPARAM\" TARGET=\"_BLANK\" ACCESSKEY=\"h\">Portal</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/zoom.plGENPARAM\" TARGET=\"ZOOMER\" ACCESSKEY=\"z\" GENJSCODE>Zoom</a>\r\n       </font>\r\n      </td>\r\n     </tr>\r\n\r\n     <tr valign=\"middle\"> \r\n      <td colspan=\"2\" bgcolor=\"#666666\">\r\n\r\n       <!- Posting table -->\r\n       <table width=100% border=\"0\" align=\"center\" cellpadding=\"0\" cellspacing=\"0\">\r\n        <tr> \r\n         <!- Custom Text area -->\r\n         <td align=\"left\">\r\n          <textarea name=\"POST\" rows=\"4\" cols=\"75\" wrap=\"SOFT\" accesskey=\"t\" tabindex=\"2\"></textarea>\r\n         </td>\r\n\r\n         <!- Posting button -->\r\n         <td valign=\"middle\">WPOSTSEND</td>\r\n        </tr>\r\n       </table>\r\n      </td>\r\n     </tr>      \r\n\r\n     <tr> \r\n      <!- Font Selection and Advanced Scrolling -->\r\n      <td colspan=\"2\" bgcolor=\"#666666\">\r\n       WFONTCOLR WFONTFACE WFONTSIZE\r\n      </td>\r\n     </tr>\r\n\r\n     <tr> \r\n      <!- Lower bar links -->\r\n      <td colspan=\"2\"  align=\"center\"  bgcolor=\"#666666\">\r\n       <font face=\"Verdana\">\r\n        <a class=\"NAV\" HREF=\"/erealms/post/who.plGENPARAM\" TARGET=\"WHOSON\" TABINDEX=\"7\" GENJSCODE>Who\'s On?</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/config/ignore.plGENPARAM\" TARGET=\"REALMS\" TABINDEX=\"9\" GENJSCODE>Ignore</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/colours.plGENPARAM\" TARGET=\"REALMS\" ACCESSKEY=\"g\" GENJSCODE>Colour Guide</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/board.plGENPARAM\" TARGET=\"REALMS\" TABINDEX=\"8\" GENJSCODE>Forums</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/mail.plBASEPARAM\" TARGET=\"REALMS\" TABINDEX=\"10\" GENJSCODE>E-mail</a>\r\n       </font>\r\n      </td>\r\n     </tr>\r\n    </table>\r\n   </td>\r\n  </tr>\r\n </table>\r\n</div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('OfflineWarning','system','  <!- Spacer -->\r\n  <br><br>\r\n\r\n  <!- Warning of being offline -->\r\n  <div style=\"text-align: justify;\">\r\n   <b>Warning this is an offline realm.   Posts within are\r\n   stored for an extended period of time as to allow for\r\n   extended roleplays.  Please be aware of this when you post\r\n   in this mode.</b>\r\n  </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmBanner','system','   <!- Realm Banner for Fresh Entrances -->\r\n  <div style=\"margin: 10px; text-align: center;\">\r\n   <img src=\"/img/banner/banner1.gif\" width=468 height=\"60\"><br>\r\n   <cite>\"FRTNFORTUNES\"<cite>\r\n  </div>');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmDice','system','<html>\r\n <head>\r\n  <title>Ethereal Realms - Die Roller</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Die Roller</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n  <!- Start Form -->\r\n  WFORMSTRT \r\n\r\n\r\n  <!- Die Rolling Capabilities -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Colour spacer -->\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"5\">Die Roller</td>\r\n    </tr>\r\n\r\n    <!- Player Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"5\">Player Options</td>\r\n    </tr>\r\n\r\n    <!- Widgits -->\r\n    <tr>\r\n\r\n     <!- Character selections -->\r\n     <td class=\"fancy_descr\">Character</td>\r\n     <td class=\"fancy_blank\">WCHARSLCT</td>\r\n\r\n     <!- Space things out -->\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n\r\n     <!- Send out privately -->\r\n     <td class=\"fancy_descr\">Private</td>\r\n     <td class=\"fancy_blank\">WDICEPVTE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Dice Preferences -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"5\">Dice Preferences</td>\r\n    </tr>\r\n\r\n    <!- Widgits -->\r\n    <tr>\r\n     <!- Number of sides -->\r\n     <td class=\"fancy_descr\">Side</td>\r\n     <td class=\"fancy_blank\">WDICETYPE</td>\r\n\r\n     <!- Space things out -->\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n\r\n     <!- If one should drop the lowest scores -->\r\n     <td class=\"fancy_descr\">Lowest Drop</td>\r\n     <td class=\"fancy_blank\">WDICELOWR</td>\r\n\r\n    </tr>\r\n    <tr>\r\n\r\n     <!- Number of Rolls to Make -->\r\n     <td class=\"fancy_descr\">Rolls</td>\r\n     <td class=\"fancy_blank\">WDICEFREQ</td>\r\n\r\n     <!- Space things out -->\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n\r\n     <!- Drop highest scores -->\r\n     <td class=\"fancy_descr\">Highest Drop </td>\r\n     <td class=\"fancy_blank\">WDICEHIGH</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Roll Modifiers -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"5\">Roll Modifiers</td>\r\n    </tr>\r\n\r\n    <!- Widgits -->\r\n    <tr>\r\n\r\n     <!- Difficulty -->\r\n     <td class=\"fancy_descr\">Difficulty</td>\r\n     <td class=\"fancy_blank\">WDICEDIFF</td>\r\n\r\n     <!- Space things out -->\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n\r\n     <!- Send out privately -->\r\n     <td class=\"fancy_descr\">Damage</td>\r\n     <td class=\"fancy_blank\">WDICEDAMG WDICEINDV</td>\r\n\r\n    </tr>\r\n    <tr>\r\n\r\n     <!- Botches -->\r\n     <td class=\"fancy_descr\">Botch</td>\r\n     <td class=\"fancy_blank\">WDICEBTCH</td>\r\n\r\n     <!- Space things out -->\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n\r\n     <!- Lower Then for Botches -->\r\n     <td class=\"fancy_descr\">Lower Then</td>\r\n     <td class=\"fancy_blank\">WDICEBLOW</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Player Options -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"5\">Roll Comments/Actions</td>\r\n    </tr>\r\n\r\n    <!- Widgits -->\r\n    <tr>\r\n\r\n     <!- Posting area -->\r\n     <td  class=\"fancy_blank\" colspan=\"2\">\r\n      <input type=\"text\" name=\"DPOST\" value=\"\" size=\"50\" maxlength=\"300\">\r\n     </td>\r\n\r\n     <!- Space things out -->\r\n     <td>&nbsp;</td>\r\n\r\n     <!- Rolling Rolling Rolling -->\r\n     <td  class=\"fancy_blank\" colspan=\"2\">WDICEROLL</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This interface allows you to role die randomly against many systems\r\n     ranging supporting D10, D20 and other systems used commonly in\r\n     realms based on such systems.    Simply fill in the appropriate\r\n     fields and the system will post to you the results!<br><br>\r\n\r\n     In more custom realm, you may find that this panel is missing\r\n     features as they have been preset by the hosts to smooth things\r\n     along.\r\n     \r\n   </div>\r\n  </div>\r\n\r\n  <!- Form Ends -->\r\n  WFORMENDS\r\n\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmFooter','system',' <!- Close document -->\r\n </body>\r\n</html>');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmFrameAutoscroll','system','<html>\r\n <head>\r\n  <title>MNAME</title>\r\n </head>\r\n\r\n <!-- Creates two colums -->\r\n <frameset cols=\"65,*\">\r\n  <!-- Remote control for Auto-Scroll -->\r\n  <frame name=\"Remote\" SRC=\"LSCRL\">\r\n\r\n  <!-- Additionally adds two rows -->\r\n  <frameset id=\"resize\" rows=\"*,135\">\r\n   <!-- Main post window -->\r\n   <frame name=\"Main\" SRC=\"LMAIN\">\r\n   <!-- Communications panel -->\r\n   <frame name=\"Comm\" SRC=\"LCOMM\">\r\n  </frameset>\r\n\r\n </frameset>\r\n</html>');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmFrameNormal','system','<html>\r\n <head>\r\n  <title>MNAME</title>\r\n </head>\r\n\r\n <!-- Creates two rows -->\r\n <frameset id=\"resize\" rows=\"*,135\">\r\n  <!-- Main post window -->\r\n  <frame name=\"Main\" SRC=\"LMAIN\">\r\n  <!-- Communications panel -->\r\n  <frame name=\"Comm\" SRC=\"LCOMM\">\r\n </frameset>\r\n</html>');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmHeader','system','<html>\r\n <head>\r\n  <!- Change below to match your realm name -->\r\n  <title>Ethereal Realms - Roleplay and Chat</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/realm.css\" title=\"Realms\">\r\n </head>\r\n\r\n <!- Change body to modify overall settings -->\r\n <body>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmInfo','system','  <!- Ethereal Realms Online Realms Splash Page -->\r\n  <!- Outer border -->\r\n  <div class=\"ermedium\" style=\"width: 325px; margin: 0px; float: right;\">\r\n\r\n   <!- Title field -->\r\n   <div class=\"rowdark\">Quick Notes!</div>\r\n\r\n   <!- Wrapper Table -->\r\n   <div class=\"erlight\" style=\"width: auto; text-align: justify; padding: 3px;\">\r\n    Welcome to an Ethereal Realms generic realm.    These realms all\r\n    have the same look and feel due to their temporary existence.   \r\n    They do, however, offer you the opportunity to sit back, relax\r\n    and experiment since these realms are accessible directly and are\r\n    not monitored by hosts.<br><br>\r\n\r\n    Realms of this nature will work the same as any public realm you\r\n    may have already visted during your tenure on Ethereal Realms.\r\n    You will be able to quickly retrieve new posts as they become\r\n    available and respond almost as quickly to them. Only imagination\r\n    and the speed of your fingers will affect the speed of the\r\n    messages.    The following are a few hints and tips that may be\r\n    of value to anyone recent to this scene.<br><br>\r\n\r\n    <ul>\r\n     <li>\r\n      The icons besides a users name are called gummies.   Gummies,\r\n      when clicked on, will allow you to perform specific functions\r\n      such as send a message privately, send a message or see useful\r\n      information on the user and his/her handle.\r\n     </li>\r\n\r\n     <li>\r\n      The panel in which you type your responses is called a Comm\r\n      Panel. Most of the interaction you would make, as a user in a\r\n      realm, is conducted through here.\r\n     </li>\r\n\r\n     <li>\r\n      For the purpose of speed, you can press on the \'Tab\' key on\r\n      your keyboard then hit enter to post without using the mouse.\r\n     </li>\r\n\r\n     <li>\r\n      You can return back to the portal at any time by clicking on\r\n      the \'Portal\' link.\r\n     </li>\r\n\r\n     <li>\r\n      You can switch from one handle to the other (with each\r\n      characters unique colours and font selections) by first\r\n      selecting the desired handle and posting without any text in\r\n      the box.\r\n     </li>\r\n\r\n     <li>\r\n      Post zoom is a convenient way to see your posts in a larger\r\n      window.   It also offers you the unique ability to format the\r\n      text using a toolbar and to even check for spelling mistakes!\r\n     </li>\r\n    </ul>\r\n\r\n    If you get an error when attempting to enter this realm, it\r\n    could mean that the realm has already been created using a\r\n    password.   In order to enter this realm you will have to\r\n    provide a password when you enter.    So simply type it along\r\n    with the name in order to proceed with an @ symbol in\r\n    between.   <i>\'mypass@realm\'</i> will provde the password\r\n    of <i>\'myppass\'</i> in the realm \'Realm.\'<br><br>  \r\n\r\n    If you have any additional questions or comments on using\r\n    private/generic realms, feel free to contact us on the matter!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmJavascript','system',' <!- Javascript activation -->\r\n <script language=\"Javascript\" src=\"/js/main.js\"></script>\r\n\r\n\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmNotice','system',' <!- Notices -->\r\n <!- Encapsulate and define -->\r\n <div align=\"center\">\r\n  <div class=\"notice\">\r\n  \r\n   <!- Header -->\r\n   <div class=\"notice_head\">\r\n    MDESCR\r\n   </div>\r\n\r\n   <!- Body -->\r\n   <div class=\"notice_foot\">\r\n    For those making use of Stream or Auto-Scolling modes, your streams will end shortly \r\n    after seeing this post.    In order to restart the stream, simply press on the\r\n    \'Refresh\' button found below.<br><br>\r\n\r\n    It is recommended however, that you wait a few moments before attempting to do\r\n    so.   This will allow for the servers to be properly restarted and reduce your \r\n    chance of errors.<br><br>\r\n\r\n    If any errors appear restart after the streams reset and persist, please report\r\n    them to the <a href=\"mailto:council@ethereal-realms.org\" class=\"a\">Council</a>.\r\n   </div>\r\n  </div>\r\n </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmPanel','system','<!- Online active panel -->\r\n<div align=\"center\">\r\n <!- Top wrapper table -->\r\n <table width=\"550\" border=\"0\" align=\"center\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#cccccc\">\r\n  <tr> \r\n   <td align=\"center\" bgcolor=\"#999999\">\r\n\r\n    <!- Inner wrapper table -->\r\n    <table width=\"100%\" border=\"0\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#FFFFFF\">\r\n     <tr> \r\n      <!- Character Select -->\r\n      <td width=\"30%\" bgcolor=\"#666666\">WCHARSLCT</td>\r\n\r\n      <!- Top bar links -->\r\n      <td width=\"70%\" align=\"center\" bgcolor=\"#666666\">\r\n       <font face=\"Verdana\">\r\n        <a class=\"NAV\" HREF=\"/erealms/config/puppet.plGENPARAM\" TARGET=\"CONFIG\" TABINDEX=\"4\" GENJSCODE>Config</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/portal.plBASEPARAM\" TARGET=\"_BLANK\" ACCESSKEY=\"h\">Portal</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/private.plGENPARAM\" TARGET=\"PRIVTE\" TABINDEX=\"5\" GENJSCODE>Private</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/zoom.plGENPARAM\" TARGET=\"ZOOMER\" ACCESSKEY=\"z\" GENJSCODE>Zoom</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/dice.plGENPARAM\" TARGET=\"DIEROL\" TABINDEX=\"6\" GENJSCODE>Dice</a>\r\n       </font>\r\n      </td>\r\n     </tr>\r\n\r\n     <tr valign=\"middle\"> \r\n      <td colspan=\"2\" bgcolor=\"#666666\">\r\n\r\n       <!- Posting table -->\r\n       <table width=100% border=\"0\" align=\"center\" cellpadding=\"0\" cellspacing=\"0\">\r\n        <tr> \r\n         <!- Custom Text area -->\r\n         <td align=\"left\">\r\n          <textarea name=\"POST\" rows=\"4\" cols=\"75\" wrap=\"SOFT\" accesskey=\"t\" tabindex=\"2\"></textarea>\r\n         </td>\r\n\r\n         <!- Posting button -->\r\n         <td valign=middle>WPOSTSEND</td>\r\n        </tr>\r\n       </table>\r\n      </td>\r\n     </tr>      \r\n\r\n     <tr> \r\n      <!- Font Selection and Advanced Scrolling -->\r\n      <td colspan=\"2\" bgcolor=\"#666666\">\r\n       WFONTCOLR WFONTFACE WFONTSIZE <font class=\"panel\">WSCRLADVD</font>\r\n      </td>\r\n     </tr>\r\n\r\n     <tr> \r\n      <!- Lower bar links -->\r\n      <td colspan=\"2\" align=\"center\"  bgcolor=\"#666666\">\r\n       <font face=\"Verdana\">\r\n        <a class=\"NAV\" HREF=\"/erealms/post/who.plGENPARAM\" TARGET=\"WHOSON\" TABINDEX=\"7\" GENJSCODE>Who\'s On?</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/config/ignore.plGENPARAM\" TARGET=\"REALMS\" TABINDEX=\"9\" GENJSCODE>Ignore</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/post/colours.plGENPARAM\" TARGET=\"REALMS\" ACCESSKEY=\"g\" GENJSCODE>Colour Guide</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/board.plGENPARAM\" TARGET=\"REALMS\" TABINDEX=\"8\" GENJSCODE>Forums</a>\r\n        <a class=\"NAV\" HREF=\"/erealms/mail.plBASEPARAM\" TARGET=\"REALMS\" TABINDEX=\"10\" GENJSCODE>E-mail</a>\r\n       </font>\r\n      </td>\r\n     </tr>\r\n    </table>\r\n   </td>\r\n  </tr>\r\n </table>\r\n\r\n <!- Scroll Control and Stream Control -->\r\n <table width=\"550\" border=\"0\" align=\"center\" cellpadding=\"1\" cellspacing=\"3\">\r\n  <tr>\r\n   <td align=\"left\"><font class=panel>WSCRLCTRL</font></td>\r\n   <td align=\"right\"><font class=panel>WSTRMCTRL</font></td>\r\n  </tr>\r\n </table>\r\n</div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmPrivate','system','<html>\r\n <head>\r\n  <title>Ethereal Realms - Private Messaging</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Private Messaging</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n  <!- Start Form -->\r\n  WFORMSTRT \r\n\r\n\r\n  <!- Private Messaging -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Colour spacer -->\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Private Messaging</td>\r\n    </tr>\r\n\r\n    <!- Additional Description -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Post Your Message Below?</td>\r\n    </tr>\r\n\r\n\r\n    <!- Posting Widgit -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WPOSTTEXT</td>\r\n    </tr>\r\n\r\n    <!- Additional Widgits -->\r\n    <tr>\r\n     <!- Pesky Global Messaging -->\r\n     <td class=\"fancy_blank\"><a LWPESKY class=\"menub\">Global/Local Level Toggle</a></td>\r\n\r\n     <!- Sending Capabilities -->\r\n     <td class=\"fancy_blank\">WPOSTSEND</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Puppet -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Puppet</td>\r\n     <td class=\"fancy_blank\">WCHARSLCT</td>\r\n    </tr>\r\n\r\n    <!- Destination-->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Recepient</td>\r\n     <td class=\"fancy_blank\">WCHARTRGT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Colour -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Colour</td>\r\n     <td class=\"fancy_blank\">WFONTCOLR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Font -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Font Face</td>\r\n     <td class=\"fancy_blank\">WFONTFACE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Size -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Font Size</td>\r\n     <td class=\"fancy_blank\">WFONTSIZE</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Sending a private message is a snap.  Simply select from the list on\r\n     the left who you want to get the message, type in the message and\r\n     press send!    For those who wish to reach people outside of their\r\n     realms you may want to click on the \'Global/Local\' link.<br><br>\r\n\r\n     Please note that you can also send a message to more then one\r\n     person.  Simply depress on the CTRL key while selecting recipients\r\n     and the site will send them to all in the party.\r\n     \r\n   </div>\r\n  </div>\r\n\r\n  <!- Form Ends -->\r\n  WFORMENDS\r\n\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmRefresh','system','    <!- Realm Refresh for all users not Basic -->\r\n    <!- Wrapper -->\r\n    <div style=\"margin: 10px;\" align=\"center\">\r\n\r\n     <!- Option Selection --> \r\n     <table style=\"width: 350px; height: 20px;\">\r\n      <tr>\r\n\r\n       <!- Refresh capabilities -->\r\n       <td rowspan=\"2\">\r\n        WWREFRESH\r\n       </td>\r\n\r\n       <!- Advanced scrolling capabilities -->\r\n       <td style=\"text-align: right;\">\r\n        WSCRLADVD\r\n       </td>\r\n      </tr>\r\n\r\n      <tr>\r\n\r\n       <!- Post saving capabilities -->\r\n       <td style=\"text-align: right;\">\r\n        WSCRLCTRL\r\n       </td>\r\n      </tr>\r\n     </table> \r\n    </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmRemote','system','<html>\r\n <head>\r\n  <title>Remote Control</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/realm.css\" title=\"Realm\">\r\n  <script language=\"Javascript\" src=\"/js/auto.js\"></script>\r\n </head>\r\n\r\n <body bgcolor=\"#000000\" text=\"#000000\" link=\"#204068\" vlink=\"#204068\" alink=\"#D0ECF8\" leftmargin=\"0\" topmargin=\"0\" rightmargin=\"0\" marginwidth=\"0\" marginheight=\"0\" onLoad=\"Scroller()\" spacing=\"0\">\r\n  <table width=\"100%\" height=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\">\r\n   <tr> \r\n    <td align=\"center\"> \r\n\r\n        \r\n     <!- Portable variables These have to remain -->\r\n     <form name=\"Active\">\r\n      <input type=\"hidden\" name=\"INSTANCE\" value=\"0\">\r\n      <input type=\"hidden\" name=\"ACTIVE\"   value=\"0\">\r\n      <input type=\"hidden\" name=\"SPEED\"    value=\"0\">\r\n     </form>\r\n\r\n     <!- Buttons -->\r\n     <table border=\"0\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#CCCCCC\">\r\n      <tr>\r\n       <td align=\"center\" bgcolor=\"666666\"> \r\n        <span class=\"pspec\" onClick=\"ScrollerSpeed(2);return false;\">1</span><br>\r\n        <span class=\"pspec\" onClick=\"ScrollerSpeed(3);return false;\">2</span><br>\r\n        <span class=\"pspec\" onClick=\"ScrollerSpeed(4);return false;\">3</span><br>\r\n        <span class=\"pspec\" onClick=\"ScrollerSpeed(5);return false;\">4</span><br>\r\n        <span class=\"pspec\" onClick=\"ScrollerSpeed(5);return false;\">5</span><br>\r\n        <span class=\"pspec\" onClick=\"ScrollerOff();return false;\">0</span><br>\r\n       </td>\r\n      </tr>\r\n     </table>\r\n        \r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmSeperator','system','  <!- Realm Seperator -->\r\n  <!- Simple Horizontal Row - Change with desired bar -->\r\n  <div align=\"center\">\r\n   <hr width=300 color=\"#999999\">\r\n  </div>');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmSupp','system','  <!- Supplementary item to the Comm Panel -->\r\n  <div align=\"center\">[<a LATTACH>Attach/Detach Panel</a>]</div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmWarning','system','   <!- Warning users of their fails -->\r\n   <!- Wrapper -->\r\n   <div style=\"margin: 10px; text-align: justify;\">\r\n\r\n    <!- Nice and simple table -->\r\n    <table border=\"0\" cellspacing=\"5\" cellpadding=\"5\" align=\"center\" bgcolor=\"#000000\">\r\n     <tr bgcolor=\"80B4D8\"> \r\n      <td>\r\n\r\n       <!- Warning image -->\r\n       <img src=\"/pic/em.jpg\" width=\"30\" height=\"30\" align=\"absmiddle\"> \r\n\r\n       <!- Simple notice of intent -->\r\n       <span style=\"color: #000000;\">\r\n        <b>You have been warned MLOGIN!</b>\r\n       </span>\r\n      </td>\r\n     </tr>\r\n \r\n     <tr bgcolor=\"204068\"> \r\n      <td>\r\n\r\n       <!- More descriptive message -->\r\n       <span style=\"color: #88B4D8;\">\r\n        For the following reasons: MNOTICE\r\n       <span>\r\n      </td>\r\n     </tr>\r\n    </table>\r\n   </div>\r\n');
INSERT INTO ethereal.RealmDesign (TagName,RealmName,DesignContent) VALUES('RealmZoom','system','<html>\r\n <head>\r\n  <title>Ethereal Realms - Post Zooming</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <!- Additional Javascript to make things work -->\r\n  <script language=\"Javascript\" src=\"/js/format.js\"></script>\r\n  <script language=\"Javascript\" src=\"/js/zoom.js\"></script>\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Post Zooming</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n  <!- Start Form -->\r\n  WFORMSTRT \r\n\r\n\r\n  <!- Private Messaging -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Colour spacer -->\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Post Zooming</td>\r\n    </tr>\r\n\r\n    <!- Control Widgets-->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">\r\n\r\n      <!- Bold, Italics, Underline, Center -->\r\n      <img src=\"/img/ctl_bold.gif\" onClick=\"strZoom(this, 0);\" align=\"middle\">\r\n      <img src=\"/img/ctl_italics.gif\" onClick=\"strZoom(this, 1);\" align=\"middle\">\r\n      <img src=\"/img/ctl_underline.gif\" onClick=\"strZoom(this, 2);\" align=\"middle\">\r\n      <img src=\"/img/ctl_centre.gif\" onClick=\"strZoom(this, 3);\" align=\"middle\">\r\n\r\n      <!- Spacer -->\r\n      &nbsp; &#9702; &nbsp;\r\n\r\n      <!- Plus and Minus -->\r\n      <img src=\"/img/ctl_plus.gif\" onClick=\"strZoom(this, 4);\" align=\"middle\">\r\n      <img src=\"/img/ctl_minus.gif\" onClick=\"strZoom(this, 5);\" align=\"middle\">\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Posting Widgit -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WTEXTPOST</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Send Things Off -->\r\n    <tr>\r\n     <!- Transfer -->\r\n     <td class=\"fancy_blank\">WSUBTXFER</td>\r\n\r\n     <!- Spelling -->\r\n     <td class=\"fancy_blank\">WSUBTSPEL</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Damage in spelling -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\">MSPELLERS</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Post Zoom is an excellent way to write on larger posts without\r\n     interrupting what is taking place in realm itself.   Simply write\r\n     out your message and transfer the text back once your done!\r\n     \r\n   </div>\r\n  </div>\r\n\r\n  <!- Form Ends -->\r\n  WFORMENDS\r\n\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Aries','2000-03-21','2000-04-22');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Taurus','2000-04-21','2000-05-21');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Gemini','2000-05-22','2000-06-21');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Cancer','2000-06-22','2000-07-22');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Leo','2000-07-23','2000-08-23');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Virgo','2000-08-22','2000-09-22');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Libra','2000-09-24','2000-10-23');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Scorpio','2000-10-24','2000-11-22');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Sagittarius','2000-11-23','2000-12-21');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Capricorn','2000-12-22','2000-12-31');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Capricorn','2000-01-01','2000-01-20');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Aquarius','2000-01-21','2000-02-19');
INSERT INTO ethereal.Astrology (AstroSign,AstroStart,AstroEnd) VALUES('Pisces','2000-02-20','2000-03-20');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Primary','email','email');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Secondary','email','email');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Gallery','links','http');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Homepage','links','http');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Weblog','links','http');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('AOL Instant Messenger','messenger','none');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('ICQ','messenger','numeric');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Microsoft MSN Messenger','messenger','email');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Yahoo! Instant Messenger','messenger','none');
INSERT INTO ethereal.Contact (ContactName,ContactType,ContactFilter) VALUES('Puppeteer','picture','http');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('CreateDate','MCREATE');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('ExposureTime','MEXPOSURE');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('FNumber','MFNUMBER');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('FocalLength','MFOCAL');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('Make','MMAKE');
INSERT INTO ethereal.Exif (ExifTag, ExifMacro) VALUES('Model','MMODEL');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Are there \'Quick Keys\' in realms?','realms','There are quick keys in realms and by using the key combinations listed below, specific actions will be completed. \r\n<br><br>\r\n<b>Note: </b> Based on your browser the behavior may differ. \r\n<br><br>\r\n\r\n<b>Alt+P:</b> Sends off a post. <br>\r\n<b>Alt+T:</b> Selects the text box. <br>\r\n<b>Alt+R:</b> Refreshes the frame / restarts stream. <br>\r\n<b>Alt+Z:</b> Brings up the post zoom window. <br>\r\n<b>Alt+G:</b> Brings up the color selection chart. <br>\r\n<br>\r\n\r\nWhen posting however, the classical TAB-Enter combination will still be available. ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Can I be a mod and host?','hosts','In versions prior to 3.7.0 of Ethereal Realms hosts could not be a moderator in another realm.   This was restricted at the code level in other to prevent a conflict of interest.\r\n<br><br>\r\nWith 3.7.0 and the addition of roles for moderative staff, this restriction has been lifted.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Can I stop getting private messages?','users','Yes you can!  This option is available through the \'User Details\' portion of the site itself, available from the Portal.   Simply look up \'Privacy Options\' for more details. ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Can we make a donation to Ethereal Realms?','general','All donations to Ethereal Realms are welcome and gratefully recieved. Follow the Donate link in the top right menu to peruse our donation options.  Please note, you need a Pay Pal account in order to donate to Ethereal Realms.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Help I get an error when selecting a realm!','users','Certain personal and/or corporate firewalls filter out Javascript or cripple the code in such a way that it will behave differently then expected.  \'EZ Firewall version 4.5\' for example, will disable the virtual links used and result in a file listing instead.\r\n<br><br>\r\nThe simplest way to correct this issue is to simply disable the sites use of generating Javascript.   This can be done through the \'User Details\' section of the site.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How can I post emoticons?','users','Visit the current <a href=\"/erealms/gummies/inject\" target=\"_new\">listing</a> of useable emoticons.    In order to use them simply copy the descriptor next to the image and your done!\r\n<br><br>\r\n<b>Note:</b> Emoticons are not available for use everywhere.   If they fail to show up, it simply means that script does not support the capability.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I change images in realm select?','administrators','If you wish to change the highlight images in the realm selection portion of the site, then change \'<i>r_on</i>\' and \'<i>r_off</i>\' variables in \'<i>/Template/WebDescription</i>\' to match the desired values.\r\n<br><br>\r\nThe rest can be managed directly from  \'<i>/Attribute/Portal/TmplRealmItem</i>\' or in rare cases from \'<i>/Template/WebPortal</i>.\' ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I change images in toolbars?','administrators','Toolbars are the Javascript enabled sections which allow a user to implement HTML formatting with little knowledge of the markup language.\r\n<br><br>\r\nWhile the initial images are changed directly using the appropriate macro such as \'<i>/Template/RealmZoom</i>\' and \'<i>/Attribute/Configuration/TmplFormat</i>.\'  The additional changes are done through modification of the Javascript code itself.\r\n<br><br>\r\nSimply change the relevant links in the <i>format.js</i> file provided with the Ethereal Realms release and all image changes will be complete.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I change news items displayed?','administrators','Behaviour of the news items displayed in realms can be dyanmically changed.  When the \'<i>/Attribute/SystemSetPortalNewsItem</i>\' is set to \'0\' the system will only display items which are recent.   Otherwise, if a non-zero value is provided the system will show up to that amount of entries.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I change the puppet list?','administrators','The \'<i>/Attribute/System/SetPortalPuppet</i>\' tag must be set to 1 in order to generate the condensed line.    Reversion to 0 will cause the larger scrolling list to appear.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I change the realm list?','administrators','The \'<i>/Attribute/System/SetPortalPuppet</i>\' tag must be set to 1 in order to generate the javascript functionality of the realms selection.    Reversion to 0 will cause the larger scrolling list to appear.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I create a realm?','realms','For information in this matter, see \'Hosting Guidelines\' in the \'Information\' menu at the top of this page.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I fine tune gallery image settings?','administrators','There are six attributes which can be set at the system level in order to fine tune the look, size and format of thumbnails/images used on the site.  Listed below:\r\n<br><br>\r\n<ul>\r\n <li><b>SetImgBackground:</b> The background <a href=\"http://www.imagemagick.org/script/color.php\" target=\"_new\">colour</a> of the full demension thumbnails. - <b>Default</b> Transparent</li>\r\n <li><b>SetImgQuality:</b> Compression level used - <b>Default</b> 30</li>\r\n <li><b>SetImgType:</b> Format of image used - <b>Default</b> GIF</li>\r\n <li><b>SetImgView:</b> Viewing images maximum size - <b>Default</b> 640</li>\r\n <li><b>SetImgFull:</b> Maximum size of an image - <b>Default</b> 800</li>\r\n <li><b>SetThumbnail:</b> Thumbnail size - <b>Current</b> 200</li>\r\n</ul>');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I hide the date time tag?','users','The DATETIME tag works the same was the NAME macros works in the title field of your Puppet Configuration panel.  You can alter its appearance as you like with appropriate HTML or CSS attributes.<br><br>\r\n\r\nTo conceal it against a black background, simply set the font to black and size one. <br><br>\r\n\r\nTo conceal it against a background image, select the dominant color in the image as the font color for the tag.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I make use of cache?','administrators','Caching on Ethereal Realms is done through Berkeley DB and requires some minor changes to the Ethereal::Database module file.    Before you proceed, realize that you will need to create/use a directory structure which will allow the web user name and group to access these files directly.<br><br>\r\n\r\n<b>Note:</b>  It may also help if the maintenance script user has enough rights to remove stale files from time to time.<br><br>\r\n\r\nIf you are attempting to implement caching under a multi-server system (more then one web server) you will need to make sure that the servers share the same cached information.  This can be done through a network share or for those with money some sort of SAN.<br><br>\r\n\r\nTo make use of this feature modify lines 68-70 in the Database.pm file.   This file MUST be the same that is used by the scripts otherwise the changes will not take effect.<br><br>\r\n\r\nChange the lines to look like the ones below:<br>\r\n\r\n<blockquote>\r\n  DBAUTH => \'/path/to/db/auth\',		# Path for auth cache<br>\r\n  DBHASH => \'/path/to/db/hash\',		# Path for system tags<br>\r\n  DBROOM => \'/path/to/db/room\',		# Path for room tags\r\n</blockquote>\r\n\r\nAlternatively, to disable you\'d reset all of these to \'undef.\'   That will stop the cache files from being used even if they are present.<br><br>\r\n\r\nTo create the hashes an administrator will need to access each series of attributes and the templates as to create the initial set.   The files will update automatically as changes are made.\r\n\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I protect a private room?','realms','Password protecting a private room means added security from uninvited guests.  If you intend to protect a private room called \'Secret\' with the password \'safe\' you enter \'safe@Secret\' in the Private Room field. <br><br>\r\n\r\nThis will create the room \'Secret\', and allow only those with the password to enter.  Note that you cannot password protect a private realm that already exists. Private realms linger on the system for 24 hours after last use, then expires.  You can keep your private room indefinitely private by not allowing it to expire.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I remove my gummy?','users','Removing gummies is a bonus for verified users, along with access to an assortment of contributor gummies.  Verified users are patrons who have made a donation to Ethereal Realms via Pay Pal. <br><br>\r\n\r\nIf you have made a donation to Ethereal Realms you will find a --none-- option at the bottom of the drop down menu for gummies in your Puppet Details panel.  <br><br>\r\n\r\nRemoving the gummy will place your user details in a link under your puppet handle instead.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I show/remove forum lists?','administrators','The \'<i>/Attribute/System/SetPortalForum</i>\' tag must be set to 1 in order for the appropriate macro to be generated.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I show/remove news lists?','administrators','The \'<i>/Attribute/System/SetPortalNews</i>\' tag must be set to 1 in order for the appropriate macro to be generated.\r\n<br><br>\r\n<b>Note:</b> Setting the amount of items displayed is not done through the above attribute.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I upgrade?','administrators','<b>NOTE:</b> Upgrades from version 3.0.0- to 3.1.0+ is not advised.\r\n<br><br>\r\nThere are several scripts which exist to upgrade certain components of the site to 4.0.0+ and above.  Most of which located in <i>./mgmt/commandline</i> and are listed below:\r\n<br>\r\n<ul>\r\n<li><b>locate_tags.pl</b> - Used to locate unused tags on a system and remove them;</li>\r\n<li><b>publish.pl</b> - Used to generate PDF documents for all written prose in a given gallery; and</li>\r\n<li><b>reverse.pl</b> - Used to regenerate the gallery reverse indexes used in 4.0.0+;</li>\r\n<li><b>thumbail.pl</b> - Used to regenerate all thumbnails and images in galleries to bring them up to 4.0.0+ specs;</li>\r\n<li><b>update_comm.pl</b> - Used to adapt all comm panels to the new GENPARAM linking system.</li>\r\n</ul>\r\nNew with version 4.0.0 of the scripts is the addition of an installer script for the site.   This installer script exists to support the virtual hosting capabilities.  However, it will also make sure all modules are installed, change the execute path of Perl and setup the search path for the Ethereal:: modules necessary for use of the scripts.\r\n<br><br>\r\nThese upgrades are located in the ./upgrade directory and once moved into the ./conf directory can be used on the command line by typing perl ./conf/config.pl.  This new file will prompt the system to give you the option to bring the system up to date. \r\n<br><br>\r\n<b>NOTE:</b> Sites not making use of virtual hosting cannot make use of this script.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('How do I use the weather generator?','hosts','The weather generate is automatic once you have selected a weather station with which to track.   In order to do this visit the <a href=\"http://www.nws.noaa.gov/tg/siteloc.shtml\" target=\"_new\">National Weather Service</a> and find an appropriate station.    With that information, input the ICAO number which is 4 characters in length and the system will automatically post that information to  your splash page!');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('I am missing files in my install?','administrators','Under no circumstance should you open the archived file on a Windows based operating system and transfer the contents to its new home.    This will cause several needed symbolic links in being lost and may severely hinder your ability to use the site.          ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('I cannot change realms after install?','administrators','There is a known issue where escaped characters in database dumps may not remain as such.   This causes issue in the JavaScript code found under <i>/Templates/WebDescription</i> and can be easily corrected by using the following lines:\r\n\r\n<blockquote>\r\n   var re  = / \(\d+\)$/;<br>\r\n   var spc = /\W+/g;\r\n</blockquote>\r\n\r\nThis will re-enable the regular expressions critical to the operation of the code itself. ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('I used to get Emails all the time, now I don\'t?','users',NULL);
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Just installed Ethereal Realms!  Password?!?','administrators','The password for the user \'admin\' is simple \'password\' and as a general rule it is considered wise to change this as soon as humanly possible.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Key error when using maps?','administrators','Google is pretty explicit in its errors and this is normally related to the fact that they key provided is not valid for the site attempting to use it, is not being used at all or the domains do not match.<br><br>\r\n\r\nIf this is related to a site like Ethereal Realms itself which has many domain names then there is little you can do on the matter.   Only request that your users be directed to the registered domain.<br><br>\r\n\r\nFor those interested in their own key, please visit: <a href=\"http://www.google.com/apis/maps/signup.html\" target=\"new\">http://www.google.com/apis/maps/signup.html</a>');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('My login does not work. What do I do?','users','There are a few reasons why your account may not be working as expected:\r\n<br><br>\r\nThe first is related to an account going idle.  Any account that has not seen activity within the last 90 days will in fact be removed from the system.    In order to correct this, the user simply needs to register a new account with Ethereal Realms.\r\n<br><br>\r\nThe second can be due to a lost password.    Ethereal Realms does offer a <a href=\"/erealms/reset.pl\"><u>reset</u></a> ability for password, but must have a valid and current Email address for the new password to be sent to.\r\n<br><br>\r\nIf you are having problems continued with your log-in please <a href=\"/contact.html\"><u>contact</u></a> us and we will assist you with your account. Be sure to include your log-in name and the email address that you used to sign up for your account. We will get back to you as soon as possible. ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Problems with Image::Magick, help?','administrators','Image::Magick is critical for the use of advanced features used in contributor scripts.   Unfortunately, there is little one can do on this matter, Image::Magick is required for all image related actions including determining the size of images.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('The ./conf/config.pl script does not work?','administrators','This script requires Config::IniFiles, DBI, Digest::MD5, File::Copy in order to work properly.   If the first module especially is missing, the script will complain that it cannot find specific files in the search path.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What are chat preferences?','users','Chat preferences are different methods in which the user plays in a realm.  The following modes are outlined below:\r\n<br><br>\r\n<b>Basic Mode</b> is the simplest chat interface avialable.  It will work under a myriad of browsers even some which do not support images!\r\n<br><br>\r\n<b>Framed Mode</b> is the second generation of chat interfaces.   This one features a posting frame and viewing frame, allowing you to type up a post and check for new posts manually from time to time.\r\n<br><br>\r\n<b>Stream Mode</b> is similiar in many ways to Framed, however the posts arrive automatically and require no manual request.\r\n<br><br>\r\n<b>Autoscrolling Mode</b> is an upgrade to Stream in which a user can opt to have the posts move into focus for them without any use of the scrollbars.   The speed is entirely controlled by the user.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What does a \'Verified\' user get?','contributors','Verified users have access to additional content (if it exists) on the site itself.   For example, an realms or gallerys restricted to adults would require verification in order to continue.\r\n<br><br>\r\nVerified users also have access to a different series of gummies and the ability to remove gummies altogether from a users handle.\r\n<br><br>\r\nVerified users will also never expire from the system itself.   This allows the users to ensure their accounts will last, even if their ability to return to the site is severly reduced.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What does \'Verified\' mean?','contributors','Users who have donated to Ethereal Realms via Pay Pal have been verified as adults, therefore allowing them access to our adult realms.  This is our way of ensuring minors cannot access inappropriate material.  Verified users have a \'tick\' beside their login in their Privileged portal.  Those who have access to the Privileged portal, but are not verified, have a \'denied\' symbol.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What do gummies do?','users','Gummies provide a link to all your user information you choose to make available, including E-Mail, Homepage, Instant Message Services, and an image.  Gummies also allow for private messaging and ignoring.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is a macro and template?','administrators','Macro\'s are keywords the system will recognize and replace with appropriate material.   These range from simple name fill-in to the more complex addition of user interface widgits.\r\n<br><br>\r\nA brief list is as follows:\r\n<br><br>\r\n<b>M-SERIES</b> - Dropping in words and phrases;<br>\r\n<b>L-SERIES</b> - Dropping in urls and links;<br>\r\n<b>LST-SERIES</b> - Drops in generated lists of elements such as the realms list on the portal; and<br>\r\n<b>W-SERIES</b> - Drops in a user widget such as a drop-down menu, textarea and such.<br>\r\n<br><br>\r\n<b>Note:</b>  Some older templates do not make use of this precise naming scheme, however their function should become clear upon examination.\r\n<br><br>\r\nTemplates are areas of text which contain macro and are expanded to form into a finished end product.  There are two sets of templates.\r\n<br><br>\r\nOnes which reside in the \'Templates\' section of the administrative section and are considered major templates independant of other attributes.\r\n<br><br>\r\nLastly templates under \'Attributes\' combined with others similiar and will generally always begin with \'Tmpl.\'  These work the same however and are left together to make modifications easier. \r\n<br><br>\r\n<b>Note:</b> Some templates use other templates to generate their macros.    The LSTREALMS macro in WebPortal for example uses another template within the Portal grouping to generate the listing.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is Berkeley DB?','administrators','Berkeley DB are single file databases which can carry information using various methods from hashing to binary search trees.   These files have the additional capability of being implemented directly into Perl cutting out a lot of overhead when used.<br><br>\r\n\r\nEthereal Realms uses this format of database in order to cache frequently accessed information cutting down on database load.  For more information on this matter look up the \'How do I make use of cache\' question in this FAQ.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is Ethereal Realms?','general','Ethereal Realms is a concept web-based chat system, originally based on two chat sites which are now both defunct. This system emulates what features and functionality those sites possessed while adding to the initial design and scope as time progressed.  Over time the code base has picked up message boards, internal messaging, image/prose galleries and a social network interface.<br><br>\r\n \r\nReleased under the GNU General Public License  (GPL), this project also has the secondary aim of creating an advanced role-play and gallery environment that will can be shared and modified freely throughout the community.<br><br>\r\n\r\nEthereal Realms has also moved well beyond the original mandate of offering chat capabilities. This includes the addition of threaded message boards, web polls, homepage management, collaborative galleries and social networking profiles with geographical searching. While these additions are not necessarily core to the role-play aspect of the site, they do compliment the existing feature set and provides communities a method of remaining self-sufficient.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is lock-down?','administrators','Lock-down mode is a simplification of Ethereal Realms to support sites which cannot or will not deal with a multi-handle environment.   Sites such as Plenty of Fish and MySpace typically require the user to exist as one avatar due to the nature of the content they are peddling.<br><br>\r\n\r\nAs a result of the recent code changes and future plans of on the code supporting social networks, it becomes critical to feature a locked-down experience for sites who choose to be more like a MySpace; in turn becoming a lot less like the traditional Ethereal Realms site is.   The best aspect of lock-down however is that the changes are entirely at code level with no database changes that could potentially slow either mode of operation.<br><br>\r\n\r\nIn order to enable lock-down the user simply needs to uncomment the definition of the $self->{\'DEFAULT\'} variable within the Database.pm module.   This in turn will trigger all basic intelligence for the site to force the user to make use of their default handles wherever they go, all scripts that in turn require an avatar will simply force the default and continue.<br><br>\r\n\r\nCaveats to this method are that the macro\'s still exist as they did in the other mode.   This is simply to allow the site owners to transition from one to the other with minor annoyance.    For those administrators wishing to make it permanent, move the macros to an out of the way place and they will not bother you any longer (since it generates a hidden form attribute).<br><br>\r\n\r\nAlso note that beyond simple template changes, the Puppet management page will also never allow a locked-down site to reach any other page other then the default handles properties.   Sites who use lock-down would be best served removing the appropriate menu macros to avoid confusion.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is the [Attach/Detach] link for?','realms','For those who make use of Javascript and Internet Explorer. There exists the ability to detach the Comm Panel from the browser itself. \r\n<br><br>\r\nVisually, it creates a new window, which is separate from the main post viewing area. This does not reduce functionality in any way shape or form and it can be reversed as the user sees fit. \r\n<br><br>\r\nIn order to enable this option, simply click on the [Detach/Attach] link located at the bottom of the Comm Panel itself. In order to reverse the effect, simply press again on that the same link. \r\n<br><br>\r\n<b>Note:</b> This feature is only available for Internet Explorer.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What is the \'Post Zoom?\'','realms','The \'Post Zoom\' allow your to increase the size of your posting window in order to compose larger posts are your ease.    This feature also allows you to check for spelling mistakes and insert various HTML formatting from the click of a button.<br><br>\r\n\r\nIn certain browsers, it is even possible to transfer a post to the post zoom in order to quickly post a reply and multi-task in realm.<br><br>\r\n\r\n<b>Note:</b>  This option requires javascript in order to function properly.   ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('What Perl modules do I need installed?','administrators','These are the modules required for Ethereal Realms version 4.1.0 and above.<br>\r\n\r\n<ul>\r\n <li>Standard Modules</li>\r\n <ul>\r\n  <li>CGI</li>\r\n  <li>CGI::Carp</li>\r\n  <li>Cwd</li>\r\n  <li>File::Copy</li>\r\n  <li>IO::Socket</li>\r\n  <li>IPC::Open2</li>\r\n  <li>Math::Trig</li>\r\n  <li>POSIX</li>\r\n  <li>Symbol</li>\r\n </ul>\r\n\r\n\r\n <li>Bundled Modules</li>\r\n <ul>\r\n  <li>Config::IniFiles</li>\r\n  <li>Lingua::EN::NameCase</li>\r\n  <li>Lingua::EN::Tagger</li>\r\n  <li>Lingua::Stem</li>\r\n  <li>Number::Format</li>\r\n  <li>Text::Wrap</li>\r\n </ul>\r\n\r\n\r\n <li>Non-Standard Modules</li>\r\n <ul>\r\n  <li>Archive::Zip</li>\r\n  <li>DBI</li>\r\n  <li>DBD::Pg</li>\r\n  <li>Digest::MD5</li>\r\n  <li>Geo::IP</li>\r\n  <li>Geo::IP2Location</li>\r\n  <li>Image::ExifTool</li>\r\n  <li>Image::Magick</li>\r\n  <li>LWP::Simple</li>\r\n  <li>LWP::UserAgent</li>\r\n  <li>MIME::Entity</li>\r\n  <li>Time::HiRes</li>\r\n  <li>XML::RSS</li>\r\n </ul>\r\n</ul>\r\n\r\n<b>Note:</b> Standard modules are characterized by those which can be readily found on most modern Perl installations.   While bundled modules are released with Ethereal Realms itself in order to reduce the need for installation.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Where\'s the keywords field?','contributors','Some sites require you to select certain keywords which would play out in a search for the work in particular.   Ethereal Realms instead uses the title, description and text body of works to produce keywords.<br><br>\r\nThis process is first started when you update a work.  The site will take process your works and generate a wider set of keywords allowing for more generalized searches to work!');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Who manages Ethereal Realms?','general','Ethereal Realms was created by Martin Foster, who continues to maintain the site at his own expense. It is run by a body of people known as the Council, who anonymously donate their time to managing it on his behalf. Both Martin and the Council are contactable via the Contact page found in the top right menu.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why can\'t I ignore a user in my realm?','hosts','By default no host can ignore a user in their own realms.   This would reduce their capabilities of actually being able to monitor a scene since information is missing.\r\n<br><br>\r\nHowever, this can be overrided in the \'User Details\' area available through the Portal.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why can\'t I select a handle?','users','You used to be able to select handles, manage them and that option is no longer available or hidden from you?   Chances are that the staff of the site has implemented lock-down mode which prevents that sort of activity.   Speak to them about your problem and see if that is the case.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why can\'t I view a profile?','users','Before you can search for a user\'s profile, you must first have your own.  Details from your own profile will be used directly in the searching ability for the site.<br><br>\r\n\r\nYou can create a new profile through the \'User Details\' section of the site. ');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why does the site think I am in X city?','users','The system users your IP address to determine where you are from.  Now this technology is not exactly perfect so it may be picking up invalid information or reflecting the network you are on.<br><br>\r\n\r\nThere is no need to worry, simply change the information to reflect proper information and use the map to pinpoint your proper location.   While you can specify location like Antarctica, you would be best to avoid such places because you will not be able to find people close to you as a result!<br><br>\r\n\r\n<b>Note:</b>  Sites such as Ethereal Realms use debugging keys to lock people into a specific location.   This is due to the fact that the site proper is non-functional and is not meant to be used live.\r\n\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why do my works not show up in search?','contributors','In order for works to show up in a search they need to have been updated at least once.    For image galleries in particular this allows the search engine to avoid entire galleries which exist as image farms.<br><br>\r\n\r\nIn order to correct this, simply update the work, putting in a description will only help matters and the search engine will pick it up when the appropriate criteria is met!');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why do posts take a while to show when I stream?','users',NULL);
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why do users, realms and mail expire?','administrators','The system as a whole is required to expire certain information in order to keep the database from getting bloated.    However, the lapse in time requires for the expiry of such features can be controlled individually.\r\n<br><br>\r\nModifications to the \'<i>/Attribute/System/SetTimeout*</i>\' attributes will set the expiry time in days for each listed component.\r\n<br><br>\r\n<b>Note:</b> The use of the commandline tools are requires for any maintenance to be conducted.\r\n');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why is my profile not visible?','users','Profiles on Ethereal Realms require a certain amount of information to function.  First and foremost location information is required else you will not be able to continue to other steps for registration until that step is complete.<br><br>\r\n\r\nIn addition you will have to provide a default handle.   These can be selected from the Puppet Management screen and will become your default avatar for social networking once you establish it as default.<br><br>\r\n\r\n<b>Note:</b>  All new users will have a default handle created at registration time.   This problem only applies to established users.');
INSERT INTO ethereal.Faq (FaqQuestion, FaqGroup, FaqAnswer) VALUES('Why won\'t Tab-Enter work?','hosts','Check your Comm Panel and make sure that the TAB INDEX attributes for the buttons and links are not in conflict with one another.\r\n<br><br>\r\nIf this is a recent change in which even the default realms will not work, then chances are an upgrade of a module has resulted in this failure.    This can only be corrected by moving to version 3.7.0+ of Ethereal Realms.');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Alice Blue','color','#F0F8FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Antique White','color','#FAEBD7');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Aqua','color','#00FFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Aqua Marine','color','#7FFFD4');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Azure','color','#F0FFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Beige','color','#F5F5DC');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Bisque','color','#FFE4C4');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Black','color','#000000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Blanched Almond','color','#FFEBCD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Blue','color','#0000FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Blue Violet','color','#8A2BE2');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Brown','color','#A52A2A');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Burly Wood','color','#DEB887');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Cadet Blue','color','#5F9EA0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Chartreuse','color','#7FFF00');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Chocolate','color','#D2691E');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Coral','color','#FF7F50');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Cornflower Blue','color','#6495ED');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Cornsilk','color','#FFF8DC');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Crimson','color','#DC143C');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Cyan','color','#00FFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Blue','color','#00008B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Cyan','color','#008B8B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Goldenrod','color','#B8860B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Gray','color','#A9A9A9');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Green','color','#006400');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Khaki','color','#BDB76B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Magenta','color','#8B008B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Olive Green','color','#556B2F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Orange','color','#FF8C00');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Orchid','color','#9932CC');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Red','color','#8B0000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Salmon','color','#E9967A');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Sea Green','color','#8FBC8F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Slate Blue','color','#483D8B');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Slate Gray','color','#2F4F4F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Turquoise','color','#00CED1');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dark Violet','color','#9400D3');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Deep Pink','color','#FF1493');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Deep Sky Blue','color','#00BFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dim Gray','color','#696969');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Dodger Blue','color','#1E90FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Fire Brick','color','#B22222');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Floral White','color','#FFFAF0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Forest Green','color','#228B22');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Fuchsia','color','#FF00FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Gainsboro','color','#DCDCDC');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Ghost White','color','#F8F8FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Gold','color','#FFD700');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Goldenrod','color','#DAA520');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Gray','color','#808080');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Green','color','#008000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Green Yellow','color','#ADFF2F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Honeydew','color','#F0FFF0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Hot Pink','color','#FF69B4');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Indian Red','color','#CD5C5C');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Indigo','color','#4B0082');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Ivory','color','#FFFFF0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Khaki','color','#F0E68C');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lavender','color','#E6E6FA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lavender Blush','color','#FFF0F5');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lawn Green','color','#7CFC00');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lemon Chiffon','color','#FFFACD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Blue','color','#ADD8E6');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Coral','color','#F08080');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Cyan','color','#E0FFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Goldenrod Yellow','color','#FAFAD2');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Green','color','#90EE90');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Grey','color','#D3D3D3');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Pink','color','#FFB6C1');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Salmon','color','#FFA07A');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Sea Green','color','#20B2AA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Sky Blue','color','#87CEFA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Slate Gray','color','#778899');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Steel Blue','color','#B0C4DE');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Light Yellow','color','#FFFFE0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lime','color','#00FF00');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Lime Green','color','#32CD32');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Linen','color','#FAF0E6');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Magenta','color','#FF00FF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Maroon','color','#800000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Aqua Marine','color','#66CDAA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Blue','color','#0000CD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Orchid','color','#BA55D3');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Purple','color','#9370D8');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Red','color','9C0000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Sea  Green','color','#3CB371');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Slate Blue','color','#7B68EE');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Spring Green','color','#00FA9A');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Turquoise','color','#48D1CC');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Medium Violet Red','color','#C71585');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Midnight Blue','color','#191970');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Mint Cream','color','#F5FFFA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Misty Rose','color','#FFE4E1');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Moccasin','color','#FFE4B5');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Navajo White','color','#FFDEAD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Navy','color','#000080');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Oldlace','color','#FDF5E6');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Olive','color','#808000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Olive Drab','color','#688E23');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Orange','color','#FFA500');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Orange Red','color','#FF4500');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Orchid','color','#DA70D6');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Pale Goldenrod','color','#EEE8AA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Pale Green','color','#98FB98');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Pale Turquoise','color','#AFEEEE');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Pale Violet Red','color','#D87093');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Papaya Whip','color','#FFEFD5');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Peach Puff','color','#FFDAB9');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Peru','color','#CD853F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Pink','color','#FFC0CB');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Plum','color','#DDA0DD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Powder Blue','color','#B0E0E6');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Purple','color','#800080');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Red','color','#FF0000');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Rosy Brown','color','#BC8F8F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Royal Blue','color','#4169E1');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Saddle Brown','color','#8B4513');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Salmon','color','#FA8072');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Sandy Brown','color','#F4A460');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Sea Green','color','#2E8B57');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Seashell','color','#FFF5EE');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Sienna','color','#A0522D');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Silver','color','#C0C0C0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Skyblue','color','#87CEEB');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Slate Blue','color','#6A5ACD');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Slate Gray','color','#708090');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Snow','color','#FFFAFA');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Spring Green','color','#00FF7F');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Steel Blue','color','#4682B4');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Tan','color','#D2B48C');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Teal','color','#008080');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Thistle','color','#D8BFD8');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Tomato','color','#FF6347');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Turquoise','color','#40E0D0');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Violet','color','#EE82EE');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Wheat','color','#F5DEB3');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('White','color','#FFFFFF');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('White Smoke','color','#F5F5F5');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Yellow','color','#FFFF00');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Yellow Green','color','#9ACD32');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Andale Mono','face','Andale Mono');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Arial','face','Helvetica, Arial, sans-serif');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Arial Black','face','Arial Black');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Comic Sans MS','face','Comic Sans MS');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Courier New','face','Courier New, Courier, monospace');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Cursive','face','cursive');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Fantasy','face','fantasy');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Georgia','face','Georgia');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Impact','face','Impact');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Tahoma','face','Tahoma');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Times New Roman','face','Times New Roman, Times, serif');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Trebuchet MS','face','Trebuchet MS');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('Verdana','face','Verdana');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('1','size','1');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('2','size','2');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('3','size','3');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('4','size','4');
INSERT INTO ethereal.Font (FontName,FontType,FontCode) VALUES('5','size','5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If God had intended Man to Watch TV, He would have given him Rabbit Ears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Forms follow function, and often obliterate it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is anything you can get away with.<BR>\n&nbsp;-- Marshall McLuhan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The Great Movie Posters:<BR>\n&nbsp;The nightmare terror of the slithering eye that unleashed agonizing<BR>\nhorror on a screaming world!<BR>\n&nbsp;-- The Crawling Eye (1958)<BR>\n&nbsp;SEE a female colossus... her mountainous torso, scyscraper limbs,<BR>\ngiant desires!<BR>\n&nbsp;-- Attack of the Fifty-Foot Woman (1958)<BR>\n&nbsp;Here Is Your Chance To Know More About Sex.<BR>\nWhat Should a Movie Do?  Hide Its Head in the Sand Like an Ostrich?<BR>\nOr Face the JOLTING TRUTH as does...<BR>\n&nbsp;-- The Desperate Women (1958)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If it were thought that anything I wrote was influenced by Robert Frost,<BR>\nI would take that particular work of mine, shred it, and flush it down<BR>\nthe toilet, hoping not to clog the pipes.  A more sententious, holding-<BR>\nforth old bore who expected every hero-worshiping adenoidal little twerp<BR>\nof a student-poet to hang on to his every word I never saw.<BR>\n&nbsp;-- James Dickey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The Great Movie Posters:<BR>\n&nbsp;SCENES THAT WILL STAGGER YOUR SIGHT!<BR>\n-- DANCING CALLED GO-GO<BR>\n-- MUSIC CALLED JU-JU<BR>\n-- NARCOTICS CALLED BANGI!<BR>\n-- FIRES OF PUBERTY!<BR>\n&nbsp;SEE the burning of a virgin!<BR>\n&nbsp;SEE power of witch doctor over women!<BR>\n&nbsp;SEE pygmies with fantastic Physical Endowments!!!<BR>\n&nbsp;-- Kwaheri (1965)<BR>\n&nbsp;The Big Comedy of Nineteen-Sexty-Sex!<BR>\n&nbsp;-- Boeing-Boeing (1965)<BR>\n&nbsp;AN ASTRONAUT WENT UP-<BR>\nA \"GUESS WHAT\" CAME DOWN!<BR>\n&nbsp;The picture that comes complete with a 10-foot tall monster to<BR>\ngive you the wim-wams!<BR>\n&nbsp;-- Monster a Go-Go (1965)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is the tree of life.  Science is the tree of death.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A young man wrote to Mozart and said:<BR>\n&nbsp;Q: \"Herr Mozart, I am thinking of writing symphonies. Can you give me any<BR>\n&nbsp;suggestions as to how to get started?\"<BR>\nA: \"A symphony is a very complex musical form, perhaps you should begin with<BR>\n&nbsp;some simple lieder and work your way up to a symphony.\"<BR>\nQ: \"But Herr Mozart, you were writing symphonies when you were 8 years old.\"<BR>\nA: \"But I never asked anybody how.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The trouble with superheros is what to do between phone booths.<BR>\n&nbsp;-- Ken Kesey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The sun never sets on those who ride into it.<BR>\n&nbsp;-- RKO');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The streets were dark with something more than night.<BR>\n&nbsp;-- Raymond Chandler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The story you are about to hear is true.  Only the names have been<BR>\nchanged to protect the innocent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Immature poets imitate, mature poets steal.<BR>\n&nbsp;-- T.S. Eliot, \"Philip Massinger\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','&nbsp;FROM THE DESK OF<BR>\n&nbsp;Dorothy Gale<BR>\n&nbsp;Auntie Em:<BR>\n&nbsp;Hate you.<BR>\n&nbsp;Hate Kansas.<BR>\n&nbsp;Taking the dog.<BR>\n&nbsp;Dorothy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is Nature speeded up and God slowed down.<BR>\n&nbsp;-- Chazal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The profession of book writing makes horse racing seem like a solid,<BR>\nstable business.<BR>\n&nbsp;-- John Steinbeck<BR>\n&nbsp;[Horse racing *is* a stable business ...]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The plot was designed in a light vein that somehow became varicose.<BR>\n&nbsp;-- David Lardner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Immature artists imitate, mature artists steal.<BR>\n&nbsp;-- Lionel Trilling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The only real advantage to punk music is that nobody can whistle it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The only \"ism\" Hollywood believes in is plagiarism.<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Imitation is the sincerest form of television.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Fremen add life to spice!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The older I grow, the less important the comma becomes.  Let the reader<BR>\ncatch his own breath.<BR>\n&nbsp;-- Elizabeth Clarkson Zwart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The old complaint that mass culture is designed for eleven-year-olds<BR>\nis of course a shameful canard.  The key age has traditionally been<BR>\nmore like fourteen.<BR>\n&nbsp;-- Robert Christgau, \"Esquire\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The last vestiges of the old Republic have been swept away.<BR>\n&nbsp;-- Governor Tarkin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is either plagiarism or revolution.<BR>\n&nbsp;-- Paul Gauguin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A yawn is a silent shout.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"The human brain is like an enormous fish -- it is flat and slimy and<BR>\nhas gills through which it can see.\"<BR>\n&nbsp;-- Monty Python');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The human brain is a wonderful thing.  It starts working the moment<BR>\nyou are born, and never stops until you stand up to speak in public.<BR>\n&nbsp;-- Sir George Jessel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The human animal differs from the lesser primates in his passion for<BR>\nlists of \"Ten Best\".<BR>\n&nbsp;-- H. Allen Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The horror... the horror!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The Hollywood tradition I like best is called \"sucking up to the stars.\"<BR>\n&nbsp;-- Johnny Carson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If you are of the opinion that the contemplation of suicide is sufficient<BR>\nevidence of a poetic nature, do not forget that actions speak louder than words.<BR>\n&nbsp;-- Fran Lebowitz, \"Metropolitan Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There is only one thing in the world worse than being talked about, and<BR>\nthat is not being talked about.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There is nothing wrong with writing ... as long as it is done in private<BR>\nand you wash your hands afterward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It happened that a fire broke out backstage in a theater.  The clown came<BR>\nout to inform the public.  They thought it was just a jest and applauded.<BR>\nHe repeated his warning, they shouted even louder.  So I think the world<BR>\nwill come to an end amid general applause from all the wits, who believe<BR>\nthat it is a joke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Go ahead... make my day.<BR>\n&nbsp;-- Dirty Harry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','As a goatherd learns his trade by goat, so a writer learns his trade by wrote.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There is much Obi-Wan did not tell you.<BR>\n&nbsp;-- Darth Vader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There are two ways of disliking poetry; one way is to dislike it, the<BR>\nother is to read Pope.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There are two ways of disliking art.   One is to dislike it.  The other is<BR>\nto like it rationally.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','George Bernard Shaw once sent two tickets to the opening night of one of<BR>\nhis plays to Winston Churchill with the following note:<BR>\n&nbsp;\"Bring a friend, if you have one.\"<BR>\n&nbsp;Churchill wrote back, returning the two tickets and excused himself as he<BR>\nhad a previous engagement.  He also attached the following:<BR>\n&nbsp;\"Please send me two tickets for the next night, if there is one.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','There are three rules for writing a novel.  Unfortunately, no one knows<BR>\nwhat they are.<BR>\n&nbsp;-- Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','In Oz, never say \"krizzle kroo\" to a Woozy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The world has many unintentionally cruel mechanisms that are not<BR>\ndesigned for people who walk on their hands.<BR>\n&nbsp;-- John Irving, \"The World According to Garp\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Gauls! We have nothing to fear; except perhaps that the sky may fall on<BR>\nour heads tomorrow.  But as we all know, tomorrow never comes!!<BR>\n&nbsp;-- Adventures of Asterix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Acting is not very hard.  The most important things are to be able to laugh<BR>\nand cry.  If I have to cry, I think of my sex life.  And if I have to laugh,<BR>\nwell, I think of my sex life.<BR>\n&nbsp;-- Glenda Jackson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Trifles make perfection, and perfection is no trifle.<BR>\n&nbsp;-- Michelangelo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Today, of course, it is considered very poor taste to use the F-word<BR>\nexcept in major motion pictures.\"<BR>\n&nbsp;-- Dave Barry, \"$#$%#^%!^%&@%@!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Good night, Mrs. Calabash, wherever you are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Authors (and perhaps columnists) eventually rise to the top of whatever<BR>\ndepths they were once able to plumb.<BR>\n&nbsp;-- Stanley Kaufman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','This unit... must... survive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','This novel is not to be tossed lightly aside, but to be hurled with great force.<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','God save us from a bad neighbor and a beginner on the fiddle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','This is the ____LAST time I take travel suggestions from Ray Bradbury!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','This door is baroquen, please wiggle Handel.<BR>\n(If I wiggle Handel, will it wiggle Bach?)<BR>\n&nbsp;-- Found on a door in the MSU music building');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It is up to us to produce better-quality movies.<BR>\n&nbsp;-- Lloyd Kaufman, producer of \"Stuff Stephanie in the Incinerator\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','God is really only another artist.  He invented the giraffe, the elephant<BR>\nand the cat.  He has no real style, He just goes on trying other things.<BR>\n&nbsp;-- Pablo Picasso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Asking a working writer what he thinks about critics is like asking a<BR>\nlamp-post how it feels about dogs.<BR>\n&nbsp;-- Christopher Hampton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Acting is an art which consists of keeping the audience from coughing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A man paints with his brains and not with his hands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A critic is a bundle of biases held loosely together by a sense of taste.<BR>\n&nbsp;-- Whitney Balliett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A celebrity is a person who is known for his well-knownness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It is something to be able to paint a particular picture, or to carve a<BR>\nstatue, and so to make a few objects beautiful; but it is far more glorious <BR>\nto carve and paint the very atmosphere and medium through which we look, <BR>\nwhich morally we can do.  To affect the quality of the day, that is the<BR>\nhighest of arts. Every man is tasked to make his life, even in its details,<BR>\nworthy of the contemplation of his most elevated and critical hour.<BR>\n&nbsp;-- Henry David Thoreau, \"Where I Live\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It is difficult to produce a television documentary that is both<BR>\nincisive and probing when every twelve minutes one is interrupted by<BR>\ntwelve dancing rabbits singing about toilet paper.<BR>\n&nbsp;-- Rod Serling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','God help the troubadour who tries to be a star.  The more that you try<BR>\nto find success, the more that you will fail.<BR>\n&nbsp;-- Phil Ochs, on the Second System Effect');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Be regular and orderly in your life, so that you may be violent<BR>\nand original in your work.<BR>\n&nbsp;-- Flaubert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Actor			Real Name<BR>\n&nbsp;Boris Karloff		William Henry Pratt<BR>\nCary Grant		Archibald Leach<BR>\nEdward G. Robinson	Emmanual Goldenburg<BR>\nGene Wilder		Gerald Silberman<BR>\nJohn Wayne		Marion Morrison<BR>\nKirk Douglas		Issur Danielovitch<BR>\nRichard Burton		Richard Jenkins Jr.<BR>\nRoy Rogers		Leonard Slye<BR>\nWoody Allen		Allen Stewart Konigsberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','&nbsp;A musical reviewer admitted he always praised the first show of a<BR>\nnew theatrical season.  \"Who am I to stone the first cast?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','To be is to do.<BR>\n&nbsp;-- I. Kant<BR>\nTo do is to be.<BR>\n&nbsp;-- A. Sartre<BR>\nDo be a Do Bee!<BR>\n&nbsp;-- Miss Connie, Romper Room<BR>\nDo be do be do!<BR>\n&nbsp;-- F. Sinatra<BR>\nYabba-Dabba-Doo!<BR>\n&nbsp;-- F. Flintstone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It was a book to kill time for those who liked it better dead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Three hours a day will produce as much as a man ought to write.<BR>\n&nbsp;-- Trollope');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','We have art that we do not die of the truth.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','H. L. Mencken suffers from the hallucination that he is H. L. Mencken --<BR>\nthere is no cure for a disease of that magnitude.<BR>\n&nbsp;-- Maxwell Bodenheim');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Watch all-night Donna Reed reruns until your mind resembles oatmeal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Very few people do anything creative after the age of thirty-five.  The<BR>\nreason is that very few people do anything creative before the age of<BR>\nthirty-five.<BR>\n&nbsp;-- Joel Hildebrand');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Use what talents you possess: the woods would be very silent if no birds<BR>\nsang there except those that sang best.<BR>\n&nbsp;-- Henry Van Dyke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Use an accordion.  Go to jail.<BR>\n&nbsp;-- KFOG, San Francisco');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Unprovided with original learning, unformed in the habits of thinking,<BR>\nunskilled in the arts of composition, I resolved to write a book.<BR>\n&nbsp;-- Edward Gibbon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','TV is chewing gum for the eyes.<BR>\n&nbsp;-- Frank Lloyd Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Truth is stranger than fiction, because fiction has to make sense.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','GREAT MOMENTS IN AMERICAN HISTORY (#17):<BR>\n&nbsp;On November 13, Felix Unger was asked to remove himself from his place<BR>\nof residence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Hummingbirds never remember the words to songs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Writing about music is like dancing about architecture.<BR>\n&nbsp;-- Frank Zappa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Would it help if I got out and pushed?<BR>\n&nbsp;-- Princess Leia Organa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Life is like arriving late for a movie, having to figure out what was<BR>\ngoing on without bothering everybody with a lot of questions, and then<BR>\nbeing unexpectedly called away before you find out how it ends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','When one woman was asked how long she had been going to symphony concerts,<BR>\nshe paused to calculate and replied, \"Forty-seven years -- and I find I mind<BR>\nit less and less.\"<BR>\n&nbsp;-- Louise Andrews Kent');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Hi Jimbo.  Dennis.  Really appreciate the help on the income tax.  You wanna<BR>\nhelp on the audit now?<BR>\n&nbsp;-- \"The Rockford Files\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Being disintegrated makes me ve-ry an-gry!\" <huff, huff>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Actors will happen even in the best-regulated families.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','When in doubt, have a man come through the door with a gun in his hand.<BR>\n&nbsp;-- Raymond Chandler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','When confronted by a difficult problem, you can solve it more easily by<BR>\nreducing it to the question, \"How would the Lone Ranger handle this?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','JOHN PAUL ELECTED POPE!!<BR>\n&nbsp;(George and Ringo miffed.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','When all else fails, try Kate Smith.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','What garlic is to food, insanity is to art.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','What ever happened to happily ever after?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','&nbsp;\"What do you do when your real life exceeds your wildest fantasies?\"<BR>\n&nbsp;\"You keep it to yourself.\"<BR>\n&nbsp;-- Broadcast News');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Hello,\" he lied.<BR>\n&nbsp;-- Don Carpenter, quoting a Hollywood agent');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','What an author likes to write most is his signature on the back of a cheque.<BR>\n&nbsp;-- Brendan Francis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','What an artist dies with me!<BR>\n&nbsp;-- Nero');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','He was a fiddler, and consequently a rogue.<BR>\n&nbsp;-- Jonathon Swift');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Wharbat darbid yarbou sarbay?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Well, that was a piece of cake, eh K-9?\"<BR>\n&nbsp;\"Piece of cake, Master?  Radial slice of baked confection ... coefficient of<BR>\nrelevance to Key of Time: zero.\"<BR>\n&nbsp;-- Dr. Who');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','James Joyce -- an essentially private man who wished his total<BR>\nindifference to public notice to be universally recognized.<BR>\n&nbsp;-- Tom Stoppard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','He played the king as if afraid someone else would play the ace.<BR>\n&nbsp;-- John Mason Brown, drama critic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Worth seeing?  Yes, but not worth going to see.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Working with Julie Andrews is like getting hit over the head with a valentine.<BR>\n&nbsp;-- Christopher Plummer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','How wonderful opera would be if there were no singers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Benson, you are so free of the ravages of intelligence\"<BR>\n&nbsp;-- Time Bandits');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A diva who specializes in risque arias is an off-coloratura soprano.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Why you say you no bunny rabbit when you have little powder-puff tail? <BR>\n&nbsp;-- The Tasmanian Devil');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Lensmen eat Jedi for breakfast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Why do we have two eyes?  To watch 3-D movies with.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','&nbsp;Why are you doing this to me?<BR>\n&nbsp;Because knowledge is torture, and there must be awareness before<BR>\nthere is change.<BR>\n&nbsp;-- Jim Starlin, \"Captain Marvel\", #29');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Holy Dilemma!  Is this the end for the Caped Crusader and the Boy Wonder?<BR>\nWill the Joker and the Riddler have the last laugh?<BR>\n&nbsp;Tune in again tomorrow:<BR>\n&nbsp;same Bat-time, same Bat-channel!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Why am I so soft in the middle when the rest of my life is so hard?<BR>\n&nbsp;-- Paul Simon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Who was that masked man?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Who is W.O. Baker, and why is he saying those terrible things about me?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Who is John Galt?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Who is D.B. Cooper, and where is he now?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Hoaars-Faisse Gallery presents:<BR>\nAn exhibit of works by the artist known only as Pretzel.<BR>\n&nbsp;The exhibit includes several large conceptual works using non-traditional<BR>\nmedia and found objects including old sofa-beds, used mace canisters,<BR>\ndiscarded sanitary napkins and parts of freeways.  The artist explores<BR>\nour dehumanization due to high technology and unresponsive governmental<BR>\nstructures in a post-industrial world.  She/he (the artist prefers to<BR>\nremain without gender) strives to create dialogue between viewer and<BR>\ncreator, to aid us in our quest to experience contemporary life with its<BR>\ninner-city tensions, homelessness, global warming and gender and<BR>\nclass-based stress.  The works are arranged to lead us to the essence of<BR>\nthe argument: that the alienation of the person/machine boundary has<BR>\nsapped the strength of our voices and must be destroyed for society to<BR>\nexist in a more fundamental sense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A poet who reads his verse in public may have other nasty habits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Many of the characters are fools and they are always playing<BR>\ntricks on me and treating me badly.<BR>\n&nbsp;-- Jorge Luis Borges, from \"Writers on Writing\" by Jon Winokur');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I believe that the moment is near when by a procedure of active paranoiac<BR>\nthought, it will be possible to systematize confusion and contribute to the<BR>\ntotal discrediting of the world of reality.<BR>\n&nbsp;-- Salvador Dali');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I am a deeply superficial person.<BR>\n&nbsp;-- Andy Warhol');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I always had a repulsive need to be something more than human.<BR>\n&nbsp;-- David Bowie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','BS:	You remind me of a man.<BR>\nB:	What man?<BR>\nBS:	The man with the power.<BR>\nB:	What power?<BR>\nBS:	The power of voodoo.<BR>\nB:	Voodoo?<BR>\nBS:	You do.<BR>\nB:	Do what?<BR>\nBS:	Remind me of a man.<BR>\nB:	What man?<BR>\nBS:	The man with the power...<BR>\n&nbsp;-- Cary Grant, \"The Bachelor and the Bobby-Soxer\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Adding sound to movies would be like putting lipstick on the Venus de Milo.<BR>\n&nbsp;-- actress Mary Pickford, 1925');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Love thy neighbor, tune thy piano.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Naked children have never played in _o_u_r fountains, and I.M. Pei will<BR>\nnever be happy on Route 66.<BR>\n&nbsp;-- \"Learning from Las Vegas\", Robert Venturi, Denise Scott<BR>\n&nbsp;Brown, and Steven Izenour');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I accept chaos.  I am not sure whether it accepts me.  I know some people<BR>\nare terrified of the bomb.  But then some people are terrified to be seen<BR>\ncarrying a modern screen magazine.  Experience teaches us that silence<BR>\nterrifies people the most.<BR>\n&nbsp;-- Bob Dylan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Live fast, die young, and leave a good looking corpse.<BR>\n&nbsp;-- James Dean');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Yevtushenko has... an ego that can crack crystal at a distance of twenty feet.<BR>\n&nbsp;-- John Cheever');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Humpty Dumpty was pushed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','X-rated movies are all alike ... the only thing they leave to the<BR>\nimagination is the plot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Writing free verse is like playing tennis with the net down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','No house should ever be on any hill or on anything.  It should be of the hill,<BR>\nbelonging to it.<BR>\n&nbsp;-- Frank Lloyd Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','No Civil War picture ever made a nickel.<BR>\n&nbsp;-- MGM executive Irving Thalberg to Louis B. Mayer about<BR>\n&nbsp;film rights to \"Gone With the Wind\".<BR>\n&nbsp;Cerf/Navasky, \"The Experts Speak\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','My tears stuck in their little ducts, refusing to be jerked.<BR>\n&nbsp;-- Peter Stack, movie review<BR>\n&nbsp;His performance is so wooden you want to spray him with Liquid Pledge.<BR>\n&nbsp;-- John Stark, movie review');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I have a very strange feeling about this...<BR>\n&nbsp;-- Luke Skywalker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"My life is a soap opera, but who has the rights?\"<BR>\n&nbsp;-- MadameX');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','My band career ended late in my senior year when John Cooper and I threw my<BR>\namplifier out the dormitory window.  We did not act in haste. First we<BR>\nchecked to make sure the amplifier would fit through the frame, using the<BR>\nbelt from my bathrobe to measure, then we picked up the amplifier and backed<BR>\nup to my bedroom door.  Then we rushed forward, shouting \"The WHO!  The<BR>\nWHO!\" and we launched my amplifier perfectly, as though we had been doing it<BR>\nall our lives, clean through the window and down onto the sidewalk, where a<BR>\nsmall but appreciative crowd had gathered.  I would like to be able to say<BR>\nthat this was a symbolic act, an effort on my part to break cleanly away<BR>\nfrom one state in my life and move on to another, but the truth is, Cooper<BR>\nand I really just wanted to find out what it would sound like.  It sounded<BR>\nOK.<BR>\n&nbsp;-- Dave Barry, \"The Snake\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I had another dream the other day about music critics.  They were small<BR>\nand rodent-like with padlocked ears, as if they had stepped out of a<BR>\npainting by Goya.<BR>\n&nbsp;-- Stravinsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','But you shall not escape my iambics.<BR>\n&nbsp;-- Gaius Valerius Catullus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Modern art is what happens when painters stop looking at girls and persuade<BR>\nthemselves that they have a better idea.<BR>\n&nbsp;-- John Ciardi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Minnie Mouse is a slow maze learner.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Mike:	\"The Fourth Dimension is a shambles?\"<BR>\nBernie:	\"Nobody ever empties the ashtrays.  People are SO inconsiderate.\"<BR>\n&nbsp;-- Gary Trudeau, \"Doonesbury\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Might as well be frank, monsieur.  It would take a miracle to get you out<BR>\nof Casablanca and the Germans have outlawed miracles.<BR>\n&nbsp;-- Casablanca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','But if you wish at once to do nothing and to be respectable<BR>\nnowdays, the best pretext is to be at work on some profound study.<BR>\n&nbsp;-- Leslie Stephen, \"Sketches from Cambridge\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Adhere to your own act, and congratulate yourself if you have done something<BR>\nstrange and extravagant, and broken the monotony of a decorous age.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The typewriting machine, when played with expression, is no more<BR>\nannoying than the piano when played by a sister or near relation.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The ultimate game show will be the one where somebody gets killed at the end.<BR>\n&nbsp;-- Chuck Barris, creator of \"The Gong Show\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','It is a sobering thought that when Mozart was my age, he had been<BR>\ndead for two years.<BR>\n&nbsp;-- Tom Lehrer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','In just seven days, I can make you a man!<BR>\n&nbsp;-- The Rocky Horror Picture Show');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Where is John Carson now that we need him?<BR>\n&nbsp;-- RLG');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','FORTUNE DISCUSSES THE OBSCURE FILMS: #5<BR>\n&nbsp;THE ATOMIC GRANDMOTHER:<BR>\n&nbsp;This humorous but heart-warming story tells of an elderly woman<BR>\n&nbsp;forced to work at a nuclear power plant in order to help the family<BR>\n&nbsp;make ends meet.  At night, granny sits on the porch, tells tales<BR>\n&nbsp;of her colorful past, and the family uses her to cook barbecues<BR>\n&nbsp;and to power small electrical appliances.  Maureen Stapleton gives<BR>\n&nbsp;a glowing performance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Oprah Winfrey has an incredible talent for getting the weirdest people to<BR>\ntalk to.  And you just HAVE to watch it.  \"Blind, masochistic minority,<BR>\ncrippled, depressed, government latrine diggers, and the women who love<BR>\nthem too much on the next Oprah Winfrey.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Television is now so desperately hungry for material that it is scraping<BR>\nthe top of the barrel.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Television is a medium because anything well done is rare.<BR>\n&nbsp;-- attributed to both Fred Allen and Ernie Kovacs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"First things first -- but not necessarily in that order\"<BR>\n&nbsp;-- The Doctor, \"Doctor Who\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Television has proved that people will look at anything rather than each other.<BR>\n&nbsp;-- Ann Landers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Television has brought back murder into the home -- where it belongs.<BR>\n&nbsp;-- Alfred Hitchcock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Tallulah Bankhead barged down the Nile last night as Cleopatra and sank.<BR>\n&nbsp;-- John Mason Brown, drama critic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Television -- the longest amateur night in history.<BR>\n&nbsp;-- Robert Carson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A writer is congenitally unable to tell the truth and that is why we call<BR>\nwhat he writes fiction.<BR>\n&nbsp;-- William Faulkner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The Great Movie Posters:<BR>\n&nbsp;HOT STEEL BETWEEN THEIR LEGS!<BR>\n&nbsp;-- The Cycle Savages (1969)<BR>\n&nbsp;The Hand that Rocks the Cradle...   Has no Flesh on It!<BR>\n&nbsp;-- Who Slew Auntie Roo? (1971)<BR>\n&nbsp;TWO GREAT BLOOD HORRORS TO RIP OUT YOUR GUTS!<BR>\n&nbsp;-- I Eat Your Skin & I Drink Your Blood (1971 double-bill)<BR>\n&nbsp;They Went In People and Came Out Hamburger!<BR>\n&nbsp;-- The Corpse Grinders (1971)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A drama critic is a person who surprises a playwright by informing him<BR>\nwhat he meant.<BR>\n&nbsp;-- Wilson Mizner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Talking about music is like dancing about architecture.<BR>\n&nbsp;-- Laurie Anderson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Fame lost its appeal for me when I went into a public restroom and an<BR>\nautograph seeker handed me a pen and paper under the stall door.<BR>\n&nbsp;-- Marlo Thomas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Some performers on television appear to be horrible people, but when<BR>\nyou finally get to know them in person, they turn out to be even worse.<BR>\n&nbsp;-- Avery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','\"Spare no expense to save money on this one.\"<BR>\n&nbsp;-- Samuel Goldwyn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The first thing I do in the morning is brush my teeth and sharpen my tongue.<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is a lie which makes us realize the truth.<BR>\n&nbsp;-- Picasso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A true artist will let his wife starve, his children go barefoot, his mother<BR>\ndrudge for his living at seventy, sooner than work at anything but his art.<BR>\n&nbsp;-- Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I WISH I HAD A KRYPTONITE CROSS, because then you could keep both Dracula<BR>\nand Superman away.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Snakes.  Why did it have to be snakes?<BR>\n&nbsp;-- Indiana Jones, \"Raiders of the Lost Ark\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I went to a Grateful Dead Concert and they played for SEVEN hours.  Great song.<BR>\n&nbsp;-- Fred Reuss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If I had any humility I would be perfect.<BR>\n&nbsp;-- Ted Turner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Skill without imagination is craftsmanship and gives us many useful objects<BR>\nsuch as wickerwork picnic baskets.  Imagination without skill gives us modern<BR>\nart.<BR>\n&nbsp;-- Tom Stoppard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The chief enemy of creativity is \"good\" sense<BR>\n&nbsp;-- Picasso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The capacity of human beings to bore one another seems to be vastly<BR>\ngreater than that of any other animals.  Some of their most esteemed<BR>\ninventions have no other apparent purpose, for example, the dinner party<BR>\nof more than two, the epic poem, and the science of metaphysics.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Any dramatic series the producers want us to take seriously as a representation<BR>\nof contemporary reality cannot be taken seriously as a representation of<BR>\nanything -- except a show to be ignored by anyone capable of sitting upright<BR>\nin a chair and chewing gum simultaneously.<BR>\n&nbsp;-- Richard Schickel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Show business is just like high school, except you get paid.<BR>\n&nbsp;-- Martin Mull');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','She was good at playing abstract confusion in the same way a midget is<BR>\ngood at being short.<BR>\n&nbsp;-- Clive James, on Marilyn Monroe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Eeny, Meeny, Jelly Beanie, the spirits are about to speak!<BR>\n&nbsp;-- Bullwinkle Moose');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Satire is what closes Saturday night.<BR>\n&nbsp;-- George Kaufman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Satire is what closes in New Haven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If life is a stage, I want some better lighting.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Ed Sullivan will be around as long as someone else has talent.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I stick my neck out for nobody.<BR>\n&nbsp;-- Humphrey Bogart, \"Casablanca\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Satire is tragedy plus time.<BR>\n&nbsp;-- Lenny Bruce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I stopped believing in Santa Claus when I was six.  Mother took me to<BR>\nsee him in a department store and he asked for my autograph.<BR>\n&nbsp;-- Shirley Temple');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Playing an unamplified electric guitar is like strumming on a picnic table.<BR>\n&nbsp;-- Dave Barry, \"The Snake\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A copy of the universe is not what is required of art; one of the damned<BR>\nthings is ample.<BR>\n&nbsp;-- Rebecca West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Dustin Farnum:	Why, yesterday, I had the audience glued to their seats!<BR>\nOliver Herford:	Wonderful!  Wonderful!  Clever of you to think of it!<BR>\n&nbsp;-- Brian Herbert, \"Classic Comebacks\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The Angels want to wear my red shoes.<BR>\n&nbsp;-- E. Costello');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','So do the noble fall.  For they are ever caught in a trap of their own making.<BR>\nA trap -- walled by duty, and locked by reality.  Against the greater force<BR>\nthey must fall -- for, against that force they fight because of duty, because<BR>\nof obligations.  And when the noble fall, the base remain.  The base -- whose<BR>\nonly purpose is the corruption of what the noble did protect.  Whose only<BR>\npurpose is to destroy.  The noble: who, even when fallen, retain a vestige of<BR>\nstrength.  For theirs is a strength born of things other than mere force.<BR>\nTheirs is a strength supreme... theirs is the strength -- to restore.<BR>\n&nbsp;-- Gerry Conway, \"Thor\", #193');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Dying is easy.  Comedy is difficult.<BR>\n&nbsp;-- Actor Edmond Gween, on his deathbed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I saw Lassie.  It took me four shows to figure out why the hairy kid never<BR>\nspoke. I mean, he could roll over and all that, but did that deserve a series?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','An artist should be fit for the best society and keep out of it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Fools rush in -- and get the best seats in the house.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Perhaps no person can be a poet, or even enjoy poetry without a certain<BR>\nunsoundness of mind.<BR>\n&nbsp;-- Thomas Macaulay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Snow White has become a camera buff.  She spends hours and hours<BR>\nshooting pictures of the seven dwarfs and their antics.  Then she<BR>\nmails the exposed film to a cut rate photo service.  It takes weeks<BR>\nfor the developed film to arrive in the mail, but that is all right<BR>\nwith Snow White.  She clears the table, washes the dishes and sweeps<BR>\nthe floor, all the while singing \"Someday my prints will come.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','People in general do not willingly read if they have anything else to<BR>\namuse them.<BR>\n&nbsp;-- S. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Any fool can paint a picture, but it takes a wise person to be able to sell it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A team effort is a lot of people doing what I say.<BR>\n&nbsp;-- Michael Winner, British film director');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I never made a mistake in my life.  I thought I did once, but I was wrong.<BR>\n&nbsp;-- Lucy Van Pelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Did you know that the voice tapes easily identify the Russian pilot<BR>\nthat shot down the Korean jet?  At one point he definitely states:<BR>\n&nbsp;\"Natasha!  First we shoot jet, then we go after moose and squirrel.\"<BR>\n&nbsp;-- ihuxw!tommyo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Everyone is in the best seat.<BR>\n&nbsp;-- John Cage');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','All art is but imitation of nature.<BR>\n&nbsp;-- Lucius Annaeus Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Notes for a ballet, \"The Spell\": ... Suddenly Sigmund hears the flutter of<BR>\nwings, and a group of wild swans flies across the moon ... Sigmund is<BR>\nastounded to see that their leader is part swan and part woman --<BR>\nunfortunately, divided lengthwise.  She enchants Sigmund, who is careful<BR>\nnot to make any poultry jokes.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I never failed to convince an audience that the best thing they<BR>\ncould do was to go away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Not all who own a harp are harpers.<BR>\n&nbsp;-- Marcus Terentius Varro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I have more humility in my little finger than you have in your whole ____BODY!<BR>\n&nbsp;-- from \"Cerebus\" #82');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','7:30, Channel 5: The Bionic Dog (Action/Adventure)<BR>\n&nbsp;The Bionic Dog drinks too much and kicks over the National<BR>\n&nbsp;Redwood Forest.<BR>\n&nbsp;7:30, Channel 8: The Bionic Dog (Action/Adventure)<BR>\n&nbsp;The Bionic Dog gets a hormonal short-circuit and violates the<BR>\n&nbsp;Mann Act with an interstate Greyhound bus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','No two persons ever read the same book.<BR>\n&nbsp;-- Edmund Wilson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','A \"critic\" is a man who creates nothing and thereby feels qualified to judge<BR>\nthe work of creative men. There is logic in this; he is unbiased -- he hates<BR>\nall creative people equally.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I knew her before she was a virgin.<BR>\n&nbsp;-- Oscar Levant, on Doris Day');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The faster we go, the rounder we get.<BR>\n&nbsp;-- The Grateful Dead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Noone ever built a statue to a critic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Darth Vader!  Only you would be so bold!<BR>\n&nbsp;-- Princess Leia Organa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Rembrandt is not to be compared in the painting of character with our<BR>\nextraordinarily gifted English artist, Mr. Rippingille.<BR>\n&nbsp;-- John Hunt, British editor, scholar and art critic<BR>\n&nbsp;Cerf/Navasky, \"The Experts Speak\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Nobody can be exactly like me.  Sometimes even I have trouble doing it.<BR>\n&nbsp;-- Tallulah Bankhead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','NOBODY EXPECTS THE SPANISH INQUISITION!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','If dolphins are so smart, why did Flipper work for television?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','For the next hour, WE will control all that you see and hear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','E.T. GO HOME!!!  (And take your Smurfs with you.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Publishing a volume of verse is like dropping a rose petal down the<BR>\nGrand Canyon and waiting for the echo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Public use of any portable music system is a virtually guaranteed indicator<BR>\nof sociopathic tendencies.<BR>\n&nbsp;-- Zoso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I suggest a new strategy, Artoo: let the Wookie win.<BR>\n&nbsp;-- C3P0');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Darth Vader sleeps with a Teddywookie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Art is a jealous mistress.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The difference between waltzes and disco is mostly one of volume.<BR>\n&nbsp;-- T.K.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Once, I read that a man be never stronger than when he truly realizes how<BR>\nweak he is.<BR>\n&nbsp;-- Jim Starlin, \"Captain Marvel #31\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Alex Haley was adopted!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Rascal, am I?  Take THAT!<BR>\n&nbsp;-- Errol Flynn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Pure drivel tends to drive ordinary drivel off the TV screen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','&nbsp;\"I suppose you expect me to talk.\"<BR>\n&nbsp;\"No, Mr. Bond.  I expect you to die.\"<BR>\n&nbsp;-- Goldfinger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Disco is to music what Etch-A-Sketch is to art.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Old musicians never die, they just decompose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Old MacDonald had an agricultural real estate tax abatement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','I often quote myself; it adds spice to my conversation.<BR>\n&nbsp;-- G. B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','Prizes are for children.<BR>\n&nbsp;-- Charles Ives, upon being given, but refusing, the<BR>\n&nbsp;Pulitzer prize');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','The covers of this book are too far apart.<BR>\n&nbsp;-- Book review by Ambrose Bierce.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('art','One big pile is better than two little piles.<BR>\n&nbsp;-- Arlo Guthrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"So, you doing anything special?\"<BR>\n\"Tree. Nog. Roast beast. Just me and Mom and hopefully an excess of gifts.<BR>\n&nbsp;What are you doing for Christmas?\"<BR>\n\"Being Jewish. Remember, people? Not everybody worships Santa.\"<BR>\n&nbsp;-- Xander, Buffy, and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"The fact is, there is talk in the council that you have become a bit<BR>\n&nbsp;too... American.\"<BR>\n\"Me?\"<BR>\n\"Him?\"<BR>\n&nbsp;-- Gwendolyn Post, Giles, and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Buffy, Im thrown by this, Im confused... - But I can feel my skin<BR>\n&nbsp;humming, my hands, my every inch of me. Ive never been this excited about<BR>\n&nbsp;anybody before. Im not trying to scare you, and Im not going to force<BR>\n&nbsp;myself on you. But Im, by God, not going to walk away because I think it<BR>\n&nbsp;might not work.\"<BR>\n&nbsp;-- Riley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Think of the happy. If we dont find what were looking for, we face an<BR>\n&nbsp;apocalypse.\"<BR>\n\"Really? Youre not just saying that?\"<BR>\n&nbsp;-- Xander and Spike');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"What are you, retarded?\"<BR>\n\"No! No, I had to take that test when I was seven. A little slow in some<BR>\n&nbsp;stuff, mostly math and spatial relations, but certainly not challenged or<BR>\n&nbsp;anything.\"<BR>\n&nbsp;-- Jack, student at Sunnydale, and Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I thought a professional demon chaser like yourself would have figured it<BR>\n&nbsp;out by now. - Im the Slayer. Slay-er? - Chosen One. She who hangs out a<BR>\n&nbsp;lot in cemeteries? - Youre kidding. Ask around. Look it up: Slayer comma<BR>\n&nbsp;the.\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"What are you?\"<BR>\n\"Capricorn on the cusp of Aquarius. You?\"<BR>\n&nbsp;-- Riley and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Its kind of the CBS logo. Hey, could this be the handiwork of one Mr.<BR>\n&nbsp;Morley Safer?\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Ooh, and something else. He, the dead guy, was-was propped up, like<BR>\n&nbsp;whatever killed him wanted to drain the blood out of him. So Im thinking<BR>\n&nbsp;the whatever took a bunch of the guys blood with it. And I havent been a<BR>\n&nbsp;nerd for a very long time! Hello dating a guitarist, - or I - was.\"<BR>\n&nbsp;-- Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I have stuff in my locker. Henbane, hellebore, mandrake root.\"<BR>\n\"Excuse me. Playboys. Can we turn the sympathy this way?\"<BR>\n&nbsp;-- Willow and Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I swear, I am just trying to find my necklace.\"<BR>\n\"Well, did you try looking inside the sofa in Hell?\"<BR>\n&nbsp;-- Anya and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Willow, did you remember to tape Biography last Friday?\"<BR>\n\"Uh-huh.\"<BR>\n\"See, I told you. Old Reliable.\"<BR>\n&nbsp;-- Xander, Willow, and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"No Slayer of mine is gonna live in a fleabag hotel. That place has a very<BR>\n&nbsp;unsavory reputation. There are immoral liaisons going on there.\"<BR>\n\"Yeah, plus all the screwing. This place is the kick!\"<BR>\n&nbsp;-- Mayor Wilkins and Faith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Ow!\"<BR>\n\"Oh! Sorry!\"<BR>\n\"Oh, right. Bloody priceless.\"<BR>\n&nbsp;-- Giles and Buffy, after Buffy accidentally shoots Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Is he evil?\"<BR>\n\"Not in the strictest sense.\"<BR>\n&nbsp;-- Buffy and Giles, talking about Wesley, the new Watcher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Scott? There you are, honey!  Hey, good news.  The doctor says that the<BR>\n&nbsp;itching and the swelling and the burning should clear up, but we gotta<BR>\n&nbsp;keep using the ointment.\"<BR>\n&nbsp;-- Faith, after Scott dumps Buffy before prom and goes with another girl');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"No one else exists either. Buffy is all of us. We think therefore she exists.\"<BR>\n&nbsp;-- Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I am my thoughts. If they exist in her, Buffy contains everything that is<BR>\n&nbsp;me and she becomes me and I cease to exist. Hmm.\"<BR>\n&nbsp;-- Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"What am I gonna do? I think about sex all the time. Sex! Help! 4 times 5<BR>\n&nbsp;is 30. 5 times 6 is 32. Naked girls! Naked woman! Naked Buffy! Oh, stop<BR>\n&nbsp;me!\"<BR>\n\"God Xander! Is that all you think about?!\"<BR>\n\"Actually.....bye!\"<BR>\n&nbsp;-- Xander and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Twenty-eight bucks. Does the Council reimburse for that kind of stuff?\"<BR>\n\"Did you get a receipt?\"<BR>\n\"Damn.\"<BR>\n&nbsp;-- Xander and Giles, talking about the money Xander used to bride Willy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Demons after money. Whatever happened to the still beating heart of a<BR>\n&nbsp;virgin? No one has any standards anymore.\"<BR>\n&nbsp;-- Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Be quiet! Sorry, but, but this is important. Talk to everyone on your<BR>\n&nbsp;list. And use the sample questions....... Today people!....Oh, write<BR>\n&nbsp;neatly. And label your worksheet.\"<BR>\n&nbsp;-- Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Oh, ugh...\"<BR>\n\"Oh, bloody hell!\"<BR>\n\"Spike lips! Lips of Spike!\"<BR>\n&nbsp;-- Buffy and Spike');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Peace of Westphalia.\"<BR>\n\"Uh, yalta?\"<BR>\n\"Oh, you moron. That dinette set should be mine.\"<BR>\n&nbsp;-- Giles and a Contestant and TV');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Thats right. Im back. And Im a BLOODY ANIMAL! Yeah!\"<BR>\n&nbsp;-- Spike');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Ewww! Who left their gum here?\"<BR>\n\"Gum gnome?\"<BR>\n&nbsp;-- Kathy and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Well, I guess we have to talk.\"<BR>\n\"I guess we do.\"<BR>\n&nbsp;-- Riley and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I myself am dipping into my road trip fund to procure a shiny new tux, so<BR>\n&nbsp;look for me to dazzle.\"<BR>\n\"And I myself will be wearing pink taffeta as chenille would not go with<BR>\n&nbsp;my complection. Can we please talk about the Ascension?\"<BR>\n&nbsp;-- Xander and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I think I should work with Wesley.\"<BR>\n\"You have no shame.\"<BR>\n\"Oh, please. Like shame is something to be proud of.\"<BR>\n&nbsp;-- Cordy and Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Hi Mr. Beech. I was just wondering, were you planning on killing a bunch<BR>\n&nbsp;of people tomorrow? Oh, its for the yearbook!\"<BR>\n&nbsp;-- Cordy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"You took your roommate patrolling with you?\"<BR>\n\"Well I invited the whole dorm, but she was the only one that could make it.\"<BR>\n&nbsp;-- Giles and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Of course. I wish Id thought of that before I put down my deposit. I<BR>\n&nbsp;could have been God.\"<BR>\n\"Blasphemer.\"<BR>\n&nbsp;-- Xander and Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Is there something you want to tell me?\"<BR>\n\"What? Oh, yes, I am a lesbian.\"<BR>\n&nbsp;-- Buffy and Riley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Whats this? Sitting around watching the telly while theres evil still a<BR>\n&nbsp;foot.  Thats not very industrious of you. I say we go out there and kick<BR>\n&nbsp;a little demon ass! What, cant go without your Buffy, is that it? Too<BR>\n&nbsp;chicken? Lets find her! She is the Chosen One after all.  Come on!<BR>\n&nbsp;Vampires! Grrr! Nasty! Lets annihilate them. For justice - and for - the<BR>\n&nbsp;safety of puppies  and Christmas, right? Lets fight that evil! - Lets<BR>\n&nbsp;kill something!  Oh, come on!\"<BR>\n&nbsp;-- Spike');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Shut up, repressed crybabies!\"<BR>\n&nbsp;-- Anya');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Looks like a job for Wiccan girl. What do you say, Will? Big time danger.\"<BR>\n\"Hey, I eat danger for breakfast.\"<BR>\n\"But oddly enough, she panics in the face of breakfast foods.\"<BR>\n&nbsp;-- Buffy, Willow and Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Holy moley.\"<BR>\n\"I know.\"<BR>\n\"I totally get it now.  Can I have sex with Riley too?\"<BR>\n&nbsp;-- Xander and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Spiritus... spirit.\"<BR>\n\"Animus... heart.\"<BR>\n\"Sophus... mind.\"<BR>\n\"And Manus... the hand.\"<BR>\n&nbsp;-- Willow, Xander and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"We enjoin that we may inhabit the vessel.  The hand, daughter of Sineya,<BR>\n&nbsp;first of the Ones.\"<BR>\n&nbsp;-- Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Giles, do you have a Jonathan swimsuit calendar?\"<BR>\n\"No... Yes.  It was a gift.\"<BR>\n&nbsp;-- Buffy and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"We implore thee.  Admit us.  Bring us to the vessel.  Take us- now!\"<BR>\n&nbsp;-- Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Every inch of this installation is under constant twenty-four hour<BR>\n&nbsp;surveillance!\"<BR>\n\"Including the secret lab?\"<BR>\n\"Including everything! ... What secret lab?\"<BR>\n&nbsp;-- McNamara and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Slap my hand now!\"<BR>\n\"Beg your pardon?\"<BR>\n\"In celebration.\"<BR>\n\"Oh... Yes.\"<BR>\n\"Ow!\"<BR>\n&nbsp;-- Anya and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Angel was in your bedroom?\"<BR>\n\"Ours is a forbidden love.\"<BR>\n&nbsp;-- Xander and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Angel was in your bedroom?\"<BR>\n\"Ours is a forbidden love.\"<BR>\n&nbsp;-- Xander and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Goody! Research party!\"<BR>\n\"Will, you need a life in the worst way.\"<BR>\n&nbsp;-- Willow and Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Angel, there must be some part of you inside that still remembers who you<BR>\n&nbsp;are.\"<BR>\n\"Dream on, schoolgirl.\"<BR>\n&nbsp;-- Buffy and Angelus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Passion. It lies in all of us. Sleeping... waiting... And though<BR>\n&nbsp;unwanted... unbidden... it will stir... open its jaws, and howl. It<BR>\n&nbsp;speaks to us... guides us... Passion rules us all. And we obey. What other choice<BR>\n&nbsp;do we have?\"<BR>\n&nbsp;-- Angelus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"All I can think is, it coulda been me!\"<BR>\n\"We can dream.\"<BR>\n&nbsp;-- Cordelia and Xander talking after a student is murdered');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Cool! Crossbow! uh. Check out these babies. Hmm. Goodbye stakes, hello<BR>\n&nbsp;flying fatality. What can I shoot?\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I was ten years old when my father told me I was destined to be a<BR>\n&nbsp;Watcher. He was one, and his, uh, mother before him, and I was to be<BR>\n&nbsp;next.\"<BR>\n\"Were you thrilled beyond all measure?\"<BR>\n\"No, I had very definite plans about my future. I was going to be a<BR>\n&nbsp;fighter pilot. Or possibly a grocer, well, uh... My father gave me a very<BR>\n&nbsp;tiresome speech about, uh, responsibility and sacrifice.\"<BR>\n&nbsp;-- Giles and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"This type of creatuere, the Kleptes-Virgo or virginthief, appears in many<BR>\n&nbsp;cultures: the Greek Sirens, the Celtic seamaidens who tore the living<BR>\n&nbsp;flesh from the bones of. . . .\"<BR>\n&nbsp;-- Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Can I just say one thing? HEEELLLLPPP!\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"This is madness! What can you have been thinking? You are the Slayer!<BR>\n&nbsp;Lives depend upon you! (begins pacing) I make allowances for your youth,<BR>\n&nbsp;but I expect a certain amount of responsibility, and instead of which you<BR>\n&nbsp;enslave yourself to this, this... Cult?\"<BR>\n&nbsp;-- Giles lecturing Buffy about cheerleading');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I mean, the dead rose. We should at least have an assembly.\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"And I, in the meantime, will help by standing around like an idiot.\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Yeah. You know, I kinda had a problem with the math.\"<BR>\n\"Uh, which part?\"<BR>\n\"The math. Can you help me out tonight, pleeeease, be my study buddy?\"<BR>\n&nbsp;-- Xander and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"For I am Xander, King of Cretins. May all lesser cretins bow before me.\"<BR>\n&nbsp;-- Xander, after sticking his foot in his mouth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Can I just mention, that detention is a time-honored form of punishment?\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Being this popular is not just my right, but my responsibility, and I<BR>\n&nbsp;want you to know I take it very seriously.\"<BR>\n&nbsp;-- Cordelia, being her usual snobby self');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I wonder where Ive seen this before? Where else? The place I spend most<BR>\n&nbsp;of my waking hours memorizing stuff of the sides of mausoleums, big<BR>\n&nbsp;freaky cereal boxes of death.\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Anyways, I think that the boys in the car are contained for the time<BR>\n&nbsp;being. This will give them some time to ponder the geo-political<BR>\n&nbsp;ramifications of BEING MEAN TO ME!\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Im just trying to  make up my mind about something. - Buffy, - shes<BR>\n&nbsp;pretty cool, isnt she?\"<BR>\n\"Yes already, shes cool, shes hot, she is tepid, shes all temperature<BR>\n&nbsp;Buffy. Now can we concentrate on the game here?\"<BR>\n&nbsp;-- Riley and Forrest');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"This... guy. Dark, gorgeous in an annoying sort of way. I figured you two<BR>\n&nbsp;were buds.\"<BR>\n&nbsp;-- Buffy speaking about meeting Angel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"That was bracing.\"<BR>\n\"Interesting lady. Can we kill her?\"<BR>\n\"I think the council might frown upon that.\"<BR>\n&nbsp;-- Giles and Buffy, talking about Gwendolyn Post');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"To read makes our speaking English good.\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I wasnt scared, I was in the spirit.\"<BR>\n\"And we back you up on that. Even if they question us separately.\"<BR>\n&nbsp;-- Xander and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"First vampires, now witches. No wonder you can still afford a house in<BR>\n&nbsp;Sunnydale.\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Why should someone want to harm Cordelia?\"<BR>\n\"Maybe because they met her? Did I say that?\"<BR>\n&nbsp;-- Giles and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Okay, next time we split up someone else is on Cordy detail. Five more<BR>\n&nbsp;minutes with her and we woulda had another organ donor.\"<BR>\n&nbsp;-- Xander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Uh, our dreams are coming true?\"<BR>\n\"Dreams? That would be a musical comedy version of this. Nightmares, our,<BR>\n&nbsp;our nightmares are coming true.\"<BR>\n&nbsp;-- Xander and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"You are a lousy clown! Your balloon animals are pathetic! Everyone can<BR>\n&nbsp;make a giraffe!\"<BR>\n&nbsp;-- Xander, facing his fear of the clown from his sixth birthday');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','Neck. Paler. The puppy. The angry puppy.\"<BR>\nYeah, we came to warn you about the - angry puppy.\"<BR>\n&nbsp;-- Buffy and Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Mm. He thought it would behoove me to have more contact with the<BR>\n&nbsp;students. I did try to explain that my vocational choice of librarian was<BR>\n&nbsp;a deliberate attempt to minimize said contact, but, uh, he would have<BR>\n&nbsp;none of it.\"<BR>\n&nbsp;-- Giles, explaining why he was given taleny show duty by Principal Snyder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"See, this is a school, and we have students, and they check out books,<BR>\n&nbsp;and then they learn things.\"<BR>\n\"I was beginning to suspect that was a myth.\"<BR>\n&nbsp;-- Buffy and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Cordelia, your mouth is open and sound is coming from it. This is never good.\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"You have a scar.\"<BR>\n\"Yeah ... right ... angry puppy. So, I get to see any of your scars?\"<BR>\n\"Oh, mine are all psychological.\"<BR>\n&nbsp;-- Parker and Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Every man faces this moment. Here. Now. Watching. Waiting For an unseen<BR>\n&nbsp;enemy that has no face. Nerve endings screaming in silence. Never knowing<BR>\n&nbsp;which thought might be your last.\"<BR>\n\"Oh, shut up.\"<BR>\n&nbsp;-- Xander and Giles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I-I found a ritual to revoke the invitation to vampires.\"<BR>\n\"Oh, thank goodness. I actually had to talk my grandmother into switching<BR>\n&nbsp;cars with me last night.\"<BR>\n&nbsp;-- Giles and Cordelia<BR>\n\"Passion is the source of our finest moments. The joy of love... the<BR>\n&nbsp;clarity of hatred... and the ecstasy of grief.\"<BR>\n&nbsp;-- Angelus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Still, not every dream you have comes true. I mean, what else did you<BR>\n&nbsp;dream last night? Can you remember?\"<BR>\n\"I dreamt... I dreamt that Giles and I opened an office supply warehouse<BR>\n&nbsp;in Vegas.\"<BR>\n\"See my point?\"<BR>\n&nbsp;-- Angel and Buffy, after Buffy has a nightmare in which Angel is killed');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I suppose there is a sort of... Machiavellian ingenuity to your<BR>\n&nbsp;transgression.\"<BR>\n\"I resent that! Or possibly thank you.\"<BR>\n&nbsp;-- Giles and Xander, after they find out Xander boiled his egg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"I had good reason to tink you were. Did I not see you kissing a vampire?\"<BR>\n\"Buffy would never do that! Oh. Except for that sometimes you do that. But<BR>\n&nbsp;only with Angel. Right?\"<BR>\n&nbsp;-- Kendra and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Does this look like a Barnes & Noble?\"<BR>\n\"This is a school library, Xander.\"<BR>\n\"Since when?\"<BR>\n&nbsp;-- Xander and Giles, when some students come into the library');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"You really love Xander?\"<BR>\n\"Well, he kinda grows on you, like... a Chia Pet.\"<BR>\n&nbsp;-- Buffy and Cordy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"A big, expensive limo?\"<BR>\n\"That sounds like fun! And it is our last Homecoming Dance, so maybe we<BR>\n&nbsp;should make a big deal of it.\"<BR>\n\"You wanna talk fun? Public bus. You meet the funnest people.\"<BR>\n&nbsp;-- Xander and Willow, after Cordy suggests renting a limo for Homecoming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"As Willow goes, so goes my nation.\"<BR>\n&nbsp;-- Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Whoa! There are some foxy ladies here tonight!\"<BR>\n&nbsp;-- Snyder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"At first it was fun, you know? They seemed like they were in this really<BR>\n&nbsp;good mood -- not like parents -- and then...\"<BR>\n\"Badness?\"<BR>\n\"Mom started borrowing my clothes. There should be an age limit on lycra<BR>\n&nbsp;pants. And Dad, he just locked himself in the bathroom with old copies of<BR>\n&nbsp;Esquire.\"<BR>\n&nbsp;-- Cordy and Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Oh, no, I have to go take an English makeup exam. They give you credit<BR>\n&nbsp;just for speaking it, right?\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"All right, yes, date and shop and hang out and go to school and save the<BR>\n&nbsp;world from unspeakable demons. You know, I wanna do girlie stuff!\"<BR>\n&nbsp;-- Buffy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('buffy','\"Hi, Scott. What are you doing here?\"<BR>\n\"You told me if I came after 8:00, I could run into Buffy.\"<BR>\n&nbsp;-- Willow and Scott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Those who would repeat the past must control the teaching of history.<BR>\n&nbsp;-Bene Gesserit Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','When I set out to lead humanity along my Golden Path I promised a lesson their <BR>\nbones would remember.  I know a profound pattern humans deny with words even <BR>\nwhile their actions affirm it.  They say they seek security and quiet, <BR>\nconditions they call peace.  Even as they speak, they create seeds of turmoil <BR>\nand violence.<BR>\n&nbsp;-Leto II, the God Emperor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','We tend to become like the worst in those we oppose.<BR>\n&nbsp;-Bene Gesserit Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','You cannot know history unless you know how leaders move with its currents.  <BR>\nEvery leader requires outsiders to perpetuate his leadership.  Examine my <BR>\ncareer:  I was leader and outsider.  Do not assume I merely created a <BR>\nChurch-State.  That was my function as leader and I copied historical models.  <BR>\nBarbaric arts of my time reveal me as outsider.  Favorite poetry:  epics.  <BR>\nPopular dramatic ideal:  heroism.  Dances:  wildly abandoned.  Stimulants to <BR>\nmake people sense what I took from them.  What did I take?  The right to choose <BR>\na role in history.<BR>\n&nbsp;-Leto II (The Tyrant):  Vether Bebe Translation');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Many things we do naturally become difficult only when we try to make them <BR>\nintellectual subjects.  It is possible to know so much about a subject that you <BR>\nbecome totally ignorant.<BR>\n&nbsp;-Mentat Text Two (dicto)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Humans are born with a susceptibility to that most persistent and debilitating <BR>\ndisease of intellect:  self-deception.  The best of all possible worlds and the <BR>\nworst get their dramatic coloration from it.  As nearly as we can determine, <BR>\nthere is no natural immunity.  Constant alertness is required.<BR>\n&nbsp;-The Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Uproot your questions from their ground and the dangling roots will be seen.  <BR>\nMore questions!<BR>\n&nbsp;-Mentat Zensufi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Give me the judgment of balanced minds in preference to laws every time.  Codes <BR>\nand manuals create patterned behavior.  All patterned behavior tends to go <BR>\nunquestioned, gathering destructive momentum.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Major flaws in government arise from a fear of making radical internal changes <BR>\neven though a need is clearly seen.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Time does not count itself.  You have only to look at a circle and this is <BR>\napparent.<BR>\n&nbsp;-Leto II (The Tyrant)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','A major concept guides the Missionaria Protectiva:  Purposeful instruction of <BR>\nthe masses.  This is firmly seated in our belief that the aim of argument <BR>\nshould be to change the nature of truth.  In such matters, we prefer the use of <BR>\npower rather than force.<BR>\n&nbsp;-The Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Enter no conflict against fanatics unless you can defuse them.  Oppose a <BR>\nreligion with another religion only if your proofs (miracles) are irrefutable <BR>\nor if you can mesh in a way that the fanatics accept you as god-inspired.  This <BR>\nhas long been the barrier to science assuming a mantle of divine revelation.  <BR>\nScience is so obviously manmade.  Fanatics (and many are fanatic on one subject <BR>\nor another) must know where you stand, but more important, must recognize who <BR>\nwhispers in your ear.<BR>\n&nbsp;-Missionaria Protectiva, Primary Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Some never participate.  Life happens to them.  They get by on little more than <BR>\ndumb persistence and resist with anger or violence all things that might lift <BR>\nthem out of resentment-filled illusions of security.<BR>\n&nbsp;-Alma Mavis Taraza');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','All states are abstractions.<BR>\n&nbsp;-Octun Politicus, BG Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','To know a thing well, know its limits.  Only when pushed beyond its tolerances <BR>\nwill true nature be seen.  (The Amtal Rule) Do not depend only on theory if <BR>\nyour life is at stake.  (Bene Gesserit Commentary)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','We do not teach history; we recreate the experience.  We follow the chain of <BR>\nconsequences -- the tracks of the beast in its forest.  Look behind our words <BR>\nand you see the broad sweep of social behavior that no historian has ever <BR>\ntouched.<BR>\n&nbsp;-Bene Gesserit Panoplia Propheticus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','They say Mother Superior can disregard nothing -- a meaningless aphorism until <BR>\nyou grasp its other significance:  I am the servant of all my Sisters.  They <BR>\nwatch their servant with critical eyes.  I cannot spend too much time on <BR>\ngeneralities nor on trivia.  Mother Superior must display insightful action <BR>\nelse a sense of disquiet penetrates to the farthest corners of our order.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Laws to suppress tend to strengthen what they would prohibit.  This is the fine <BR>\npoint on which all the legal professions of history have based their job <BR>\nsecurity.<BR>\n&nbsp;-Bene Gesserit Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Religion (emulation of adults by the child) encysts past mythologies:  guesses, <BR>\nhidden assumptions of trust in the universe, pronouncements made in search of <BR>\npersonal power, all mingled with shreds of enlightenment.  And always an <BR>\nunspoken commandment:  Thou shalt not question!  We break that commandment <BR>\ndaily in the harnessing of human imagination to our deepest creativity.<BR>\n&nbsp;-Bene Gesserit Credo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Ready comprehension is often a knee-jerk response and the most dangerous form <BR>\nof understanding.  It blinks an opaque screen over your ability to learn.  The <BR>\njudgmental precedents of law function that way, littering your path with dead <BR>\nends.  Be warned.  Understand nothing.  All comprehension is temporary.<BR>\n&nbsp;-Mentat Fixe (adacto)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','The writing of history is largely a process of diversion.  Most historical <BR>\naccounts distract attention from the secret influences behind great events.<BR>\n&nbsp;-The Bashar Teg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','All governments suffer a recurring problem:  Power attracts pathological <BR>\npersonalities.  It is not that power corrupts but that it is magnetic to the <BR>\ncorruptible.  Such people have a tendency to become drunk on violence, a <BR>\ncondition to which they are quickly addicted.<BR>\n&nbsp;-Missionaria Protectiva, Text QIV (decto)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Corruption wears infinite disguises.<BR>\n&nbsp;-Tleilaxu Thu-zen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Education is no substitute for intelligence.  That elusive quality is defined <BR>\nonly in part by puzzle-solving ability.  It is in the creation of new puzzles <BR>\nreflecting what your senses report that you round out the definition.<BR>\n&nbsp;-Mentat Text One (decto)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','You cannot manipulate a marionette with only one string.<BR>\n&nbsp;-The Zensunni Whip');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Confine yourself to observing and you always miss the point of your own life.  <BR>\nThe object can be stated this way:  Live the best life you can.  Life is a game <BR>\nwhose rules you learn if you leap into it and play it to the hilt.  Otherwise, <BR>\nyou are caught off balance, continually surprised by the shifting play.  <BR>\nNon-players often whine and complain that luck always passes them by.  They <BR>\nrefuse to see that they can create some of their own luck.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Rules build up fortifications behind which small minds create satrapies.  A <BR>\nperilous state of affairs in the best of times, disastrous during crises.<BR>\n&nbsp;-Bene Gesserit Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','The person who takes the banal and ordinary and illuminates it in a new way can <BR>\nterrify.  We do not want our ideas changed.  We feel threatened by such <BR>\ndemands.  \"I already know the important things!\" we say.  Then Changer comes <BR>\nand throws our old ideas away.<BR>\n&nbsp;-The Zensufi Master');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Answers are a perilous grip on the universe.  They can appear sensible yet <BR>\nexplain nothing.<BR>\n&nbsp;-The Zensunni Whip');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','When are the witches to be trusted?  Never!  The dark side of the magic <BR>\nuniverse belongs to the Bene Gesserit and we must reject them.<BR>\n&nbsp;-Tylwyth Waff, Master of Masters');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Seek freedom and become captive of your desires.  Seek discipline and find your <BR>\nliberty.<BR>\n&nbsp;-The Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Making workable choices occurs in a crucible of informative mistakes.  Thus <BR>\nIntelligence accepts fallibility.  And when absolute (infallible) choices are <BR>\nnot known, Intelligence takes chances with limited data in an arena where <BR>\nmistakes are not only possible but also necessary.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Our household god is this thing we carry forward generation after generation:  <BR>\nour message for humankind if it matures.  The closest thing we have to a <BR>\nhousehold goddess is a failed Reverend Mother -- Chenoeh there in her niche.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Do not be quick to reveal judgment.  Hidden judgment often is more potent.  It <BR>\ncan guide reactions whose effects are felt only when too late to divert them.<BR>\n&nbsp;-Bene Gesserit Advice to Postulants');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Ish yara al-ahdab hadbat-u.  (A hunchback does not see his own hunch. -- Folk <BR>\nSaying.) Bene Gesserit Commentary:  The hunch may be seen with the aid of <BR>\nmirrors but mirrors may show the whole being.<BR>\n&nbsp;-The Bashar Teg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Religion must be accepted as a source of energy.  It can be directed for our <BR>\npurposes, but only within limits that experience reveals.  Here is the secret <BR>\nmeaning of Free Will.<BR>\n&nbsp;-Missionaria Protectiva, Primary Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Spend energies on those who make you strong.  Energy spent on weaklings drags <BR>\nyou to doom.  (HM rule) Bene Gesserit Commentary:  Who judges?<BR>\n&nbsp;-The Dortujla Record');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','We witness a passing phase of eternity.  Important things happen but some <BR>\npeople never notice.  Accidents intervene.  You are not present at episodes.  <BR>\nYou depend on reports.  And people shutter their minds.  What good are reports? <BR>\n&nbsp;History in a news account?  Preselected at an editorial conference, digested <BR>\nand excreted by prejudice?  Accounts you need seldom come from those who make <BR>\nhistory.  Diaries, memoirs and autobiographies are subjective forms of special <BR>\npleading.  Archives are crammed with such suspect stuff.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','What do Holy Accidents teach?  Be resilient.  Be strong.  Be ready for change, <BR>\nfor the new.  Gather many experiences and judge them by the steadfast nature of <BR>\nour faith.<BR>\n&nbsp;-Tleilaxu Doctrine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Paired opposites define your longings and those longings imprison you.<BR>\n&nbsp;-The Zensunni Whip');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','When you think to take determination of your fate into your own hands, that is <BR>\nthe moment you can be crushed.  Be cautious.  Allow for surprises.  When we <BR>\ncreate, there are always other forces at work.<BR>\n&nbsp;-Darwi Odrade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('chapterhouse-du','Ultimately, all things are known because you want to believe you know.<BR>\n&nbsp;-Zensunni koan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Thou didst divide the sand by thy strength; Thou breakest the heads of the <BR>\ndragons in the desert. Yea, I behold thee as a beast coming up from the dunes; <BR>\nthou hast the two horns of the lamb, but thou speakest as the dragon.<BR>\n&nbsp;-Revised Orange Catholic Bible Arran 11:4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Fremen were the first humans to develop a conscious/unconscious symbology <BR>\nthrough which to experience the movements and relationships of their planetary <BR>\nsystem. They were the first people anywhere to express climate in terms of a <BR>\nsemi-mathematic language whose written symbols embody (and internalize) the <BR>\nexternal relationships. The language itself was part of the system it <BR>\ndescribed. Its written form carried the shape of what it described. The <BR>\nintimate local knowledge of what was available to support life was implicit in <BR>\nthis development. One can measure the extent of this language/system <BR>\ninteraction by the fact that Fremen accepted themselves as foraging and <BR>\nbrowsing animals.<BR>\n&nbsp;-The Story of Liet-Kynes by Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Any path which narrows future possibilities may become a lethal trap. Humans <BR>\nare not threading their way through a maze; they scan a vast horizon filled <BR>\nwith unique opportunities. The narrowing viewpoint of the maze should appeal <BR>\nonly to creatures with their noses buried in sand. Sexually produced uniqueness <BR>\nand differences are the life-protection of the spices.<BR>\n&nbsp;-The Spacing Guild Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','What you of the CHOAM directorate seem unable to understand is that you seldom <BR>\nfind real loyalties in commerce. When did you last hear of a clerk giving his <BR>\nlife for the company? Perhaps your deficiency rests in the false assumption <BR>\nthat you can order men to think and cooperate. This has been a failure of <BR>\neverything from religions to general staffs throughout history. General staffs <BR>\nhave a long record of destroying their own nations. As to religions, I <BR>\nrecommend a rereading of Thomas Aquinas. As to you of CHOAM, what nonsense you <BR>\nbelieve! Men must want to do things out of their own innermost drives. People, <BR>\nnot commercial organizations or chains of command, are what make great <BR>\ncivilizations work. Every civilization depends upon the quality of the <BR>\nindividuals it produces. If you over-organize humans, over-legalize them, <BR>\nsuppress their urge to greatness -- they cannot work and their civilization <BR>\ncollapses.<BR>\n&nbsp;-A letter to CHOAM, Attributed to The Preacher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','The Fremen must return to his original faith, to his genius in forming human <BR>\ncommunities; he must return to the past, where that lesson of survival was <BR>\nlearned in the struggle with Arrakis. The only business of the Fremen should be <BR>\nthat of opening his soul to the inner teachings. The worlds of the Imperium, <BR>\nthe Landsraad and the CHOAM Confederacy have no message to give him. They will <BR>\nonly rob him of his soul.<BR>\n&nbsp;-The Preacher at Arrakeen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','CHALLENGE: \"Have you seen The Preacher?\" <BR>\nRESPONSE: \"I have seen a sandworm.\"<BR>\nCHALLENGE: \"What about that sandworm?\" <BR>\nRESPONSE: \"It gives us the air we breathe.\"<BR>\nCHALLENGE: \"Then why do we destroy its land?\" <BR>\nRESPONSE: \"Because Shai-Hulud [sandworm deified] orders it.\"<BR>\n&nbsp;-Riddles of Arrakis by Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','I give you the desert chameleon, whose ability to blend itself into the <BR>\nbackground tells you all you need to know about the roots of ecology and the <BR>\nfoundations of a personal identity.<BR>\n&nbsp;-Book of Diatribes from the Hayt Chronicle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','And I beheld another beast coming up out of the sand; and he had two horns like <BR>\na lamb, but his mouth was fanged and fiery as the dragon and his body shimmered <BR>\nand burned with great heat while it did hiss like the serpent.<BR>\n&nbsp;-Revised Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','You Bene Gesserit call your activity of the Panoplia Prophetica a \"Science of <BR>\nReligion.\" Very well. I, a seeker after another kind of scientist, find this an <BR>\nappropriate definition. You do, indeed, build your own myths, but so do all <BR>\nsocieties. You I must warn, however. You are behaving as so many other <BR>\nmisguided scientists have behaved. Your actions reveal that you wish to take <BR>\nsomething out of [away from] life. It is time you were reminded of that which <BR>\nyou so often profess: One cannot have a single thing without its opposite.<BR>\n&nbsp;-The Preacher at Arrakeen: A Message to the Sisterhood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','When I am weaker than you, I ask you for freedom because that is according to <BR>\nyour principles; when I am stronger than you, I take away your freedom because <BR>\nthat is according to my principles.<BR>\n&nbsp;-Words of an ancient philosopher (Attributed by Harq al-Ada to one Louis <BR>\nVeuillot)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','A Fremen dies when he is too long from the desert; this we call \"the water <BR>\nsickness.\"<BR>\n&nbsp;-Stilgar, the Commentaries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','The assumption that humans exist within an essentially impermanent universe, <BR>\ntaken as an operational precept, demands that the intellect become a totally <BR>\naware balancing instrument. But the intellect cannot react thus without <BR>\ninvolving the entire organism. Such an organism may be recognized by its <BR>\nburning, driving behavior. And thus it is with a society treated as organism. <BR>\nBut here we encounter an old inertia. Societies move to the goading of ancient, <BR>\nreactive impulses. They demand permanence. Any attempt to display the universe <BR>\nof impermanence arouses rejection patterns, fear, anger, and despair. Then how <BR>\ndo we explain the acceptance of prescience? Simply: the giver of prescient <BR>\nvisions, because he speaks of an absolute (permanent) realization, may be <BR>\ngreeted with joy by humankind even while predicting the most dire events.<BR>\n&nbsp;-The Book of Leto, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','The life of a single human, as the life of a family or an entire people, <BR>\npersists as memory. My people must come to see this as part of their maturing <BR>\nprocess. They are people as organism, and in this persistent memory they store <BR>\nmore and more experiences in a subliminal reservoir. Humankind hopes to call <BR>\nupon this material if it is needed for a changing universe. But much that is <BR>\nstored can be lost in that chance play of accident which we call \"fate.\" Much <BR>\nmay not be integrated into evolutionary relationships, and thus may not be <BR>\nevaluated and keyed into activity by those ongoing environmental changes which <BR>\ninflict themselves upon flesh. The species can forget! This is the special <BR>\nvalue of the Kwisatz Haderach which the Bene Gesserits never suspected: the <BR>\nKwisatz Haderach cannot forget.<BR>\n&nbsp;-The Book of Leto, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','These are illusions of popular history which a successful religion must <BR>\npromote: Evil men never prosper; only the brave deserve the fair; honesty is <BR>\nthe best policy; actions speak louder than words; virtue always triumphs; a <BR>\ngood deed is its own reward; any bad human can be reformed; religious talismans <BR>\nprotect one from demon possession; only females understand the ancient <BR>\nmysteries; the rich are doomed to unhappiness . . .<BR>\n&nbsp;-From the Instruction Manual: Missionaria Protectiva');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','One small bird has called thee <BR>\nFrom a beak streaked crimson. <BR>\nIt cried once over Sietch Tabr <BR>\nAnd thou went forth unto Funeral Plain.<BR>\n&nbsp;-Lament for Leto II');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','In this age when the means of human transport include devices which can span <BR>\nthe deeps of space in transtime, and other devices which can carry men swiftly <BR>\nover virtually impassable planetary surfaces, it seems odd to think of <BR>\nattempting long journeys afoot. Yet this remains a primary means of travel on <BR>\nArrakis, a fact attributed partly to preference and partly to the brutal <BR>\ntreatment which this planet reserves for anything mechanical. In the strictures <BR>\nof Arrakis, human flesh remains the most durable and reliable resource for the <BR>\nHajj. Perhaps it is the implicit awareness of this fact which makes Arrakis the <BR>\nultimate mirror of the soul.<BR>\n&nbsp;-Handbook of the Hajj');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Good government never depends upon laws, but upon the personal qualities of <BR>\nthose who govern. The machinery of government is always subordinate to the will <BR>\nof those who administer that machinery. The most important element of <BR>\ngovernment, therefore, is the method of choosing leaders.<BR>\n&nbsp;-Law and Governance, The Spacing Guild Manual');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','This rocky shrine to the skull of a ruler grants no prayers. It has become the <BR>\ngrave of lamentations. Only the wind hears the voice of this place. The cries <BR>\nof night creatures and the passing wonder of two moons, all say his day has <BR>\nended. No more supplicants come. The visitors have gone from the feast. How <BR>\nbare the pathway down this mountain.<BR>\n&nbsp;-Lines at the Shrine of an Atreides Duke, Anon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Governments, if they endure, always tend increasingly toward aristocratic <BR>\nforms. No government in history has been known to evade this pattern. And as <BR>\nthe aristocracy develops, government tends more and more to act exclusively in <BR>\nthe interests of the ruling class -- whether that class be hereditary royalty, <BR>\noligarchs of financial empires, or entrenched bureaucracy.<BR>\n&nbsp;-Politics as Repeat Phenomenon: Bene Gesserit Training Manual');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','After the Fremen, all Planetologists see life as expressions of energy and look <BR>\nfor the overriding relationships. In small pieces, bits and parcels which grow <BR>\ninto general understanding, the Fremen racial wisdom is translated into a new <BR>\ncertainty. The thing Fremen have as a people, any people can have. They need <BR>\nbut develop a sense for energy relationships. They need but observe that energy <BR>\nsoaks up the patterns of things and builds with those patterns.<BR>\n&nbsp;-The Arrakeen Catastrophe, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','The assumption that a whole system can be made to work better through an <BR>\nassault on its conscious elements betrays a dangerous ignorance. This has often <BR>\nbeen the ignorant approach of those who call themselves scientists and <BR>\ntechnologists.<BR>\n&nbsp;-The Butlerian Jihad, by Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','By these acts Leto II removed himself from the evolutionary succession. He did <BR>\nit with a deliberate cutting action, saying: \"To be independent is to be <BR>\nremoved.\" Both twins saw beyond the needs of memory as a measuring process, <BR>\nthat is, a way of determining their distance from their human origins. But it <BR>\nwas left to Leto II to do the audacious thing, recognizing that a real creation <BR>\nis independent of its creator. He refused to reenact the evolutionary sequence, <BR>\nsaying, \"That, too, takes me farther and farther from humanity.\" He saw the <BR>\nimplications in this: that there can be no truly closed systems in life.<BR>\n&nbsp;-The Holy Metamorphosis, by Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','In all major socializing forces you will find an underlying movement to gain <BR>\nand maintain power through the use of words. From witch doctor to priest to <BR>\nbureaucrat it is all the same. A governed populace must be conditioned to <BR>\naccept power-words as actual things, to confuse the symbolized system with the <BR>\ntangible universe. In the maintenance of such a power structure, certain <BR>\nsymbols are kept out of the reach of common understanding -- symbols such as <BR>\nthose dealing with economic manipulation or those which define the local <BR>\ninterpretation of sanity. Symbol-secrecy of this form leads to the development <BR>\nof fragmented sub-languages, each being a signal that its users are <BR>\naccumulating some form of power. With this insight into a power process, our <BR>\nImperial Security Force must be ever alert to the formation of sub-languages.<BR>\n&nbsp;-Lecture to the Arrakeen War College by, The Princess Irulan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','You will learn the integrated communication methods as you complete the next <BR>\nstep in your mentat education. This is a gestalten function which will overlay <BR>\ndata paths in your awareness, resolving complexities and masses of input from <BR>\nthe mentat index-catalogue techniques which you already have mastered. Your <BR>\ninitial problem will be the breaking tensions arising from the divergent <BR>\nassembly of minutiae/data on specialized subjects. Be warned. Without mentat <BR>\noverlay integration, you can be immersed in the Babel Problem, which is the <BR>\nlabel we give to the omnipresent dangers of achieving wrong combinations from <BR>\naccurate information.<BR>\n&nbsp;-The Mentat Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','There is no guilt or innocence in you. All of that is past. Guilt belabors the <BR>\ndead and I am not the Iron Hammer. You multitude of the dead are merely people <BR>\nwho have done certain things, and the memory of those things illuminates my <BR>\npath.<BR>\n&nbsp;-Leto II to His Memory-Lives, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Fremen speech implies great concision, a precise sense of expression. It is <BR>\nimmersed in the illusion of absolutes. Its assumptions are a fertile ground for <BR>\nabsolutist religions. Furthermore, Fremen are fond of moralizing. They confront <BR>\nthe terrifying instability of all things with institutionalized statements. <BR>\nThey say: \"We know there is no summa of all attainable knowledge; that is the <BR>\npreserve of God. But whatever men can learn, men can contain.\" Out of this <BR>\nknife-edged approach to the universe they carve a fantastic belief in signs and <BR>\nomens and in their own destiny. This is an origin of their Kralizec legend: the <BR>\nwar at the end of the universe.<BR>\n&nbsp;-Bene Gesserit Private Reports/folio 800881');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','The one-eyed view of our universe says you must not look far afield for <BR>\nproblems. Such problems may never arrive. Instead, tend to the wolf within your <BR>\nfences. The packs ranging outside may not even exist.<BR>\n&nbsp;-The Azhar Book; Shamra I:4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','We can still remember the golden days before Heisenberg, who showed humans the <BR>\nwalls enclosing our predestined arguments. The lives within me find this <BR>\namusing. Knowledge, you see, has no uses without purpose, but purpose is what <BR>\nbuilds enclosing walls.<BR>\n&nbsp;-Leto Atreides II, His Voice');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Natural selection has been described as an environment selectively screening <BR>\nfor those who will have progeny. Where humans are concerned, though, this is an <BR>\nextremely limiting viewpoint. Reproduction by sex tends toward experiment and <BR>\ninnovation. It raises many questions, including the ancient one about whether <BR>\nenvironment is a selective agent after the variation occurs, or whether <BR>\nenvironment plays a pre-selective role in determining the variations which it <BR>\nscreens. Dune did not realty answer those questions: it merely raised new <BR>\nquestions which Leto and the Sisterhood may attempt to answer over the next <BR>\nfive hundred generations.<BR>\n&nbsp;-The Dune Catastrophe, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','If you believe certain words, you believe their hidden arguments. When you <BR>\nbelieve something is right or wrong, true or false, you believe the assumptions <BR>\nin the words which express the arguments. Such assumptions are often full of <BR>\nholes, but remain most precious to the convinced.<BR>\n&nbsp;-The Open-Ended Proof from, The Panoplia Prophetica');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','There exist obvious higher-order influences in any planetary system. This is <BR>\noften demonstrated by introducing terraform life onto newly discovered planets. <BR>\nIn all such cases, the life in similar zones develops striking similarities of <BR>\nadaptive form. This form signifies much more than shape; it connotes a survival <BR>\norganization and a relationship of such organizations. The human quest for this <BR>\ninterdependent order and our niche within it represents a profound necessity. <BR>\nThe quest can, however, be perverted into a conservative grip on sameness. This <BR>\nhas always proved deadly for the entire system.<BR>\n&nbsp;-The Dune Catastrophe, After Harq al-Ada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','I will not argue with the Fremen claims that they are divinely inspired to <BR>\ntransmit a religious revelation, it is their concurrent claim to ideological <BR>\nrevelation which inspires me to shower them with derision. Of course, they make <BR>\nthe dual claim in the hope that it will strengthen their mandarinate and help <BR>\nthem to endure in a universe which finds them increasingly oppressive. It is in <BR>\nthe name of all those oppressed people that I warn the Fremen: short-term <BR>\nexpediency always fails in the long term.<BR>\n&nbsp;-The Preacher at Arrakeen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','You have loved Caladan <BR>\nAnd lamented its lost host -- <BR>\nBut pain discovers <BR>\nNew lovers cannot erase <BR>\nThose forever ghost.<BR>\n&nbsp;-Refrain from The Habbanya Lament');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('children-of-dun','Because of the one-pointed Time awareness in which the conventional mind <BR>\nremains immersed, humans tend to think of everything in a sequential, <BR>\nword-oriented framework. This mental trap produces very short-term concepts of <BR>\neffectiveness and consequences, a condition of constant, unplanned response to <BR>\ncrises.<BR>\n&nbsp;-Liet-Kynes, The Arrakis Workbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','PL/I -- \"the fatal disease\" -- belongs more to the problem set than to the<BR>\nsolution set.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A year spent in artificial intelligence is enough to make one believe in God.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Please go away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','About the use of language: it is impossible to sharpen a pencil with a blunt<BR>\nax.  It is equally vain to try to do it with ten blunt axes instead.<BR>\n&nbsp;-- Edsger Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Play Rogue, visit exotic locations, meet strange creatures and kill them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Per buck you get more computing action with the small computer.<BR>\n&nbsp;-- R.W. Hamming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Pause for storage relocation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A well-used door needs no oil on its hinges.<BR>\nA swift-flowing steam does not grow stagnant.<BR>\nNeither sound nor thoughts can travel through a vacuum.<BR>\nSoftware rots if not used.<BR>\n&nbsp;These are great mysteries.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Passwords are implemented as a result of insecurity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Pascal is Pascal is Pascal is dog meat.\"<BR>\n&nbsp;-- M. Devine and P. Larson, Computer Science 340');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A successful [software] tool is one that was used to do something<BR>\nundreamed of by its author.<BR>\n&nbsp;-- S. C. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Pascal is not a high-level language.<BR>\n&nbsp;-- Steven Feiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Pascal is a language for children wanting to be naughty.<BR>\n&nbsp;-- Dr. Kasi Ananthanarayanan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A student, in hopes of understanding the Lambda-nature, came to Greenblatt.<BR>\nAs they spoke a Multics system hacker walked by.  \"Is it true\", asked the<BR>\nstudent, \"that PL-1 has many of the same data types as Lisp?\"  Almost before<BR>\nthe student had finished his question, Greenblatt shouted, \"FOO!\", and hit<BR>\nthe student with a stick.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','panic: kernel trap (ignored)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','panic: kernel segmentation violation. core dumped		(only kidding)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Overload -- core meltdown sequence initiated.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A rolling disk gathers no MOS.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Overflow on /dev/null, please empty the bit bucket.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A recent study has found that concentrating on difficult off-screen<BR>\nobjects, such as the faces of loved ones, causes eye strain in computer<BR>\nscientists.  Researchers into the phenomenon cite the added concentration<BR>\nneeded to \"make sense\" of such unnatural three dimensional objects.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Overall, the philosophy is to attack the availability problem from two<BR>\ncomplementary directions:  to reduce the number of software errors through<BR>\nrigorous testing of running systems, and to reduce the effect of the remaining<BR>\nerrors by providing for recovery from them.  An interesting footnote to this<BR>\ndesign is that now a system failure can usually be considered to be the<BR>\nresult of two program errors:  the first, in the program that started the<BR>\nproblem; the second, in the recovery routine that could not protect the<BR>\nsystem.<BR>\n&nbsp;-- A.L. Scherr, \"Functional Structure of IBM Virtual Storage<BR>\n&nbsp;Operating Systems, Part II: OS/VS-2 Concepts and<BR>\n&nbsp;Philosophies,\" IBM Systems Journal, Vol. 12, No. 4.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Over the shoulder supervision is more a need of the manager than the<BR>\nprogramming task.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A programming language is low level when its programs require attention<BR>\nto the irrelevant.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','PLUG IT IN!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Save energy:  Drive a smaller shell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Row, row, row your bits, gently down the stream...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','An algorithm must be seen to be believed.<BR>\n&nbsp;-- D.E. Knuth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Reactor error - core dumped!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','RADIO SHACK LEVEL II BASIC<BR>\nREADY<BR>\n>_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','===  ALL CSH USERS PLEASE NOTE  ========================<BR>\n&nbsp;Set the variable $LOSERS to all the people that you think are losers.  This<BR>\nwill cause all said losers to have the variable $PEOPLE-WHO-THINK-I-AM-A-LOSER<BR>\nupdated in their .login file.  Should you attempt to execute a job on a <BR>\nmachine with poor response time and a machine on your local net is currently<BR>\npopulated by losers, that machine will be freed up for your job through a<BR>\ncold boot process.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Put no trust in cryptic comments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','PURGE COMPLETE.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','All constants are variables.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Proposed Additions to the PDP-11 Instruction Set:<BR>\n&nbsp;PI	Punch Invalid<BR>\nPOPI	Punch Operator Immediately<BR>\nPVLC	Punch Variable Length Card<BR>\nRASC	Read And Shred Card<BR>\nRPM	Read Programmers Mind<BR>\nRSSC	reduce speed, step carefully  (for improved accuracy)<BR>\nRTAB	Rewind tape and break<BR>\nRWDSK	rewind disk<BR>\nRWOC	Read Writing On Card<BR>\nSCRBL	scribble to disk  - faster than a write<BR>\nSLC	Search for Lost Chord<BR>\nSPSW	Scramble Program Status Word<BR>\nSRSD	Seek Record and Scar Disk<BR>\nSTROM	Store in Read Only Memory<BR>\nTDB	Transfer and Drop Bit<BR>\nWBT	Water Binary Tree');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Proposed Additions to the PDP-11 Instruction Set:<BR>\n&nbsp;DC	Divide and Conquer<BR>\nDMPK	Destroy Memory Protect Key<BR>\nDO	Divide and Overflow<BR>\nEMPC	Emulate Pocket Calculator<BR>\nEPI	Execute Programmer Immediately<BR>\nEROS	Erase Read Only Storage<BR>\nEXCE	Execute Customer Engineer<BR>\nHCF	Halt and Catch Fire<BR>\nIBP	Insert Bug and Proceed<BR>\nINSQSW	Insert into queue somewhere (for FINO queues [First in never out])<BR>\nPBC	Print and Break Chain<BR>\nPDSK	Punch Disk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Algol-60 surely must be regarded as the most important programming language<BR>\nyet developed.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Proposed Additions to the PDP-11 Instruction Set:<BR>\n&nbsp;BBW	Branch Both Ways<BR>\nBEW	Branch Either Way<BR>\nBBBF	Branch on Bit Bucket Full<BR>\nBH	Branch and Hang<BR>\nBMR	Branch Multiple Registers<BR>\nBOB	Branch On Bug<BR>\nBPO	Branch on Power Off<BR>\nBST	Backspace and Stretch Tape<BR>\nCDS	Condense and Destroy System<BR>\nCLBR	Clobber Register<BR>\nCLBRI	Clobber Register Immediately<BR>\nCM	Circulate Memory<BR>\nCMFRM	Come From -- essential for truly structured programming<BR>\nCPPR	Crumple Printer Paper and Rip<BR>\nCRN	Convert to Roman Numerals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Programming is an unnatural act.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Alan Turing thought about criteria to settle the question of whether<BR>\nmachines can think, a question of which we now know that it is about<BR>\nas relevant as the question of whether submarines can swim.<BR>\n&nbsp;-- Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Programmers used to batch environments may find it hard to live without<BR>\ngiant listings; we would find it hard to use them.<BR>\n&nbsp;-- D.M. Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Programmers do it bit by bit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Profanity is the one language all programmers know best.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Prof:    So the American government went to IBM to come up with a data<BR>\n&nbsp;encryption standard and they came up with ...<BR>\nStudent: EBCDIC!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Adding manpower to a late software project makes it later.<BR>\n&nbsp;-- F. Brooks, \"The Mythical Man-Month\"<BR>\n&nbsp;Whenever one person is found adequate to the discharge of a duty by<BR>\nclose application thereto, it is worse execute by two persons and<BR>\nscarcely done at all if three or more are employed therein.<BR>\n&nbsp;-- George Washington, 1732-1799');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Premature optimization is the root of all evil.<BR>\n&nbsp;-- D.E. Knuth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Adding features does not necessarily increase functionality -- it just<BR>\nmakes the manuals thicker.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','===  ALL USERS PLEASE NOTE  ========================<BR>\n&nbsp;Bug reports now amount to an average of 12,853 per day.  Unfortunately,<BR>\nthis is only a small fraction [ < 1% ] of the mail volume we receive.  In<BR>\norder that we may more expeditiously deal with these valuable messages,<BR>\nplease communicate them by one of the following paths:<BR>\n&nbsp;ARPA:  WastebasketSLMHQ.ARPA<BR>\n&nbsp;UUCP:  [berkeley, seismo, harpo]!fubar!thekid!slmhq!wastebasket<BR>\n&nbsp;Non-network sites:  Federal Express to:<BR>\n&nbsp;Wastebasket<BR>\n&nbsp;Room NE43-926<BR>\n&nbsp;Copernicus, The Moon, 12345-6789<BR>\n&nbsp;For that personal contact feeling call 1-415-642-4948; our trained<BR>\n&nbsp;operators are on call 24 hours a day.  VISA/MC accepted.*<BR>\n&nbsp;* Our very rich lawyers have assured us that we are not <BR>\n&nbsp;responsible for any errors or advice given over the phone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','===  ALL USERS PLEASE NOTE  ========================<BR>\n&nbsp;A new system, the CIRCULATORY system, has been added.<BR>\n&nbsp;The long-experimental CIRCULATORY system has been released to users.  The<BR>\nLisp Machine uses Type B fluid, the L machine uses Type A fluid.  When the <BR>\nswitch to Common Lisp occurs both machines will, of course, be Type O.<BR>\nPlease check fluid level by using the DIP stick which is located in the<BR>\nback of VMI monitors.  Unchecked low fluid levels can cause poor paging<BR>\nperformance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real programmers disdain structured programming.  Structured programming is<BR>\nfor compulsive neurotics who were prematurely toilet- trained.  They wear<BR>\nneckties and carefully line up pencils on otherwise clear desks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real computer scientists only write specs for languages that might run<BR>\non future hardware.  Nobody trusts them to write specs for anything homo<BR>\nsapiens will ever be able to fit on a single planet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','All programmers are playwrights and all computers are lousy actors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','All programmers are optimists.  Perhaps this modern sorcery especially attracts<BR>\nthose who believe in happy endings and fairy godmothers.  Perhaps the hundreds<BR>\nof nitty frustrations drive away all but those who habitually focus on the end<BR>\ngoal.  Perhaps it is merely that computers are young, programmers are younger,<BR>\nand the young are always optimists.  But however the selection process works,<BR>\nthe result is indisputable:  \"This time it will surely run,\" or \"I just found<BR>\nthe last bug.\"<BR>\n&nbsp;-- Frederick Brooks, \"The Mythical Man Month\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Remember: use logout to logout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','An adequate bootstrap is a contradiction in terms.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Remember, UNIX spelled backwards is XINU.<BR>\n&nbsp;-- Mt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Remember the good old days, when CPU was singular?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Recursion is the root of computation since it trades description for time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real Users never use the Help key.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','All your files have been destroyed (sorry).  Paul.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real software engineers work from 9 to 5, because that is the way the job is<BR>\ndescribed in the formal spec.  Working late would feel like using an<BR>\nundocumented external procedure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','All the simple programs have been written.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real computer scientists like having a computer on their desk, else how<BR>\ncould they read their mail?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"... all the good computer designs are bootlegged; the formally planned<BR>\nproducts, if they are built at all, are dogs!\"<BR>\n&nbsp;-- David E. Lundstrom, \"A Few Good Men From Univac\",<BR>\n&nbsp;MIT Press, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real Programmers think better when playing Adventure or Rogue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','===  ALL USERS PLEASE NOTE  ========================<BR>\n&nbsp;JCL support as alternative to system menu.<BR>\n&nbsp;In our continuing effort to support languages other than LISP on the CADDR,<BR>\nwe have developed an OS/360-compatible JCL.  This can be used as an<BR>\nalternative to the standard system menu.  Type System J to get to a JCL<BR>\ninteractive read-execute-diagnose loop window.  [Note that for 360<BR>\ncompatibility, all input lines are truncated to 80 characters.]  This<BR>\nwindow also maintains a mouse-sensitive display of critical job parameters<BR>\nsuch as dataset allocation, core allocation, channels, etc.  When a JCL<BR>\nsyntax error is detected or your job ABENDs, the window-oriented JCL<BR>\ndebugger is entered.  The JCL debugger displays appropriate OS/360 error<BR>\nmessages (such as IEC703, \"disk error\") and allows you to dequeue your job.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','She sells cshs by the cshore.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Any given program will expand to fill available memory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Sendmail may be safely run set-user-id to root.<BR>\n&nbsp;-- Eric Allman, \"Sendmail Installation Guide\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Another megabytes the dust.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Send some filthy mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','And on the seventh day, He exited from append mode.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Seems a computer engineer, a systems analyst, and a programmer were<BR>\ndriving down a mountain when the brakes gave out.  They screamed down the<BR>\nmountain, gaining speed, but finally managed to grind to a halt, more by<BR>\nluck than anything else, just inches from a thousand foot drop to jagged<BR>\nrocks.  They all got out of the car:<BR>\n&nbsp;The computer engineer said, \"I think I can fix it.\"<BR>\n&nbsp;The systems analyst said, \"No, no, I think we should take it<BR>\ninto town and have a specialist look at it.\"<BR>\n&nbsp;The programmer said, \"OK, but first I think we should get back<BR>\nin and see if it does it again.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Security check: INTRUDER ALERT!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Section 2.4.3.5   AWNS   (Acceptor Wait for New Cycle State).<BR>\n&nbsp;In AWNS the AH function indicates that it has received a<BR>\nmultiline message byte.<BR>\n&nbsp;In AWNS the RFD message must be sent false and the DAC message<BR>\nmust be sent passive true.<BR>\n&nbsp;The AH function must exit the AWNS and enter:<BR>\n&nbsp;(1)  The ANRS if DAV is false<BR>\n&nbsp;(2)  The AIDS if the ATN message is false and neither:<BR>\n&nbsp;(a)  The LADS is active<BR>\n&nbsp;(b)  Nor LACS is active\"<BR>\n&nbsp;-- from the IEEE Standard Digital Interface for<BR>\n&nbsp;Programmable Instrumentation');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','An interpretation _I satisfies a sentence in the table language if and only if<BR>\neach entry in the table designates the value of the function designated by the<BR>\nfunction constant in the upper-left corner applied to the objects designated<BR>\nby the corresponding row and column labels.<BR>\n&nbsp;-- Genesereth & Nilsson, \"Logical foundations of Artificial<BR>\n&nbsp;Intelligence\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Scientists were preparing an experiment to ask the ultimate question.<BR>\nThey had worked for months gathering one each of every computer that was<BR>\nbuilt. Finally the big day was at hand.  All the computers were linked<BR>\ntogether.  They asked the question, \"Is there a God?\".  Lights started<BR>\nblinking, flashing and blinking some more.  Suddenly, there was a loud<BR>\ncrash, and a bolt of lightning came down from the sky, struck the<BR>\ncomputers, and welded all the connections permanently together.  \"There<BR>\nis now\", came the reply.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Science is to computer science as hydrodynamics is to plumbing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','An engineer is someone who does list processing in FORTRAN.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','SCCS, the source motel!  Programs check in and never check out!<BR>\n&nbsp;-- Ken Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Say \"twenty-three-skiddoo\" to logout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','An elephant is a mouse with an operating system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Save yourself!  Reboot in 5 seconds!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','APL is a natural extension of assembler language programming;<BR>\n...and is best for educational purposes.<BR>\n&nbsp;-- A. Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Standards are crucial.  And the best thing about standards is: there are<BR>\nso ____many to choose from!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Staff meeting in the conference room in 3 minutes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','APL is a mistake, carried through to perfection.  It is the language of the<BR>\nfuture for the programming techniques of the past: it creates a new generation<BR>\nof coding bums.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Staff meeting in the conference room in %d minutes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','APL hackers do it in the quad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Speaking as someone who has delved into the intricacies of PL/I, I am sure<BR>\nthat only Real Men could have written such a machine-hogging, cycle-grabbing,<BR>\nall-encompassing monster.  Allocate an array and free the middle third?<BR>\nSure!  Why not?  Multiply a character string times a bit string and assign the<BR>\nresult to a float decimal?  Go ahead!  Free a controlled variable procedure<BR>\nparameter and reallocate it before passing it back?  Overlay three different<BR>\ntypes of variable on the same memory location?  Anything you say!  Write a<BR>\nrecursive macro?  Well, no, but Real Men use rescan.  How could a language<BR>\nso obviously designed and written by Real Men not be intended for Real Man use?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;Something mysterious is formed, born in the silent void.  Waiting<BR>\nalone and unmoving, it is at once still and yet in constant motion.  It is<BR>\nthe source of all programs.  I do not know its name, so I will call it the<BR>\nTao of Programming.<BR>\n&nbsp;If the Tao is great, then the operating system is great.  If the<BR>\noperating system is great, then the compiler is great.  If the compiler is<BR>\ngreater, then the applications is great.  The user is pleased and there is<BR>\nharmony in the world.<BR>\n&nbsp;The Tao of Programming flows far away and returns on the wind of<BR>\nmorning.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Testing can show the presense of bugs, but not their absence.<BR>\n&nbsp;-- Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As long as there are ill-defined goals, bizarre bugs, and unrealistic <BR>\nschedules, there will be Real Programmers willing to jump in and Solve <BR>\nThe Problem, saving the documentation for later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Systems programmers are the high priests of a low cult.<BR>\n&nbsp;-- R.S. Barton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','	*** System shutdown message from root ***<BR>\n&nbsp;System going down in 60 seconds<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','System restarting, wait...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As in certain cults it is possible to kill a process if you know its true name.<BR>\n&nbsp;-- Ken Thompson and Dennis M. Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','System going down at 1:45 this afternoon for disk crashing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','System checkpoint complete.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As a computer, I find your faith in technology amusing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Syntactic sugar causes cancer of the semicolon.<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Swap read error.  You lose your mind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Around computers it is difficult to find the correct unit of time to<BR>\nmeasure progress.  Some cathedrals took a century to complete.  Can you<BR>\nimagine the grandeur and scope of a program that would take as long?<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Suppose for a moment that the automobile industry had developed at the same<BR>\nrate as computers and over the same period:  how much cheaper and more<BR>\nefficient would the current models be?  If you have not already heard the<BR>\nanalogy, the answer is shattering.  Today you would be able to buy a<BR>\nRolls-Royce for $2.75, it would do three million miles to the gallon, and<BR>\nit would deliver enough power to drive the Queen Elizabeth II.  And if you<BR>\nwere interested in miniaturization, you could place half a dozen of them on<BR>\na pinhead.<BR>\n&nbsp;-- Christopher Evans');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Such efforts are almost always slow, laborious, political, petty, boring,<BR>\nponderous, thankless, and of the utmost criticality.<BR>\n&nbsp;-- Leonard Kleinrock, on standards efforts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Are we running light with overbyte?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Stinginess with privileges is kindness in disguise.<BR>\n&nbsp;-- Guide to VAX/VMS Security, Sep. 1984');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Assembly language experience is [important] for the maturity<BR>\nand understanding of how computers work that it provides.<BR>\n&nbsp;-- D. Gries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The computing field is always in need of new cliches.<BR>\n&nbsp;-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"The Computer made me do it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Ask not for whom the <CONTROL-G> tolls.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The computer is to the information industry roughly what the<BR>\ncentral power station is to the electrical industry.<BR>\n&nbsp;-- Peter Drucker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','ASHes to ASHes, DOS to DOS.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The clothes have no emperor.<BR>\n&nbsp;-- C.A.R. Hoare, commenting on ADA.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"The C Programming Language -- A language which combines the flexibility of<BR>\nassembly language with the power of assembly language.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','ASCII a stupid question, you get an EBCDIC answer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The bugs you have to avoid are the ones that give the user not only<BR>\nthe inclination to get on a plane, but also the time.<BR>\n&nbsp;-- Kay Bostic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The Buddha, the Godhead, resides quite as comfortably in the circuits of a<BR>\ndigital computer or the gears of a cycle transmission as he does at the top<BR>\nof a mountain or in the petals of a flower.  To think otherwise is to demean<BR>\nthe Buddha -- which is to demean oneself.<BR>\n&nbsp;-- Robert Pirsig, \"Zen and the Art of Motorcycle Maintenance\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As Will Rogers would have said, \"There is no such things as a free variable.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The bogosity meter just pegged.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The best way to accelerate a Macintoy is at 9.8 meters per second per second.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As the trials of life continue to take their toll, remember that there<BR>\nis always a future in Computer Maintenance.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The beer-cooled computer does not harm the ozone layer.<BR>\n&nbsp;-- John M. Ford, a.k.a. Dr. Mike<BR>\n&nbsp;[If I can read my notes from the Ask Dr. Mike session at Baycon, I<BR>\n&nbsp;believe he added that the beer-cooled computer uses \"Forget Only<BR>\n&nbsp;Memory\".  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As the system comes up, the component builders will from time to time appear,<BR>\nbearing hot new versions of their pieces -- faster, smaller, more complete,<BR>\nor putatively less buggy.  The replacement of a working component by a new<BR>\nversion requires the same systematic testing procedure that adding a new<BR>\ncomponent does, although it should require less time, for more complete and<BR>\nefficient test cases will usually be available.<BR>\n&nbsp;-- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','System going down at 5 this afternoon to install scheduler bug.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As far as we know, our computer has never had an undetected error.<BR>\n&nbsp;-- Weisert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The Analytical Engine weaves Algebraical patterns just as the Jacquard<BR>\nloom weaves flowers and leaves.<BR>\n&nbsp;-- Ada Augusta, Countess of Lovelace, the first programmer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"The algorithm to do that is extremely nasty.  You might want to mug<BR>\nsomeone with it.\"<BR>\n&nbsp;-- M. Devine, Computer Science 340');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As part of the conversion, computer specialists rewrote 1,500 programs;<BR>\na process that traditionally requires some debugging.<BR>\n&nbsp;-- USA Today, referring to the Internal Revenue Service<BR>\n&nbsp;conversion to a new computer system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The absence of labels [in ECL] is probably a good thing.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The 11 is for people with the pride of a 10 and the pocketbook of an 8.<BR>\n&nbsp;-- R.B. Greenberg [referring to PDPs?]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As part of an ongoing effort to keep you, the Fortune reader, abreast of<BR>\nthe valuable information the daily crosses the USENET, Fortune presents:<BR>\n&nbsp;News articles that answer *your* questions, #1:<BR>\n&nbsp;Newsgroups: comp.sources.d<BR>\n&nbsp;Subject: how do I run C code received from sources<BR>\n&nbsp;Keywords: C sources<BR>\n&nbsp;Distribution: na<BR>\n&nbsp;I do not know how to run the C programs that are posted in the<BR>\n&nbsp;sources newsgroup.  I save the files, edit them to remove the<BR>\n&nbsp;headers, and change the mode so that they are executable, but I<BR>\n&nbsp;cannot get them to run.  (I have never written a C program before.)<BR>\n&nbsp;Must they be compiled?  With what compiler?  How do I do this?  If<BR>\n&nbsp;I compile them, is an object code file generated or must I generate<BR>\n&nbsp;it explicitly with the > character?  Is there something else that<BR>\n&nbsp;must be done?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As of next week, passwords will be entered in Morse code.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... that the notions of \"hardware\", and \"software\" should be extended by<BR>\nthe notion of LIVEWARE - being that which produces software for use on<BR>\nhardware.  This produces an obvious extension to the concept of MONITORS.<BR>\nA liveware monitor is a person dedicated to the task of ensuring that the<BR>\nliveware does not interfere with the real-time processes, invoking the<BR>\nREAL-TIME EXECUTIONER to delete liveware that adversely affects ...<BR>\n&nbsp;-- Linden and Wihelminalaan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #16: C-<BR>\n&nbsp;This language was named for the grade received by its creator when he<BR>\nsubmitted it as a class project in a graduate programming class.  C- is best<BR>\ndescribed as a \"low-level\" programming language.  In fact, the language<BR>\ngenerally requires more C- statements than machine-code statements to<BR>\nexecute a given task.  In this respect, it is very similar to COBOL.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Basic is a high level languish.  APL is a high level anguish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The fountain code has been tightened slightly so you can no longer dip<BR>\nobjects into a fountain or drink from one while you are floating in mid-air<BR>\ndue to levitation.<BR>\n&nbsp;Teleporting to hell via a teleportation trap will no longer occur<BR>\nif the character does not have fire resistance.<BR>\n&nbsp;-- README file from the NetHack game');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The following quote is from page 4-27 of the MSCP Basic Disk Functions<BR>\nManual which is part of the UDA50 Programmers Doc Kit manuals:<BR>\n&nbsp;As stated above, the host area of a disk is structured as a vector of<BR>\nlogical blocks.  From a performance viewpoint, however, it is more<BR>\nappropriate to view the host area as a four dimensional hyper-cube, the<BR>\nfour dimensions being cylinder, group, track, and sector.<BR>\n. . .<BR>\nReferring to our hyper-cube analogy, the set of potentially accessible<BR>\nblocks form a line parallel to the track axis.  This line moves<BR>\nparallel to the sector axis, wrapping around when it reaches the edge<BR>\nof the hyper-cube.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Avoid strange women and temporary variables.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The flow chart is a most thoroughly oversold piece of program documentation.<BR>\n&nbsp;-- Frederick Brooks, \"The Mythical Man Month\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The first version always gets thrown away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','At the source of every error which is blamed on the computer you will find<BR>\nat least two human errors, including the error of blaming it on the computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The FIELD GUIDE to NORTH AMERICAN MALES<BR>\n&nbsp;SPECIES:	Cranial Males<BR>\nSUBSPECIES:	The Hacker (homo computatis)<BR>\nPlumage:<BR>\n&nbsp;All clothes have a slightly crumpled look as though they came off the<BR>\n&nbsp;top of the laundry basket.  Style varies with status.  Hacker managers<BR>\n&nbsp;wear gray polyester slacks, pink or pastel shirts with wide collars,<BR>\n&nbsp;and paisley ties; staff wears cinched-up baggy corduroy pants, white<BR>\n&nbsp;or blue shirts with button-down collars, and penholder in pocket.<BR>\n&nbsp;Both managers and staff wear running shoes to work, and a black<BR>\n&nbsp;plastic digital watch with calculator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','At Group L, Stoffel oversees six first-rate programmers, a managerial<BR>\nchallenge roughly comparable to herding cats.<BR>\n&nbsp;-- The Washington Post Magazine, 9 June, 1985');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The FIELD GUIDE to NORTH AMERICAN MALES<BR>\n&nbsp;SPECIES:	Cranial Males<BR>\nSUBSPECIES:	The Hacker (homo computatis)<BR>\nDescription:<BR>\n&nbsp;Gangly and frail, the hacker has a high forehead and thinning hair.<BR>\n&nbsp;Head disproportionately large and crooked forward, complexion wan and<BR>\n&nbsp;sightly gray from CRT illumination.  He has heavy black-rimmed glasses<BR>\n&nbsp;and a look of intense concentration, which may be due to a software<BR>\n&nbsp;problem or to a pork-and-bean breakfast.<BR>\nFeathering:<BR>\n&nbsp;HOMO COMPUTATIS saw a Brylcreem ad fifteen years ago and believed it.<BR>\n&nbsp;Consequently, crest is greased down, except for the cowlick.<BR>\nSong:<BR>\n&nbsp;A rather plaintive \"Is it up?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','At first sight, the idea of any rules or principles being superimposed on<BR>\nthe creative mind seems more likely to hinder than to help, but this is<BR>\nquite untrue in practice.  Disciplined thinking focuses inspiration rather<BR>\nthan blinkers it.<BR>\n&nbsp;-- G.L. Glegg, \"The Design of Design\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The disks are getting full; purge a file today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','At about 2500 A.D., humankind discovers a computer problem that *must* be<BR>\nsolved.  The only difficulty is that the problem is NP complete and will<BR>\ntake thousands of years even with the latest optical biologic technology<BR>\navailable.  The best computer scientists sit down to think up some solution.<BR>\nIn great dismay, one of the C.S. people tells her husband about it.  There<BR>\nis only one solution, he says.  Remember physics 103, Modern Physics, general<BR>\nrelativity and all.  She replies, \"What does that have to do with solving<BR>\na computer problem?\"<BR>\n&nbsp;\"Remember the twin paradox?\"<BR>\n&nbsp;After a few minutes, she says, \"I could put the computer on a very<BR>\nfast machine and the computer would have just a few minutes to calculate but<BR>\nthat is the exact opposite of what we want... Of course!  Leave the<BR>\ncomputer here, and accelerate the earth!\"<BR>\n&nbsp;The problem was so important that they did exactly that.  When<BR>\nthe earth came back, they were presented with the answer:<BR>\n&nbsp;IEH032 Error in JOB Control Card.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The difference between art and science is that science is what we<BR>\nunderstand well enough to explain to a computer.  Art is everything else.<BR>\n&nbsp;-- Donald Knuth, \"Discover\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The debate rages on: Is PL/I Bachtrian or Dromedary?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Asynchronous inputs are at the root of our race problems.<BR>\n&nbsp;-- D. Winker and F. Prosser');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The day-to-day travails of the IBM programmer are so amusing to most of<BR>\nus who are fortunate enough never to have been one -- like watching<BR>\nCharlie Chaplin trying to cook a shoe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The connection between the language in which we think/program and the problems<BR>\nand solutions we can imagine is very close.  For this reason restricting<BR>\nlanguage features with the intent of eliminating programmer errors is at best<BR>\ndangerous.<BR>\n&nbsp;-- Bjarne Stroustrup');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Beware of Programmers who carry screwdrivers.<BR>\n&nbsp;-- Leonard Brandwein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #15 -- DOGO<BR>\n&nbsp;Developed at the Massachusetts Institute of Obedience Training, DOGO<BR>\nDOGO heralds a new era of computer-literate pets.  DOGO commands include<BR>\nSIT, STAY, HEEL, and ROLL OVER.  An innovative feature of DOGO is \"puppy<BR>\ngraphics\", a small cocker spaniel that occasionally leaves a deposit as<BR>\nit travels across the screen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #14 -- VALGOL<BR>\n&nbsp;VALGOL is enjoying a dramatic surge of popularity across the<BR>\nindustry.  VALGOL commands include REALLY, LIKE, WELL, and Y*KNOW.<BR>\nVariables are assigned with the =LIKE and =TOTALLY operators.  Other<BR>\noperators include the \"California booleans\", AX and NOWAY.  Loops are<BR>\naccomplished with the FOR SURE construct.  A simple example:<BR>\n&nbsp;LIKE, Y*KNOW(I MEAN)START<BR>\n&nbsp;IF PIZZA	=LIKE BITCHEN AND<BR>\n&nbsp;GUY		=LIKE TUBULAR AND<BR>\n&nbsp;VALLEY GIRL	=LIKE GRODY**MAX(FERSURE)**2<BR>\n&nbsp;THEN<BR>\n&nbsp;FOR I =LIKE 1 TO OH*MAYBE 100<BR>\n&nbsp;DO*WAH - (DITTY**2); BARF(I)=TOTALLY GROSS(OUT)<BR>\n&nbsp;SURE<BR>\n&nbsp;LIKE, BAG THIS PROGRAM; REALLY; LIKE TOTALLY(Y*KNOW); IM*SURE<BR>\n&nbsp;GOTO THE MALL<BR>\n&nbsp;VALGOL is also characterized by its unfriendly error messages.  For<BR>\nexample, when the user makes a syntax error, the interpreter displays the<BR>\nmessage GAG ME WITH A SPOON!  A successful compile may be termed MAXIMALLY<BR>\nAWESOME!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Beware of bugs in the above code; I have only proved it correct, not tried it.<BR>\n&nbsp;-- Donald Knuth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #13: SLOBOL<BR>\n&nbsp;SLOBOL is best known for the speed, or lack of it, of its compiler.<BR>\nAlthough many compilers allow you to take a coffee break while they<BR>\ncompile, SLOBOL compilers allow you to travel to Bolivia to pick the<BR>\ncoffee.  Forty-three programmers are known to have died of boredom<BR>\nsitting at their terminals while waiting for a SLOBOL program to<BR>\ncompile.  Weary SLOBOL programmers often turn to a related (but<BR>\ninfinitely faster) language, COCAINE.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #12: LITHP<BR>\n&nbsp;This otherwise unremarkable language is distinguished by the absence of<BR>\nan \"S\" in its character set; users must substitute \"TH\".  LITHP is said<BR>\nto be useful in protheththing lithtth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Bell Labs Unix -- Reach out and grep someone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The IBM purchase of ROLM gives new meaning to the term \"twisted pair\".<BR>\n&nbsp;-- Howard Anderson, \"Yankee Group\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The IBM 2250 is impressive ...<BR>\nif you compare it with a system selling for a tenth its price.<BR>\n&nbsp;-- D. Cohen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','BASIC is to computer programming as QWERTY is to typing.<BR>\n&nbsp;-- Seymour Papert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The human mind ordinarily operates at only ten percent of its capacity<BR>\n-- the rest is overhead for the operating system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Software suppliers are trying to make their software packages more<BR>\n\"user-friendly\".  ...  Their best approach, so far, has been to take all<BR>\nthe old brochures, and stamp the words, \"user-friendly\" on the cover.<BR>\n&nbsp;-- Bill Gates, Microsoft, Inc.<BR>\n&nbsp;[Pot. Kettle. Black.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Software production is assumed to be a line function, but it is run<BR>\nlike a staff function.<BR>\n&nbsp;-- Paul Licker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Any programming language is at its best before it is implemented and used.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Breadth-first search is the bulldozer of science.<BR>\n&nbsp;-- Randy Goebel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The New Testament offers the basis for modern computer coding theory,<BR>\nin the form of an affirmation of the binary number system.<BR>\n&nbsp;But let your communication be Yea, yea; nay, nay:<BR>\n&nbsp;for whatsoever is more than these cometh of evil.<BR>\n&nbsp;-- Matthew 5:37');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Brain fried -- Core dumped');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The moving cursor writes, and having written, blinks on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The most important early product on the way to developing a good product<BR>\nis an imperfect version.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The misnaming of fields of study is so common as to lead to what might be<BR>\ngeneral systems laws.  For example, Frank Harary once suggested the law that<BR>\nany field that had the word \"science\" in its name was guaranteed thereby<BR>\nnot to be a science.  He would cite as examples Military Science, Library<BR>\nScience, Political Science, Homemaking Science, Social Science, and Computer<BR>\nScience.  Discuss the generality of this law, and possible reasons for its<BR>\npredictive power.<BR>\n&nbsp;-- Gerald Weinberg, \"An Introduction to General Systems<BR>\n&nbsp;Thinking\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Both models are identical in performance, functional operation, and<BR>\ninterface circuit details.  The two models, however, are not compatible<BR>\non the same communications line connection.<BR>\n&nbsp;-- Bell System Technical Reference');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The meta-Turing test counts a thing as intelligent if it seeks to<BR>\ndevise and apply Turing tests to objects of its own creation.<BR>\n&nbsp;-- Lew Mammel, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The meat is rotten, but the booze is holding out.<BR>\n&nbsp;Computer translation of \"The spirit is willing, but the flesh is weak.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','BLISS is ignorance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The master programmer moves from program to program without fear.  No<BR>\nchange in management can harm him.  He will not be fired, even if the project<BR>\nis canceled. Why is this?  He is filled with the Tao.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Behind every great computer sits a skinny little geek.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The last time somebody said, \"I find I can write much better with a word<BR>\nprocessor.\", I replied, \"They used to say the same thing about drugs.\"<BR>\n&nbsp;-- Roy Blount, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The idea that an arbitrary naive human should be able to properly use a given<BR>\ntool without training or understanding is even more wrong for computing than<BR>\nit is for other tools (e.g. automobiles, airplanes, guns, power saws).<BR>\n&nbsp;-- Doug Gwyn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Blinding speed can compensate for a lot of deficiencies.<BR>\n&nbsp;-- David Nichols');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The Macintosh is Xerox technology at its best.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Beware the new TTY code!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #2: RENE<BR>\n&nbsp;Named after the famous French philosopher and mathematician Rene DesCartes,<BR>\nRENE is a language used for artificial intelligence.  The language is being<BR>\ndeveloped at the Chicago Center of Machine Politics and Programming under a<BR>\ngrant from the Jane Byrne Victory Fund.  A spokesman described the language<BR>\nas \"Just as great as dis [sic] city of ours.\"<BR>\n&nbsp;The center is very pleased with progress to date.  They say they have almost<BR>\nsucceeded in getting a VAX to think. However, sources inside the<BR>\norganization say that each time the machine fails to think it ceases to exist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The \"cutting edge\" is getting rather dull.<BR>\n&nbsp;-- Andy Purshottam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #18: FIFTH<BR>\n&nbsp;FIFTH is a precision mathematical language in which the data types<BR>\nrefer to quantity.  The data types range from CC, OUNCE, SHOT, and<BR>\nJIGGER to FIFTH (hence the name of the language), LITER, MAGNUM and<BR>\nBLOTTO.  Commands refer to ingredients such as CHABLIS, CHARDONNAY,<BR>\nCABERNET, GIN, VERMOUTH, VODKA, SCOTCH, and WHATEVERSAROUND.<BR>\n&nbsp;The many versions of the FIFTH language reflect the sophistication and<BR>\nfinancial status of its users.  Commands in the ELITE dialect include<BR>\nVSOP and LAFITE, while commands in the GUTTER dialect include HOOTCH<BR>\nand RIPPLE. The latter is a favorite of frustrated FORTH programmers<BR>\nwho end up using this language.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Beware of the Turing Tar-pit in which everything is possible but nothing of <BR>\ninterest is easy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE LESSER-KNOWN PROGRAMMING LANGUAGES #17: SARTRE<BR>\n&nbsp;Named after the late existential philosopher, SARTRE is an extremely<BR>\nunstructured language.  Statements in SARTRE have no purpose; they just are.<BR>\nThus SARTRE programs are left to define their own functions. SARTRE<BR>\nprogrammers tend to be boring and depressed, and are no fun at parties.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... there are about 5,000 people who are part of that commitee.  These guys<BR>\nhave a hard time sorting out what day to meet, and whether to eat croissants<BR>\nor doughnuts for breakfast -- let alone how to define how all these complex<BR>\nlayers that are going to be agreed upon.<BR>\n&nbsp;-- Craig Burton of Novell, Network World');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','CCI Power 6/40: one board, a megabyte of cache, and an attitude...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','THEGODDESSOFTHENETHASTWISTINGFINGERSANDHERVOICEISLIKEAJAVELININTHENIGHTDUDE');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The young lady had an unusual list,<BR>\nLinked in part to a structural weakness.<BR>\nShe set no preconditions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','CChheecckk yyoouurr dduupplleexx sswwiittcchh..');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The road to hell is paved with NAND gates.<BR>\n&nbsp;-- J. Gooding');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','BYTE editors are people who separate the wheat from the chaff, and then<BR>\ncarefully print the chaff.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The relative importance of files depends on their cost in terms of the<BR>\nhuman effort needed to regenerate them.<BR>\n&nbsp;-- T.A. Dolotta');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The question of whether computers can think is just like the question of<BR>\nwhether submarines can swim.<BR>\n&nbsp;-- Edsger W. Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"But what we need to know is, do people want nasally-insertable computers?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The programmers of old were mysterious and profound.  We cannot fathom<BR>\ntheir thoughts, so all we do is describe their appearance.<BR>\n&nbsp;Aware, like a fox crossing the water.  Alert, like a general on the<BR>\nbattlefield.  Kind, like a hostess greeting her guests. Simple, like uncarved<BR>\nblocks of wood.  Opaque, like black pools in darkened caves.<BR>\n&nbsp;Who can tell the secrets of their hearts and minds?<BR>\n&nbsp;The answer exists only in the Tao.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The problems of business administration in general, and database management in<BR>\nparticular are much to difficult for people that think in IBMese, compounded<BR>\nwith sloppy english.<BR>\n&nbsp;-- Edsger Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The problem with engineers is that they tend to cheat in order to<BR>\nget results.<BR>\n&nbsp;The problem with mathematicians is that they tend to work on toy<BR>\nproblems in order to get results.<BR>\n&nbsp;The problem with program verifiers is that they tend to cheat at<BR>\ntoy problems in order to get results.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','But in our enthusiasm, we could not resist a radical overhaul of the<BR>\nsystem, in which all of its major weaknesses have been exposed,<BR>\nanalyzed, and replaced with new weaknesses.<BR>\n&nbsp;-- Bruce Leverett, \"Register Allocation in Optimizing Compilers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The primary purpose of the DATA statement is to give names to constants;<BR>\ninstead of referring to pi as 3.141592653589793 at every appearance, the<BR>\nvariable PI can be given that value with a DATA statement and used instead<BR>\nof the longer form of the constant.  This also simplifies modifying the<BR>\nprogram, should the value of pi change.<BR>\n&nbsp;-- FORTRAN manual for Xerox Computers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The primary function of the design engineer is to make things<BR>\ndifficult for the fabricator and impossible for the serviceman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Bus error -- please leave by the rear door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The party adjourned to a hot tub, yes.  Fully clothed, I might add.<BR>\n&nbsp;-- IBM employee, testifying in California State Supreme Court');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Bus error -- driver executed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The only thing worse than X Windows: (X Windows) - X');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The only thing cheaper than hardware is talk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Building translators is good clean fun.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Build a system that even a fool can use and only a fool will want to use it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The number of computer scientists in a room is inversely proportional<BR>\nto the number of bugs in their code.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The number of arguments is unimportant unless some of them are correct.<BR>\n&nbsp;-- Ralph Hartley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The notion of a \"record\" is an obsolete remnant of the days of the 80-column<BR>\ncard.<BR>\n&nbsp;-- Dennis M. Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The nice thing about standards is that there are so many of them to choose from.<BR>\n&nbsp;-- Andrew S. Tanenbaum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The next person to mention spaghetti stacks to me is going to have<BR>\nhis head knocked off.<BR>\n&nbsp;-- Bill Conrad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The world will end in 5 minutes.  Please log out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The world is not octal despite DEC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The world is coming to an end.  Please log off.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The world is coming to an end ... SAVE YOUR BUFFERS!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;The wise programmer is told about the Tao and follows it.  The average<BR>\nprogrammer is told about the Tao and searches for it.  The foolish programmer<BR>\nis told about the Tao and laughs at it.  If it were not for laughter, there<BR>\nwould be no Tao.<BR>\n&nbsp;The highest sounds are the hardest to hear.  Going forward is a way to<BR>\nretreat.  Greater talent shows itself late in life.  Even a perfect program<BR>\nstill has bugs.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The value of a program is proportional to the weight of its output.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The use of COBOL cripples the mind; its teaching should, therefore, be<BR>\nregarded as a criminal offence.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The use of anthropomorphic terminology when dealing with computing systems<BR>\nis a symptom of professional immaturity.<BR>\n&nbsp;-- Edsger Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The UNIX philosophy basically involves giving you enough rope to<BR>\nhang yourself.  And then a couple of feet more, just to be sure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','C++ is the best example of second-system effect since OS/360.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The trouble with computers is that they do what you tell them, not what<BR>\nyou want.<BR>\n&nbsp;-- D. Cohen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The tao that can be tar(1)ed<BR>\nis not the entire Tao.<BR>\nThe path that can be specified <BR>\nis not the Full Path.<BR>\n&nbsp;We declare the names<BR>\nof all variables and functions.<BR>\nYet the Tao has no type specifier.<BR>\n&nbsp;Dynamically binding, you realize the magic.<BR>\nStatically binding, you see only the hierarchy.<BR>\n&nbsp;Yet magic and hierarchy<BR>\narise from the same source,<BR>\nand this source has a null pointer.<BR>\n&nbsp;Reference the NULL within NULL,<BR>\nit is the gateway to all wizardry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','C makes it easy for you to shoot yourself in the foot.  C++ makes that<BR>\nharder, but when you do, it blows away your whole leg.<BR>\n&nbsp;-- Bjarne Stroustrup');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The system will be down for 10 days for preventive maintenance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The system was down for backups from 5am to 10am last Saturday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','C for yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;THE STORY OF CREATION<BR>\n&nbsp;or<BR>\n&nbsp;THE MYTH OF URK<BR>\n&nbsp;In the beginning there was data.  The data was without form and null, and<BR>\ndarkness was upon the face of the console; and the Spirit of IBM was moving<BR>\nover the face of the market.  And DEC said, \"Let there be registers;\" and<BR>\nthere were registers.  And DEC saw that they carried; and DEC separated the<BR>\ndata from the instructions.  DEC called the data Stack, and the instructions<BR>\nthey called Code.  And there was evening and there was morning, one interrupt<BR>\n...<BR>\n&nbsp;-- Rico Tudor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The steady state of disks is full.<BR>\n&nbsp;-- Ken Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','C Code.<BR>\nC Code Run.<BR>\nRun, Code, RUN!<BR>\n&nbsp;PLEASE!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The sendmail configuration file is one of those files that looks like someone<BR>\nbeat their head on the keyboard.  After working with it... I can see why!<BR>\n&nbsp;-- Harry Skelton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Byte your tongue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computers will not be perfected until they can compute how much more<BR>\nthan the estimate the job will cost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... computer hardware progress is so fast.  No other technology since<BR>\ncivilization began has seen six orders of magnitude in performance-price<BR>\ngain in 30 years.<BR>\n&nbsp;-- Fred Brooks');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;There was once a programmer who was attached to the court of the<BR>\nwarlord of Wu.  The warlord asked the programmer: \"Which is easier to design:<BR>\nan accounting package or an operating system?\"<BR>\n&nbsp;\"An operating system,\" replied the programmer.<BR>\n&nbsp;The warlord uttered an exclamation of disbelief.  \"Surely an<BR>\naccounting package is trivial next to the complexity of an operating<BR>\nsystem,\" he said.<BR>\n&nbsp;\"Not so,\" said the programmer, \"when designing an accounting package,<BR>\nthe programmer operates as a mediator between people having different ideas:<BR>\nhow it must operate, how its reports must appear, and how it must conform to<BR>\nthe tax laws.  By contrast, an operating system is not limited my outside<BR>\nappearances.  When designing an operating system, the programmer seeks the<BR>\nsimplest harmony between machine and ideas.  This is why an operating system<BR>\nis easier to design.\"<BR>\n&nbsp;The warlord of Wu nodded and smiled.  \"That is all good and well, but<BR>\nwhich is easier to debug?\"<BR>\n&nbsp;The programmer made no reply.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;There once was a master programmer who wrote unstructured programs.<BR>\nA novice programmer, seeking to imitate him, also began to write unstructured<BR>\nprograms.  When the novice asked the master to evaluate his progress, the<BR>\nmaster criticized him for writing unstructured programs, saying: \"What is<BR>\nappropriate for the master is not appropriate for the novice.  You must<BR>\nunderstand the Tao before transcending structure.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','COMPASS [for the CDC-6000 series] is the sort of assembler one expects from<BR>\na corporation whose president codes in octal.<BR>\n&nbsp;-- J.N. Gray');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;There once was a man who went to a computer trade show.  Each day as<BR>\nhe entered, the man told the guard at the door:<BR>\n&nbsp;\"I am a great thief, renowned for my feats of shoplifting.  Be<BR>\nforewarned, for this trade show shall not escape unplundered.\"<BR>\n&nbsp;This speech disturbed the guard greatly, because there were millions<BR>\nof dollars of computer equipment inside, so he watched the man carefully.<BR>\nBut the man merely wandered from booth to booth, humming quietly to himself.<BR>\n&nbsp;When the man left, the guard took him aside and searched his clothes,<BR>\nbut nothing was to be found.<BR>\n&nbsp;On the next day of the trade show, the man returned and chided the<BR>\nguard saying: \"I escaped with a vast booty yesterday, but today will be even<BR>\nbetter.\"  So the guard watched him ever more closely, but to no avail.<BR>\n&nbsp;On the final day of the trade show, the guard could restrain his<BR>\ncuriosity no longer. \"Sir Thief,\" he said, \"I am so perplexed, I cannot live<BR>\nin peace.  Please enlighten me.  What is it that you are stealing?\"<BR>\n&nbsp;The man smiled.  \"I am stealing ideas,\" he said.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You will have many recoverable tape errors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You will have a head crash on your private pack.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTRAN is the language of Powerful Computers.<BR>\n&nbsp;-- Steven Feiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You must realize that the computer has it in for you.  The irrefutable<BR>\nproof of this is that the computer always does what you tell it to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTRAN is not a flower but a weed -- it is hardy, occasionally blooms,<BR>\nand grows in every computer.<BR>\n&nbsp;-- A.J. Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You have mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You have junk mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTH IF HONK THEN');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You have a tendency to feel you are superior to most computers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"For that matter, compare your pocket computer with the massive jobs of<BR>\na thousand years ago.  Why not, then, the last step of doing away with<BR>\ncomputers altogether?\"<BR>\n&nbsp;-- Jehan Shuman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You have a message from the operator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You have a massage (from the Swedish prime minister).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Fly Windows NT:<BR>\nAll the passengers carry their seats out onto the tarmac, placing the chairs<BR>\nin the outline of a plane. They all sit down, flap their arms and make jet<BR>\nswooshing sounds as if they are flying.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You had mail.  Paul read it, so ask him what it said.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You had mail, but the super-user read it, and deleted it!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I am a computer. I am dumber than any human and smarter than any administrator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I *____knew* I had some reason for not logging you off... If I could just<BR>\nremember what it was.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','How much net work could a network work, if a network could net work?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"How do I love thee?  My accumulator overflows.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','HOST SYSTEM RESPONDING, PROBABLY UP...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','HOST SYSTEM NOT RESPONDING, PROBABLY DOWN. DO YOU WANT TO WAIT? (Y/N)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','HOLY MACRO!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Help stamp out Mickey-Mouse computer interfaces -- Menus are for Restaurants!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','HEAD CRASH!!  FILES LOST!!<BR>\nDetails at 11.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Have you reconsidered a computer career?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Has everyone noticed that all the letters of the word \"database\" are<BR>\ntyped with the left hand?  Now the layout of the QWERTYUIOP typewriter<BR>\nkeyboard was designed, among other things, to facilitate the even use<BR>\nof both hands.  It follows, therefore, that writing about databases is<BR>\nnot only unnatural, but a lot harder than it appears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;Hardware met Software on the road to Changtse.  Software said: \"You<BR>\nare the Yin and I am the Yang.  If we travel together we will become famous<BR>\nand earn vast sums of money.\"  And so the pair set forth together, thinking<BR>\nto conquer the world.<BR>\n&nbsp;Presently, they met Firmware, who was dressed in tattered rags, and<BR>\nhobbled along propped on a thorny stick.  Firmware said to them: \"The Tao<BR>\nlies beyond Yin and Yang.  It is silent and still as a pool of water.  It does<BR>\nnot seek fame, therefore nobody knows its presence.  It does not seeks fortune,<BR>\nfor it is complete within itself.  It exists beyond space and time.\"<BR>\n&nbsp;Software and Hardware, ashamed, returned to their homes.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You might have mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Happiness is twin floppies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Happiness is a hard disk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Hackers of the world, unite!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Hackers are just a migratory lifeform with a tropism for computers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Good evening, gentlemen.  I am a HAL 9000 computer.  I became operational<BR>\nat the HAL plant in Urbana, Illinois, on January 11th, nineteen hundred<BR>\nninety-five.  My supervisor was Mr. Langley, and he taught me to sing a<BR>\nsong.  If you would like, I could sing it for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','God made machine language; all the rest is the work of man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','God is real, unless declared integer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','//GO.SYSIN DD *, DOODAH, DOODAH');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Giving up on assembly language was the apple in our Garden of Eden:  Languages<BR>\nwhose use squanders machine cycles are sinful.  The LISP machine now permits<BR>\nLISP programmers to abandon bra and fig-leaf.<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Given its constituency, the only thing I expect to be \"open\" about [the<BR>\nOpen Software Foundation] is its mouth.<BR>\n&nbsp;-- John Gilmore');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','GIVE:	Support the helpless victims of computer error.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Garbage In -- Gospel Out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I wish you humans would leave me alone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I must have slipped a disk -- my pack hurts!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I have sacrificed time, health, and fortune, in the desire to complete these<BR>\nCalculating Engines.  I have also declined several offers of great personal<BR>\nadvantage to myself.  But, notwithstanding the sacrifice of these advantages<BR>\nfor the purpose of maturing an engine of almost intellectual power, and<BR>\nafter expending from my own private fortune a larger sum than the government<BR>\nof England has spent on that machine, the execution of which it only<BR>\ncommenced, I have received neither an acknowledgement of my labors, not even<BR>\nthe offer of those honors or rewards which are allowed to fall within the<BR>\nreach of men who devote themselves to purely scientific investigations...<BR>\n&nbsp;If the work upon which I have bestowed so much time and thought were<BR>\na mere triumph over mechanical difficulties, or simply curious, or if the<BR>\nexecution of such engines were of doubtful practicability or utility, some<BR>\njustification might be found for the course which has been taken; but I<BR>\nventure to assert that no mathematician who has a reputation to lose will<BR>\never publicly express an opinion that such a machine would be useless if<BR>\nmade, and that no man distinguished as a civil engineer will venture to<BR>\ndeclare the construction of such machinery impracticable...<BR>\n&nbsp;And at a period when the progress of physical science is obstructed<BR>\nby that exhausting intellectual and manual labor, indispensable for its<BR>\nadvancement, which it is the object of the Analytical Engine to relieve, I<BR>\nthink the application of machinery in aid of the most complicated and abtruse<BR>\ncalculations can no longer be deemed unworthy of the attention of the country.<BR>\nIn fact, there is no reason why mental as well as bodily labor should not<BR>\nbe economized by the aid of machinery.<BR>\n&nbsp;-- Charles Babbage, \"The Life of a Philosopher\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I have not yet begun to byte!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I have never seen anything fill up a vacuum so fast and still suck.<BR>\n&nbsp;-- Rob Pike, on X.<BR>\n&nbsp;Steve Jobs said two years ago that X is brain-damaged and it will be<BR>\ngone in two years.  He was half right.<BR>\n&nbsp;-- Dennis Ritchie<BR>\n&nbsp;Dennis Ritchie is twice as bright as Steve Jobs, and only half wrong.<BR>\n&nbsp;-- Jim Gettys');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I have a very small mind and must live with it.<BR>\n&nbsp;-- E. Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I had the rare misfortune of being one of the first people to try and<BR>\nimplement a PL/1 compiler.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I do not fear computers.  I fear the lack of them.<BR>\n&nbsp;-- Isaac Asimov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I cannot conceive that anybody will require multiplications at the rate<BR>\nof 40,000 or even 4,000 per hour ...<BR>\n&nbsp;-- F. H. Wales (1936)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I came, I saw, I deleted all your files.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I bet the human brain is a kludge.<BR>\n&nbsp;-- Marvin Minsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I am the wandering glitch -- catch me if you can.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I am professionally trained in computer science, which is to say<BR>\n(in all seriousness) that I am extremely poorly educated.<BR>\n&nbsp;-- Joseph Weizenbaum, \"Computer Power and Human Reason\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I am not now, nor have I ever been, a member of the demigodic party.<BR>\n&nbsp;-- Dennis Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','I am NOMAD!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If this is timesharing, give me my share right now.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;If the Tao is great, then the operating system is great.  If the<BR>\noperating system is great, then the compiler is great.  If the compiler<BR>\nis great, then the application is great.  If the application is great, then<BR>\nthe user is pleased and there is harmony in the world.<BR>\n&nbsp;The Tao gave birth to machine language.  Machine language gave birth<BR>\nto the assembler.<BR>\n&nbsp;The assembler gave birth to the compiler.  Now there are ten thousand<BR>\nlanguages.<BR>\n&nbsp;Each language has its purpose, however humble.  Each language<BR>\nexpresses the Yin and Yang of software.  Each language has its place within<BR>\nthe Tao.<BR>\n&nbsp;But do not program in COBOL if you can avoid it.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If the code and the comments disagree, then both are probably wrong.<BR>\n&nbsp;-- Norm Schryer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If the automobile had followed the same development as the computer, a<BR>\nRolls-Royce would today cost $100, get a million miles per per gallon,<BR>\nand explode once a year killing everyone inside.<BR>\n&nbsp;-- Robert Cringely, InfoWorld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"If that makes any sense to you, you have a big problem.\"<BR>\n&nbsp;-- C. Durance, Computer Science 234');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If he once again pushes up his sleeves in order to compute for 3 days<BR>\nand 3 nights in a row, he will spend a quarter of an hour before to<BR>\nthink which principles of computation shall be most appropriate.<BR>\n&nbsp;-- Voltaire, \"Diatribe du docteur Akakia\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If computers take over (which seems to be their natural tendency), it will<BR>\nserve us right.<BR>\n&nbsp;-- Alistair Cooke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If builders built buildings the way programmers wrote programs,<BR>\nthen the first woodpecker to come along would destroy civilization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If addiction is judged by how long a dumb animal will sit pressing a lever<BR>\nto get a \"fix\" of something, to its own detriment, then I would conclude<BR>\nthat netnews is far more addictive than cocaine.<BR>\n&nbsp;-- Rob Stampfli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If a group of _N persons implements a COBOL compiler, there will be _N-1<BR>\npasses.  Someone in the group has to be the manager.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If a 6600 used paper tape instead of core memory, it would use up tape<BR>\nat about 30 miles/second.<BR>\n&nbsp;-- Grishman, Assembly Language Programming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;In the beginning there was data.  The data was without form and<BR>\nnull, and darkness was upon the face of the console; and the Spirit of<BR>\nIBM was moving over the face of the market.  And DEC said, \"Let there<BR>\nbe registers\"; and there were registers.  And DEC saw that they<BR>\ncarried; and DEC separated the data from the instructions.  DEC called<BR>\nthe data Stack, and the instructions they called Code.  And there was<BR>\nevening and there was morning, one interrupt.<BR>\n&nbsp;-- Rico Tudor, \"The Story of Creation or, The Myth of Urk\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In seeking the unattainable, simplicity only gets in the way.<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In practice, failures in system development, like unemployment in Russia,<BR>\nhappens a lot despite official propaganda to the contrary.<BR>\n&nbsp;-- Paul Licker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In less than a century, computers will be making substantial progress on<BR>\n... the overriding problem of war and peace.<BR>\n&nbsp;-- James Slagle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In every non-trivial program there is at least one bug.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real Users know your home telephone number.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real Users hate Real Programmers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Real Users find the one combination of bizarre input values that shuts<BR>\ndown the system for days.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Some programming languages manage to absorb change, but withstand progress.<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Any sufficiently advanced bug is indistinguishable from a feature.<BR>\n&nbsp;-- Rich Kulawiec');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Some people claim that the UNIX learning curve is steep, but at least you<BR>\nonly have to climb it once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... Any resemblance between the above views and those of my employer,<BR>\nmy terminal, or the view out my window are purely coincidental.  Any<BR>\nresemblance between the above and my own views is non-deterministic.  The<BR>\nquestion of the existence of views in the absence of anyone to hold them<BR>\nis left as an exercise for the reader.  The question of the existence of<BR>\nthe reader is left as an exercise for the second god coefficient.  (A<BR>\ndiscussion of non-orthogonal, non-integral polytheism is beyond the scope<BR>\nof this article.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Slowly and surely the unix crept up on the Nintendo user ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Any program which runs right is obsolete.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Simulations are like miniskirts, they show a lot and hide the essentials.<BR>\n&nbsp;-- Hubert Kirrman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Any given program, when running, is obsolete.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As of next Tuesday, C will be flushed in favor of COBOL.<BR>\nPlease update your programs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','That does not compute.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Text processing has made it possible to right-justify any idea, even<BR>\none which cannot be justified on any other grounds.\"<BR>\n&nbsp;-- J. Finnegan, USC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','As of next Thursday, UNIX will be flushed in favor of TOPS-10.<BR>\nPlease update your programs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','TeX is potentially the most significant invention in typesetting in this<BR>\ncentury.  It introduces a standard language for computer typography, and in<BR>\nterms of importance could rank near the introduction of the Gutenberg press.<BR>\n&nbsp;-- Gordon Bell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In English, every word can be verbed.  Would that it were so in our<BR>\nprogramming languages.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In computing, the mean time to failure keeps getting shorter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In any problem, if you find yourself doing an infinite amount of work,<BR>\nthe answer may be obtained by inspection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In any formula, constants (especially those obtained from handbooks)<BR>\nare to be treated as variables.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In a surprise raid last night, federal agents ransacked a house in search<BR>\nof a rebel computer hacker.  However, they were unable to complete the arrest<BR>\nbecause the warrant was made out in the name of Don Provan, while the only<BR>\nperson in the house was named don provan.  Proving, once again, that Unix is<BR>\nsuperior to Tops10.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In a display of perverse brilliance, Carl the repairman mistakes a room<BR>\nhumidifier for a mid-range computer but manages to tie it into the network<BR>\nanyway.<BR>\n&nbsp;-- The 5th Wave');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','**** IMPORTANT ****  ALL USERS PLEASE NOTE ****<BR>\n&nbsp;Due to a recent systems overload error your recent disk files have been<BR>\nerased.  Therefore, in accordance with the UNIX Basic Manual, University of<BR>\nWashington Geophysics Manual, and Bylaw 9(c), Section XII of the Revised<BR>\nFederal Communications Act, you are being granted Temporary Disk Space,<BR>\nvalid for three months from this date, subject to the restrictions set forth<BR>\nin Appendix II of the Federal Communications Handbook (18th edition) as well<BR>\nas the references mentioned herein.  You may apply for more disk space at any<BR>\ntime.  Disk usage in or above the eighth percentile will secure the removal<BR>\nof all restrictions and you will immediately receive your permanent disk<BR>\nspace.  Disk usage in the sixth or seventh percentile will not effect the<BR>\nvalidity of your temporary disk space, though its expiration date may be<BR>\nextended for a period of up to three months.  A score in the fifth percentile<BR>\nor below will result in the withdrawal of your Temporary Disk space.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Imagine if every Thursday your shoes exploded if you tied them the usual<BR>\nway.  This happens to us all the time with computers, and nobody thinks of<BR>\ncomplaining.<BR>\n&nbsp;-- Jeff Raskin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Ignorance is bliss.<BR>\n&nbsp;-- Thomas Gray<BR>\n&nbsp;Fortune updates the great quotes, #42:<BR>\n&nbsp;BLISS is ignorance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If you put tomfoolery into a computer, nothing comes out but tomfoolery.<BR>\nBut this tomfoolery, having passed through a very expensive machine,<BR>\nis somehow enobled and no-one dare criticise it.<BR>\n&nbsp;-- Pierre Gallois');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','If you have a procedure with 10 parameters, you probably missed some.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is easier to write an incorrect program than understand a correct one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is easier to change the specification to fit the program than vice versa.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is against the grain of modern education to teach children to program.<BR>\nWhat fun is there in making plans, acquiring discipline in organizing<BR>\nthoughts, devoting attention to detail, and learning to be self-critical?<BR>\n&nbsp;-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is a very humbling experience to make a multimillion-dollar mistake, but<BR>\nit is also very memorable.  I vividly recall the night we decided how to<BR>\norganize the actual writing of external specifications for OS/360.  The<BR>\nmanager of architecture, the manager of control program implementation, and<BR>\nI were threshing out the plan, schedule, and division of responsibilities.<BR>\n&nbsp;The architecture manager had 10 good men.  He asserted that they<BR>\ncould write the specifications and do it right.  It would take ten months,<BR>\nthree more than the schedule allowed.<BR>\n&nbsp;The control program manager had 150 men.  He asserted that they<BR>\ncould prepare the specifications, with the architecture team coordinating;<BR>\nit would be well-done and practical, and he could do it on schedule.<BR>\nFuthermore, if the architecture team did it, his 150 men would sit twiddling<BR>\ntheir thumbs for ten months.<BR>\n&nbsp;To this the architecture manager responded that if I gave the control<BR>\nprogram team the responsibility, the result would not in fact be on time,<BR>\nbut would also be three months late, and of much lower quality.  I did, and<BR>\nit was.  He was right on both counts.  Moreover, the lack of conceptual<BR>\nintegrity made the system far more costly to build and change, and I would<BR>\nestimate that it added a year to debugging time.<BR>\n&nbsp;-- Frederick Brooks Jr., \"The Mythical Man Month\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It appears that PL/I (and its dialects) is, or will be, the most widely<BR>\nused higher level language for systems programming.<BR>\n&nbsp;-- J. Sammet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers',': is not an identifier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Is it possible that software is not like anything else, that it is meant to<BR>\nbe discarded:  that the whole point is to always see it as a soap bubble?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','IOT trap -- core dumped');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Introducing, the 1010, a one-bit processor.<BR>\n&nbsp;INSTRUCTION SET<BR>\n&nbsp;Code	Mnemonic	What<BR>\n&nbsp;0	NOP		No Operation<BR>\n&nbsp;1	JMP		Jump (address specified by next 2 bits)<BR>\n&nbsp;Now Available for only 12 1/2 cents!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','>>> Internal error in fortune program:<BR>\n>>>	fnum=2987  n=45  flag=1  goose_level=-232323<BR>\n>>> Please write down these values and notify fortune program administrator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Intel CPUs are not defective, they just act that way.<BR>\n&nbsp;-- Henry Spencer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... in three to eight years we will have a machine with the general<BR>\nintelligence of an average human being ... The machine will begin<BR>\nto educate itself with fantastic speed.  In a few months it will be<BR>\nat genius level and a few months after that its powers will be<BR>\nincalculable ...<BR>\n&nbsp;-- Marvin Minsky, LIFE Magazine, November 20, 1970');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','In the long run, every program becomes rococco, and then rubble.<BR>\n&nbsp;-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;In the east there is a shark which is larger than all other fish.  It<BR>\nchanges into a bird whose winds are like clouds filling the sky.  When this<BR>\nbird moves across the land, it brings a message from Corporate Headquarters.<BR>\nThis message it drops into the midst of the program mers, like a seagull<BR>\nmaking its mark upon the beach.  Then the bird mounts on the wind and, with<BR>\nthe blue sky at its back, returns home.<BR>\n&nbsp;The novice programmer stares in wonder at the bird, for he understands<BR>\nit not.  The average programmer dreads the coming of the bird, for he fears<BR>\nits message.  The master programmer continues to work at his terminal, for he<BR>\ndoes not know that the bird has come and gone.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;In the days when Sussman was a novice Minsky once came to him as he<BR>\nsat hacking at the PDP-6.<BR>\n&nbsp;\"What are you doing?\", asked Minsky.<BR>\n&nbsp;\"I am training a randomly wired neural net to play Tic-Tac-Toe.\"<BR>\n&nbsp;\"Why is the net wired randomly?\", inquired Minsky.<BR>\n&nbsp;\"I do not want it to have any preconceptions of how to play\".<BR>\n&nbsp;At this Minsky shut his eyes, and Sussman asked his teacher \"Why do<BR>\nyou close your eyes?\"<BR>\n&nbsp;\"So that the room will be empty.\"<BR>\n&nbsp;At that momment, Sussman was enlightened.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;In the beginning was the Tao.  The Tao gave birth to Space and Time.<BR>\nTherefore, Space and Time are the Yin and Yang of programming.<BR>\n&nbsp;Programmers that do not comprehend the Tao are always running out of<BR>\ntime and space for their programs.  Programmers that comprehend the Tao always<BR>\nhave enough time and space to accomplish their goals.<BR>\n&nbsp;How could it be otherwise?<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','((lambda (foo) (bar foo)) (baz))');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Know Thy User.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Kiss your keyboard goodbye!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Keep the number of passes in a compiler to a minimum.<BR>\n&nbsp;-- D. Gries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Just go with the flow control, roll with the crunches, and, when you get<BR>\na prompt, type like hell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Just about every computer on the market today runs Unix, except the Mac<BR>\n(and nobody cares about it).<BR>\n&nbsp;-- Bill Joy 6/21/85');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... Jesus cried with a loud voice: Lazarus, come forth; the bug hath been<BR>\nfound and thy program runneth.  And he that was dead came forth...<BR>\n&nbsp;-- John 11:43-44 [version 2.0?]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;It took 300 years to build and by the time it was 10% built,<BR>\neveryone knew it would be a total disaster. But by then the investment<BR>\nwas so big they felt compelled to go on. Since its completion, it has<BR>\ncost a fortune to maintain and is still in danger of collapsing.<BR>\n&nbsp;There are at present no plans to replace it, since it was never<BR>\nreally needed in the first place.<BR>\n&nbsp;I expect every installation has its own pet software which is<BR>\nanalogous to the above.<BR>\n&nbsp;-- K.E. Iverson, on the Leaning Tower of Pisa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"It runs like _x, where _x is something unsavory\"<BR>\n&nbsp;-- Prof. Romas Aleliunas, CS 435');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It must be remembered that there is nothing more difficult to plan, more<BR>\ndoubtful of success, nor more dangerous to manage, than the creation of<BR>\na new system.  For the initiator has the emnity of all who would profit<BR>\nby the preservation of the old institutions and merely lukewarm defenders<BR>\nin those who would gain by the new ones.<BR>\n&nbsp;-- Niccolo Machiavelli, 1513');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[It is] best to confuse only one issue at a time.<BR>\n&nbsp;-- K&R');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is practically impossible to teach good programming style to students<BR>\nthat have had prior exposure to BASIC: as potential programmers they are<BR>\nmentally mutilated beyond hope of regeneration.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is possible by ingenuity and at the expense of clarity... {to do almost<BR>\nanything in any language}.  However, the fact that it is possible to push<BR>\na pea up a mountain with your nose does not mean that this is a sensible<BR>\nway of getting it there.  Each of these techniques of language extension<BR>\nshould be used in its proper place.<BR>\n&nbsp;-- Christopher Strachey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','It is now pitch dark.  If you proceed, you will likely fall into a pit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Machines certainly can solve problems, store information, correlate,<BR>\nand play games -- but not with pleasure.<BR>\n&nbsp;-- Leo Rosten');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','4.2 BSD UNIX #57: Sun Jun 1 23:02:07 EDT 1986<BR>\n&nbsp;You swing at the Sun.  You miss.  The Sun swings.  He hits you with a<BR>\n575MB disk!  You read the 575MB disk.  It is written in an alien<BR>\ntongue and cannot be read by your tired Sun-2 eyes.  You throw the<BR>\n575MB disk at the Sun.  You hit!  The Sun must repair your eyes.  The<BR>\nSun reads a scroll.  He hits your 130MB disk!  He has defeated the<BR>\n130MB disk!  The Sun reads a scroll.  He hits your Ethernet board!  He<BR>\nhas defeated your Ethernet board!  You read a scroll of \"postpone until<BR>\nMonday at 9 AM\".  Everything goes dark...<BR>\n&nbsp;-- /etc/motd, cbosgd');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','1: No code table for op: ++post');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Loose bits sink chips.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','101 USES FOR A DEAD MICROPROCESSOR<BR>\n&nbsp;(1)  Scarecrow for centipedes<BR>\n&nbsp;(2)  Dead cat brush<BR>\n&nbsp;(3)  Hair barrettes<BR>\n&nbsp;(4)  Cleats<BR>\n&nbsp;(5)  Self-piercing earrings<BR>\n&nbsp;(6)  Fungus trellis<BR>\n&nbsp;(7)  False eyelashes<BR>\n&nbsp;(8)  Prosthetic dog claws<BR>\n&nbsp;.<BR>\n&nbsp;.<BR>\n&nbsp;.<BR>\n&nbsp;(99)  Window garden harrow (pulled behind Tonka tractors)<BR>\n&nbsp;(100) Killer velcro<BR>\n&nbsp;(101) Currency');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Long computations which yield zero are probably all for naught.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Little known fact about Middle Earth: The Hobbits had a very sophisticated<BR>\ncomputer network!  It was a Tolkien Ring...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Lisp Users:<BR>\nDue to the holiday next Monday, there will be no garbage collection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Line Printer paper is strongest at the perforations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Like punning, programming is a play on words.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Life would be so much easier if we could just look at the source code.<BR>\n&nbsp;-- Dave Olson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Leveraging always beats prototyping.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Let the machine do the dirty work.<BR>\n&nbsp;-- \"Elements of Programming Style\", Kernighan and Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','MOUNT TAPE U1439 ON B3, NO RING');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A CONS is an object which cares.<BR>\n&nbsp;-- Bernie Greenberg.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Most public domain software is free, at least at first glance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Mommy, what happens to your files when you die?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A computer without COBOL and Fortran is like a piece of chocolate cake<BR>\nwithout ketchup and mustard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Modeling paged and segmented memories is tricky business.<BR>\n&nbsp;-- P.J. Denning');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Message from Our Sponsor on ttyTV at 13:58 ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','MESSAGE ACKNOWLEDGED -- The Pershing II missiles have been launched.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Memory fault -- core...uh...um...core... Oh dammit, I forget!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Memory fault -- brain fried');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Memory fault - where am I?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A computer lets you make more mistakes faster than any other invention,<BR>\nwith the possible exceptions of handguns and Tequilla.<BR>\n&nbsp;-- Mitch Ratcliffe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Maybe Computer Science should be in the College of Theology.<BR>\n&nbsp;-- R. S. Barton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[A computer is] like an Old Testament god, with a lot of rules and no mercy.<BR>\n&nbsp;-- Joseph Campbell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','May the bluebird of happiness twiddle your bits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','May Euell Gibbons eat your only copy of the manual!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A complex system that works is invariably found to have evolved from a<BR>\nsimple system that works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','May all your PUSHes be POPped.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','** MAXIMUM TERMINALS ACTIVE.  TRY AGAIN LATER **');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Man is the best computer we can put aboard a spacecraft ... and the<BR>\nonly one that can be mass produced with unskilled labor.<BR>\n&nbsp;-- Wernher von Braun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... A booming voice says, \"Wrong, cretin!\", and you notice that you<BR>\nhave turned into a pile of dust.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Make sure your code does nothing gracefully.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Machines that have broken down will work perfectly when the repairman arrives.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No extensible language will be universal.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No directory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A LISP programmer knows the value of everything, but the cost of nothing.<BR>\n&nbsp;-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Niklaus Wirth has lamented that, whereas Europeans pronounce his name correctly<BR>\n(Ni-klows Virt), Americans invariably mangle it into (Nick-les Worth).  Which<BR>\nis to say that Europeans call him by name, but Americans call him by value.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','news: gotcha');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A large number of installed systems work by fiat.  That is, they work<BR>\nby being declared to work.<BR>\n&nbsp;-- Anatol Holt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','*** NEWS FLASH ***<BR>\n&nbsp;Archeologists find PDP-11/24 inside brain cavity of fossilized dinosaur<BR>\nskeleton!  Many Digital users fear that RSX-11M may be even more primitive<BR>\nthan DEC admits.  Price adjustments at 11:00.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','New systems generate new problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','New crypt.  See /usr/news/crypt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Never underestimate the bandwidth of a station wagon full of tapes.<BR>\n&nbsp;-- Dr. Warren Jackson, Director, UTCS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Never trust an operating system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A hacker does for love what others would not do for money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A Fortran compiler is the hobgoblin of little minis.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Never put off till run-time what you can do at compile-time.<BR>\n&nbsp;-- D. Gries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Never make anything simple and efficient when a way can be found to<BR>\nmake it complex and wonderful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A formal parsing algorithm should not always be used.<BR>\n&nbsp;-- D. Gries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Nearly every complex solution to a programming problem that I<BR>\nhave looked at carefully has turned out to be wrong.<BR>\n&nbsp;-- Brent Welch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;n = ((n >>  1) & 0x55555555) | ((n <<  1) & 0xaaaaaaaa);<BR>\n&nbsp;n = ((n >>  2) & 0x33333333) | ((n <<  2) & 0xcccccccc);<BR>\n&nbsp;n = ((n >>  4) & 0x0f0f0f0f) | ((n <<  4) & 0xf0f0f0f0);<BR>\n&nbsp;n = ((n >>  8) & 0x00ff00ff) | ((n <<  8) & 0xff00ff00);<BR>\n&nbsp;n = ((n >> 16) & 0x0000ffff) | ((n << 16) & 0xffff0000);<BR>\n&nbsp;-- C code which reverses the bits in a word.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A famous Lisp Hacker noticed an Undergraduate sitting in front of a Xerox<BR>\n1108, trying to edit a complex Klone network via a browser. Wanting to<BR>\nhelp, the Hacker clicked one of the nodes in the network with the mouse,<BR>\nand asked \"what do you see?\" Very earnestly, the Undergraduate replied \"I<BR>\nsee a cursor.\" The Hacker then quickly pressed the boot toggle at the back<BR>\nof the keyboard, while simultaneously hitting the Undergraduate over the head<BR>\nwith a thick Interlisp Manual.  The Undergraduate was then Enlightened.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','My sister opened a computer store in Hawaii.  She sells C shells down <BR>\nby the seashore.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','MVS Air Lines: <BR>\nThe passengers all gather in the hangar, watching hundreds of technicians<BR>\ncheck the flight systems on this immense, luxury aircraft. This plane has at<BR>\nleast 10 engines and seats over 1,000 passengers; bigger models in the fleet<BR>\ncan have more engines than anyone can count and fly even more passengers<BR>\nthan there are on Earth. It is claimed to cost less per passenger mile to<BR>\noperate these humungous planes than any other aircraft ever built, unless<BR>\nyou personally have to pay for the ticket. All the passengers scramble<BR>\naboard, as do the 200 technicians needed to keep it from crashing. The pilot<BR>\ntakes his place up in the glass cockpit. He guns the engines, only to<BR>\nrealise that the plane is too big to get through the hangar doors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A bug in the hand is better than one as yet undetected.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Many of the convicted thieves Parker has met began their<BR>\nlife of crime after taking college Computer Science courses.<BR>\n&nbsp;-- Roger Rapoport, \"Programs for Plunder\", Omni, March 1981');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Many companies that have made themselves dependent on [the equipment of a<BR>\ncertain major manufacturer] (and in doing so have sold their soul to the<BR>\ndevil) will collapse under the sheer weight of the unmastered complexity of<BR>\ntheir data processing systems.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Multics is security spelled sideways.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A disciple of another sect once came to Drescher as he was eating<BR>\nhis morning meal.  \"I would like to give you this personality test\", said<BR>\nthe outsider, \"because I want you to be happy.\"<BR>\n&nbsp;Drescher took the paper that was offered him and put it into the<BR>\ntoaster -- \"I wish the toaster to be happy too\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','MSDOS is not dead, it just smells that way.<BR>\n&nbsp;-- Henry Spencer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A debugged program is one for which you have not yet found the conditions<BR>\nthat make it fail.<BR>\n&nbsp;-- Jerry Ogdin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A manager went to the master programmer and showed him the requirements<BR>\ndocument for a new application.  The manager asked the master: \"How long will<BR>\nit take to design this system if I assign five programmers to it?\"<BR>\n&nbsp;\"It will take one year,\" said the master promptly.<BR>\n&nbsp;\"But we need this system immediately or even sooner!  How long will it<BR>\ntake it I assign ten programmers to it?\"<BR>\n&nbsp;The master programmer frowned.  \"In that case, it will take two years.\"<BR>\n&nbsp;\"And what if I assign a hundred programmers to it?\"<BR>\n&nbsp;The master programmer shrugged.  \"Then the design will never be<BR>\ncompleted,\" he said.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A manager went to his programmers and told them: \"As regards to your<BR>\nwork hours: you are going to have to come in at nine in the morning and leave<BR>\nat five in the afternoon.\"  At this, all of them became angry and several<BR>\nresigned on the spot.<BR>\n&nbsp;So the manager said: \"All right, in that case you may set your own<BR>\nworking hours, as long as you finish your projects on schedule.\"  The<BR>\nprogrammers, now satisfied, began to come in a noon and work to the wee<BR>\nhours of the morning.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','nohup rm -fr /&');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Nobody said computers were going to be polite.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A manager asked a programmer how long it would take him to finish the<BR>\nprogram on which he was working.  \"I will be finished tomorrow,\" the programmer<BR>\npromptly replied.<BR>\n&nbsp;\"I think you are being unrealistic,\" said the manager. \"Truthfully,<BR>\nhow long will it take?\"<BR>\n&nbsp;The programmer thought for a moment.  \"I have some features that I wish<BR>\nto add.  This will take at least two weeks,\" he finally said.<BR>\n&nbsp;\"Even that is too much to expect,\" insisted the manager, \"I will be<BR>\nsatisfied if you simply tell me when the program is complete.\"<BR>\n&nbsp;The programmer agreed to this.<BR>\n&nbsp;Several years later, the manager retired.  On the way to his<BR>\nretirement lunch, he discovered the programmer asleep at his terminal.<BR>\nHe had been programming all night.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A man from AI walked across the mountains to SAIL to see the Master,<BR>\nKnuth.  When he arrived, the Master was nowhere to be found.  \"Where is the<BR>\nwise one named Knuth?\" he asked a passing student.<BR>\n&nbsp;\"Ah,\" said the student, \"you have not heard. He has gone on a<BR>\npilgrimage across the mountains to the temple of AI to seek out new<BR>\ndisciples.\"<BR>\n&nbsp;Hearing this, the man was Enlightened.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No part of this message may reproduce, store itself in a retrieval system,<BR>\nor transmit disease, in any form, without the permissiveness of the author.<BR>\n&nbsp;-- Chris Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A little retrospection shows that although many fine, useful software systems<BR>\nhave been designed by committees and built as part of multipart projects,<BR>\nthose software systems that have excited passionate fans are those that are<BR>\nthe products of one or a few designing minds, great designers.  Consider Unix,<BR>\nAPL, Pascal, Modula, the Smalltalk interface, even Fortran; and contrast them<BR>\nwith Cobol, PL/I, Algol, MVS/370, and MS-DOS.<BR>\n&nbsp;-- Fred Brooks');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No line available at 300 baud.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No hardware designer should be allowed to produce any piece of hardware<BR>\nuntil three software guys have signed off for it.<BR>\n&nbsp;-- Andy Tanenbaum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A list is only as strong as its weakest link.<BR>\n&nbsp;-- Don Knuth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Our OS who art in CPU, UNIX be thy name.<BR>\n&nbsp;Thy programs run, thy syscalls done,<BR>\n&nbsp;In kernel as it is in user!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Our informal mission is to improve the love life of operators worldwide.<BR>\n&nbsp;-- Peter Behrendt, president of Exabyte');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','On the eighth day, God created FORTRAN.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','On a clear disk you can seek forever.<BR>\n&nbsp;-- P. Denning');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A novice asked the Master: \"Here is a programmer that never designs,<BR>\ndocuments, or tests his programs.  Yet all who know him consider him one of<BR>\nthe best programmers in the world.  Why is this?\"<BR>\n&nbsp;The Master replies: \"That programmer has mastered the Tao.  He has<BR>\ngone beyond the need for design; he does not become angry when the system<BR>\ncrashes, but accepts the universe without concern.  He has gone beyond the<BR>\nneed for documentation; he no longer cares if anyone else sees his code.  He<BR>\nhas gone beyond the need for testing; each of his programs are perfect within<BR>\nthemselves, serene and elegant, their purpose self-evident.  Truly, he has<BR>\nentered the mystery of the Tao.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Old programmers never die, they just hit account block limit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Old programmers never die, they just branch to a new address.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Old programmers never die, they just become managers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Old mail has arrived.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A nasty looking dwarf throws a knife at you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Oh, so there you are!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A modem is a baudy house.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Nuclear war can ruin your whole compile.\"<BR>\n&nbsp;-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A master was explaining the nature of Tao to one of his novices.<BR>\n\"The Tao is embodied in all software -- regardless of how insignificant,\"<BR>\nsaid the master.<BR>\n&nbsp;\"Is Tao in a hand-held calculator?\" asked the novice.<BR>\n&nbsp;\"It is,\" came the reply.<BR>\n&nbsp;\"Is the Tao in a video game?\" continued the novice.<BR>\n&nbsp;\"It is even in a video game,\" said the master.<BR>\n&nbsp;\"And is the Tao in the DOS for a personal computer?\"<BR>\n&nbsp;The master coughed and shifted his position slightly.  \"The lesson<BR>\nis over for today,\" he said.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Now this is a totally brain damaged algorithm.  Gag me with a smurfette.\"<BR>\n&nbsp;-- P. Buhr, Computer Science 354');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No proper program contains an indication which as an operator-applied<BR>\noccurrence identifies an operator-defining occurrence which as an<BR>\nindication-applied occurrence identifies an indication-defining occurrence<BR>\ndifferent from the one identified by the given indication as an<BR>\nindication-applied occurrence.<BR>\n&nbsp;-- ALGOL 68 Report');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Nothing happens.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','NOTE: No warranties, either express or implied, are hereby given. All<BR>\nsoftware is supplied as is, without guarantee.  The user assumes all<BR>\nresponsibility for damages resulting from the use of these features,<BR>\nincluding, but not limited to, frustration, disgust, system abends, disk<BR>\nhead-crashes, general malfeasance, floods, fires, shark attack, nerve<BR>\ngas, locust infestation, cyclones, hurricanes, tsunamis, local<BR>\nelectromagnetic disruptions, hydraulic brake system failure, invasion,<BR>\nhashing collisions, normal wear and tear of friction surfaces, comic<BR>\nradiation, inadvertent destruction of sensitive electronic components,<BR>\nwindstorms, the Riders of Nazgul, infuriated chickens, malfunctioning<BR>\nmechanical or electrical sexual devices, premature activation of the<BR>\ndistant early warning system, peasant uprisings, halitosis, artillery<BR>\nbombardment, explosions, cave-ins, and/or frogs falling from the sky.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... one of the main causes of the fall of the Roman Empire was that,<BR>\nlacking zero, they had no way to indicate successful termination of<BR>\ntheir C programs.<BR>\n&nbsp;-- Robert Firth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','One good reason why computers can do more work than people is that they<BR>\nnever have to stop and answer the phone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;One day a student came to Moon and said, \"I understand how to make<BR>\na better garbage collector.  We must keep a reference count of the pointers<BR>\nto each cons.\"<BR>\n&nbsp;Moon patiently told the student the following story -- \"One day a<BR>\nstudent came to Moon and said, \"I understand how to make a better garbage<BR>\ncollector...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"One basic notion underlying Usenet is that it is a cooperative.\"<BR>\n&nbsp;Having been on USENET for going on ten years, I disagree with this.<BR>\nThe basic notion underlying USENET is the flame.<BR>\n&nbsp;-- Chuq Von Rospach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"One Architecture, One OS\" also translates as \"One Egg, One Basket\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','On two occasions I have been asked [by members of Parliament!], \"Pray, Mr.<BR>\nBabbage, if you put into the machine wrong figures, will the right answers<BR>\ncome out?\"  I am not able rightly to apprehend the kind of confusion of<BR>\nideas that could provoke such a question.<BR>\n&nbsp;-- Charles Babbage');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A novice asked the master: \"I perceive that one computer company is<BR>\nmuch larger than all others.  It towers above its competition like a giant<BR>\namong dwarfs.  Any one of its divisions could comprise an entire business.<BR>\nWhy is this so?\"<BR>\n&nbsp;The master replied, \"Why do you ask such foolish questions?  That<BR>\ncompany is large because it is so large.  If it only made hardware, nobody<BR>\nwould buy it.  If it only maintained systems, people would treat it like a<BR>\nservant.  But because it combines all of these things, people think it one<BR>\nof the gods!  By not seeking to strive, it conquers without effort.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A novice asked the master: \"I have a program that sometimes runs and<BR>\nsometimes aborts.  I have followed the rules of programming, yet I am totally<BR>\nbaffled. What is the reason for this?\"<BR>\n&nbsp;The master replied: \"You are confused because you do not understand<BR>\nthe Tao.  Only a fool expects rational behavior from his fellow humans.  Why<BR>\ndo you expect it from a machine that humans have constructed?  Computers<BR>\nsimulate determinism; only the Tao is perfect.<BR>\n&nbsp;The rules of programming are transitory; only the Tao is eternal.<BR>\nTherefore you must contemplate the Tao before you receive enlightenment.\"<BR>\n&nbsp;\"But how will I know when I have received enlightenment?\" asked the<BR>\nnovice.<BR>\n&nbsp;\"Your program will then run correctly,\" replied the master.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A programmer is a person who passes as an exacting expert on the basis of<BR>\nbeing able to turn out, after innumerable punching, an infinite series of<BR>\nincomprehensible answers calculated with micrometric precisions from vague <BR>\nassumptions based on debatable figures taken from inconclusive documents <BR>\nand carried out on instruments of problematical accuracy by persons of <BR>\ndubious reliability and questionable mentality for the avowed purpose of<BR>\nannoying and confounding a hopelessly defenseless department that was<BR>\nunfortunate enough to ask for the information in the first place.<BR>\n&nbsp;-- IEEE Grid newsmagazine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A programmer from a very large computer company went to a software<BR>\nconference and then returned to report to his manager, saying: \"What sort<BR>\nof programmers work for other companies?  They behaved badly and were<BR>\nunconcerned with appearances. Their hair was long and unkempt and their<BR>\nclothes were wrinkled and old. They crashed out hospitality suites and they<BR>\nmade rude noises during my presentation.\"<BR>\n&nbsp;The manager said: \"I should have never sent you to the conference.<BR>\nThose programmers live beyond the physical world.  They consider life absurd,<BR>\nan accidental coincidence.  They come and go without knowing limitations.<BR>\nWithout a care, they live only for their programs.  Why should they bother<BR>\nwith social conventions?\"<BR>\n&nbsp;\"They are alive within the Tao.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','OS/2 Skyways:<BR>\nThe terminal is almost empty, with only a few prospective passengers milling<BR>\nabout. The announcer says that their flight has just departed, wishes them a<BR>\ngood flight, though there are no planes on the runway. Airline personnel<BR>\nwalk around, apologising profusely to customers in hushed voices, pointing<BR>\nfrom time to time to the sleek, powerful jets outside the terminal on the<BR>\nfield. They tell each passenger how good the real flight will be on these<BR>\nnew jets and how much safer it will be than Windows Airlines, but that they<BR>\nwill have to wait a little longer for the technicians to finish the flight<BR>\nsystems. Maybe until mid-1995. Maybe longer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Only great masters of style can succeed in being obtuse.<BR>\n&nbsp;-- Oscar Wilde<BR>\n&nbsp;Most UNIX programmers are great masters of style.<BR>\n&nbsp;-- The Unnamed Usenetter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A person who is more than casually interested in computers should be well<BR>\nschooled in machine language, since it is a fundamental part of a computer.<BR>\n&nbsp;-- Donald Knuth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','One picture is worth 128K words.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;A novice was trying to fix a broken lisp machine by turning the<BR>\npower off and on.  Knight, seeing what the student was doing spoke sternly,<BR>\n\"You cannot fix a machine by just power-cycling it with no understanding<BR>\nof what is going wrong.\"  Knight turned the machine off and on.  The<BR>\nmachine worked.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTRAN is for pipe stress freaks and crystallography weenies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','The less time planning, the more time programming.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','A bug in the code is worth two in the documentation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','No wonder Clairol makes so much money selling shampoo.<BR>\nLather, Rinse, Repeat is an infinite loop!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','System going down in 5 minutes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Coding is easy;  All you do is sit staring at a terminal until the drops<BR>\nof blood form on your forehead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There are two ways to write error-free programs; only the third one works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There are two ways of constructing a software design.  One way is to make<BR>\nit so simple that there are obviously no deficiencies and the other is to<BR>\nmake it so complicated that there are no obvious deficiencies.<BR>\n&nbsp;-- C.A.R. Hoare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Cobol programmers are down in the dumps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','COBOL is for morons.<BR>\n&nbsp;-- E.W. Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There are three kinds of people: men, women, and unix.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Civilization, as we know it, will end sometime this evening.<BR>\nSee SYSNOTE tomorrow for more information.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There are no games on this system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There are new messages.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Center meeting at 4pm in 2C-543.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','* * * * * THIS TERMINAL IS IN USE * * * * *');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This system will self-destruct in five minutes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This screen intentionally left blank.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This quote is taken from the Diamondback, the University of Maryland<BR>\nstudent newspaper, of Tuesday, 3/10/87.<BR>\n&nbsp;One disadvantage of the Univac system is that it does not use<BR>\n&nbsp;Unix, a recently developed program which translates from one<BR>\n&nbsp;computer language to another and has a built-in editing system<BR>\n&nbsp;which identifies errors in the original program.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This process can check if this value is zero, and if it is, it does<BR>\nsomething child-like.<BR>\n&nbsp;-- Forbes Burkowski, CS 454, University of Washington');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This login session: $13.99');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computers are useless.  They can only give you answers.<BR>\n&nbsp;-- Pablo Picasso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This login session: $13.76, but for you $11.88.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computers are unreliable, but humans are even more unreliable.<BR>\nAny system which depends on human reliability is unreliable.<BR>\n&nbsp;-- Gilb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This is the first numerical problem I ever did.  It demonstrates the<BR>\npower of computers:<BR>\n&nbsp;Enter lots of data on calorie & nutritive content of foods.  Instruct<BR>\nthe thing to maximize a function describing nutritive content, with a<BR>\nminimum level of each component, for fixed caloric content.  The<BR>\nresults are that one should eat each day:<BR>\n&nbsp;1/2 chicken<BR>\n&nbsp;1 egg<BR>\n&nbsp;1 glass of skim milk<BR>\n&nbsp;27 heads of lettuce.<BR>\n&nbsp;-- Rev. Adrian Melott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"This is lemma 1.1.  We start a new chapter so the numbers all go back to one.\"<BR>\n&nbsp;-- Prof. Seager, C&O 351');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computers are not intelligent.  They only think they are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This is an unauthorized cybernetic announcement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This file will self-destruct in five minutes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computer Science is the only discipline in which we view adding a new wing<BR>\nto a building as being maintenance<BR>\n&nbsp;-- Jim Horning');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','This dungeon is owned and operated by Frobozz Magic Co., Ltd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Comparing software engineering to classical engineering assumes that software<BR>\nhas the ability to wear out.  Software typically behaves, or it does not.  It<BR>\neither works, or it does not.  Software generally does not degrade, abrade,<BR>\nstretch, twist, or ablate.  To treat it as a physical entity, therefore, is<BR>\nmisapplication of our engineering skills.  Classical engineering deals with<BR>\nthe characteristics of hardware; software engineering should deal with the<BR>\ncharacteristics of *software*, and not with hardware or management.<BR>\n&nbsp;-- Dan Klein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There is is no reason for any individual to have a computer in their home.<BR>\n&nbsp;-- Ken Olsen (President of Digital Equipment Corporation),<BR>\n&nbsp;Convention of the World Future Society, in Boston, 1977');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computer Science is merely the post-Turing decline in formal systems theory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Think of your family tonight.  Try to crawl home after the computer crashes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Think of it!  With VLSI we can pack 100 ENIACs in 1 sq. cm.!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computer programs expand so as to fill the core available.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','They seem to have learned the habit of cowering before authority even when<BR>\nnot actually threatened.  How very nice for authority.  I decided not to<BR>\nlearn this particular lesson.<BR>\n&nbsp;-- Richard Stallman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','They are relatively good but absolutely terrible.<BR>\n&nbsp;-- Alan Kay, commenting on Apollos');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computer programmers never die, they just get lost in the processing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','They are called computers simply because computation is the only significant<BR>\njob that has so far been given to them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Computer programmers do it byte by byte.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;There was once a programmer who worked upon microprocessors.  \"Look at<BR>\nhow well off I am here,\" he said to a mainframe programmer who came to visit,<BR>\n\"I have my own operating system and file storage device.  I do not have to<BR>\nshare my resources with anyone.  The software is self-consistent and<BR>\neasy-to-use.  Why do you not quit your present job and join me here?\"<BR>\n&nbsp;The mainframe programmer then began to describe his system to his<BR>\nfriend, saying: \"The mainframe sits like an ancient sage meditating in the<BR>\nmidst of the data center.  Its disk drives lie end-to-end like a great ocean<BR>\nof machinery.  The software is a multi-faceted as a diamond and as convoluted<BR>\nas a primeval jungle.  The programs, each unique, move through the system<BR>\nlike a swift-flowing river.  That is why I am happy where I am.\"<BR>\n&nbsp;The microcomputer programmer, upon hearing this, fell silent.  But the<BR>\ntwo programmers remained friends until the end of their days.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To understand a program you must become both the machine and the program.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','%DCL-MEM-BAD, bad memory<BR>\nVMS-F-PDGERS, pudding between the ears');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To the systems programmer, users and applications serve only to provide a<BR>\ntest load.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Creating computer software is always a demanding and painstaking<BR>\nprocess -- an exercise in logic, clear expression, and almost fanatical<BR>\nattention to detail.  It requires intelligence, dedication, and an<BR>\nenormous amount of hard work.  But, a certain amount of unpredictable<BR>\nand often unrepeatable inspiration is what usually makes the difference<BR>\nbetween adequacy and excellence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To iterate is human, to recurse, divine.<BR>\n&nbsp;-- Robert Heller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To err is human, to forgive, beyond the scope of the Operating System.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Creating computer software is always a demanding and painstaking<BR>\nprocess -- an exercise in logic, clear expression, and almost fanatical<BR>\nattention to detail.  It requires intelligence, dedication, and an<BR>\nenormous amount of hard work.  But, a certain amount of unpredictable<BR>\nand often unrepeatable inspiration is what usually makes the difference<BR>\nbetween adequacy and excellence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To err is human -- to blame it on a computer is even more so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','To communicate is the beginning of understanding.<BR>\n&nbsp;-- AT&T');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Crazee Edeee, his prices are INSANE!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Time-sharing is the junk-mail part of the computer business.<BR>\n&nbsp;-- H.R.J. Grosch (attributed)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[Crash programs] fail because they are based on the theory that, with nine<BR>\nwomen pregnant, you can get a baby a month.<BR>\n&nbsp;-- Wernher von Braun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Time sharing: The use of many people by the computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"Without the wind, the grass does not move.  Without software,<BR>\n&nbsp;hardware is useless.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"Though a program be but three lines long, someday it will have to<BR>\n&nbsp;be maintained.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"Let the programmers be many and the managers few -- then all will<BR>\n&nbsp;be productive.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;Cosmotronic Software Unlimited Inc. does not warrant that the<BR>\nfunctions contained in the program will meet your requirements or that<BR>\nthe operation of the program will be uninterrupted or error-free.<BR>\n&nbsp;However, Cosmotronic Software Unlimited Inc. warrants the<BR>\ndiskette(s) on which the program is furnished to be of black color and<BR>\nsquare shape under normal use for a period of ninety (90) days from the<BR>\ndate of purchase.<BR>\n&nbsp;NOTE: IN NO EVENT WILL COSMOTRONIC SOFTWARE UNLIMITED OR ITS<BR>\nDISTRIBUTORS AND THEIR DEALERS BE LIABLE TO YOU FOR ANY DAMAGES, INCLUDING<BR>\nANY LOST PROFIT, LOST SAVINGS, LOST PATIENCE OR OTHER INCIDENTAL OR<BR>\nCONSEQUENTIAL DAMAGES.<BR>\n&nbsp;-- Horstmann Software Design, the \"ChiWriter\" user manual');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"After three days without programming, life becomes meaningless.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"A well-written program is its own heaven; a poorly-written program<BR>\nis its own hell.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thrashing is just virtual crashing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Those who do not understand Unix are condemned to reinvent it, poorly.<BR>\n&nbsp;-- Henry Spencer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Conceptual integrity in turn dictates that the design must proceed<BR>\nfrom one mind, or from a very small number of agreeing resonant minds.<BR>\n&nbsp;-- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','DEC diagnostics would run on a dead whale.<BR>\n&nbsp;-- Mel Ferentz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix Express: <BR>\nAll passenger bring a piece of the aeroplane and a box of tools with them to<BR>\nthe airport. They gather on the tarmac, arguing constantly about what kind<BR>\nof plane they want to build and how to put it together. Eventually, the<BR>\npassengers split into groups and build several different aircraft, but give<BR>\nthem all the same name. Some passengers actually reach their destinations.<BR>\nAll passengers believe they got there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Trying to be happy is like trying to build a machine for which the only<BR>\nspecification is that it should run noiselessly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Try to find the real tense of the report you are reading:  Was it done, is<BR>\nit being done, or is something to be done?  Reports are now written in four<BR>\ntenses:  past tense, present tense, future tense, and pretense.  Watch for<BR>\nnovel uses of CONGRAM (CONtractor GRAMmar), defined by the imperfect past,<BR>\nthe insufficient present, and the absolutely perfect future.<BR>\n&nbsp;-- Amrom Katz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','try again');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Dear Emily:<BR>\n&nbsp;I saw a long article that I wish to rebut carefully, what should<BR>\nI do?<BR>\n&nbsp;-- Angry<BR>\n&nbsp;Dear Angry:<BR>\n&nbsp;Include the entire text with your article, and include your comments<BR>\nbetween the lines.  Be sure to post, and not mail, even though your article<BR>\nlooks like a reply to the original.  Everybody *loves* to read those long<BR>\npoint-by-point debates, especially when they evolve into name-calling and<BR>\nlots of \"Is too!\" -- \"Is not!\" -- \"Is too, twizot!\" exchanges.<BR>\n&nbsp;-- Emily Postnews Answers Your Questions on Netiquette');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Truly simple systems... require infinite testing.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Trap full -- please empty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','TRANSACTION CANCELLED - FARECARD RETURNED');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Be careful when a loop exits to the same place from side and bottom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"When you have learned to snatch the error code from<BR>\n&nbsp;the trap frame, it will be time for you to leave.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Counting in binary is just like counting in decimal -- if you are all thumbs.<BR>\n&nbsp;-- Glaser and Way');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Too often people have come to me and said, \"If I had just one wish for<BR>\nanything in all the world, I would wish for more user-defined equations<BR>\nin the HP-51820A Waveform Generator Software.\"<BR>\n&nbsp;-- Instrument News<BR>\n&nbsp;[Once is too often.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Dear Emily:<BR>\n&nbsp;How can I choose what groups to post in?<BR>\n&nbsp;-- Confused<BR>\n&nbsp;Dear Confused:<BR>\n&nbsp;Pick as many as you can, so that you get the widest audience.  After<BR>\nall, the net exists to give you an audience.  Ignore those who suggest you<BR>\nshould only use groups where you think the article is highly appropriate.<BR>\nPick all groups where anybody might even be slightly interested.<BR>\n&nbsp;Always make sure followups go to all the groups.  In the rare event<BR>\nthat you post a followup which contains something original, make sure you<BR>\nexpand the list of groups.  Never include a \"Followup-to:\" line in the<BR>\nheader, since some people might miss part of the valuable discussion in<BR>\nthe fringe groups.<BR>\n&nbsp;-- Emily Postnews Answers Your Questions on Netiquette');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Today is the first day of the rest of your lossage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Debug is human, de-fix divine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix Beer: Comes in several different brands, in cans ranging from 8 oz. <BR>\nto 64 oz.  Drinkers of Unix Beer display fierce brand loyalty, even <BR>\nthough they claim that all the different brands taste almost identical. <BR>\nSometimes the pop-tops break off when you try to open them, so you have <BR>\nto have your own can opener around for those occasions, in which case you <BR>\neither need a complete set of instructions, or a friend who has been <BR>\ndrinking Unix Beer for several years.<BR>\n&nbsp;BSD stout: Deep, hearty, and an acquired taste.  The official<BR>\nbrewer has released the recipe, and a lot of home-brewers now use it.<BR>\n&nbsp;Hurd beer: Long advertised by the popular and politically active<BR>\nGNU brewery, so far it has more head than body.  The GNU brewery is<BR>\nmostly known for printing complete brewing instructions on every can,<BR>\nwhich contains hops, malt, barley, and yeast ... not yet fermented.<BR>\n&nbsp;Linux brand: A recipe originally created by a drunken Finn in his<BR>\nbasement, it has since become the home-brew of choice for impecunious<BR>\nbrewers and Unix beer-lovers worldwide, many of whom change the recipe.<BR>\n&nbsp;POSIX ales: Sweeter than lager, with the kick of a stout; the<BR>\nnewer batches of a lot of beers seem to blend ale and stout or lager.<BR>\n&nbsp;Solaris brand: A lager, intended to replace Sun brand stout.<BR>\nUnlike most lagers, this one has to be drunk more slowly than stout.<BR>\n&nbsp;Sun brand: Long the most popular stout on the Unix market, it was<BR>\ndiscontinued in favor of a lager.<BR>\n&nbsp;SysV lager: Clear and thirst-quenching, but lacking the body of<BR>\nstout or the sweetness of ale.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unfortunately, most programmers like to play with new toys.  I have many<BR>\nfriends who, immediately upon buying a snakebite kit, would be tempted to<BR>\nthrow the first person they see to the ground, tie the tourniquet on him,<BR>\nslash him with the knife, and apply suction to the wound.<BR>\n&nbsp;-- Jon Bentley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"When a program is being tested, it is too late to make design changes.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;U       X<BR>\ne dUdX, e dX, cosine, secant, tangent, sine, 3.14159...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Type louder, please.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Dear Emily:<BR>\n&nbsp;Today I posted an article and forgot to include my signature.<BR>\nWhat should I do?<BR>\n&nbsp;-- Forgetful<BR>\n&nbsp;Dear Forgetful:<BR>\n&nbsp;Rush to your terminal right away and post an article that says,<BR>\n\"Oops, I forgot to post my signature with that last article.  Here<BR>\nit is.\"<BR>\n&nbsp;Since most people will have forgotten your earlier article,<BR>\n(particularly since it dared to be so boring as to not have a nice, juicy<BR>\nsignature) this will remind them of it.  Besides, people care much more<BR>\nabout the signature anyway.<BR>\n&nbsp;-- Emily Postnews Answers Your Questions on Netiquette');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Two hundred years ago today, Irma Chine of White Plains, New York, was <BR>\nperforming her normal housekeeping routines.  She was interrupted by <BR>\nBritish soldiers who, rallying to the call of their supervisor, General<BR>\nHughes, sought to gain control of the voter registration lists kept in<BR>\nher home.  Masking her fear and thinking fast, Mrs. Chine quickly divided<BR>\na nearby apple in two and deftly stored the list in its center.  Upon<BR>\nentering, the British blatantly violated every conceivable convention,<BR>\nand, though they went through the house virtually bit by bit, their<BR>\nsearch was fruitless.  They had to return empty handed.  Word of the<BR>\nincident propagated rapidly through the region.  This historic event<BR>\nbecame the first documented use of core storage for the saving of registers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Trying to establish voice contact ... please ____yell into keyboard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Do not simplify the design of a program if a way can be found to make<BR>\nit complex and wonderful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','<< WAIT >>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Do not meddle in the affairs of troff, for it is subtle and quick to anger.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Von Neumann was the subject of many dotty professor stories.  Von Neumann<BR>\nsupposedly had the habit of simply writing answers to homework assignments on<BR>\nthe board (the method of solution being, of course, obvious) when he was asked<BR>\nhow to solve problems.  One time one of his students tried to get more helpful<BR>\ninformation by asking if there was another way to solve the problem.  Von<BR>\nNeumann looked blank for a moment, thought, and then answered, \"Yes.\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','VMS version 2.0 ==>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Disraeli was pretty close: actually, there are Lies, Damn lies, Statistics,<BR>\nBenchmarks, and Delivery dates.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','VMS is like a nightmare about RXS-11M.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','VMS Beer: Requires minimal user interaction, except for popping the top <BR>\nand sipping.  However cans have been known on occasion to explode, or <BR>\ncontain extremely un-beer-like contents.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Disks travel in packs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Vitamin C deficiency is apauling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Virtual\" means never knowing where your next byte is coming from.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Disk crisis, please clean up!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Vax Vobiscum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Disclaimer: \"These opinions are my own, though for a small fee they be<BR>\nyours too.\"<BR>\n&nbsp;-- Dave Haynie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','/usr/news/gotcha');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Using TSO is like kicking a dead whale down the beach.<BR>\n&nbsp;-- S.C. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','DISCLAIMER:<BR>\nUse of this advanced computing technology does not imply an endorsement<BR>\nof Western industrial civilization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','User hostile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','USENET would be a better laboratory if there were more labor and less oratory.<BR>\n&nbsp;-- Elizabeth Haley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Disc space -- the final frontier!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Usage: fortune -P [] -a [xsz] [Q: [file]] [rKe9] -v6[+] dataspec ... inputdir');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Usage: fortune -P [-f] -a [xsz] Q: file [rKe9] -v6[+] file1 ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Digital circuits are made from analog parts.<BR>\n&nbsp;-- Don Vonada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix will self-destruct in five seconds... 4... 3... 2... 1...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','UNIX was not designed to stop you from doing stupid things, because that<BR>\nwould also stop you from doing clever things.<BR>\n&nbsp;-- Doug Gwyn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Thus spake the master programmer:<BR>\n&nbsp;\"Time for you to leave.\"<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Different all twisty a of in maze are you, passages little.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','UNIX was half a billion (500000000) seconds old on<BR>\nTue Nov  5 00:53:20 1985 GMT (measuring since the time(2) epoch).<BR>\n&nbsp;-- Andy Tannenbaum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix soit qui mal y pense<BR>\n&nbsp;[Unix to him who evil thinks?]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix is the worst operating system; except for all others.<BR>\n&nbsp;-- Berry Kercheval');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Deliver yesterday, code today, think tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','* UNIX is a Trademark of Bell Laboratories.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Unix is a Registered Bell of AT&T Trademark Laboratories.<BR>\n&nbsp;-- Donn Seeley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','#define BITCOUNT(x)	(((BX_(x)+(BX_(x)>>4)) & 0x0F0F0F0F) % 255)<BR>\n#define  BX_(x)		((x) - (((x)>>1)&0x77777777)			<BR>\n&nbsp;- (((x)>>2)&0x33333333)			<BR>\n&nbsp;- (((x)>>3)&0x11111111))<BR>\n&nbsp;-- really weird C code to count the number of bits in a word');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Where a calculator on the ENIAC is equpped with 18,000 vaccuum tubes and<BR>\nweighs 30 tons, computers in the future may have only 1,000 vaccuum tubes<BR>\nand perhaps weigh 1 1/2 tons.<BR>\n&nbsp;-- Popular Mechanics, March 1949');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Whenever a system becomes completely defined, some damn fool discovers<BR>\nsomething which either abolishes the system or expands it beyond recognition.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','E Pluribus Unix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We the Users, in order to form a more perfect system, establish priorities,<BR>\nensure connective tranquility, provide for common repairs, promote preventive<BR>\nmaintenance, and secure the blessings of liberty for ourselves and our<BR>\nprocesses, do ordain and establish this Software of The Unixed States<BR>\nof America.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Does a good farmer neglect a crop he has planted?<BR>\nDoes a good teacher overlook even the most humble student?<BR>\nDoes a good father allow a single child to starve?<BR>\nDoes a good programmer refuse to maintain his code?<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We may hope that machines will eventually compete with men in all purely<BR>\nintellectual fields.  But which are the best ones to start with?  Many people<BR>\nthink that a very abstract activity, like the playing of chess, would be<BR>\nbest.  It can also be maintained that it is best to provide the machine with<BR>\nthe best sense organs that money can buy, and then teach it to understand<BR>\nand speak English.<BR>\n&nbsp;-- Alan M. Turing');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Documentation is the castor oil of programming.<BR>\nManagers know it must be good because the programmers hate it so much.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Documentation is like sex: when it is good, it is very, very good; and<BR>\nwhen it is bad, it is better than nothing.<BR>\n&nbsp;-- Dick Brandon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;UNIX Trix<BR>\n&nbsp;For those of you in the reseller business, here is a helpful tip that will<BR>\nsave your support staff a few hours of precious time.  Before you send your<BR>\nnext machine out to an untrained client, change the permissions on /etc/passwd<BR>\nto 666 and make sure there is a copy somewhere on the disk.  Now when they<BR>\nforget the root password, you can easily login as an ordinary user and correct<BR>\nthe damage.  Having a bootable tape (for larger machines) is not a bad idea<BR>\neither.  If you need some help, give us a call.<BR>\n&nbsp;-- CommUNIXque 1:1, ASCAR Business Systems');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We can found no scientific discipline, nor a healthy profession on the<BR>\ntechnical mistakes of the Department of Defense and IBM.<BR>\n&nbsp;-- Edsger Dijkstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Do you suffer painful elimination?<BR>\n&nbsp;-- Don Knuth, \"Structured Programming with Gotos\"<BR>\n&nbsp;Do you suffer painful recrimination?<BR>\n&nbsp;-- Nancy Boxer, \"Structured Programming with Come-froms\"<BR>\n&nbsp;Do you suffer painful illumination?<BR>\n&nbsp;-- Isaac Newton, \"Optics\"<BR>\n&nbsp;Do you suffer painful hallucination?<BR>\n&nbsp;-- Don Juan, cited by Carlos Casteneda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We are preparing to think about contemplating preliminary work on plans to<BR>\ndevelop a schedule for producing the 10th Edition of the Unix Programmers<BR>\nManual.<BR>\n&nbsp;-- Andrew Hume');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We are not a clone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We are Microsoft.  Unix is irrelevant.  Openness is futile.  Prepare<BR>\nto be assimilated.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We are experiencing system trouble -- do not adjust your terminal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','We are drowning in information but starved for knowledge.<BR>\n&nbsp;-- John Naisbitt, Megatrends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Do not use the blue keys on this terminal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','When we understand knowledge-based systems, it will be as before --<BR>\nexcept our fingertips will have been singed.<BR>\n&nbsp;-- Epigrams in Programming, ACM SIGPLAN Sept. 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','During the next two hours, the system will be going up and down several<BR>\ntimes, often with lin~po_~{po       ~poz~ppo~{ o n~po_~{o[po	 ~y oodsou>#w4k**n~po_~{ol;lkld;f;g;dd;po~{o');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','When someone says \"I want a programming language in which I need only<BR>\nsay what I wish done,\" give him a lollipop.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Due to lack of disk space, this fortune database has been discontinued.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','&nbsp;When managers hold endless meetings, the programmers write games.<BR>\nWhen accountants talk of quarterly profits, the development budget is about<BR>\nto be cut.  When senior scientists talk blue sky, the clouds are about to<BR>\nroll in.<BR>\n&nbsp;Truly, this is not the Tao of Programming.<BR>\n&nbsp;When managers make commitments, game programs are ignored.  When<BR>\naccountants make long-range plans, harmony and order are about to be restored.<BR>\nWhen senior scientists address the problems at hand, the problems will soon<BR>\nbe solved.<BR>\n&nbsp;Truly, this is the Tao of Programming.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','... when fits of creativity run strong, more than one programmer or writer<BR>\nhas been known to abandon the desktop for the more spacious floor.<BR>\n&nbsp;-- Fred Brooks');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','DOS Air:<BR>\nAll the passengers go out onto the runway, grab hold of the plane, push it<BR>\nuntil it gets in the air, hop on, jump off when it hits the ground again.<BR>\nThen they grab the plane again, push it back into the air, hop on, et<BR>\ncetera.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','What this country needs is a good five cent microcomputer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','What the hell is it good for?<BR>\n&nbsp;-- Robert Lloyd (engineer of the Advanced Computing Systems<BR>\n&nbsp;Division of IBM), to colleagues who insisted that the<BR>\n&nbsp;microprocessor was the wave of the future, c. 1968');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Welcome to boggle - do you want instructions?<BR>\n&nbsp;D    G    G    O<BR>\n&nbsp;O    Y    A    N<BR>\n&nbsp;A    D    B    T<BR>\n&nbsp;K    I    S    P<BR>\nEnter words:<BR>\n>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[We] use bad software and bad machines for the wrong things.<BR>\n&nbsp;-- R.W. Hamming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','fortune: No such file or directory');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your mode of life will be changed to EBCDIC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your mode of life will be changed to ASCII.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','fortune: cpu time/usefulness ratio too high -- core dumped.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your files are now being encrypted and thrown into the bit bucket.<BR>\nEOF');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Writing software is more fun than working.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Established technology tends to persist in the face of new technology.<BR>\n&nbsp;-- G. Blaauw, one of the designers of System 360');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Would you people stop playing these stupid games?!?!?!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Error in operator: add beer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Worthless.<BR>\n&nbsp;-- Sir George Bidell Airy, KCB, MA, LLD, DCL, FRS, FRAS<BR>\n&nbsp;(Astronomer Royal of Great Britain), estimating for the<BR>\n&nbsp;Chancellor of the Exchequer the potential value of the<BR>\n&nbsp;\"analytical engine\" invented by Charles Babbage, September<BR>\n&nbsp;15, 1842.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Equal bytes for women.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Within a computer, natural language is unnatural.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','With your bare hands?!?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Einstein argued that there must be simplified explanations of nature, because<BR>\nGod is not capricious or arbitrary.  No such faith comforts the software<BR>\nengineer.<BR>\n&nbsp;-- Fred Brooks');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Wings of OS/400: <BR>\nThe airline has bought ancient DC-3s, arguably the best and safest planes<BR>\nthat ever flew, and painted \"747\" on their tails to make them look as if<BR>\nthey are fast. The flight attendants, of course, attend to your every need,<BR>\nthough the drinks cost $15 a pop. Stupid questions cost $230 per hour,<BR>\nunless you have SupportLine, which requires a first class ticket and<BR>\nmembership in the frequent flyer club. Then they cost $500, but your<BR>\naccounting department can call it overhead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','There is no distinction between any AI program and some existent game.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','/earth: file system full.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Windows Airlines:<BR>\nThe terminal is very neat and clean, the attendants all very attractive, the<BR>\npilots very capable. The fleet of Learjets the carrier operates is immense.<BR>\nYour jet takes off without a hitch, pushing above the clouds, and at 20,000<BR>\nfeet it explodes without warning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Earth is a beta site.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Why do we want intelligent terminals  when there are so many stupid users?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','/earth is 98% full ... please delete anyone you can.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Why did the Roman Empire collapse?  What is the Latin for office automation?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Why are programmers non-productive?<BR>\nBecause their time is wasted in meetings.<BR>\n&nbsp;Why are programmers rebellious?<BR>\nBecause the management interferes too much.<BR>\n&nbsp;Why are the programmers resigning one by one?<BR>\nBecause they are burnt out.<BR>\n&nbsp;Having worked for poor management, they no longer value their jobs.<BR>\n&nbsp;-- Geoffrey James, \"The Tao of Programming\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Whom computers would destroy, they must first drive mad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Each new user of a new system uncovers a new class of bugs.<BR>\n&nbsp;-- Kernighan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Function reject.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','From the Pro 350 Pocket Service Guide, p. 49, Step 5 of the<BR>\ninstructions on removing an I/O board from the card cage, comes a new<BR>\nexperience in sound:<BR>\n&nbsp;5.  Turn the handle to the right 90 degrees.  The pin-spreading<BR>\n&nbsp;sound is normal for this type of connector.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[From the operation manual for the CI-300 Dot Matrix Line Printer, made<BR>\nin Japan]:<BR>\n&nbsp;The excellent output machine of MODEL CI-300 as extraordinary DOT MATRIX<BR>\nLINE PRINTER, built in two MICRO-PROCESSORs as well as EAROM, is featured by<BR>\npermitting wonderful co-existence such as; \"high quality against low cost,\"<BR>\n\"diversified functions with compact design,\" \"flexibility in accessibleness<BR>\nand durability of approx. 2000,000,00 Dot/Head,\" \"being sophisticated in<BR>\nmechanism but possibly agile operating under noises being extremely<BR>\nsuppressed\" etc.<BR>\n&nbsp;And as a matter of course, the final goal is just simply to help achieve<BR>\n\"super shuttle diplomacy\" between cool data, perhaps earned by HOST<BR>\nCOMPUTER, and warm heart of human being.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','\"Yacc\" owes much to a most stimulating collection of users, who have<BR>\ngoaded me beyond my inclination, and frequently beyond my ability in<BR>\ntheir endless search for \"one more feature.\"  Their irritating<BR>\nunwillingness to learn how to do things my way has usually led to my<BR>\ndoing things their way; most of the time, they have been right.<BR>\n&nbsp;-- S. C. Johnson, \"Yacc guide acknowledgements\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Even bytes get lonely for a little bit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','X windows:<BR>\n&nbsp;The ultimate bottleneck.<BR>\n&nbsp;Flawed beyond belief.<BR>\n&nbsp;The only thing you have to fear.<BR>\n&nbsp;Somewhere between chaos and insanity.<BR>\n&nbsp;On autopilot to oblivion.<BR>\n&nbsp;The joke that kills.<BR>\n&nbsp;A disgrace you can be proud of.<BR>\n&nbsp;A mistake carried out to perfection.<BR>\n&nbsp;Belongs more to the problem set than the solution set.<BR>\n&nbsp;To err is X windows.<BR>\n&nbsp;Ignorance is our most important resource.<BR>\n&nbsp;Complex nonsolutions to simple nonproblems.<BR>\n&nbsp;Built to fall apart.<BR>\n&nbsp;Nullifying centuries of progress.<BR>\n&nbsp;Falling to new depths of inefficiency.<BR>\n&nbsp;The last thing you need.<BR>\n&nbsp;The defacto substandard.<BR>\n&nbsp;Elevating brain damage to an art form.<BR>\n&nbsp;X windows.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','fortune: not found');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your program is sick!  Shoot it and put it out of its memory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your password is pitifully obvious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You do not have mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FACILITY REJECTED 100044200000;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You can write a small letter to Grandma in the filename.<BR>\n&nbsp;-- Forbes Burkowski, CS, University of Washington');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Excessive login or logout messages are a sure sign of senility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You can tell how far we have to go, when FORTRAN is the language of<BR>\nsupercomputers.<BR>\n&nbsp;-- Steven Feiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Evolution is a million line computer program falling into place by accident.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You can now buy more gates with less specifications than at any other time<BR>\nin history.<BR>\n&nbsp;-- Kenneth Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Everyone can be taught to sculpt: Michelangelo would have had to be<BR>\ntaught how ___not to.  So it is with the great programmers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You can do this in a number of ways.  IBM chose to do all of them.<BR>\nWhy do you find that funny?<BR>\n&nbsp;-- D. Taylor, Computer Science 350');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Everybody needs a little love sometime; stop hacking and fall in love!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You can be replaced by this computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Every Solidarity center had piles and piles of paper ... everyone was<BR>\neating paper and a policeman was at the door.  Now all you have to do is<BR>\nbend a disk.<BR>\n&nbsp;-- A member of the outlawed Polish trade union, Solidarity, <BR>\n&nbsp;commenting on the benefits of using computers in support<BR>\n&nbsp;of their movement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are lost in the Swamps of Despair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are in the hall of the mountain king.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Every program is a part of some other program, and rarely fits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are in a maze of little twisting passages, all different.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are in a maze of little twisting passages, all alike.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are false data.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You are an insult to my intelligence!  I demand that you log off immediately.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Yes, we will be going to OSI, Mars, and Pluto, but not necessarily in<BR>\nthat order.<BR>\n&nbsp;-- Jeffrey Honig');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Yea, though I walk through the valley of the shadow of APL, I shall fear no<BR>\nevil, for I can string six primitive monadic and dyadic operators together.<BR>\n&nbsp;-- Steve Higgins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Ever wondered about the origins of the term \"bugs\" as applied to computer<BR>\ntechnology?  U.S. Navy Capt. Grace Murray Hopper has firsthand explanation.<BR>\nThe 74-year-old captain, who is still on active duty, was a pioneer in <BR>\ncomputer technology during World War II.  At the C.W. Post Center of Long<BR>\nIsland University, Hopper told a group of Long Island public school adminis-<BR>\ntrators that the first computer \"bug\" was a real bug--a moth.  At Harvard<BR>\none August night in 1945, Hopper and her associates were working on the<BR>\n\"granddaddy\" of modern computers, the Mark I.  \"Things were going badly;<BR>\nthere was something wrong in one of the circuits of the long glass-enclosed<BR>\ncomputer,\" she said.  \"Finally, someone located the trouble spot and, using<BR>\nordinary tweezers, removed the problem, a two-inch moth.  From then on, when<BR>\nanything went wrong with a computer, we said it had bugs in it.\"  Hopper<BR>\nsaid that when the veracity of her story was questioned recently, \"I referred<BR>\nthem to my 1945 log book, now in the collection of the Naval Surface Weapons<BR>\nCenter, and they found the remains of that moth taped to the page in<BR>\nquestion.\"<BR>\n&nbsp;[actually, the term \"bug\" had even earlier usage in<BR>\n&nbsp;regard to problems with radio hardware.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your fault -- core dumped');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','fortune: cannot execute.  Out of cookies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your computer account is overdrawn.  Please see Big Brother.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your computer account is overdrawn.  Please reauthorize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Fortune suggests uses for YOUR favorite UNIX commands!<BR>\n&nbsp;Try:<BR>\n&nbsp;ar t \"God\"<BR>\n&nbsp;drink < bottle; opener			(Bourne Shell)<BR>\n&nbsp;cat \"food in tin cans\"			(all but 4.[23]BSD)<BR>\n&nbsp;Hey UNIX!  Got a match?			(V6 or C shell)<BR>\n&nbsp;mkdir matter; cat > matter		(Bourne Shell)<BR>\n&nbsp;rm God<BR>\n&nbsp;man: Why did you get a divorce?		(C shell)<BR>\n&nbsp;date me					(anything up to 4.3BSD)<BR>\n&nbsp;make \"heads or tails of all this\"<BR>\n&nbsp;who is smart<BR>\n&nbsp;(C shell)<BR>\n&nbsp;If I had a ) for every dollar of the national debt, what would I have?<BR>\n&nbsp;sleep with me				(anything up to 4.3BSD)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','Your code should be more efficient!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','[FORTRAN] will persist for some time -- probably for at least the next decade.<BR>\n&nbsp;-- T. Cheatham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTRAN, \"the infantile disorder\", by now nearly 20 years old, is hopelessly<BR>\ninadequate for whatever computer application you have in mind today: it is<BR>\ntoo clumsy, too risky, and too expensive to use.<BR>\n&nbsp;-- Edsger W. Dijkstra, SIGPLAN Notices, Volume 17, Number 5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You will lose an important tape file.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','You will lose an important disk file.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','FORTRAN rots the brain.<BR>\n&nbsp;-- John McQuillin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('computers','<<<<< EVACUATION ROUTE <<<<<');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How many Zen Buddhist does it take to change a light bulb?<BR>\n&nbsp;Two.  One to change it and one not to change it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The majority of the stupid is invincible and guaranteed for all time. The <BR>\nterror of their tyranny, however, is alleviated by their lack of consistency.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I DO want your money, because god wants your money!\"<BR>\n-- The Reverend Jimmy, from _Repo_Man_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"And do you think (fop that I am) that I could be the Scarlet Pumpernickel?\"<BR>\n-- Looney Tunes, The Scarlet Pumpernickel (1950, Chuck Jones)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Would I turn on the gas if my pal Mugsy were in there?\"<BR>\n&nbsp;\"You might, rabbit, you might!\"<BR>\n-- Looney Tunes, Bugs and Thugs (1954, Friz Freleng)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Once at a social gathering, Gladstone said to Disraeli, \"I predict, Sir, that <BR>\nyou will die either by hanging or of some vile disease\".  Disraeli replied, <BR>\n\"That all depends, Sir, upon whether I embrace your principles or your <BR>\nmistress.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The way of the world is to praise dead saints and prosecute live ones.\"<BR>\n&nbsp;-- Nathaniel Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"For the man who has everything... Penicillin.\"<BR>\n&nbsp;-- F. Borquin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An Academic speculated whether a bather is beautiful<BR>\nif there is none in the forest to admire her. He hid<BR>\nin the bushes to find out, which vitiated his premise<BR>\nbut made him happy.<BR>\nMoral: Empiricism is more fun than speculation.\"<BR>\n-- Sam Weber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The good Christian should beware of mathematicians and all those who make <BR>\nempty prophecies.  The danger already exists that mathematicians have made <BR>\na covenant with the devil to darken the spirit and confine man in the <BR>\nbonds of Hell.\"<BR>\n&nbsp;-- Saint Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Pray to God, but keep rowing to shore.<BR>\n&nbsp;-- Russian Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Your mother was a hamster, and your father smelt of elderberrys!\"<BR>\n-- Monty Python and the Holy Grail');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Calling J-Man Kink.  Calling J-Man Kink.  Hash missile sighted, target<BR>\nLos Angeles.  Disregard personal feelings about city and intercept.\"<BR>\n-- The Firesign Theatre movie, _J-Men Forever_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The pyramid is opening!\"<BR>\n&nbsp;\"Which one?\"<BR>\n\"The one with the ever-widening hole in it!\"<BR>\n-- The Firesign Theatre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Save the whales.  Collect the whole set.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Open Channel D...\"<BR>\n-- Napoleon Solo, The Man From U.N.C.L.E.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I saw _Lassie_. It took me four shows to figure out why the hairy kid never <BR>\nspoke. I mean, he could roll over and all that, but did that deserve a series?\"<BR>\n-- the alien guy, in _Explorers_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You tweachewous miscweant!\"<BR>\n-- Elmer Fudd');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Nuclear war would really set back cable.\"<BR>\n- Ted Turner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','What to do in case of an alien attack:<BR>\n&nbsp;1)   Hide beneath the seat of your plane and look away.<BR>\n&nbsp;2)   Avoid eye contact.<BR>\n&nbsp;3) If there are no eyes, avoid all contact.<BR>\n&nbsp;-- The Firesign Theatre, _Everything you know is Wrong_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If you are beginning to doubt what I am saying, you are<BR>\n&nbsp;probably hallucinating.\"<BR>\n-- The Firesign Theatre, _Everything you know is Wrong_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If Ricky Schroder and Gary Coleman had a fight on<BR>\n&nbsp;television with pool cues, who would win?<BR>\n&nbsp;1) Ricky Schroder<BR>\n&nbsp;2) Gary Coleman<BR>\n&nbsp;3) The television viewing public\"<BR>\n-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Based on what you know about him in history books, what do you think Abraham <BR>\nLincoln would be doing if he were alive today?<BR>\n&nbsp;1) Writing his memoirs of the Civil War.<BR>\n&nbsp;2) Advising the President.<BR>\n&nbsp;3) Desperately clawing at the inside of his<BR>\n&nbsp;coffin.\"<BR>\n-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An anthropologist at Tulane has just come back from a field trip to New <BR>\nGuinea with reports of a tribe so primitive that they have Tide but not <BR>\nnew Tide with lemon-fresh Borax.\"<BR>\n-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Not only is God dead, but just try to find a plumber on weekends.\"<BR>\n--Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"They ought to make butt-flavored cat food.\"   --Gallagher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"As I was walking among the fires of Hell, delighted with the enjoyments of<BR>\n&nbsp;Genius; which to Angels look like torment and insanity.  I collected some of<BR>\n&nbsp;their Proverbs...\" - Blake, \"The Marriage of Heaven and Hell\"<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is hopeful symbolism in the fact that flags do not wave in a vacuum.\"<BR>\n--Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Proboscis:  The rudimentary organ of an elephant which serves him in place<BR>\nof the knife-and-fork that Evolution has as yet denied him.  For purposes<BR>\nof humor it is popularly called a trunk.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Presidency:  The greased pig in the field game of American politics.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Pray:  To ask that the laws of the universe be annulled in behalf of a single<BR>\npetitioner confessedly unworthy.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Politician:  An eel in the fundamental mud upon which the superstructure of<BR>\norganized society is reared.  When he wriggles he mistakes the agitation of<BR>\nhis tail for the trembling of the edifice.  As compared with the statesman,<BR>\nhe suffers the disadvantage of being alive.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Politics:  A strife of interests masquerading as a contest of principles.<BR>\nThe conduct of public affairs for private advantage.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Philosophy:  A route of many roads leading from nowhere to nothing.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Physician:  One upon whom we set our hopes when ill and our dogs when well.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I prefer rogues to imbeciles, because they sometimes take a rest.\"<BR>\n-- Alexandre Dumas (fils)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Ocean:  A body of water occupying about two-thirds of a world made for man --<BR>\nwho has no gills.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A penny saved is a penny to squander.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Administration:  An ingenious abstraction in politics, designed to receive<BR>\nthe kicks and cuffs due to the premier or president.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Egotist:  A person of low taste, more interested in himself than in me.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','1 1 was a race-horse, 2 2 was 1 2. When 1 1 1 1 race, 2 2 1 1 2.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Disobedience:  The silver lining to the cloud of servitude.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Abstainer:  A weak person who yields to the temptation of denying himself a<BR>\npleasure.  A total abstainer is one who abstains from everything but<BR>\nabstention, and especially from inactivity in the affairs of others.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Never give in.  Never give in.  Never. Never. Never.\"<BR>\n-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Meekness:  Uncommon patience in planning a revenge that is worth while.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Forty two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Saint:  A dead sinner revised and edited.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','All things are either sacred or profane.<BR>\nThe former to ecclesiasts bring gain;<BR>\nThe latter to the devil appertain.<BR>\n-- Dumbo Omohundro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Riches:  A gift from Heaven signifying, \"This is my beloved son, in whom I<BR>\nam well pleased.\"<BR>\n-- John D. Rockefeller, (slander by Ambrose Bierce)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Mausoleum:  The final and funniest folly of the rich.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I have five dollars for each of you.\"<BR>\n-- Bernhard Goetz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Insofar as I may be heard by anything, which may or may not care<BR>\nwhat I say, I ask, if it matters, that you be forgiven for anything<BR>\nyou may have done or failed to do which requires forgiveness.<BR>\nConversely, if not forgiveness but something else may be required to<BR>\ninsure any possible benefit for which you may be eligible after the<BR>\ndestruction of your body, I ask that this, whatever it may be,<BR>\nbe granted or withheld, as the case may be, in such a manner as to<BR>\ninsure your receiving said benefit. I ask this in my capacity as <BR>\nyour elected intermediary between yourself and that which may not be<BR>\nyourself, but which may have an interest in the matter of your<BR>\nreceiving as much as it is possible for you to receive of this<BR>\nthing, and which may in some way be influenced by this ceremony. Amen.\"<BR>\n&nbsp;Madrak, in _Creatures of Light and Darkness_, by Roger Zelazny');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Marriage Ceremony:  An incredible metaphysical sham of watching God and the <BR>\nlaw being dragged into the affairs of your family.<BR>\n-- O. C. Ogilvie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Professional wrestling:  ballet for the common man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;\"Are those cocktail-waitress fingernail marks?\"  I asked Colletti as he<BR>\nshowed us these scratches on his chest.  \"No, those are on my back,\" Colletti<BR>\nanswered.  \"This is where a case of cocktail shrimp fell on me.  I told her<BR>\nto slow down a little, but you know cocktail waitresses, they seem to have<BR>\na mind of their own.\"<BR>\n-- The Incredibly Monstrous, Mind-Roasting Summer of O.C. and Stiggs<BR>\n&nbsp;National Lampoon, October 1982');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I figured there was this holocaust, right, and the only ones left alive were<BR>\n&nbsp;Donna Reed, Ozzie and Harriet, and the Cleavers.\"<BR>\n-- Wil Wheaton explains why everyone in \"Star Trek: The Next Generation\" <BR>\n&nbsp;is so nice');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If I do not return to the pulpit this weekend, millions of people will go<BR>\nto hell.\"<BR>\n-- Jimmy Swaggart, 5/20/88');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I will make no bargains with terrorist hardware.\"<BR>\n-- Peter da Silva');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','This is now.  Later is later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','What the gods would destroy they first submit to an IEEE standards committee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Many aligators will be slain,<BR>\nbut the swamp will remain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','One evening Mr. Rudolph Block, of New York, found himself seated at dinner<BR>\nalongside Mr. Percival Pollard, the distinguished critic.<BR>\n&nbsp;\"Mr. Pollard,\" said he, \"my book, _The Biography of a Dead Cow_, is<BR>\n&nbsp;published anonymously, but you can hardly be ignorant of its authorship.<BR>\n&nbsp;Yet in reviewing it you speak of it as the work of the Idiot of the Century.<BR>\n&nbsp;Do you think that fair criticism?\"<BR>\n&nbsp;\"I am very sorry, sir,\" replied the critic, amiably, \"but it did not<BR>\noccur to me that you really might not wish the public to know who wrote it.\"<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ask not what A Group of Employees can do for you.  But ask what can <BR>\nAll Employees do for A Group of Employees.\"    <BR>\n-- Mike Dennison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Maintain an awareness for contribution -- to your schedule, your project, <BR>\nour company.\"  <BR>\n-- A Group of Employees');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Being against torture ought to be sort of a bipartisan thing.\"<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Ill-chosen abstraction is particularly evident in the design of the ADA<BR>\nruntime system. The interface to the ADA runtime system is so opaque that<BR>\nit is impossible to model or predict its performance, making it effectively<BR>\nuseless for real-time systems. -- Marc D. Donner and David H. Jameson.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Never ascribe to malice that which is caused by greed and ignorance.\"<BR>\n-- Cal Keegan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"In the fight between you and the world, back the world.\"<BR>\n&nbsp;--Frank Zappa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If you want to know what happens to you when you die, go look at some dead<BR>\nstuff.\"<BR>\n-- Dave Enyeart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"When the going gets weird, the weird turn pro...\"<BR>\n-- Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Be there.  Aloha.\"<BR>\n-- Steve McGarret, _Hawaii Five-Oh_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I prefer to think that God is not dead, just drunk\" <BR>\n-- John Huston');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The voters have spoken, the bastards...\"<BR>\n-- unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I have a friend who just got back from the Soviet Union, and told me the people<BR>\nthere are hungry for information about the West.  He was asked about many <BR>\nthings, but I will give you two examples that are very revealing about life in<BR>\nthe Soviet Union.  The first question he was asked was if we had exploding<BR>\ntelevision sets.  You see, they have a problem with the picture tubes on color<BR>\ntelevision sets, and many are exploding.  They assumed we must be having <BR>\nproblems with them too.  The other question he was asked often was why the<BR>\nCIA had killed Samantha Smith, the little girl who visited the Soviet Union a<BR>\nfew years ago; their propaganda is very effective.<BR>\n-- Victor Belenko, MiG-25 fighter pilot who defected in 1976<BR>\n&nbsp;\"Defense Electronics\", Vol 20, No. 6, pg. 100');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Engineering meets art in the parking lot and things explode.\"<BR>\n-- Garry Peterson, about Survival Research Labs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There is something you must understand about the Soviet system.  They have the<BR>\nability to concentrate all their efforts on a given design, and develop all<BR>\ncomponents simulateously, but sometimes without proper testing.  Then they end<BR>\nup with a technological disaster like the Tu-144.  In a technology race at<BR>\nthe time, that aircraft was two months ahead of the Concorde.  Four Tu-144s<BR>\nwere built; two have crashed, and two are in museums.  The Concorde has been<BR>\nflying safely for over 10 years.<BR>\n-- Victor Belenko, MiG-25 fighter pilot who defected in 1976<BR>\n&nbsp;\"Defense Electronics\", Vol 20, No. 6, pg. 100');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;...and before I knew what I was doing, I had kicked the<BR>\n&nbsp;typewriter and threw it around the room and made it beg for<BR>\n&nbsp;mercy.  At this point the typewriter pleaded for me to dress<BR>\n&nbsp;him in feminine attire but instead I pressed his margin release<BR>\n&nbsp;over and over again until the typewriter lost consciousness.<BR>\n&nbsp;Presently, I regained consciousness and realized with shame what<BR>\n&nbsp;I had done.  My shame is gone and now I am looking for a<BR>\n&nbsp;submissive typewriter, any color, or model.  No electric<BR>\n&nbsp;typewriters please!<BR>\n&nbsp;--Rick Kleiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In recognizing AT&T Bell Laboratories for corporate innovation, for its<BR>\ninvention of cellular mobile communications, IEEE President Russell C. Drew<BR>\nreferred to the cellular telephone as a \"basic necessity.\"  How times have<BR>\nchanged, one observer remarked: many in the room recalled the advent of<BR>\ndirect dialing.<BR>\n-- The Institute, July 1988, pg. 11');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The Amiga is the only personal computer where you can run a multitasking <BR>\noperating system and get realtime performance, out of the box.\"<BR>\n-- Peter da Silva');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Atomic batteries to power, turbines to speed.\"<BR>\n-- Robin, The Boy Wonder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"This knowledge I pursure is the finest pleasure I have ever known.  I could<BR>\nno sooner give it up that I could the very air that I breath.\"<BR>\n-- Paolo Uccello, Renaissance artist, discoverer of the laws of perspective');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An idealist is one who, on noticing that a rose smells better than a<BR>\ncabbage, concludes that it will also make better soup.\" - H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...Veloz is indistinguishable from hundreds of other electronics businesses<BR>\nin the Valley, run by eager young engineers poring over memory dumps late<BR>\ninto the night.  The difference is that a bunch of self-confessed \"car nuts\"<BR>\nare making money doing what they love: writing code and driving fast.<BR>\n-- \"Electronics puts its foot on the gas\", IEEE Spectrum, May 88');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Gozer the Gozerian:  As the duly appointed representative of the city,<BR>\ncounty and state of New York, I hereby order you to cease all supernatural<BR>\nactivities at once and proceed immediately to your place of origin or<BR>\nthe nearest parallel dimension, whichever is nearest.\"<BR>\n-- Ray (Dan Akyroyd, _Ghostbusters_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"History is a tool used by politicians to justify their intentions.\"<BR>\n-- Ted Koppel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Old age and treachery will beat youth and skill every time.\"<BR>\n-- a coffee cup');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A car is just a big purse on wheels.\"<BR>\n-- Johanna Reynolds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We will be better and braver if we engage and inquire than if we indulge in<BR>\nthe idle fancy that we already know -- or that it is of no use seeking to<BR>\nknow what we do not know.\"<BR>\n-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I just want to be a good engineer.\"<BR>\n-- Steve Wozniak, co-founder of Apple Computer, concluding his keynote speech <BR>\n&nbsp;at the 1988 AppleFest');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Remember Kruschev:  he tried to do too many things too fast, and he was <BR>\nremoved in disgrace.  If Gorbachev tries to destroy the system or make too<BR>\nmany fundamental changes to it, I believe the system will get rid of him.<BR>\nI am not a political scientist, but I understand the system very well.<BR>\nI believe he will have a \"heart attack\" or retire or be removed.  He is<BR>\nup against a brick wall.  If you think they will change everything and<BR>\nbecome a free, open society, forget it!\"<BR>\n-- Victor Belenko, MiG-25 fighter pilot who defected in 1976<BR>\n&nbsp;\"Defense Electronics\", Vol 20, No. 6, pg. 110');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"...I could accept this openness, glasnost, perestroika, or whatever you want<BR>\nto call it if they did these things: abolish the one party system; open the<BR>\nSoviet frontier and allow Soviet people to travel freely; allow the Soviet<BR>\npeople to have real free enterprise; allow Western businessmen to do business<BR>\nthere, and permit freedom of speech and of the press.  But so far, the whole<BR>\ncountry is like a concentration camp.  The barbed wire on the fence around<BR>\nthe Soviet Union is to keep people inside, in the dark.  This openness that<BR>\nyou are seeing, all these changes, are cosmetic and they have been designed<BR>\nto impress shortsighted, naive, sometimes stupid Western leaders.  These<BR>\nleaders gush over Gorbachev, hoping to do business with the Soviet Union or<BR>\nappease it.  He will say: \"Yes, we can do business!\"  This while his<BR>\nmilitary machine in Afghanistan has killed over a million people out of a<BR>\npopulation of 17 million.  Can you imagine that?<BR>\n-- Victor Belenko, MiG-25 fighter pilot who defected in 1976<BR>\n&nbsp;\"Defense Electronics\", Vol 20, No. 6, pg. 110');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The magician is seated in his high chair and looks upon the world with favor.<BR>\nHe is at the height of his powers.  If he closes his eyes, he causes the world<BR>\nto disappear.  If he opens his eyes, he causes the world to come back.  If<BR>\nthere is harmony within him, the world is harmonious.  If rage shatters his<BR>\ninner harmony, the unity of the world is shattered.  If desire arises within<BR>\nhim, he utters the magic syllables that causes the desired object to appear.<BR>\nHis wishes, his thoughts, his gestures, his noises command the universe.<BR>\n-- Selma Fraiberg, _The Magic Years_, pg. 107');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Sigmund Freud is alleged to have said that in the last analysis the entire field<BR>\nof psychology may reduce to biological electrochemistry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Only a brain-damaged operating system would support task switching and not<BR>\nmake the simple next step of supporting multitasking.\"<BR>\n-- George McFry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If you permit yourself to read meanings into (rather than drawing meanings out<BR>\nof) the evidence, you can draw any conclusion you like.<BR>\n-- Michael Keith, \"The Bar-Code Beast\", The Skeptical Enquirer Vol 12 No 4 p 416');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The stars are made of the same atoms as the earth.\"  I usually pick one small<BR>\ntopic like this to give a lecture on.  Poets say science takes away from the<BR>\nbeauty of the stars -- mere gobs of gas atoms.  Nothing is \"mere.\"  I too can<BR>\nsee the stars on a desert night, and feel them.  But do I see less or more?<BR>\nThe vastness of the heavens stretches my imagination -- stuck on this carousel<BR>\nmy little eye can catch one-million-year-old light.  A vast pattern -- of which<BR>\nI am a part -- perhaps my stuff was belched from some forgotten star, as one<BR>\nis belching there.  Or see them with the greater eye of Palomar, rushing all<BR>\napart from some common starting point when they were perhaps all together.<BR>\nWhat is the pattern, or the meaning, or the *why?*  It does not do harm to the <BR>\nmystery to know a little about it.  For far more marvelous is the truth than<BR>\nany artists of the past imagined!  Why do the poets of the present not speak<BR>\nof it?  What men are poets who can speak of Jupiter if he were like a man, but<BR>\nif he is an immense spinning sphere of methane and ammonia must be silent?<BR>\n-- Richard P. Feynman (1918-1988)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"BTW, does Jesus know you flame?\"<BR>\n-- Diane Holt, dianeh@binky.UUCP, to Ed Carp');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We came.  We saw.  We kicked its ass.\"<BR>\n-- Bill Murray, _Ghostbusters_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Comparing information and knowledge is like asking whether the fatness of a<BR>\npig is more or less green than the designated hitter rule.\"<BR>\n-- David Guaspari');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Uncertain fortune is thoroughly mastered by the equity of the calculation.<BR>\n- Blaise Pascal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Machines take me by surprise with great frequency.<BR>\n- Alan Turing');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is surely a great calamity for a human being to have no obsessions.<BR>\n- Robert Bly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The main thing is the play itself.  I swear that greed for money has nothing<BR>\nto do with it, although heaven knows I am sorely in need of money.<BR>\n- Feodor Dostoyevsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Things are not as simple as they seems at first.<BR>\n- Edward Thorp');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Unlike most net.puritans, however, I feel that what OTHER consenting computers<BR>\n&nbsp;do in the privacy of their own phone connections is their own business.\"<BR>\n-- John Woods, jfw@eddie.mit.edu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Prediction is very difficult, especially of the future.<BR>\n- Niels Bohr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You may call me by my name, Wirth, or by my value, Worth.<BR>\n- Nicklaus Wirth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The only thing necessary for the triumph of evil is for good men to do nothing.<BR>\n- Edmund Burke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Help Mr. Wizard!\"<BR>\n-- Tennessee Tuxedo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Successful and fortunate crime is called virtue.<BR>\n- Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The lawgiver, of all beings, most owes the law allegiance.<BR>\n&nbsp;He of all men should behave as though the law compelled him.<BR>\n&nbsp;But it is the universal weakness of mankind that what we are<BR>\n&nbsp;given to administer we presently imagine we own.\"<BR>\n-- H.G. Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Lack of skill dictates economy of style.<BR>\n- Joey Ramone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Life in the state of nature is solitary, poor, nasty, brutish, and short.<BR>\n- Thomas Hobbes, Leviathan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Gort, klaatu nikto barada.\"<BR>\n-- The Day the Earth Stood Still');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Wherever you go...There you are.<BR>\n- Buckaroo Banzai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The life of a repo man is always intense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You will be successful in your work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"All my life I wanted to be someone; I guess I should have been more specific.\"<BR>\n-- Jane Wagner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Hoping to goodness is not theologically sound. - Peanuts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We scientists, whose tragic destiny it has been to make the methods of<BR>\nannihilation ever more gruesome and more effective, must consider it our solemn<BR>\nand transcendent duty to do all in our power in preventing these weapons from<BR>\nbeing used for the brutal purpose for which they were invented.\" <BR>\n-- Albert Einstein, Bulletin of Atomic Scientists, September 1948');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There you go man,<BR>\nKeep as cool as you can.<BR>\nIt riles them to believe that you perceive the web they weave.<BR>\nKeep on being free!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Perfection is acheived only on the point of collapse.<BR>\n- C. N. Parkinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The only way to learn a new programming language is by writing programs in it.<BR>\n- Brian Kernighan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The connection between the language in which we think/program and the problems<BR>\nand solutions we can imagine is very close.  For this reason restricting<BR>\nlanguage features with the intent of eliminating programmer errors is at best<BR>\ndangerous.<BR>\n- Bjarne Stroustrup in \"The C++ Programming Language\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Except for 75% of the women, everyone in the whole world wants to have sex.<BR>\n- Ellyn Mustard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Einstein argued that there must be simplified explanations of nature, because<BR>\nGod is not capricious or arbitrary.  No such faith comforts the software<BR>\nengineer.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The complexity of software is an essential property, not an accidental one.<BR>\nHence, descriptions of a software entity that abstract away its complexity<BR>\noften abstract away its essence.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Digital computers are themselves more complex than most things people build:<BR>\nThey hyave very large numbers of states.  This makes conceiving, describing,<BR>\nand testing them hard.  Software systems have orders-of-magnitude more states<BR>\nthan computers do.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"None of our men are \"experts.\"  We have most unfortunately found it necessary <BR>\nto get rid of a man as soon as he thinks himself an expert -- because no one <BR>\never considers himself expert if he really knows his job.  A man who knows a <BR>\njob sees so much more to be done than he has done, that he is always pressing <BR>\nforward and never gives up an instant of thought to how good and how efficient <BR>\nhe is.  Thinking always ahead, thinking always of trying to do more, brings a <BR>\nstate of mind in which nothing is impossible. The moment one gets into the<BR>\n\"expert\" state of mind a great number of things become impossible.\"<BR>\n-- From Henry Ford Sr., \"My Life and Work,\" p. 86 (1922):');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Software entities are more complex for their size than perhaps any other human<BR>\nconstruct because no two parts are alike.  If they are, we make the two<BR>\nsimilar parts into a subroutine -- open or closed.  In this respect, software<BR>\nsystems differ profoundly from computers, buildings, or automobiles, where<BR>\nrepeated elements abound.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...computer hardware progress is so fast.  No other technology since<BR>\ncivilization began has seen six orders of magnitude in performance-price<BR>\ngain in 30 years.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A little retrospection shows that although many fine, useful software systems<BR>\nhave been designed by committees and built as part of multipart projects,<BR>\nthose software systems that have excited passionate fans are those that are<BR>\nthe products of one or a few designing minds, great designers.  Consider Unix,<BR>\nAPL, Pascal, Modula, the Smalltalk interface, even Fortran; and contrast them<BR>\nwith Cobol, PL/I, Algol, MVS/370, and MS-DOS.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...when fits of creativity run strong, more than one programmer or writer has<BR>\nbeen known to abandon the desktop for the more spacious floor.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In the pitiful, multipage, connection-boxed form to which the flowchart has<BR>\ntoday been elaborated, it has proved to be useless as a design tool --<BR>\nprogrammers draw flowcharts after, not before, writing the programs they<BR>\ndescribe.<BR>\n- Fred Brooks, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Cable is not a luxury, since many areas have poor TV reception.\"<BR>\n-- The mayor of Tucson, Arizona, 1989<BR>\n[apparently, good TV reception is a basic necessity -- at least in Tucson  -kl]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It was the Law of the Sea, they said.	Civilization ends at the waterline.<BR>\nBeyond that, we all enter the food chain, and not always right at the top.\"<BR>\n- Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Without coffee he could not work, or at least he could not have worked in the<BR>\nway he did.  In addition to paper and pens, he took with him everywhere as an<BR>\nindispensable article of equipment the coffee machine, which was no less<BR>\nimportant to him than his table or his white robe.<BR>\n- Stefan Zweigs, Biography of Balzac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Conceptual integrity in turn dictates that the design must proceed from one<BR>\nmind, or from a very small number of agreeing resonant minds.<BR>\n- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Each team building another component has been using the most recent tested<BR>\nversion of the integrated system as a test bed for debugging its piece.  Their<BR>\nwork will be set back by having that test bed change under them.  Of course it<BR>\nmust.  But the changes need to be quantized.  Then each user has periods of<BR>\nproductive stability, interrupted by bursts of test-bed change.  This seems<BR>\nto be much less disruptive than a constant rippling and trembling.<BR>\n- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','As the system comes up, the component builders will from time to time appear,<BR>\nbearing hot new versions of their pieces -- faster, smaller, more complete,<BR>\nor putatively less buggy.  The replacement of a working component by a new<BR>\nversion requires the same systematic testing procedure that adding a new<BR>\ncomponent does, although it should require less time, for more complete and<BR>\nefficient test cases will usually be available.<BR>\n- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Do not underestimate the value of print statements for debugging.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The inability to benefit from feedback appears to be the primary cause of<BR>\npseudoscience.  Pseudoscientists retain their beliefs and ignore or distort<BR>\ncontradictory evidence rather than modify or reject a flawed theory.  Because<BR>\nof their strong biases, they seem to lack the self-correcting mechanisms<BR>\nscientists must employ in their work.<BR>\n-- Thomas L. Creed, \"The Skeptical Inquirer,\" Summer 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Regarding astral projection, Woody Allen once wrote, \"This is not a bad way<BR>\nto travel, although there is usually a half-hour wait for luggage.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','At the heart of science is an essential tension between two seemingly<BR>\ncontradictory attitudes -- an openness to new ideas, no matter how bizarre<BR>\nor counterintuitive they may be, and the most ruthless skeptical scrutiny<BR>\nof all ideas, old and new.  This is how deep truths are winnowed from deep<BR>\nnonsense.  Of course, scientists make mistakes in trying to understand the<BR>\nworld, but there is a built-in error-correcting mechanism:  The collective<BR>\nenterprise of creative thinking and skeptical thinking together keeps the<BR>\nfield on track.<BR>\n-- Carl Sagan, \"The Fine Art of Baloney Detection,\" Parade, February 1, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','No user-servicable parts inside.  Refer to qualified service personnel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Thank God a million billion times you live in Texas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"And they told us, what they wanted...<BR>\n&nbsp;Was a sound that could kill some-one, from a distance.\" -- Kate Bush');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Remember, Information is not knowledge; Knowledge is not Wisdom;<BR>\nWisdom is not truth; Truth is not beauty; Beauty is not love;<BR>\nLove is not music; Music is the best.\" -- Frank Zappa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I go on working for the same reason a hen goes on laying eggs.\"<BR>\n- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Send lawyers, guns and money...\"<BR>\n-- Lyrics from a Warren Zevon song');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Your own mileage may vary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Scientists will study your brain to learn more about your distant cousin, Man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Trespassers will be shot.  Survivors will be SHOT AGAIN!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Trespassers will be shot.  Survivors will be prosecuted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You can have my Unix system when you pry it from my cold, dead fingers.\"<BR>\n-- Cal Keegan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"No matter where you go, there you are...\"<BR>\n-- Buckaroo Banzai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The greatest warriors are the ones who fight for peace.\"<BR>\n-- Holly Near');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','> From MAILER-DAEMON@Think.COM Thu Mar  2 13:59:11 1989<BR>\n> Subject: Returned mail: unknown mailer error 255<BR>\n&nbsp;\"Dale, your address no longer functions.  Can you fix it at your end?\"<BR>\n-- Bill Wolfe (wtwolfe@hubcap.clemson.edu)<BR>\n&nbsp;\"Bill, Your brain no longer functions.  Can you fix it at your end?\"<BR>\n-- Karl A. Nyberg (nyberg@ajpo.sei.cmu.edu)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Computer literacy is a contact with the activity of computing deep enough to<BR>\nmake the computational equivalent of reading and writing fluent and enjoyable.<BR>\nAs in all the arts, a romance with the material must be well under way.  If<BR>\nwe value the lifelong learning of arts and letters as a springboard for<BR>\npersonal and societal growth, should any less effort be spent to make computing<BR>\na part of our lives?\"<BR>\n-- Alan Kay, \"Computer Software\", Scientific American, September 1984');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The medium is the message.\"<BR>\n-- Marshall McLuhan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is important to note that probably no large operating system using current<BR>\ndesign technology can withstand a determined and well-coordinated attack,<BR>\nand that most such documented penetrations have been remarkably easy.<BR>\n-- B. Hebbard, \"A Penetration Analysis of the Michigan Terminal System\",<BR>\nOperating Systems Review, Vol. 14, No. 1, June 1980, pp. 7-20');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Mr. Watson, come here, I want you.\"   -- Alexander Graham Bell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If the presence of electricity can be made visible in any part of a circuit, I<BR>\nsee no reason why intelligence may not be transmitted instantaneously by<BR>\nelectricity.  -- Samuel F. B. Morse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You can observe a lot just by watching.  -- Yogi Berra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Each honest calling, each walk of life, has its own elite, its own aristocracy<BR>\nbased on excellence of performance.  -- James Bryant Conant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','One friend in a lifetime is much; two are many; three are hardly possible.<BR>\nFriendship needs a certain parallelism of life, a community of thought,<BR>\na rivalry of aim.  -- Henry Brook Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','For every problem there is one solution which is simple, neat, and wrong.<BR>\n-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Nothing in progression can rest on its original plan.  We may as well think of<BR>\nrocking a grown man in the cradle of an infant.  -- Edmund Burke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','What we anticipate seldom occurs; what we least expect generally happens.<BR>\n-- Bengamin Disraeli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The fancy is indeed no other than a mode of memory emancipated from the order<BR>\nof space and time.  -- Samuel Taylor Coleridge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Nothing ever becomes real till it is experienced -- even a proverb is no proverb<BR>\nto you till your life has illustrated it.  -- John Keats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A quarrel is quickly settled when deserted by one party; there is no battle<BR>\nunless there be two.  -- Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You see but you do not observe.<BR>\nSir Arthur Conan Doyle, in \"The Memoirs of Sherlock Holmes\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A person with one watch knows what time it is; a person with two watches is<BR>\nnever sure.   Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To be awake is to be alive.  -- Henry David Thoreau, in \"Walden\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A morsel of genuine history is a thing so rare as to be always valuable.<BR>\n-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The last thing one knows in constructing a work is what to put first.<BR>\n-- Blaise Pascal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...though his invention worked superbly -- his theory was a crock of sewage from<BR>\nbeginning to end. -- Vernor Vinge, \"The Peace War\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The evolution of the human race will not be accomplished in the ten thousand<BR>\nyears of tame animals, but in the million years of wild animals, because man<BR>\nis and will always be a wild animal.<BR>\n-- Charles Galton Darwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The reason ESP, for example, is not considered a viable topic in contemoprary<BR>\npsychology is simply that its investigation has not proven fruitful...After<BR>\nmore than 70 years of study, there still does not exist one example of an ESP<BR>\nphenomenon that is replicable under controlled conditions.  This simple but<BR>\nbasic scientific criterion has not been met despite dozens of studies conducted<BR>\nover many decades...It is for this reason alone that the topic is now of little<BR>\ninterest to psychology...In short, there is no demonstrated phenomenon that<BR>\nneeds explanation.<BR>\n-- Keith E. Stanovich, \"How to Think Straight About Psychology\", pp. 160-161');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is a very humbling experience to make a multimillion-dollar mistake, but it<BR>\nis also very memorable.  I vividly recall the night we decided how to organize<BR>\nthe actual writing of external specifications for OS/360.  The manager of<BR>\narchitecture, the manager of control program implementation, and I were<BR>\nthreshing out the plan, schedule, and division of responsibilities.<BR>\n&nbsp;The architecture manager had 10 good men.  He asserted that they could write<BR>\nthe specifications and do it right.  It would take ten months, three more<BR>\nthan the schedule allowed.<BR>\n&nbsp;The control program manager had 150 men.  He asserted that they could prepare<BR>\nthe specifications, with the architecture team coordinating; it would be <BR>\nwell-done and practical, and he could do it on schedule.  Futhermore, if<BR>\nthe architecture team did it, his 150 men would sit twiddling their thumbs<BR>\nfor ten months.<BR>\n&nbsp;To this the architecture manager responded that if I gave the control program<BR>\nteam the responsibility, the result would not in fact be on time, but would<BR>\nalso be three months late, and of much lower quality.  I did, and it was.  He<BR>\nwas right on both counts.  Moreover, the lack of conceptual integrity made<BR>\nthe system far more costly to build and change, and I would estimate that it<BR>\nadded a year to debugging time.<BR>\n- Frederick Brooks Jr., \"The Mythical Man Month\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Bond reflected that good Americans were fine people and that most of them<BR>\nseemed to come from Texas.\"<BR>\n- Ian Fleming, \"Casino Royale\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Single tasking: Just Say No.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Children begin by loving their parents.  After a time they judge them.  Rarely,<BR>\nif ever, do they forgive them.<BR>\n- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Stupidity, like virtue, is its own reward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There was nothing I hated more than to see a filthy old drunkie, a howling<BR>\naway at the sons of his father and going blurp blurp in between as if it were<BR>\na filthy old orchestra in his stinking rotten guts.  I could never stand to<BR>\nsee anyone like that, especially when they were old like this one was.\"<BR>\n- Alex in \"Clockwork Orange\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','When I left you, I was but the pupil.  Now, I am the master.<BR>\n- Darth Vader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The power to destroy a planet is insignificant when compared to the power of<BR>\nthe Force.<BR>\n- Darth Vader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Marriage is low down, but you spend the rest of your life paying for it.\"<BR>\n-- Baskins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Use the Force, Luke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"All these black people are screwing up my democracy.\" - Ian Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Probably the best operating system in the world is the [operating system]<BR>\n&nbsp;made for the PDP-11 by Bell Laboratories.\" - Ted Nelson, October 1977');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"...if the church put in half the time on covetousness that it does on lust,<BR>\n&nbsp;this would be a better world.\"  - Garrison Keillor, \"Lake Wobegon Days\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Live free or die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Morality is one thing.  Ratings are everything.\"<BR>\n- A Network 23 executive on \"Max Headroom\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Show business is just like high school, except you get paid.\"<BR>\n- Martin Mull');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Decaffeinated coffee?  Just Say No.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Uncompensated overtime?  Just Say No.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I have sacrificed time, health, and fortune, in the desire to complete these<BR>\nCalculating Engines.  I have also declined several offers of great personal<BR>\nadvantage to myself.  But, notwithstanding the sacrifice of these advantages<BR>\nfor the purpose of maturing an engine of almost intellectual power, and after<BR>\nexpending from my own private fortune a larger sum than the government of<BR>\nEngland has spent on that machine, the execution of which it only commenced,<BR>\nI have received neither an acknowledgement of my labors, not even the offer<BR>\nof those honors or rewards which are allowed to fall within the reach of men<BR>\nwho devote themselves to purely scientific investigations...  <BR>\n&nbsp;If the work upon which I have bestowed so much time and thought were a mere<BR>\ntriumph over mechanical difficulties, or simply curious, or if the execution<BR>\nof such engines were of doubtful practicability or utility, some justification<BR>\nmight be found for the course which has been taken; but I venture to assert<BR>\nthat no mathematician who has a reputation to lose will ever publicly express<BR>\nan opinion that such a machine would be useless if made, and that no man<BR>\ndistinguished as a civil engineer will venture to declare the construction of<BR>\nsuch machinery impracticable...<BR>\n&nbsp;And at a period when the progress of physical science is obstructed by that<BR>\nexhausting intellectual and manual labor, indispensable for its advancement,<BR>\nwhich it is the object of the Analytical Engine to relieve, I think the <BR>\napplication of machinery in aid of the most complicated and abtruse<BR>\ncalculations can no longer be deemed unworthy of the attention of the country.<BR>\nIn fact, there is no reason why mental as well as bodily labor should not<BR>\nbe economized by the aid of machinery.<BR>\n- Charles Babbage, Passage from the Life of a Philosopher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Overall, the philosophy is to attack the availability problem from two<BR>\ncomplementary directions:  to reduce the number of software errors through<BR>\nrigorous testing of running systems, and to reduce the effect of the<BR>\nremaining errors by providing for recovery from them.  An interesting footnote<BR>\nto this design is that now a system failure can usually be considered to be<BR>\nthe result of two program errors:  the first, in the program that started the<BR>\nproblem; the second, in the recovery routine that could not protect the<BR>\nsystem.  -- A. L. Scherr, \"Functional Structure of IBM Virtual Storage Operating<BR>\nSystems, Part II: OS/VS-2 Concepts and Philosophies,\" IBM Systems Journal,<BR>\nVol. 12, No. 4, 1973, pp. 382-400');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Get hold of portable property.  -- Charles Dickens, \"Great Expectations\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Suppose for a moment that the automobile industry had developed at the same<BR>\nrate as computers and over the same period:  how much cheaper and more efficient<BR>\nwould the current models be?  If you have not already heard the analogy, the<BR>\nanswer is shattering.  Today you would be able to buy a Rolls-Royce for $2.75,<BR>\nit would do three million miles to the gallon, and it would deliver enough<BR>\npower to drive the Queen Elizabeth II.  And if you were interested in<BR>\nminiaturization, you could place half a dozen of them on a pinhead.<BR>\n-- Christopher Evans');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Mirrors should reflect a little before throwing back images.<BR>\n-- Jean Cocteau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is not best to swap horses while crossing the river.<BR>\n-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...the increased productivity fostered by a friendly environment and quality<BR>\ntools is essential to meet ever increasing demands for software.<BR>\n-- M. D. McIlroy, E. N. Pinson and B. A. Tague');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Though a program be but three lines long,<BR>\nsomeday it will have to be maintained.\"<BR>\n-- The Tao of Programming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Small is beautiful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I maintain there is much more wonder in science than in pseudoscience.  And<BR>\nin addition, to whatever measure this term has any meaning, science has the<BR>\nadditional virtue, and it is not an inconsiderable one, of being true.<BR>\n- Carl Sagan, The Burden Of Skepticism, The Skeptical Inquirer, Vol. 12, Fall 87');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Just Say No.\"   - Nancy Reagan<BR>\n&nbsp;\"No.\"            - Ronald Reagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Kill Ugly Radio<BR>\n- Frank Zappa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Kill Ugly Processor Architectures<BR>\n- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','My computer can beat up your computer.<BR>\n- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There are bugs and then there are bugs.  And then there are bugs.<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The typical page layout program is nothing more than an electronic<BR>\nlight table for cutting and pasting documents.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I came home the other night and tried to open the door with my car keys...and <BR>\nthe building started up.  So I took it out for a drive.  A cop pulled me over <BR>\nfor speeding.  He asked me where I live... \"Right here\".<BR>\n-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I was playing poker the other night... with Tarot cards. I got a full house and<BR>\n4 people died.<BR>\n-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','My brother sent me a postcard the other day with this big sattelite photo of<BR>\nthe entire earth on it. On the back it said: \"Wish you were here\".<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I pledge allegiance to the flag<BR>\nof the United States of America<BR>\nand to the republic for which it stands,<BR>\none nation,<BR>\nindivisible,<BR>\nwith liberty<BR>\nand justice for all.<BR>\n- Francis Bellamy, 1892');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Operating-system software is the program that orchestrates all the basic<BR>\nfunctions of a computer.<BR>\n- The Wall Street Journal, Tuesday, September 15, 1987, page 40');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I may kid around about drugs, but really, I take them seriously.\"<BR>\n- Doctor Graper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The existence of god implies a violation of causality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Falling in love makes smoking pot all day look like the ultimate in restraint.\"<BR>\n-- Dave Sim, author of Cerebrus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I am your density.\"<BR>\n&nbsp;-- George McFly in \"Back to the Future\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','People are very flexible and learn to adjust to strange<BR>\nsurroundings -- they can become accustomed to read Lisp and<BR>\nFortran programs, for example.<BR>\n- Leon Sterling and Ehud Shapiro, Art of Prolog, MIT Press');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I program, therefore I am.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To program is to be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To be is to program.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Hokey religions and ancient weapons are no substitute for a good blaster at<BR>\nyour side.<BR>\n- Han Solo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is your destiny.<BR>\n- Darth Vader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The world is coming to an end--save your buffers!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','On a clear disk you can seek forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Memories of you remind me of you.<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In order to succeed in any enterprise, one must be persistent and patient.<BR>\nEven if one has to run some risks, one must be brave and strong enough to<BR>\nmeet and overcome vexing challenges to maintain a successful business in<BR>\nthe long run.  I cannot help saying that Americans lack this necessary <BR>\nchallenging spirit today.<BR>\n- Hajime Karatsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Even if you can deceive people about a product through misleading statements,<BR>\nsooner or later the product will speak for itself.<BR>\n- Hajime Karatsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','By one count there are some 700 scientists with respectable academic credentials<BR>\n(out of a total of 480,000 U.S. earth and life scientists) who give credence<BR>\nto creation-science, the general theory that complex life forms did not evolve<BR>\nbut appeared \"abruptly.\"<BR>\n- Newsweek, June 29, 1987, pg. 23');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If a person (a) is poorly, (b) receives treatment intended to make him better,<BR>\nand (c) gets better, then no power of reasoning known to medical science can<BR>\nconvince him that it may not have been the treatment that restored his health.<BR>\n- Sir Peter Medawar, The Art of the Soluble');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;Fiery energy lanced out, but the beams struck an intangible wall between<BR>\nthe Gubru and the rapidly turning Earth ship.<BR>\n&nbsp;\"Water!\" it shrieked as it read the spectral report.  \"A barrier of water<BR>\nvapor!  A civilized race could not have found such a trick in the Library!<BR>\nA civilized race could not have stooped so low!  A civilized race would not<BR>\nhave...\"<BR>\n&nbsp;It screamed as the Gubru ship hit a cloud of drifting snowflakes.<BR>\n&nbsp;- Startide Rising, by David Brin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ahead warp factor 1\"<BR>\n- Captain Kirk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Come on over here, baby, I want to do a thing with you.\"<BR>\n- A Cop, arresting a non-groovy person after the revolution, Firesign Theater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If imprinted foil seal under cap is broken or missing when purchased, do not <BR>\nuse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','core error - bus dumped');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In the realm of scientific observation, luck is granted only to those who are<BR>\nprepared.<BR>\n- Louis Pasteur');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Deliberate provocation of mystical experience, particularly by LSD and related<BR>\nhallucinogens, in contrast to spontaneous visionary experiences, entails<BR>\ndangers that must not be underestimated.  Practitioners must take into<BR>\naccount the peculiar effects of these substances, namely their ability to<BR>\ninfluence our consciousness, the innermost essence of our being.  The history<BR>\nof LSD to date amply demonstrates the catastrophic consequences that can<BR>\nensue when its profound effect is misjudged and the substance is mistaken<BR>\nfor a pleasure drug.  Special internal and external advance preperations<BR>\nare required; with them, an LSD experiment can become a meaningful<BR>\nexperience.<BR>\n- Dr. Albert Hoffman, the discoverer of LSD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I share the belief of many of my contemporaries that the spiritual crisis<BR>\npervading all spheres of Western industrial society can be remedied only <BR>\nby a change in our world view.  We shall have to shift from the materialistic,<BR>\ndualistic belief that people and their environment are separate, toward a<BR>\nnew conciousness of an all-encompassing reality, which embraces the <BR>\nexperiencing ego, a reality in which people feel their oneness with animate <BR>\nnature and all of creation.<BR>\n- Dr. Albert Hoffman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The characteristic property of hallucinogens, to suspend the boundaries between<BR>\nthe experiencing self and the outer world in an ecstatic, emotional experience,<BR>\nmakes it posible with their help, and after suitable internal and external<BR>\nperparation...to evoke a mystical experience according to plan, so to speak...<BR>\nI see the true importance of LSD in the possibility of providing materail aid <BR>\nto meditation aimed at the mystical experience of a deeper, comprehensive<BR>\nreality.  Such a use accords entirely with the essence and working character<BR>\nof LSD as a sacred drug.<BR>\n- Dr. Albert Hoffman, the discoverer of LSD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;It is either through the influence of narcotic potions, of which all<BR>\nprimitive peoples and races speak in hymns, or through the powerful approach<BR>\nof spring, penetrating with joy all of nature, that those Dionysian stirrings<BR>\narise, which in their intensification lead the individual to forget himself<BR>\ncompletely. . . .Not only does the bond between man and man come to be forged<BR>\nonce again by the magic of the Dionysian rite, but alienated, hostile, or<BR>\nsubjugated nature again celebrates her reconciliation with her prodigal son,<BR>\nman.<BR>\n- Fred Nietzsche, The Birth of Tragedy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To date, the firm conclusions of Project Blue Book are:<BR>\n&nbsp;1. no unidentified flying object reported, investigated and evaluated<BR>\n&nbsp;by the Air Force has ever given any indication of threat to our<BR>\n&nbsp;national security;<BR>\n&nbsp;2. there has been no evidence submitted to or discovered by the Air<BR>\n&nbsp;Force that sightings categorized as UNIDENTIFIED represent<BR>\n&nbsp;technological developments or principles beyond the range of<BR>\n&nbsp;present-day scientific knowledge; and<BR>\n&nbsp;3. there has been no evidence indicating that sightings categorized<BR>\n&nbsp;as UNIDENTIFIED are extraterrestrial vehicles.<BR>\n- the summary of Project Blue Book, an Air Force study of UFOs from 1950<BR>\n&nbsp;to 1965, as quoted by James Randi in Flim-Flam!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If I do not want others to quote me, I do not speak.\"  <BR>\n-- Phil Wayne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Those who believe in astrology are living in houses with foundations of<BR>\nSilly Putty.\"<BR>\n-  Dennis Rawlins, astronomer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Humanity has the stars in its future, and that future is too important to be<BR>\nlost under the burden of juvenile folly and ignorant superstition.<BR>\n- Isaac Asimov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Were there fewer fools, knaves would starve.<BR>\n- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Adapt.  Enjoy.  Survive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I do not believe that this generation of Americans is willing to resign itself<BR>\nto going to bed each night by the light of a Communist moon...<BR>\n- Lyndon B. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The vigor of civilized societies is preserved by the widespread sense that high<BR>\naims are worth-while.  Vigorous societies harbor a certain extravagance of<BR>\nobjectives, so that men wander beyond the safe provision of personal<BR>\ngratifications.  All strong interests easily become impersonal, the love of<BR>\na good job well done.  There is a sense of harmony about such an accomplishment,<BR>\nthe Peace brought by something worth-while.<BR>\n- Alfred North Whitehead, 1963, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Human society - man in a group - rises out of its lethargy to new levels of<BR>\nproductivity only under the stimulus of deeply inspiring and commonly <BR>\nappreciated goals.  A lethargic world serves no cause well; a spirited world<BR>\nworking diligently toward earnestly desired goals provides the means and<BR>\nthe strength toward which many ends can be satisfied...to unparalleled<BR>\nsocial accomplishment.<BR>\n- Dr. Lloyd V. Berkner, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The idea of man leaving this earth and flying to another celestial body and<BR>\nlanding there and stepping out and walking over that body has a fascination<BR>\nand a driving force that can get the country to a level of energy, ambition,<BR>\nand will that I do not see in any other undertaking.  I think if we are<BR>\nhonest with ourselves, we must admit that we needed that impetus extremely<BR>\nstrongly.  I sincerely believe that the space program, with its manned<BR>\nlanding on the moon, if wisely executed, will become the spearhead for a<BR>\nbroad front of courageous and energetic activities in all the fields of<BR>\nendeavour of the human mind - activities which could not be carried out <BR>\nexcept in a mental climate of ambition and confidence which such a spearhead<BR>\ncan give.<BR>\n- Dr. Martin Schwarzschild, 1962, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The challenge of space exploration and particularly of landing men on the moon<BR>\nrepresents the greatest challenge which has ever faced the human race.  Even<BR>\nif there were no clear scientific or other arguments for proceeding with this<BR>\ntask, the whole history of our civilization would still impel men toward the<BR>\ngoal.  In fact, the assembly of the scientific and military with these human<BR>\narguments creates such an overwhelming case that in can be ignored only by<BR>\nthose who are blind to the teachings of history, or who wish to suspend the<BR>\ndevelopment of civilization at its moment of greatest opportunity and drama.<BR>\n- Sir Bernard Lovell, 1962, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Largely because it is so tangible and exciting a program and as such will<BR>\nserve to keep alive the interest and enthusiasm of the whole spectrum of<BR>\nsociety...It is justified because...the program can give a sense of shared<BR>\nadventure and achievement to the society at large.\"<BR>\n- Dr. Colin S. Pittendrigh, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Athens built the Acropolis.  Corinth was a commercial city, interested in<BR>\npurely materialistic things.  Today we admire Athens, visit it, preserve the<BR>\nold temples, yet we hardly ever set foot in Corinth.\"<BR>\n- Dr. Harold Urey, Nobel Laureate in chemistry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"...proper attention to Earthly needs of the poor, the depressed and the<BR>\ndowntrodden, would naturally evolve from dynamic, articulate, spirited<BR>\nawareness of the great goals for Man and the society he conspired to erect.\"<BR>\n- David Baker, paraphrasing Harold Urey, in \"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is nothing so deadly as not to hold up to people the opportunity to<BR>\ndo great and wonderful things, if we wish to stimulate them in an active way.\"<BR>\n- Dr. Harold Urey, Nobel Laureate in chemistry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Of all the tyrannies that affect mankind, tyranny in religion is the worst.\"<BR>\n- Thomas Paine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Behind all the political rhetoric being hurled at us from abroad, we are <BR>\nbringing home one unassailable fact -- [terrorism is] a crime by any civilized<BR>\nstandard, committed against innocent people, away from the scene of political<BR>\nconflict, and must be dealt with as a crime. . . .<BR>\n&nbsp;[I]n our recognition of the nature of terrorism as a crime lies our best hope<BR>\nof dealing with it. . . .<BR>\n&nbsp;[L]et us use the tools that we have.  Let us invoke the cooperation we have<BR>\nthe right to expect around the world, and with that cooperation let us shrink<BR>\nthe dark and dank areas of sanctuary until these cowardly marauders are held<BR>\nto answer as criminals in an open and public trial for the crimes they have<BR>\ncommitted, and receive the punishment they so richly deserve.<BR>\n- William H. Webster, Director, Federal Bureau of Investigation, 15 Oct 1985');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You can do more with a kind word and a gun than with just a kind word.<BR>\n- Al Capone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','New York... when civilization falls apart, remember, we were way ahead of you.<BR>\n- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','As to Jesus of Nazareth...I think the system of Morals and his Religion,<BR>\nas he left them to us, the best the World ever saw or is likely to see;<BR>\nbut I apprehend it has received various corrupting Changes, and I have,<BR>\nwith most of the present Dissenters in England, some doubts as to his<BR>\ndivinity.<BR>\n- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The Bible is not my Book and Christianity is not my religion.  I could<BR>\nnever give assent to the long complicated statements of Christian dogma.<BR>\n- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The divinity of Jesus is made a convenient cover for absurdity.  Nowhere<BR>\nin the Gospels do we find a precept for Creeds, Confessions, Oaths,<BR>\nDoctrines, and whole carloads of other foolish trumpery that we find in<BR>\nChristianity.<BR>\n- John Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I do not find in orthodox Christianity one redeeming feature.<BR>\n- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Let us, then, fellow citizens, unite with one heart and one mind.  Let us<BR>\nrestore to social intercourse that harmony and affection without which<BR>\nliberty and even life itself are but dreary things.  And let us reflect<BR>\nthat having banished from our land that religious intolerance under which<BR>\nmankind so long bled, we have yet gained little if we counternance a<BR>\npolitical intolerance as despotic, as wicked, and capable of a bitter and<BR>\nbloody persecutions.<BR>\n- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The day will come when the mystical generation of Jesus, by the Supreme Being<BR>\nas his Father, in the womb of a virgin will be classified with the fable of<BR>\nthe generation of Minerva in the brain of Jupiter.  But we may hope that the<BR>\ndawn of reason and freedom of thought in these United States will do away with<BR>\nthis artificial scaffolding and restore to us the primitive and genuine<BR>\ndoctrines of this most venerated Reformer of human errors.<BR>\n- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','God requireth not a uniformity of religion.<BR>\n- Roger Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I do not believe in the creed professed by the Jewish Church, by the Roman<BR>\nChurch, by the Greek Church, by the Turkish Church, by the Protestant Church,<BR>\nnor by any Church that I know of.  My own mind is my own Church.<BR>\n- Thomas Paine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It does me no injury for my neighbor to say there are twenty gods or no God.<BR>\nIt neither picks my pocket nor breaks my leg.<BR>\n- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How long does it take a DEC field service engineer to change a lightbulb?<BR>\n&nbsp;It depends on how many bad ones he brought with him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How many Bavarian Illuminati does it take to screw in a lightbulb?<BR>\n&nbsp;Three: one to screw it in, and one to confuse the issue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How many surrealists does it take to screw in a lightbulb?<BR>\n&nbsp;One to hold the giraffe and one to fill the bathtub with brightly colored<BR>\npower tools.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Imitation is the sincerest form of plagarism.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I judge a religion as being good or bad based on whether its adherents<BR>\nbecome better people as a result of practicing it.<BR>\n- Joe Mullally, computer salesman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','And do you not think that each of you women is an Eve?  The judgement of God<BR>\nupon your sex endures today; and with it invariably endures your position of <BR>\ncriminal at the bar of justice.<BR>\n- Tertullian, second-century Christian writer, misogynist');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Faith may be defined briefly as an illogical belief in the occurence of the<BR>\nimprobable.<BR>\n- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','So we follow our wandering paths, and the very darkness acts as our guide and<BR>\nour doubts serve to reassure us.<BR>\n- Jean-Pierre de Caussade, eighteenth-century Jesuit priest');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Life is a process, not a principle, a mystery to be lived, not a problem to<BR>\nbe solved.<BR>\n- Gerard Straub, television producer and author (stolen from Frank Herbert??)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...difference of opinion is advantageious in religion.  The several sects<BR>\nperform the office of a common censor morum over each other.  Is uniformity<BR>\nattainable?  Millions of innocent men, women, and children, since the<BR>\nintroduction of Christianity, have been burnt, tortured, fined, imprisoned;<BR>\nyet we have not advanced one inch towards uniformity.<BR>\n- Thomas Jefferson, \"Notes on Virginia\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To downgrade the human mind is bad theology.<BR>\n- C. K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I cannot affirm God if I fail to affirm man.  Therefore, I affirm both.<BR>\nWithout a belief in human unity I am hungry and incomplete.  Human unity<BR>\nis the fulfillment of diversity.  It is the harmony of opposites.  It is<BR>\na many-stranded texture, with color and depth.<BR>\n- Norman Cousins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If only God would give me some clear sign!  Like making a large deposit<BR>\nin my name at a Swiss Bank.<BR>\n- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Doubt is not a pleasant condition, but certainty is absurd.<BR>\n- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Doubt is a pain too lonely to know that faith is his twin brother.<BR>\n- Kahlil Gibran');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Those who believe that they believe in God, but without passion in their<BR>\nhearts, without anguish in mind, without uncertainty, without doubt,<BR>\nwithout an element of despair even in their consolation, believe only<BR>\nin the God idea, not God Himself.<BR>\n- Miguel de Unamuno, Spanish philosopher and writer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Clothes make the man.  Naked people have little or no influence on society.<BR>\n- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Every Solidarity center had piles and piles of paper .... everyone was<BR>\neating paper and a policeman was at the door.  Now all you have to do is<BR>\nbend a disk.\"<BR>\n- an anonymous member of the outlawed Polish trade union, Solidarity, <BR>\n&nbsp;commenting on the benefits of using computers in support of their movement');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Being schizophrenic is better than living alone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Any sufficiently advanced technology is indistinguishable from a rigged demo.<BR>\n- Andy Finkel, computer guy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The meek are contesting the will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...there can be no public or private virtue unless the foundation of action is<BR>\nthe practice of truth.<BR>\n- George Jacob Holyoake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The best that we can do is to be kindly and helpful toward our friends and<BR>\nfellow passengers who are clinging to the same speck of dirt while we are<BR>\ndrifting side by side to our common doom.<BR>\n- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There is, in fact, no reason to believe that any given natural phenomenon,<BR>\nhowever marvelous it may seem today, will remain forever inexplicable.<BR>\nSoon or late the laws governing the production of life itself will be <BR>\ndiscovered in the laboratory, and man may set up business as a creator<BR>\non his own account.  The thing, indeed, is not only conceivable; it is<BR>\neven highly probable.<BR>\n- H. L. Mencken, 1930');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The evidence of the emotions, save in cases where it has strong objective<BR>\nsupport, is really no evidence at all, for every recognizable emotion has<BR>\nits opposite, and if one points one way then another points the other way.<BR>\nThus the familiar argument that there is an instinctive desire for immortality,<BR>\nand that this desire proves it to be a fact, becomes puerile when it is<BR>\nrecalled that there is also a powerful and widespread fear of annihilation,<BR>\nand that this fear, on the same principle proves that there is nothing<BR>\nbeyond the grave.  Such childish \"proofs\" are typically theological, and<BR>\nthey remain theological even when they are adduced by men who like to <BR>\nflatter themselves by believing that they are scientific gents....<BR>\n- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The notion that science does not concern itself with first causes -- that it<BR>\nleaves the field to theology or metaphysics, and confines itself to mere <BR>\neffects -- this notion has no support in the plain facts.  If it could,<BR>\nscience would explain the origin of life on earth at once--and there is <BR>\nevery reason to believe that it will do so on some not too remote tomorrow.<BR>\nTo argue that gaps in knowledge which will confront the seeker must be filled,<BR>\nnot by patient inquiry, but by intuition or revelation, is simply to give<BR>\nignorance a gratuitous and preposterous dignity....<BR>\n- H. L. Mencken, 1930');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The truth is that Christian theology, like every other theology, is not only<BR>\nopposed to the scientific spirit; it is also opposed to all other attempts<BR>\nat rational thinking.  Not by accident does Genesis 3 make the father of<BR>\nknowledge a serpent -- slimy, sneaking and abominable.  Since the earliest<BR>\ndays the church as an organization has thrown itself violently against every<BR>\neffort to liberate the body and mind of man.  It has been, at all times and<BR>\neverywhere, the habitual and incorrigible defender of bad governments, bad<BR>\nlaws, bad social theories, bad institutions.  It was, for centuries, an<BR>\napologist for slavery, as it was the apologist for the divine right of kings.<BR>\n- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ada is the work of an architect, not a computer scientist.\"<BR>\n- Jean Icbiah, inventor of Ada, weenie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Prevalent beliefs that knowledge can be tapped from previous incarnations or<BR>\nfrom a \"universal mind\" (the repository of all past wisdom and creativity)<BR>\nnot only are implausible but also unfairly demean the stunning achievements<BR>\nof individual human brains.<BR>\n- Barry L. Beyerstein, \"The Brain and Consciousness: Implications for Psi<BR>\n&nbsp;Phenomena\", The Skeptical Inquirer, Vol. XII No. 2, ppg. 163-171');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Modern psychology takes completely for granted that behavior and neural function<BR>\nare perfectly correlated, that one is completely caused by the other.  There is<BR>\nno separate soul or lifeforce to stick a finger into the brain now and then and<BR>\nmake neural cells do what they would not otherwise.  Actually, of course, this<BR>\nis a working assumption only....It is quite conceivable that someday the<BR>\nassumption will have to be rejected.  But it is important also to see that we<BR>\nhave not reached that day yet: the working assumption is a necessary one and<BR>\nthere is no real evidence opposed to it.  Our failure to solve a problem so<BR>\nfar does not make it insoluble.  One cannot logically be a determinist in<BR>\nphysics and biology, and a mystic in psychology.<BR>\n- D. O. Hebb, Organization of Behavior:  A Neuropsychological Theory, 1949');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I think trash is the most important manifestation of culture we have in my<BR>\nlifetime.\"<BR>\n- Johnny Legend');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','When bad men combine, the good must associate; else they will fall one by one,<BR>\nan unpitied sacrifice in a contemptible struggle.<BR>\n- Edmund Burke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Men ought to know that from the brain and from the brain only arise our<BR>\npleasures, joys, laughter, and jests as well as our sorrows, pains, griefs<BR>\nand tears.  ... It is the same thing which makes us mad or delirious, inspires<BR>\nus with dread and fear, whether by night or by day, brings us sleeplessness,<BR>\ninopportune mistakes, aimless anxieties, absent-mindedness and acts that are<BR>\ncontrary to habit...<BR>\n- Hippocrates (c. 460-c. 377 B.C.), The Sacred Disease');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','This was the ultimate form of ostentation among technology freaks -- to have<BR>\na system so complete and sophisticated that nothing showed; no machines,<BR>\nno wires, no controls.<BR>\n- Michael Swanwick, \"Vacuum Flowers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Weekends were made for programming.<BR>\n- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Our journey toward the stars has progressed swiftly.<BR>\n&nbsp;In 1926 Robert H. Goddard launched the first liquid-propelled rocket,<BR>\nachieving an altitude of 41 feet.  In 1962 John Glenn orbited the earth.<BR>\n&nbsp;In 1969, only 66 years after Orville Wright flew two feet off the ground<BR>\nfor 12 seconds, Neil Armstrong, Buzz Aldrin and I rocketed to the moon<BR>\nin Apollo 11.\"<BR>\n-- Michael Collins<BR>\n&nbsp;Former astronaut and past Director of the National Air and Space Museum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Your good nature will bring you unbounded happiness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Nothing ever becomes real until it is experienced.<BR>\n- John Keats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is the quality rather than the quantity that matters.<BR>\n- Lucius Annaeus Seneca (4 B.C. - A.D. 65)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To follow foolish precedents, and wink<BR>\nWith both our eyes, is easier than to think.<BR>\n- William Cowper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is no statute of limitations on stupidity.\"<BR>\n-- Randomly produced by a computer program called Markov3.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The fountain code has been tightened slightly so you can no longer dip objects<BR>\ninto a fountain or drink from one while you are floating in mid-air due to<BR>\nlevitation.<BR>\n&nbsp;Teleporting to hell via a teleportation trap will no longer occur if the <BR>\ncharacter does not have fire resistance.<BR>\n&nbsp;- README file from the NetHack game');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Anyone who knows history, particularly the history of Europe, will, I think,<BR>\nrecognize that the domination of education or of government by any one<BR>\nparticular religious faith is never a happy arrangement for the people.<BR>\n- Eleanor Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The more a man is imbued with the ordered regularity of all events, the firmer<BR>\nbecomes his conviction that there is no room left by the side of this ordered<BR>\nregularity for causes of a different nature.  For him neither the rule of<BR>\nhuman nor the rule of divine will exists as an independent cause of natural<BR>\nevents.  To be sure, the doctrine of a personal God interfering with natural<BR>\nevents could never be refuted, in the real sense, by science, for this<BR>\ndoctrine can always take refuge in those domains in which scientific knowledge<BR>\nhas not yet been able to set foot.<BR>\n&nbsp;But I am persuaded that such behavior on the part of the representatives<BR>\nof religion would not only be unworthy but also fatal.  For a doctrine which <BR>\nis able to maintain itself not in clear light, but only in the dark, will<BR>\nof necessity lose its effect on mankind, with incalculable harm to human<BR>\nprogress.  In their struggle for the ethical good, teachers of religion<BR>\nmust have the stature to give up the doctrine of a personal God, that is, <BR>\ngive up that source of fear and hope which in the past placed such vast<BR>\npowers in the hands of priests.  In their labors they will have to avail<BR>\nthemselves of those forces which are capable of cultivating the Good, the <BR>\nTrue, and the Beautiful in humanity itself.  This is, to be sure, a more<BR>\ndifficult but an incomparably more worthy task.<BR>\n- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The price one pays for pursuing any profession, or calling, is an intimate<BR>\nknowledge of its ugly side.  -- James Baldwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The further the spiritual evolution of mankind advances, the more certain it<BR>\nseems to me that the path to genuine religiosity does not lie through the<BR>\nfear of life, and the fear of death, and blind faith, but through striving<BR>\nafter rational knowledge.<BR>\n- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','My mother is a fish.<BR>\n- William Faulkner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Whenever people agree with me, I always think I must be wrong.<BR>\n- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Everyone has a purpose in life.  Perhaps yours is watching television.<BR>\n- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','This restaurant was advertising breakfast any time. So I ordered<BR>\nfrench toast in the renaissance.<BR>\n- Steven Wright, comedian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','This conjunction of an immense military establishment and a large arms <BR>\nindustry is now in the American experience... We must not fail to <BR>\ncomprehend its grave implications... We must guard against the <BR>\nacquisition of unwarranted influence...by the military-industrial<BR>\ncomplex.  The potential for the disastrous rise of misplaced power<BR>\nexists and will persist.<BR>\n- Dwight D. Eisenhower, from his farewell address in 1961');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How many nuclear engineers does it take to change a light bulb ?<BR>\n&nbsp;Seven:  One to install the new bulb, and six to determine what to do<BR>\n&nbsp;with the old one for the next 10,000 years.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Now I lay me down to sleep<BR>\nI hear the sirens in the street<BR>\nAll my dreams are made of chrome<BR>\nI have no way to get back home<BR>\n- Tom Waits');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','... The book is worth attention for only two reasons:  (1) it attacks<BR>\nattempts to expose sham paranormal studies; and (2) it is very well and<BR>\nplausibly written and so rather harder to dismiss or refute by simple<BR>\njeering.<BR>\n- Harry Eagar, reviewing \"Beyond the Quantum\" by Michael Talbot,<BR>\n&nbsp;The Skeptical Inquirer, Vol. XII No. 2, ppg. 200-201');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...It is sad to find him belaboring the science community for its united<BR>\nopposition to ignorant creationists who want teachers and textbooks to<BR>\ngive equal time to crank arguments that have advanced not a step beyond<BR>\nthe flyblown rhetoric of Bishop Wilberforce and William Jennings Bryan.<BR>\n- Martin Gardner, \"Irving Kristol and the Facts of Life\", <BR>\n&nbsp;The Skeptical Inquirer, Vol. XII No. 2, ppg. 128-131');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Evolution is as much a fact as the earth turning on its axis and going around<BR>\nthe sun.  At one time this was called the Copernican theory; but, when<BR>\nevidence for a theory becomes so overwhelming that no informed person<BR>\ncan doubt it, it is customary for scientists to call it a fact.  That all<BR>\npresent life descended from earlier forms, over vast stretches of geologic<BR>\ntime, is as firmly established as Copernican cosmology.  Biologists differ<BR>\nonly with respect to theories about how the process operates.<BR>\n- Martin Gardner, \"Irving Kristol and the Facts of Life\", <BR>\n&nbsp;The Skeptical Inquirer, Vol. XII No. 2, ppg. 128-131');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Evolution is a bankrupt speculative philosophy, not a scientific fact.<BR>\nOnly a spiritually bankrupt society could ever believe it. ... Only<BR>\natheists could accept this Satanic theory.<BR>\n- Rev. Jimmy Swaggart, \"The Pre-Adamic Creation and Evolution\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Extraordinary claims demand extraordinary proof.  There are many examples of<BR>\noutsiders who eventually overthrew entrenched scientific orthodoxies, but<BR>\nthey prevailed with irrefutable data.  More often, egregious findings that<BR>\ncontradict well-established research turn out to be artifacts.  I have<BR>\nargued that accepting psychic powers, reincarnation, \"cosmic conciousness,\"<BR>\nand the like, would entail fundamental revisions of the foundations of<BR>\nneuroscience.  Before abandoning materialist theories of mind that have paid<BR>\nhandsome dividends, we should insist on better evidence for psi phenomena<BR>\nthan presently exists, especially when neurology and psychology themselves<BR>\noffer more plausible alternatives.<BR>\n- Barry L. Beyerstein, \"The Brain and Conciousness: Implications for Psi<BR>\n&nbsp;Phenomena\", The Skeptical Inquirer, Vol. XII No. 2, ppg. 163-171');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Unix:  Some say the learning curve is steep, but you only have to climb it once.<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Those who do not understand Unix are condemned to reinvent it, poorly.<BR>\n- Henry Spencer, University of Toronto Unix hack');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','On our campus the UNIX system has proved to be not only an effective software<BR>\ntool, but an agent of technical and social change within the University.<BR>\n- John Lions (University of New South Wales)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The man scarce lives who is not more credulous than he ought to be.... The<BR>\nnatural disposition is always to believe.  It is acquired wisdom and experience<BR>\nonly that teach incredulity, and they very seldom teach it enough.<BR>\n- Adam Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I simply try to aid in letting the light of historical truth into that<BR>\ndecaying mass of outworn thought which attaches the modern world to<BR>\nmedieval conceptions of Christianity, and which still lingers among us --<BR>\na most serious barrier to religion and morals, and a menace to the whole<BR>\nnormal evolution of society.<BR>\n- Andrew D. White, author, first president of Cornell University, 1896');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is clear that the individual who persecutes a man, his brother, because<BR>\nhe is not of the same opinion, is a monster.<BR>\n- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Marriage is the only adventure open to the cowardly.<BR>\n- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is wrong always, everywhere and for everyone to believe anything upon<BR>\ninsufficient evidence.<BR>\n- W. K. Clifford, British philosopher, circa 1876');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If atheism is to be used to express the state of mind in which God is<BR>\nidentified with the unknowable, and theology is pronounced to be a<BR>\ncollection of meaningless words about unintelligible chimeras, then<BR>\nI have no doubt, and I think few people doubt, that atheists are as<BR>\nplentiful as blackberries...<BR>\n- Leslie Stephen (1832-1904), literary essayist, author');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Truth has always been found to promote the best interests of mankind...<BR>\n- Percy Bysshe Shelley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Spiritual leadership should remain spiritual leadership and the temporal<BR>\npower should not become too important in any church.<BR>\n- Eleanor Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Most non-Catholics know that the Catholic schools are rendering a greater<BR>\nservice to our nation than the public schools in which subversive textbooks<BR>\nhave been used, in which Communist-minded teachers have taught, and from<BR>\nwhose classrooms Christ and even God Himself are barred.<BR>\n- from \"Our Sunday Visitor\", an American-Catholic newspaper, 1949');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...I would go so far as to suggest that, were it not for our ego and <BR>\nconcern to be different, the African apes would be included in our <BR>\nfamily, the Hominidae.<BR>\n- Richard Leakey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','History shows that the human mind, fed by constant accessions of knowledge,<BR>\nperiodically grows too large for its theoretical coverings, and bursts<BR>\nthem asunder to appear in new habiliments, as the feeding and growing<BR>\ngrub, at intervals, casts its too narrow skin and assumes another...<BR>\nTruly the imago state of Man seems to be terribly distant, but every<BR>\nmoult is a step gained.<BR>\n- Charles Darwin, from \"Origin of the Species\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In the broad and final sense all institutions are educational in the<BR>\nsense that they operate to form the attitudes, dispositions, abilities<BR>\nand disabilities that constitute a concrete personality...Whether this<BR>\neducative process is carried on in a predominantly democratic or non-<BR>\ndemocratic way becomes, therefore, a question of transcendent importance<BR>\nnot only for education itself but for its final effect upon all the<BR>\ninterests and activites of a society that is committed to the democratic<BR>\nway of life.<BR>\n- John Dewey (1859-1953), American philosopher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','America has been discovered before, but it has always been hushed up.<BR>\n- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I know engineers.  They love to change things.<BR>\n- Dr. McCoy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','We want to create puppets that pull their own strings.<BR>\n- Ann Marion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Already the spirit of our schooling is permeated with the feeling that<BR>\nevery subject, every topic, every fact, every professed truth must be<BR>\nsubmitted to a certain publicity and impartiality.  All proffered <BR>\nsamples of learning must go to the same assay-room and be subjected to <BR>\ncommon tests.  It is the essence of all dogmatic faiths to hold that<BR>\nany such \"show-down\" is sacrilegious and perverse.  The characteristic<BR>\nof religion, from their point of view, is that it is intellectually<BR>\nsecret, not public; peculiarly revealed, not generall known; <BR>\nauthoritatively declared, not communicated and tested in ordinary <BR>\nways...It is pertinent to point out that, as long as religion is<BR>\nconceived as it is now by the great majority of professed religionists,<BR>\nthere is something self-contradictory in speaking of education in<BR>\nreligion in the same sense in which we speak of education in topics<BR>\nwhere the method of free inquiry has made its way.  The \"religious\"<BR>\nwould be the last to be willing that either the history of the<BR>\ncontent of religion should be taught in this spirit; while those<BR>\nto whom the scientific standpoint is not merely a technical device,<BR>\nbut is the embodiment of the integrity of mind, must protest against<BR>\nits being taught in any other spirit.<BR>\n- John Dewey (1859-1953), American philosopher, <BR>\n&nbsp;from \"Democracy in the Schools\", 1908');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If one inquires why the American tradition is so strong against any<BR>\nconnection of State and Church, why it dreads even the rudiments of<BR>\nreligious teaching in state-maintained schools, the immediate and<BR>\nsuperficial answer is not far to seek....<BR>\nThe cause lay largely in the diversity and vitality of the various<BR>\ndenominations, each fairly sure that, with a fair field and no favor,<BR>\nit could make its own way; and each animated by a jealous fear that,<BR>\nif any connection of State and Church were permitted, some rival<BR>\ndenomination would get an unfair advantage.<BR>\n- John Dewey (1859-1953), American philosopher, <BR>\n&nbsp;from \"Democracy in the Schools\", 1908');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The world is no nursery.<BR>\n- Sigmund Freud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The Messiah will come.  There will be a resurrection of the dead -- all<BR>\nthe things that Jews believed in before they got so damn sophisticated.<BR>\n- Rabbi Meir Kahane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','We may not be able to persuade Hindus that Jesus and not Vishnu should<BR>\ngovern their spiritual horizon, nor Moslems that Lord Buddha is at the<BR>\ncenter of their spiritual universe, nor Hebrews that Mohammed is a major<BR>\nprohpet, nor Christians that Shinto best expresses their spiritual <BR>\nconcerns, to say nothing of the fact that we may not be able to get<BR>\nChristians to agree among themselves about their relationship to God.<BR>\nBut all will agree on a proposition that they possess profound spiritual<BR>\nresources.  If, in addition, we can get them to accept the further<BR>\nproposition that whatever form the Deity may have in their own theology,<BR>\nthe Deity is not only external, but internal and acts through them, and<BR>\nthey themselves give proof or disproof of the Deity in what they do and<BR>\nthink; if this further proposition can be accepted, then we come that<BR>\nmuch closer to a truly religious situation on earth.<BR>\n- Norman Cousins, from his book \"Human Options\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Nothing is easier than to denounce the evildoer; nothing is more difficult<BR>\nthan to understand him.<BR>\n- Fyodor Dostoevski');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Saints should always be judged guilty until they are proven innocent.<BR>\n- George Orwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','They [preachers] dread the advance of science as witches do the approach<BR>\nof daylight and scowl on the fatal harbinger announcing the subversions<BR>\nof the duperies on which they live.<BR>\n- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...it still remains true that as a set of cognitive beliefs about the<BR>\nexistence of God in any recognizable sense continuous with the great<BR>\nsystems of the past, religious doctrines constitute a speculative<BR>\nhypothesis of an extremely low order of probability.<BR>\n- Sidney Hook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The greatest dangers to liberty lurk in insidious encroachment by mean of zeal,<BR>\nwell-meaning but without understanding.\"<BR>\n-- Justice Louis O. Brandeis (Olmstead vs. United States)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Now, if the leaders of the world -- people who are leaders by virtue of <BR>\npolitical, military or financial power, and not necessarily wisdom or<BR>\nconsideration for mankind -- if these leaders manage not to pull us<BR>\nover the brink into planetary suicide, despite their occasional pompous<BR>\nsuggestions that they may feel obliged to do so, we may survive beyond<BR>\n1988.  <BR>\n-- George Rostky, EE Times, June 20, 1988 p. 45');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What if\" is a trademark of Hewlett Packard, so stop using it in your<BR>\nsentences without permission, or risk being sued.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"All we are given is possibilities -- to make ourselves one thing or another.\"<BR>\n-- Ortega y Gasset');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A dirty mind is a joy forever.\"<BR>\n-- Randy Kunkee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Stupidity, like virtue, is its own reward\"<BR>\n-- William E. Davidsen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To write good code is a worthy challenge, and a source of civilized delight.<BR>\n-- stolen and paraphrased from William Safire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Little else matters than to write good code.\"<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Paul Lynde to block...\"<BR>\n-- a contestant on \"Hollywood Squares\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Survey says...\"<BR>\n-- Richard Dawson, weenie, on \"Family Feud\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We cannot put off living until we are ready.  The most salient characteristic<BR>\nof life is its coerciveness; it is always urgent, \"here and now,\" without any<BR>\npossible postponement.  Life is fired at us point blank.\"<BR>\n-- Ortega y Gasset');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Wish not to seem, but to be, the best.\"<BR>\n-- Aeschylus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The urge to destroy is also a creative urge.\"<BR>\n-- Bakunin<BR>\n[ed. note - I would say: The urge to destroy may sometimes be a creative urge.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Free markets select for winning solutions.\"<BR>\n-- Eric S. Raymond');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Hey Ivan, check your six.\"<BR>\n-- Sidewinder missile jacket patch, showing a Sidewinder driving up the tail<BR>\n&nbsp;of a Russian Su-27');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Floggings will continue until morale improves.\"<BR>\n-- anonymous flyer being distributed at Exxon USA');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"From there to here, from here to there, funny things are everywhere.\"<BR>\n-- Dr. Seuss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Laugh while you can, monkey-boy.\"<BR>\n-- Dr. Emilio Lizardo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;UNIX Shell is the Best Fourth Generation Programming Language<BR>\n&nbsp;It is the UNIX shell that makes it possible to do applications in a small <BR>\n&nbsp;fraction of the code and time it takes in third generation languages.  In <BR>\n&nbsp;the shell you process whole files at a time, instead of only a line at a <BR>\n&nbsp;time.  And, a line of code in the UNIX shell is one or more programs,<BR>\n&nbsp;which do more than pages of instructions in a 3GL.  Applications can be<BR>\n&nbsp;developed in hours and days, rather than months and years with traditional<BR>\n&nbsp;systems.  Most of the other 4GLs available today look more like COBOL or<BR>\n&nbsp;RPG, the most tedious of the third generation lanaguages.<BR>\n&nbsp;\"UNIX Relational Database Management:  Application Development in the UNIX <BR>\n&nbsp;Environment\" by Rod Manis, Evan Schaffer, and Robert Jorgensen.  Prentice<BR>\n&nbsp;Hall Software Series.  Brian Kerrighan, Advisor.  1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Gotcha, you snot-necked weenies!\"<BR>\n-- Post Bros. Comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ada is PL/I trying to be Smalltalk.<BR>\n-- Codoso diBlini');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;HOW TO PROVE IT, PART 6<BR>\n&nbsp;proof by picture:<BR>\n&nbsp;A more convincing form of proof by example. Combines well <BR>\n&nbsp;with proof by omission.<BR>\n&nbsp;proof by vehement assertion:<BR>\n&nbsp;It is useful to have some kind of authority relation to the <BR>\n&nbsp;audience.<BR>\n&nbsp;proof by ghost reference:<BR>\n&nbsp;Nothing even remotely resembling the cited theorem appears in <BR>\n&nbsp;the reference given.<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An entire fraternity of strapping Wall-Street-bound youth.  Hell - this<BR>\nis going to be a blood bath!\"<BR>\n-- Post Bros. Comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Semper Fi, dude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Your good nature will bring unbounded happiness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Everything should be made as simple as possible, but not simpler.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If you own a machine, you are in turn owned by it, and spend your time<BR>\n&nbsp;serving it...\"<BR>\n-- Marion Zimmer Bradley, _The Forbidden Tower_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Indecision is the basis of flexibility\"<BR>\n-- button at a Science Fiction convention.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Just think of a computer as hardware you can program.\"<BR>\n-- Nigel de la Tierre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An ounce of prevention is worth a ton of code.\"<BR>\n-- an anonymous programmer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Being against torture ought to be sort of a multipartisan thing.\"<BR>\n-- Karl Lehenbauer, as amended by Jeff Daiell, a Libertarian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Garbage In, Gospel Out');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Pournelle must die!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Sometimes insanity is the only alternative\"<BR>\n-- button at a Science Fiction convention.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','OS/2 must die!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','MS-DOS must die!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','VMS must die!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What a wonder is USENET; such wholesale production of conjecture from<BR>\nsuch a trifling investment in fact.\"<BR>\n-- Carl S. Gutekunst');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','8)   Use common sense in routing cable.  Avoid wrapping coax around sources of<BR>\n&nbsp;strong electric or magnetic fields.  Do not wrap the cable around<BR>\n&nbsp;flourescent light ballasts or cyclotrons, for example.<BR>\n-- Ethernet Headstart Product, Information and Installation Guide,<BR>\n&nbsp;Bell Technologies, pg. 11');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You are in a maze of UUCP connections, all alike.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The most important thing in a man is not what he knows, but what he is.\"<BR>\n-- Narciso Yepes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The late rebellion in Massachusetts has given more alarm than I think it <BR>\nshould have done.  Calculate that one rebellion in 13 states in the course <BR>\nof 11 years, is but one for each state in a century and a half.  No country <BR>\nshould be so long without one.<BR>\n-- Thomas Jefferson in letter to James Madison, 20 December 1787');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','God grant me the senility to accept the things I cannot change,<BR>\nThe frustration to try to change things I cannot affect,<BR>\nand the wisdom to tell the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It must be remembered that there is nothing more difficult to plan, more<BR>\ndoubtful of success, nor more dangerous to manage, than the creation of a<BR>\nnew system.  For the initiator has the enmity of all who would profit by<BR>\nthe preservation of the old institutions and merely lukewarm defenders in<BR>\nthose who would gain by the new ones.<BR>\n-- Machiavelli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Life is a game.  Money is how we keep score.<BR>\n-- Ted Turner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Our reruns are better than theirs.\"<BR>\n-- Nick at Nite');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Pull the wool over your own eyes!\"<BR>\n-- J.R. \"Bob\" Dobbs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We live, in a very kooky time.\"<BR>\n-- Herb Blashtfalt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;[May one] doubt whether, in cheese and timber, worms are generated,<BR>\n&nbsp;or, if beetles and wasps, in cow-dung, or if butterflies, locusts,<BR>\n&nbsp;shellfish, snails, eels, and such life be procreated of putrefied<BR>\n&nbsp;matter, which is to receive the form of that creature to which it<BR>\n&nbsp;is by formative power disposed[?]  To question this is to question<BR>\n&nbsp;reason, sense, and experience.  If he doubts this, let him go to<BR>\n&nbsp;Egypt, and there he will find the fields swarming with mice begot<BR>\n&nbsp;of the mud of the Nylus, to the great calamity of the inhabitants.<BR>\n&nbsp;A seventeenth century opinion quoted by L. L. Woodruff,<BR>\n&nbsp;in *The Evolution of Earth and Man*, 1929');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is no distinctly American criminal class except Congress.\"<BR>\n-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Out of register space (ugh)\"<BR>\n-- vi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','New York is a jungle, they tell you.  You could go further, and say that<BR>\nNew York is a jungle.  New York *is a jungle.*  Beneath the columns of<BR>\nthe old rain forest, made of melting macadam, the mean Limpopo of swamped <BR>\nNinth Avenue bears an angry argosy of crocs and dragons, tiger fish, noise<BR>\nmachines, sweating rainmakers.  On the corners stand witchdoctors and<BR>\nheadhunters, babbling voodoo-men -- the natives, the jungle-smart natives.<BR>\nAnd at night, under the equatorial overgrowth and heat-holding cloud<BR>\ncover, you hear the ragged parrot-hoot and monkeysqueak of the sirens,<BR>\nand then fires flower to ward off monsters.  Careful: the streets are<BR>\nsprung with pits and nets and traps.  Hire a guide.  Pack your snakebite<BR>\ngook and your blowdart serum.  Take it seriously.  You have to get a<BR>\nbit jungle-wise.<BR>\n-- Martin Amis, _Money_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Love may fail, but courtesy will previal.\"<BR>\n-- A Kurt Vonnegut fan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Refreshed by a brief blackout, I got to my feet and went next door.<BR>\n-- Martin Amis, _Money_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The hottest places in Hell are reserved for those who, in times of moral<BR>\ncrisis, preserved their neutrality.\"<BR>\n-- Dante');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"How many teamsters does it take to screw in a light bulb?\"<BR>\n&nbsp;\"FIFTEEN!!  YOU GOT A PROBLEM WITH THAT?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Everybody is talking about the weather but nobody does anything about it.\"<BR>\n-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;HOW TO PROVE IT, PART 5<BR>\n&nbsp;proof by accumulated evidence:<BR>\n&nbsp;Long and diligent search has not revealed a counterexample.<BR>\n&nbsp;proof by cosmology:<BR>\n&nbsp;The negation of the proposition is unimaginable or <BR>\n&nbsp;meaningless. Popular for proofs of the existence of God.<BR>\n&nbsp;proof by mutual reference:<BR>\n&nbsp;In reference A, Theorem 5 is said to follow from Theorem 3 in <BR>\n&nbsp;reference B, which is shown to follow from Corollary 6.2 in <BR>\n&nbsp;reference C, which is an easy consequence of Theorem 5 in <BR>\n&nbsp;reference A.<BR>\n&nbsp;proof by metaproof:<BR>\n&nbsp;A method is given to construct the desired proof. The <BR>\n&nbsp;correctness of the method is proved by any of these <BR>\n&nbsp;techniques.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An honest god is the noblest work of man.  ... God has always resembled his<BR>\ncreators.  He hated and loved what they hated and loved and he was invariably<BR>\nfound on the side of those in power. ... Most of the gods were pleased with<BR>\nsacrifice, and the smell of innocent blood has ever been considered a divine<BR>\nperfume.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The lesser of two evils -- is evil.\"<BR>\n-- Seymour (Sy) Leon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Imitation is the sincerest form of television.\"<BR>\n-- The New Mighty Mouse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"When the only tool you have is a hammer, you tend to treat everything as if<BR>\nit were a nail.\"<BR>\n-- Abraham Maslow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Were there no women, men might live like gods.\"<BR>\n-- Thomas Dekker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Ship it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Your butt is mine.\"<BR>\n-- Michael Jackson, Bad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The pathology is to want control, not that you ever get it, because of<BR>\ncourse you never do.\"<BR>\n-- Gregory Bateson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Why waste negative entropy on comments, when you could use the same<BR>\nentropy to create bugs instead?\"<BR>\n-- Steve Elias');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The bug starts here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The bug stops here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If people are good only because they fear punishment, and hope for reward,<BR>\nthen we are a sorry lot indeed.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is also a thriving independent student movement in<BR>\nPoland, and thus there is a strong possibility (though no<BR>\nguarantee) of making an EARN-Poland link, should it ever come<BR>\nabout, a genuine link - not a vacuum cleaner attachment for a<BR>\nBloc information gathering apparatus rationed to trusted<BR>\napparatchiks.\"<BR>\n-- David Phillips, SUNY at Buffalo, about establishing a<BR>\n&nbsp;gateway from EARN (Eurpoean Academic Research Network)<BR>\n&nbsp;to Poland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"People should have access to the data which you have about them.  There should<BR>\n&nbsp;be a process for them to challenge any inaccuracies.\"<BR>\n-- Arthur Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What is wanted is not the will to believe, but the will to find out, which is<BR>\nthe exact opposite.\"<BR>\n-- Bertrand Russell, _Sceptical_Essays_, 1928');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What people have been reduced to are mere 3-D representations of their own <BR>\ndata.\"<BR>\n-- Arthur Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Seen on a button at an SF Convention:<BR>\nVeteran of the Bermuda Triangle Expeditionary Force.  1990-1951.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Its failings notwithstanding, there is much to be said in favor<BR>\nof journalism in that by giving us the opinion of the uneducated,<BR>\nit keeps us in touch with the ignorance of the community.\"<BR>\n&nbsp;- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Live Free or Live in Massachusettes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"In the long run, every program becomes rococo, and then rubble.\"<BR>\n-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Pay no attention to the man behind the curtain.\"<BR>\n-- Karl, as he stepped behind the computer to reboot it, during a FAT');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Pay no attention to the man behind the curtain.\"<BR>\n-- The Wizard Of Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;HOW TO PROVE IT, PART 7<BR>\nproof by forward reference:<BR>\n&nbsp;Reference is usually to a forthcoming paper of the author, <BR>\n&nbsp;which is often not as forthcoming as at first.<BR>\n&nbsp;proof by semantic shift:<BR>\n&nbsp;Some of the standard but inconvenient definitions are changed <BR>\n&nbsp;for the statement of the result.<BR>\n&nbsp;proof by appeal to intuition:<BR>\n&nbsp;Cloud-shaped drawings frequently help here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Open the pod bay doors, HAL.\"<BR>\n-- Dave Bowman, 2001');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Seed me, Seymour\"<BR>\n-- a random number generator meets the big green mother from outer space');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Perhaps I am flogging a straw herring in mid-stream, but in the light of<BR>\nwhat is known about the ubiquity of security vulnerabilities, it seems vastly<BR>\ntoo dangerous for university folks to run with their heads in the sand.\"<BR>\n-- Peter G. Neumann, RISKS moderator, about the Internet virus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Science makes godlike -- it is all over with priests and gods when man becomes<BR>\n&nbsp;scientific.  Moral:  science is the forbidden as such -- it alone is <BR>\n&nbsp;forbidden.  Science is the *first* sin, the *original* sin.  *This alone is<BR>\n&nbsp;morality.* \`\`Thou shalt not know\' -- the rest follows.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The vast majority of successful major crimes against property are<BR>\nperpetrated by individuals abusing positions of trust.\"<BR>\n-- Lawrence Dalzell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Are you having fun yet?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You who hate the Jews so, why did you adopt their religion?\"<BR>\n-- Friedrich Nietzsche, addressing anti-semitic Christians');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Brain off-line, please wait.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Engineering without management is art.\"<BR>\n-- Jeff Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The net result is a system that is not only binary compatible with 4.3 BSD,<BR>\nbut is even bug for bug compatible in almost all features.\"<BR>\n-- Avadit Tevanian, Jr., \"Architecture-Independent Virtual Memory Management<BR>\n&nbsp;for Parallel and Distributed Environments:  The Mach Approach\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Baby On Board.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Let us condemn to hellfire all those who disagree with us.\"<BR>\n-- militant religionists everywhere');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Always look over your shoulder because everyone is watching and plotting<BR>\nagainst you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The whole problem with the world is that fools and fanatics are always so<BR>\ncertain of themselves, but wiser people so full of doubts.\"<BR>\n-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','These screamingly hilarious gogs ensure owners of     X Ray Gogs to be the life<BR>\nof any party.<BR>\n-- X-Ray Gogs Instructions');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Love is an ideal thing, marriage a real thing; a confusion of the real with <BR>\nthe ideal never goes unpunished.\"<BR>\n-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Experience has proved that some people indeed know everything.\"<BR>\n-- Russell Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The fundamental principle of science, the definition almost, is this: the<BR>\nsole test of the validity of any idea is experiment.\"<BR>\n-- Richard P. Feynman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Elvis is my copilot.\"<BR>\n-- Cal Keegan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"In Christianity neither morality nor religion come into contact with reality<BR>\nat any point.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Beware of programmers carrying screwdrivers.\"<BR>\n-- Chip Salzenberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The geeks shall inherit the earth.\"<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Faith:  not *wanting* to know what is true.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"An open mind has but one disadvantage: it collects dirt.\"<BR>\n-- a saying at RPI');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','If this is a service economy, why is the service so bad?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A mind is a terrible thing to have leaking out your ears.\"<BR>\n-- The League of Sadistic Telepaths');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','egrep patterns are full regular expressions; it uses a fast deterministic<BR>\nalgorithm that sometimes needs exponential space.<BR>\n-- unix manuals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Is this foreplay?\"<BR>\n&nbsp;\"No, this is Nuke Strike.  Foreplay has lousy graphics.  Beat me again.\"<BR>\n-- Duckert, in \"Bad Rubber,\" Albedo #0 (comics)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Intelligence without character is a dangerous thing.\"<BR>\n-- G. Steinem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I honestly believe that the doctrine of hell was born in the glittering eyes<BR>\nof snakes that run in frightful coils watching for their prey.  I believe<BR>\nit was born with the yelping, howling, growling and snarling of wild beasts...<BR>\nI despise it, I defy it, and I hate it.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Astrology is the sheerest hokum.  This pseudoscience has been around since<BR>\nthe day of the Chaldeans and Babylonians.  It is as phony as numerology,<BR>\nphrenology, palmistry, alchemy, the reading of tea leaves, and the practice<BR>\nof divination by the entrails of a goat.  No serious person will buy the<BR>\nnotion that our lives are influenced individually by the movement of<BR>\ndistant planets.  This is the sawdust blarney of the carnival midway.<BR>\n-- James J. Kilpatrick, Universal Press Syndicate');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The only way for a reporter to look at a politician is down.\"<BR>\n-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Call immediately.  Time is running out.  We both need to do something<BR>\nmonstrous before we die.\"<BR>\n-- Message from Ralph Steadman to Hunter Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','>One basic notion underlying Usenet is that it is a cooperative.<BR>\n&nbsp;Having been on USENET for going on ten years, I disagree with this.<BR>\nThe basic notion underlying USENET is the flame.<BR>\n-- Chuq Von Rospach, chuq@Apple.COM ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"This generation may be the one that will face Armageddon.\"<BR>\n-- Ronald Reagan, \"People\" magazine, December 26, 1985');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Work was impossible.  The geeks had broken my spirit.  They had done too<BR>\nmany things wrong.  It was never like this for Mencken.  He lived like<BR>\na Prussian gambler -- sweating worse than Bryan on some nights and drunker<BR>\nthan Judas on others.  It was all a dehumanized nightmare...and these<BR>\nraddled cretins have the gall to complain about my deadlines.<BR>\n-- Hunter Thompson, \"Bad Nerves in Fat City\", _Generation of Swine_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There was a vague, unpleasant manginess about his appearence; he somehow<BR>\nseemed dirty, though a close glance showed him as carefully shaven as an<BR>\nactor, and clad in immaculate linen.\"<BR>\n-- H.L. Mencken, on the death of William Jennings Bryan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','backups: always in season, never out of style.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I prefer the blunted cudgels of the followers of the Serpent God.\"<BR>\n-- Sean Doran the Younger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"May your future be limited only by your dreams.\"<BR>\n-- Christa McAuliffe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If the code and the comments disagree, then both are probably wrong.\"<BR>\n-- Norm Schryer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The computer programmer is a creator of universes for which he alone<BR>\n&nbsp;is responsible. Universes of virtually unlimited complexity can be<BR>\n&nbsp;created in the form of computer programs.\"<BR>\n-- Joseph Weizenbaum, _Computer Power and Human Reason_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Even if we put all these nagging thoughts [four embarrassing questions about<BR>\nastrology] aside for a moment, one overriding question remains to be asked.<BR>\nWhy would the positions of celestial objects at the moment of birth have an<BR>\neffect on our characters, lives, or destinies?  What force or influence,<BR>\nwhat sort of energy would travel from the planets and stars to all human<BR>\nbeings and affect our development or fate?  No amount of scientific-sounding<BR>\njargon or computerized calculations by astrologers can disguise this central<BR>\nproblem with astrology -- we can find no evidence of a mechanism by which<BR>\ncelestial objects can influence us in so specific and personal a way. . . .<BR>\nSome astrologers argue that there may be a still unknown force that represents<BR>\nthe astrological influence. . . .If so, astrological predictions -- like those<BR>\nof any scientific field -- should be easily tested. . . . Astrologers always<BR>\nclaim to be just a little too busy to carry out such careful tests of their<BR>\nefficacy, so in the last two decades scientists and statisticians have<BR>\ngenerously done such testing for them.  There have been dozens of well-designed<BR>\ntests all around the world, and astrology has failed every one of them. . . .<BR>\nI propose that we let those beckoning lights in the sky awaken our interest<BR>\nin the real (and fascinating) universe beyond our planet, and not let them<BR>\nkeep us tied to an ancient fantasy left over from a time when we huddled by<BR>\nthe firelight, afraid of the night.<BR>\n-- Andrew Fraknoi, Executive Officer, Astronomical Society of the Pacific,<BR>\n&nbsp;\"Why Astrology Believers Should Feel Embarrassed,\" San Jose Mercury<BR>\n&nbsp;News, May 8, 1988');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Who alone has reason to *lie himself out* of actuality?  He who *suffers*<BR>\n&nbsp;from it.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Little prigs and three-quarter madmen may have the conceit that the laws of <BR>\nnature are constantly broken for their sakes.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You must have an IQ of at least half a million.\"  -- Popeye');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"...one of the main causes of the fall of the Roman Empire was that,<BR>\nlacking zero, they had no way to indicate successful termination of<BR>\ntheir C programs.\"<BR>\n-- Robert Firth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Freedom is still the most radical idea of all.\"<BR>\n-- Nathaniel Branden');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Any excuse will serve a tyrant.\"<BR>\n-- Aesop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"My father?  My father left when I was quite young.  Well actually, he<BR>\n&nbsp;was asked to leave.  He had trouble metabolizing alcohol.\"<BR>\n&nbsp;-- George Carlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I never let my schooling get in the way of my education.\"<BR>\n-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Bite off, dirtball.\"<BR>\nRichard Sexton, richard@gryphon.COM');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Just out of curiosity does this actually mean something or have some<BR>\n&nbsp;of the few remaining bits of your brain just evaporated?\"<BR>\n-- Patricia O Tuama, rissa@killer.DALLAS.TX.US');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Inquiry is fatal to certainty.\"<BR>\n-- Will Durant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Remember:  Silly is a state of Mind, Stupid is a way of Life.<BR>\n-- Dave Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The preeminence of a learned man over a worshiper is equal to the preeminence<BR>\nof the moon, at the night of the full moon, over all the stars.  Verily, the<BR>\nlearned men are the heirs of the Prophets.\"<BR>\n-- A tradition attributed to Muhammad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I have recently been examining all the known superstitions of the world,<BR>\n&nbsp;and do not find in our particular superstition (Christianity) one redeeming<BR>\n&nbsp;feature.  They are all alike founded on fables and mythology.\"<BR>\n-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I call Christianity the *one* great curse, the *one* great intrinsic <BR>\ndepravity, the *one* great instinct for revenge for which no expedient<BR>\nis sufficiently poisonous, secret, subterranean, *petty* -- I call it<BR>\nthe *one* mortal blemish of mankind.\"<BR>\n-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A fractal is by definition a set for which the Hausdorff Besicovitch<BR>\ndimension strictly exceeds the topological dimension.\"<BR>\n-- Mandelbrot, _The Fractal Geometry of Nature_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"In matrimony, to hesitate is sometimes to be saved.\"<BR>\n-- Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Joy is wealth and love is the legal tender of the soul.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','&nbsp;EARTH          <BR>\n&nbsp;smog  |   bricks  <BR>\n&nbsp;AIR  --  mud  --  FIRE<BR>\nsoda water |   tequila <BR>\n&nbsp;WATER        ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Money is the root of all money.\"<BR>\n-- the moving finger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Marriage is the triumph of imagination over intelligence.  Second marriage is <BR>\nthe triumph of hope over experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Life begins when you can spend your spare time programming instead of<BR>\nwatching television.\"<BR>\n-- Cal Keegan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"As an adolescent I aspired to lasting fame, I craved factual certainty, and<BR>\nI thirsted for a meaningful vision of human life -- so I became a scientist.<BR>\nThis is like becoming an archbishop so you can meet girls.\" <BR>\n-- Matt Cartmill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Lying lips are abomination to the Lord; but they that deal truly are his <BR>\n&nbsp;delight.<BR>\n&nbsp;A soft answer turneth away wrath; but grievous words stir up anger.<BR>\n&nbsp;He that answereth a matter before he heareth it, it is folly and shame unto<BR>\n&nbsp;him.<BR>\n&nbsp;Be not a witness against thy neighbor without cause; and deceive not with <BR>\n&nbsp;thy lips.<BR>\n&nbsp;Death and life are in the power of the tongue.\"<BR>\n-- Proverbs, some selections from the Jewish Scripture');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We never make assertions, Miss Taggart,\" said Hugh Akston.  \"That is<BR>\nthe moral crime peculiar to our enemies.  We do not tell -- we *show*.<BR>\nWe do not claim -- we *prove*.\"  <BR>\n-- Ayn Rand, _Atlas Shrugged_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Religion is something left over from the infancy of our intelligence, it will<BR>\nfade away as we adopt reason and science as our guidelines.\"<BR>\n-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It is better for civilization to be going down the drain than to be<BR>\ncoming up it.\"<BR>\n-- Henry Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Jesus saves...but Gretzky gets the rebound!\"<BR>\n-- Daniel Hinojosa (hinojosa@hp-sdd)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Your stupidity, Allen, is simply not up to par.\"<BR>\n-- Dave Mack (mack@inco.UUCP)<BR>\n&nbsp;\"Yours is.\"<BR>\n-- Allen Gwinn (allen@sulaco.sigma.com), in alt.flame');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Heisenberg might have been here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','What did Mickey Mouse get for Christmas?<BR>\n&nbsp;A Dan Quayle watch.<BR>\n&nbsp;-- heard from a Mike Dukakis field worker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I remember when I was a kid I used to come home from Sunday School and<BR>\n&nbsp;my mother would get drunk and try to make pancakes.\"<BR>\n-- George Carlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Anyone attempting to generate random numbers by deterministic means is, of<BR>\ncourse, living in a state of sin.\"<BR>\n-- John Von Neumann');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"For a male and female to live continuously together is...  biologically <BR>\nspeaking, an extremely unnatural condition.\"<BR>\n-- Robert Briffault');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I am ... a woman ... and ... technically a parasitic uterine growth\"<BR>\n-- Sean Doran the Younger [allegedly]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If I ever get around to writing that language depompisifier, it will change<BR>\nalmost all occurences of the word \"paradigm\" into \"example\" or \"model.\"<BR>\n-- Herbie Blashtfalt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Love your country but never trust its government.\"<BR>\n-- from a hand-painted road sign in central Pennsylvania');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Truth never comes into the world but like a bastard, to the ignominy<BR>\nof him that brought her birth.\"<BR>\n-- Milton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ignorance is the soil in which belief in miracles grows.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Conversion, fastidious Goddess, loves blood better than brick, and feasts<BR>\nmost subtly on the human will.\"<BR>\n-- Virginia Woolf, \"Mrs. Dalloway\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It is hard to overstate the debt that we owe to men and women of genius.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The Street finds its own uses for technology.\"<BR>\n-- William Gibson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Our vision is to speed up time, eventually eliminating it.\" -- Alex Schure');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Love is a snowmobile racing across the tundra and then suddenly it flips<BR>\n&nbsp;over, pinning you underneath.  At night, the ice weasels come.\"<BR>\n--Matt Groening');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It is the creationists who blasphemously are claiming that God is cheating<BR>\n&nbsp;us in a stupid way.\"<BR>\n-- J. W. Nienhuys');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The hands that help are better far than the lips that pray.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Let every man teach his son, teach his daughter, that labor is honorable.\"<BR>\n-- Robert G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Go to Heaven for the climate, Hell for the company.\"<BR>\n-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The chain which can be yanked is not the eternal chain.\"<BR>\n-- G. Fitch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A man is not complete until he is married -- then he is finished.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Marriage is the sole cause of divorce.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Home life as we understand it is no more natural to us than a cage is to a <BR>\ncockatoo.\"<BR>\n-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Marriage is like a cage; one sees the birds outside desperate to get in, and <BR>\nthose inside desperate to get out.\"<BR>\n-- Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A complex system that works is invariably found to have evolved from a simple<BR>\nsystem that worked.\"<BR>\n-- John Gall, _Systemantics_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"All over the place, from the popular culture to the propaganda system, there is<BR>\nconstant pressure to make people feel that they are helpless, that the only role<BR>\nthey can have is to ratify decisions and to consume.\"<BR>\n-- Noam Chomsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"By the time they had diminished from 50 to 8, the other dwarves began<BR>\nto suspect \"Hungry.\"<BR>\n-- a Larson cartoon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I made it a rule to forbear all direct contradictions to the sentiments of <BR>\nothers, and all positive assertion of my own.  I even forbade myself the use <BR>\nof every word or expression in the language that imported a fixed opinion, <BR>\nsuch as \"certainly\", \"undoubtedly\", etc.   I adopted instead of them \"I <BR>\nconceive\", \"I apprehend\", or \"I imagine\" a thing to be so or so; or \"so it <BR>\nappears to me at present\".<BR>\n&nbsp;When another asserted something that I thought an error, I denied myself the <BR>\npleasure of contradicting him abruptly, and of showing him immediately some <BR>\nabsurdity in his proposition.  In answering I began by observing that in <BR>\ncertain cases or circumstances his opinion would be right, but in the present<BR>\ncase there appeared or semed to me some difference, etc.<BR>\n&nbsp;I soon found the advantage of this change in my manner; the conversations I <BR>\nengaged in went on more pleasantly.  The modest way in which I proposed my <BR>\nopinions procured them a readier reception and less contradiction.  I had <BR>\nless mortification when I was found to be in the wrong, and I more easily <BR>\nprevailed with others to give up their mistakes and join with me when I <BR>\nhappened to be in the right.<BR>\n-- Autobiography of Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We want to create puppets that pull their own strings.\"<BR>\n-- Ann Marion<BR>\n&nbsp;\"Would this make them Marionettes?\"<BR>\n-- Jeff Daiell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The reasonable man adapts himself to the world; the unreasonable one persists<BR>\n&nbsp;in trying to adapt the world to himself.  Therefore all progress depends on <BR>\n&nbsp;the unreasonable man.\"<BR>\n-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Stan and I thought that this experiment was so stupid, we decided to finance <BR>\n&nbsp;it ourselves.\"<BR>\n-- Martin Fleischmann, co-discoverer of room-temperature fusion (?)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','#define BITCOUNT(x)	(((BX_(x)+(BX_(x)>>4)) & 0x0F0F0F0F) % 255)<BR>\n#define  BX_(x)		((x) - (((x)>>1)&0x77777777)			<BR>\n&nbsp;- (((x)>>2)&0x33333333)			<BR>\n&nbsp;- (((x)>>3)&0x11111111))<BR>\n&nbsp;-- really weird C code to count the number of bits in a word');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"They that can give up essential liberty to obtain a little temporary<BR>\nsafety deserve neither liberty nor safety.\"<BR>\n-- Benjamin Franklin, 1759');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"BYTE editors are men who seperate the wheat from the chaff, and then<BR>\n&nbsp;print the chaff.\"<BR>\n-- Lionel Hummel (uiucdcs!hummel), derived from a quote by Adlai Stevenson, Sr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What the scientists have in their briefcases is terrifying.\"<BR>\n-- Nikita Khrushchev');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"my terminal is a lethal teaspoon.\"<BR>\n-- Patricia O Tuama');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Remember, extremism in the nondefense of moderation is not a virtue.\"<BR>\n-- Peter Neumann, about usenet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You and I as individuals can, by borrowing, live beyond our means, but<BR>\nonly for a limited period of time.  Why should we think that collectively,<BR>\nas a nation, we are not bound by that same limitation?\"<BR>\n-- Ronald Reagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"He did decide, though, that with more time and a great deal of mental effort,<BR>\nhe could probably turn the activity into an acceptable perversion.\"<BR>\n-- Mick Farren, _When Gravity Fails_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Yo baby yo baby yo.\"<BR>\n-- Eddie Murphy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I am, therefore I am.\"<BR>\n-- Akira');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You must learn to run your kayak by a sort of ju-jitsu.  You must learn to<BR>\n&nbsp;tell what the river will do to you, and given those parameters see how you<BR>\n&nbsp;can live with it.  You must absorb its force and convert it to your users<BR>\n&nbsp;as best you can.  Even with the quickness and agility of a kayak, you are<BR>\n&nbsp;not faster than the river, nor stronger, and you can beat it only by<BR>\n&nbsp;understanding it.\"<BR>\n-- Strung, Curtis and Perry, _Whitewater_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I have more information in one place than anybody in the world.\"  <BR>\n-- Jerry Pournelle, an absurd notion, apparently about the BIX BBS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"(The Chief Programmer) personally defines the functional and performance<BR>\n&nbsp;specifications, designs the program, codes it, tests it, and writes its<BR>\n&nbsp;documentation... He needs great talent, ten years experience and<BR>\n&nbsp;considerable systems and applications knowledge, whether in applied<BR>\n&nbsp;mathematics, business data handling, or whatever.\"<BR>\n-- Fred P. Brooks, _The Mythical Man Month_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','panic: kernel trap (ignored)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If anything can go wrong, it will.\"<BR>\n-- Edsel Murphy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The strength of the Constitution lies entirely in the determination of each<BR>\ncitizen to defend it.  Only if every single citizen feels duty bound to do<BR>\nhis share in this defense are the constitutional rights secure.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To err is human, to moo bovine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Nuclear war can ruin your whole compile.\"<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I got a question for ya.  Ya got a minute?\"<BR>\n-- two programmers passing in the hall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I just thought of something funny...your mother.<BR>\n- Cheech Marin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','But Rabshakeh said unto them, Hath my master sent me to thy master, and to<BR>\nthee, to speak these words?  Hath he not sent me to the men which sit on the<BR>\nwall, that they may eat their own dung, and drink their own piss with you?<BR>\n[2 Kings 18:27 (KJV)]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Wear me as a seal upon your heart, as a seal upon your arm; for love is strong<BR>\nas death, passion cruel as the grave; it blazes up like blazing fire, fiercer<BR>\nthan any flame.<BR>\n[Song of Solomon 8:6 (NEB)]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','How beautiful, how entrancing you are, my loved one, daughter of delights!<BR>\nYou are stately as a palm-tree, and your breasts are the clusters of dates.<BR>\nI said, \"I will climb up into the palm to grasp its fronds.\"  May I find your<BR>\nbreast like clusters of grapes on the vine, the scent of your breath like<BR>\napricots, and your whispers like spiced wine flowing smoothly to welcome my<BR>\ncaresses, gliding down through lips and teeth.<BR>\n[Song of Solomon 7:6-9 (NEB)]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I have stripped off my dress; must I put it on again?  I have washed my feet;<BR>\nmust I soil them again?<BR>\nWhen my beloved slipped his hand through the latch-hole, my bowels stirred<BR>\nwithin me [my bowels were moved for him (KJV)].<BR>\nWhen I arose to open for my beloved, my hands dripped with myrrh; the liquid<BR>\nmyrrh from my fingers ran over the knobs of the bolt.  With my own hands I<BR>\nopened to my love, but my love had turned away and gone by; my heart sank when<BR>\nhe turned his back.  I sought him but I did not find him, I called him but he<BR>\ndid not answer.<BR>\nThe watchmen, going the rounds of the city, met me; they struck me and<BR>\n&nbsp;wounded me; the watchmen on the walls took away my cloak.<BR>\n[Song of Solomon 5:3-7 (NEB)]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Well hello there Charlie Brown, you blockhead.\"<BR>\n-- Lucy Van Pelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It takes all sorts of in & out-door schooling to get adapted<BR>\nto my kind of fooling\"<BR>\n- R. Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Just think, with VLSI we can have 100 ENIACS on a chip!\"<BR>\n-- Alan Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If a nation values anything more than freedom, it will lose its freedom; and<BR>\n&nbsp;the irony of it is that if it is comfort or money it values more, it will<BR>\n&nbsp;lose that, too.\"<BR>\n-- W. Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There are things that are so serious that you can only joke about them\"<BR>\n- Heisenberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"God is a comedian playing to an audience too afraid to laugh.\"<BR>\n- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The one charm of marriage is that it makes a life of deception a neccessity.\"<BR>\n- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You know, of course, that the Tasmanians, who never committed adultery, are<BR>\nnow extinct.\"<BR>\n- M. Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','To the systems programmer, users and applications serve only to provide a<BR>\ntest load.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"What man has done, man can aspire to do.\"<BR>\n-- Jerry Pournelle, about space flight');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We dedicated ourselves to a powerful idea -- organic law rather than naked<BR>\n&nbsp;power.  There seems to be universal acceptance of that idea in the nation.\"<BR>\n-- Supreme Court Justice Potter Steart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The NY Times is read by the people who run the country.  The Washington Post<BR>\nis read by the people who think they run the country.   The National Enquirer<BR>\nis read by the people who think Elvis is alive and running the country...\"<BR>\n-- Robert J Woodhead (trebor@biar.UUCP)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"More software projects have gone awry for lack of calendar time than for all<BR>\n&nbsp;other causes combined.\"<BR>\n-- Fred Brooks, Jr., _The Mythical Man Month_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Do not allow this language (Ada) in its present state to be used in<BR>\napplications where reliability is critical, i.e., nuclear power stations,<BR>\ncruise missiles, early warning systems, anti-ballistic missle defense<BR>\nsystems.  The next rocket to go astray as a result of a programming language<BR>\nerror may not be an exploratory space rocket on a harmless trip to Venus:<BR>\nIt may be a nuclear warhead exploding over one of our cities.  An unreliable<BR>\nprogramming language generating unreliable programs constitutes a far<BR>\ngreater risk to our environment and to our society than unsafe cars, toxic<BR>\npesticides, or accidents at nuclear power stations.<BR>\n- C. A. R. Hoare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There are two ways of constructing a software design.  One way is to make<BR>\nit so simple that there are obviously no deficiencies and the other is to<BR>\nmake it so complicated that there are no obvious deficiencies.<BR>\n- Charles Anthony Richard Hoare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','What hath Bob wrought?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...And no philosophy, sadly, has all the answers.  No matter how assured<BR>\nwe may be about certain aspects of our belief, there are always painful<BR>\ninconsistencies, exceptions, and contradictions.  This is true in religion as<BR>\nit is in politics, and is self-evident to all except fanatics and the naive.<BR>\nAs for the fanatics, whose number is legion in our own time, we might be<BR>\nadvised to leave them to heaven.  They will not, unfortunately, do us the<BR>\nsame courtesy.  They attack us and each other, and whatever their <BR>\nprotestations to peaceful intent, the bloody record of history makes clear<BR>\nthat they are easily disposed to restore to the sword.  My own belief in<BR>\nGod, then, is just that -- a matter of belief, not knowledge.  My respect<BR>\nfor Jesus Christ arises from the fact that He seems to have been the<BR>\nmost virtuous inhabitant of Planet Earth.  But even well-educated Christians<BR>\nare frustated in their thirst for certainty about the beloved figure<BR>\nof Jesus because of the undeniable ambiguity of the scriptural record.<BR>\nSuch ambiguity is not apparent to children or fanatics, but every<BR>\nrecognized Bible scholar is perfectly aware of it.  Some Christians, alas,<BR>\nresort to formal lying to obscure such reality.<BR>\n- Steve Allen, comdeian, from an essay in the book \"The Courage of <BR>\n&nbsp;Conviction\", edited by Philip Berman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In arguing that current theories of brain function cast suspicion on ESP,<BR>\npsychokinesis, reincarnation, and so on, I am frequently challenged with<BR>\nthe most popular of all neuro-mythologies -- the notion that we ordinarily<BR>\nuse only 10 percent of our brains...<BR>\n&nbsp;This \"cerebral spare tire\" concept continues to nourish the clientele of<BR>\n\"pop psychologists\" and their many recycling self-improvement schemes.  As<BR>\na metaphor for the fact that few of us fully exploit our talents, who could<BR>\ndeny it?  As a refuge for occultists seeking a neural basis of the miraculous,<BR>\nit leaves much to be desired.<BR>\n-- Barry L. Beyerstein, \"The Brain and Consciousness:  Implications for<BR>\n&nbsp;Psi Phenomena\", The Skeptical Enquirer, Vol. XII, No. 2, pg. 171');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Your attitude determines your attitude.\"<BR>\n-- Zig Ziglar, self-improvement doofus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Regardless of the legal speed limit, your Buick must be operated at<BR>\nspeeds faster than 85 MPH (140kph).\"<BR>\n-- 1987 Buick Grand National owners manual.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is not well to be thought of as one who meekly submits to insolence and<BR>\nintimidation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Creation science\" has not entered the curriculum for a reason so simple<BR>\nand so basic that we often forget to mention it: because it is false, and<BR>\nbecause good teachers understand exactly why it is false.  What could be<BR>\nmore destructive of that most fragile yet most precious commodity in our<BR>\nentire intellectualy heritage -- good teaching -- than a bill forcing<BR>\nhonorable teachers to sully their sacred trust by granting equal treatment<BR>\nto a doctrine not only known to be false, but calculated to undermine any<BR>\ngeneral understanding of science as an enterprise?<BR>\n-- Stephen Jay Gould, \"The Skeptical Inquirer\", Vol. 12, page 186');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Wish and hope succeed in discerning signs of paranormality where reason and<BR>\ncareful scientific procedure fail.<BR>\n- James E. Alcock, The Skeptical Inquirer, Vol. 12');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Brain damage is all in your head.<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','In space, no one can hear you fart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I am approached with the most opposite opinions and advice, and by men who<BR>\nare equally certain that they represent the divine will.  I am sure that<BR>\neither the one or the other is mistaken in the belief, and perhaps in some<BR>\nrespects, both.<BR>\n&nbsp;I hope it will not be irreverent of me to say that if it is probable that<BR>\nGod would reveal his will to others on a point so connected with my duty,<BR>\nit might be supposed he would reveal it directly to me.<BR>\n- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If Diet Coke did not exist it would have been neccessary to invent it.\"<BR>\n-- Karl Lehenbauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There is such a fine line between genius and stupidity.\"<BR>\n- David St. Hubbins, \"Spinal Tap\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I have just one word for you, my boy...plastics.\"<BR>\n- from \"The Graduate\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...One thing is that, unlike any other Western democracy that I know of,<BR>\nthis country has operated since its beginnings with a basic distrust of <BR>\ngovernment.  We are constituted not for efficient operation of government,<BR>\nbut for minimizing the possibility of abuse of power.  It took the events<BR>\nof the Roosevelt era -- a catastrophic economic collapse and a world war --<BR>\nto introduce the strong central government that we now know.  But in most<BR>\nparts of the country today, the reluctance to have government is still<BR>\nstrong.  I think, barring a series of catastrophic events, that we can<BR>\nlook to at least another decade during which many of the big problems<BR>\naround this country will have to be addressed by institutions other than<BR>\nfederal government.<BR>\n- Bobby R. Inman, Admiral, USN, Retired, former director of Naval Intelligence,<BR>\n&nbsp;vice director of the DIA, former director of the NSA, deputy directory of<BR>\n&nbsp;Central Intelligence, former chairman and CEO of MCC.<BR>\n[the statist opinions expressed herein are not those of the cookie editor -ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The Middle East is certainly the nexus of turmoil for a long time to come --<BR>\nwith shifting players, but the same game: upheaval.  I think we will be<BR>\nconfronting militant Islam -- particularly fallout from the Iranian<BR>\nrevolution -- and religion will once more, as it has in our own more<BR>\ndistant past -- play a role at least as standard-bearer in death and mayhem.<BR>\n- Bobby R. Inman, Admiral, USN, Retired, former director of Naval Intelligence,<BR>\n&nbsp;vice director of the DIA, former director of the NSA, deputy director of<BR>\n&nbsp;Central Intelligence, former chairman and CEO of MCC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Why should we subsidize intellectual curiosity?\"<BR>\n&nbsp;-Ronald Reagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It may be that our role on this planet is not to worship God but to<BR>\n&nbsp;create him.\"<BR>\n&nbsp;-Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','You need tender loving care once a week - so that I can slap you into shape.<BR>\n- Ellyn Mustard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Plan to throw one away.  You will anyway.\"<BR>\n- Fred Brooks, \"The Mythical Man Month\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Why should we subsidize intellectual curiosity?\"<BR>\n&nbsp;-Ronald Reagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It may be that our role on this planet is not to worship God but to<BR>\n&nbsp;create him.\"<BR>\n&nbsp;-Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You need tender loving care once a week - so that I can slap you into shape.\"<BR>\n- Ellyn Mustard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is inconceivable that a judicious observer from another solar system<BR>\nwould see in our species -- which has tended to be cruel, destructive,<BR>\nwasteful, and irrational -- the crown and apex of cosmic evolution.<BR>\nViewing us as the culmination of *anything* is grotesque; viewing us<BR>\nas a transitional species makes more sense -- and gives us more hope.<BR>\n- Betty McCollister, \"Our Transitional Species\", <BR>\n&nbsp;Free Inquiry magazine, Vol. 8, No. 1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"jackpot:  you may have an unneccessary change record\"<BR>\n-- message from \"diff\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Two things are certain about science.  It does not stand still for long,<BR>\nand it is never boring.  Oh, among some poor souls, including even<BR>\nintellectuals in fields of high scholarship, science is frequently<BR>\nmisperceived.  Many see it as only a body of facts, promulgated from<BR>\non high in must, unintelligible textbooks, a collection of unchanging<BR>\nprecepts defended with authoritarian vigor.  Others view it as nothing<BR>\nbut a cold, dry narrow, plodding, rule-bound process -- the scientific<BR>\nmethod: hidebound, linear, and left brained.<BR>\n&nbsp;These people are the victims of their own stereotypes.  They are<BR>\ndestined to view the world of science with a set of blinders.  They<BR>\nknow nothing of the tumult, cacophony, rambunctiousness, and <BR>\ntendentiousness of the actual scientific process, let alone the <BR>\ncreativity, passion, and joy of discovery.  And they are likely to<BR>\nknow little of the continual procession of new insights and discoveries<BR>\nthat every day, in some way, change our view (if not theirs) of the<BR>\nnatural world.<BR>\n&nbsp;-- Kendrick Frazier, \"The Year in Science: An Overview,\" in<BR>\n&nbsp;1988 Yearbook of Science and the Future, Encyclopaedia Britannica, Inc.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','...this is an awesome sight.  The entire rebel resistance buried under six<BR>\nmillion hardbound copies of \"The Naked Lunch.\"<BR>\n- The Firesign Theater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','NOWPRINT. NOWPRINT. Clemclone, back to the shadows again.<BR>\n- The Firesign Theater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Ninety percent of baseball is half mental.\"<BR>\n-- Yogi Berra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Lead us in a few words of silent prayer.\"<BR>\n-- Bill Peterson, former Houston Oiler football coach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"With molasses you catch flies, with vinegar you catch nobody.\"<BR>\n-- Baltimore City Councilman Dominic DiPietro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We shall reach greater and greater platitudes of achievement.\"<BR>\n-- Richard J. Daley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','While it cannot be proved retrospectively that any experience of possession,<BR>\nconversion, revelation, or divine ecstasy was merely an epileptic discharge,<BR>\nwe must ask how one differentiates \"real transcendence\" from neuropathies<BR>\nthat produce the same extreme realness, profundity, ineffability, and sense<BR>\nof cosmic unity.  When accounts of sudden religious conversions in TLEs<BR>\n[temporal-lobe epileptics] are laid alongside the epiphanous revelations of<BR>\nthe religious tradition, the parallels are striking.  The same is true of the<BR>\nrecent spate of alleged UFO abductees.  Parsimony alone argues against invoking<BR>\nspirits, demons, or extraterrestrials when natural causes will suffice.<BR>\n-- Barry L. Beyerstein, \"Neuropathology and the Legacy of Spiritual <BR>\n&nbsp;Possession\", The Skeptical Inquirer, Vol. XII, No. 3, pg. 255');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Gravitation cannot be held responsible for people falling in love.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The triumph of libertarian anarchy is nearly (in historical terms) at<BR>\nhand... *if* we can keep the Left from selling us into slavery and the<BR>\nRight from blowing us up for, say, the next twenty years.\"<BR>\n-- Eric Rayman, usenet guy, about nanotechnology');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Spock, did you see the looks on their faces?\"<BR>\n\"Yes, Captain, a sort of vacant contentment.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"All Bibles are man-made.\"<BR>\n-- Thomas Edison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','I find you lack of faith in the forth dithturbing.<BR>\n- Darse (\"Darth\") Vader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The history of the rise of Christianity has everything to do with politics,<BR>\nculture, and human frailties and nothing to do with supernatural manipulation<BR>\nof events.  Had divine intervention been the guiding force, surely two<BR>\nmillennia after the birth of Jesus he would not have a world where there<BR>\nare more Muslims than Catholics, more Hindus than Protestants, and more<BR>\nnontheists than Catholics and Protestants combined.<BR>\n-- John K. Naland, \"The First Easter\", Free Inquiry magazine, Vol. 8, No. 2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Infidels in all ages have battled for the rights of man, and have at all times<BR>\nbeen the fearless advocates of liberty and justice.\"<BR>\n-- Robert Green Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Our business is run on trust.  We trust you will pay in advance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Bureaucracy is the enemy of innovation.\"<BR>\n-- Mark Shepherd, former President and CEO of Texas Instruments');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"For the love of phlegm...a stupid wall of death rays.  How tacky can ya get?\"<BR>\n- Post Brothers comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The language provides a programmer with a set of conceptual tools; if these are<BR>\ninadequate for the task, they will simply be ignored.  For example, seriously<BR>\nrestricting the concept of a pointer simply forces the programmer to use a<BR>\nvector plus integer arithmetic to implement structures, pointer, etc.  Good<BR>\ndesign and the absence of errors cannot be guaranteed by mere language<BR>\nfeatures.<BR>\n-- Bjarne Stroustrup, \"The C++ Programming Language\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Language shapes the way we think, and determines what we can think about.\"<BR>\n-- B. L. Whorf');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"How to make a million dollars:  First, get a million dollars.\"<BR>\n-- Steve Martin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We will bury you.\"<BR>\n-- Nikita Kruschev');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"To take a significant step forward, you must make a series of finite <BR>\nimprovements.\"<BR>\n-- Donald J. Atwood, General Motors');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"...all the good computer designs are bootlegged; the formally planned products,<BR>\nif they are built at all, are dogs!\"<BR>\n-- David E. Lundstrom, \"A Few Good Men From Univac\", MIT Press, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Our journeys to the stars will be made on spaceships created by determined,<BR>\nhardworking scientists and engineers applying the principles of science, not<BR>\naboard flying saucers piloted by little gray aliens from some other dimension.\"<BR>\n-- Robert A. Baker, \"The Aliens Among Us:  Hypnotic Regression Revisited\",<BR>\n&nbsp;The Skeptical Inquirer, Vol. XII, No. 2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','It is better to never have tried anything than to have tried something and<BR>\nfailed.<BR>\n- motto of jerks, weenies and losers everywhere');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Been through Hell?  Whaddya bring back for me?\"<BR>\n-- A. Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"But this one goes to eleven.\"<BR>\n-- Nigel Tufnel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The first sign of maturity is the discovery that the volume knob also turns to <BR>\nthe left.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The trouble with doing something right the first time is that nobody <BR>\nappreciates how difficult it was.\"<BR>\n-- Walt West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','The game of life is a game of boomerangs.  Our thoughts, deeds and words <BR>\nreturn to us sooner or later with astounding accuracy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Plastic gun.  Ingenious.  More coffee, please.\"<BR>\n-- The Phantom comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Most of us, when all is said and done, like what we like and make up reasons <BR>\nfor it afterwards.\"<BR>\n-- Soren F. Petersen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Is it really you, Fuzz, or is it Memorex, or is it radiation sickness?\" <BR>\n-- Sonic Disruptors comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Yes, and I feel bad about rendering their useless carci into dogfood...\"<BR>\n-- Badger comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The mark of an immature man is that he wants to die nobly for a cause, while <BR>\nthe mark of a mature man is that he wants to live humbly for one.\"<BR>\n-- William Stekel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Success covers a multitude of blunders.\"<BR>\n-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Whoever undertakes to set himself up as a judge of Truth and Knowledge is <BR>\nshipwrecked by the laughter of the gods.\"<BR>\n-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Security is mostly a superstition.  It does not exist in nature... Life is <BR>\neither a daring adventure or nothing.\"<BR>\n-- Helen Keller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"It is easier to fight for principles than to live up to them.\"<BR>\n-- Alfred Adler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The value of marriage is not that adults produce children, but that children <BR>\nproduce adults.\"<BR>\n-- Peter De Vries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Life is a garment we continuously alter, but which never seems to fit.\"<BR>\n-- David McCord');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Tell the truth and run.\"<BR>\n-- Yugoslav proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"A great many people think they are thinking when they are merely rearranging <BR>\ntheir prejudices.\"<BR>\n-- William James');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Summit meetings tend to be like panda matings.	 The expectations are always <BR>\nhigh, and the results usually disappointing.\"<BR>\n-- Robert Orben');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Consistency requires you to be as ignorant today as you were a year ago.\"<BR>\n-- Bernard Berenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"We learn from history that we learn nothing from history.\"<BR>\n-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Nature is very un-American.  Nature never hurries.\"<BR>\n-- William George Jordan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"When people are least sure, they are often most dogmatic.\"<BR>\n-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Lead me not into temptation... I can find it myself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Dead?	No excuse for laying off work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','An optimist believes we live in the best world possible; <BR>\na pessimist fears this is true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Most people would like to be delivered from<BR>\n&nbsp;temptation but would like it to keep in touch.\"<BR>\n-- Robert Orben');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"One day I woke up and discovered that I was in love with tripe.\"<BR>\n-- Tom Anderson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I believe the use of noise to make music will increase until we reach a<BR>\nmusic produced through the aid of electrical instruments which will make<BR>\navailable for musical purposes any and all sounds that can be heard.\"<BR>\n-- composer John Cage, 1937');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"There are some good people in it, but the orchestra as a whole is equivalent<BR>\nto a gang bent on destruction.\"<BR>\n-- John Cage, composer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Those who will be able to conquer software will be able to conquer the<BR>\nworld.\"<BR>\n-- Tadahiro Sekimoto, president, NEC Corp.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"One lawyer can steal more than a hundred men with guns.\"<BR>\n-- The Godfather');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Pig: An animal (Porcus omnivorous) closely allied to the human race by the <BR>\nsplendor and vivacity of its appetite, which, however, is inferior in scope,<BR>\nfor it balks at pig.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Turn on, tune up, rock out.\"<BR>\n-- Billy Gibbons');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"In matters of principle, stand like a rock; in matters of taste, swim with <BR>\nthe current.\"<BR>\n-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"And remember: Evil will always prevail, because Good is dumb.\"<BR>\n-- Spaceballs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Well, social relevance is a schtick, like mysteries, social relevance, <BR>\nscience fiction...\"<BR>\n-- Art Spiegelman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"To your left is the marina where several senior cabinet officials keep luxury <BR>\nyachts for weekend cruises on the Potomac.  Some of these ships are up to 100 <BR>\nfeet in length; the Presidential yacht is over 200 feet in length, and can <BR>\nremain submerged for up to 3 weeks.\"<BR>\n-- Garrison Keillor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Hello again, Peabody here...\"<BR>\n-- Mister Peabody');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Where humor is concerned there are no standards -- no one can say what is <BR>\ngood or bad, although you can be sure that everyone will.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Delta: The kids will love our inflatable slides.    -- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Delta: A real man lands where he wants to.   -- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Delta: We never make the same mistake three times.   -- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A university faculty is 500 egotists with a common parking problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"May the forces of evil become confused on the way to your house.\"<BR>\n-- George Carlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Everyone is entitled to an *informed* opinion.\"<BR>\n-- Harlan Ellison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Victory or defeat!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I mean, like, I just read your article in the Yale law recipe, on search and<BR>\nseizure.  Man, that was really Out There.\"<BR>\n&nbsp;\"I was so WRECKED when I wrote that...\"<BR>\n-- John Lovitz, as ex-Supreme Court nominee Alan Ginsburg, on SNL');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Blessed be those who initiate lively discussions with the hopelessly mute,<BR>\nfor they shall be know as Dentists.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Gary Hart:  living proof that you *can* screw your brains out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The following is not for the weak of heart or Fundamentalists.\"<BR>\n-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"And, of course, you have the commercials where savvy businesspeople Get Ahead <BR>\nby using their MacIntosh computers to create the ultimate American business <BR>\nproduct: a really sharp-looking report.\"<BR>\n-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Look! There! Evil!.. pure and simple, total evil from the Eighth Dimension!\"<BR>\n-- Buckaroo Banzai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Whom the gods would destroy, they first teach BASIC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"If truth is beauty, how come no one has their hair done in the library?\"<BR>\n-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Poor man... he was like an employee to me.\"<BR>\n-- The police commisioner on \"Sledge Hammer\" laments the death of his bodyguard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Mr. Spock succumbs to a powerful mating urge and nearly kills Captain Kirk.\"<BR>\n-- TV Guide, describing the Star Trek episode _Amok_Time_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','There are two kinds of egotists: 1) Those who admit it  2) The rest of us');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','From Sharp minds come... pointed heads.<BR>\n-- Bryan Sparrowhawk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"You stay here, Audrey -- this is between me and the vegetable!\"<BR>\n-- Seymour, from _Little Shop Of Horrors_');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','All extremists should be taken out and shot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Quod licet Iovi non licet bovi.<BR>\n(What Jove may do, is not permitted to a cow.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"Only the hypocrite is really rotten to the core.\"<BR>\n-- Hannah Arendt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Diplomacy is the art of saying \"nice doggy\" until you can find a rock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','A lot of people I know believe in positive thinking, and so do I.  <BR>\nI believe everything positively stinks.<BR>\n-- Lew Col');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Noncombatant:  A dead Quaker.<BR>\n-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"I believe that Ronald Reagan will someday make this<BR>\n&nbsp;country what it once was... an arctic wilderness.\"<BR>\n-- Steve Martin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','\"The medium is the massage.\"<BR>\n-- Crazy Nigel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Sometimes, too long is too long.<BR>\n- Joe Crowe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('cookie','Backed up the system lately?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cynic, n.:<BR>\n&nbsp;Experienced.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','court, n.:<BR>\n&nbsp;A place where they dispense with justice.<BR>\n&nbsp;-- Arthur Train');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Creditor, n.:<BR>\n&nbsp;A man who has a better memory than a debtor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cynic, n.:<BR>\n&nbsp;One who looks through rose-colored glasses with a jaundiced eye.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cursor, n.:<BR>\n&nbsp;One whose program will not run.<BR>\n&nbsp;-- Robb Russon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Consultation, n.:<BR>\n&nbsp;Medical term meaning \"to share the wealth.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Correspondence Corollary:<BR>\n&nbsp;An experiment may be considered a success if no more than half<BR>\n&nbsp;your data must be discarded to obtain correspondence with your theory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Consultant, n.:<BR>\n&nbsp;An ordinary man a long way from home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Consultant, n.:<BR>\n&nbsp;[From con \"to defraud, dupe, swindle,\" or, possibly, French con<BR>\n&nbsp;(vulgar) \"a person of little merit\" + sult elliptical form of<BR>\n&nbsp;\"insult.\"]  A tipster disguised as an oracle, especially one who<BR>\n&nbsp;has learned to decamp at high speed in spite of a large briefcase<BR>\n&nbsp;and heavy wallet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Conversation, n.:<BR>\n&nbsp;A vocal competition in which the one who is catching his breath<BR>\n&nbsp;is called the listener.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','pessimist:<BR>\n&nbsp;A man who spends all his time worrying about how he can keep the<BR>\n&nbsp;wolf from the door.<BR>\n&nbsp;optimist:<BR>\n&nbsp;A man who refuses to see the wolf until he seizes the seat of<BR>\n&nbsp;his pants.<BR>\n&nbsp;opportunist:<BR>\n&nbsp;A man who invites the wolf in and appears the next day in a fur coat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Earth Tones:<BR>\n&nbsp;A youthful subgroup interested in vegetarianism, tie-dyed<BR>\noutfits, mild recreational drugs, and good stereo equipment.  Earnest,<BR>\nfrequently lacking in humor.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Every Horse has an Infinite Number of Legs (proof by intimidation):<BR>\n&nbsp;Horses have an even number of legs.  Behind they have two legs, and in<BR>\nfront they have fore-legs.  This makes six legs, which is certainly an<BR>\nodd number of legs for a horse.  But the only number that is both even<BR>\nand odd is infinity.  Therefore, horses have an infinite number of<BR>\nlegs.  Now to show this for the general case, suppose that somewhere,<BR>\nthere is a horse that has a finite number of legs.  But that is a horse<BR>\nof another color, and by the lemma [\"All horses are the same color\"],<BR>\nthat does not exist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Electrocution, n.:<BR>\n&nbsp;Burning at the stake with all the modern improvements.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Economies of scale:<BR>\n&nbsp;The notion that bigger is better.  In particular, that if you want<BR>\n&nbsp;a certain amount of computer power, it is much better to buy one<BR>\n&nbsp;biggie than a bunch of smallies.  Accepted as an article of faith<BR>\n&nbsp;by people who love big machines and all that complexity.  Rejected<BR>\n&nbsp;as an article of faith by those who love small machines and all<BR>\n&nbsp;those limitations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Elbonics, n.:<BR>\n&nbsp;The actions of two people maneuvering for one armrest in a movie<BR>\n&nbsp;theatre.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','drug, n:<BR>\n&nbsp;A substance that, injected into a rat, produces a scientific paper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Eleventh Law of Acoustics:<BR>\n&nbsp;In a minimum-phase system there is an inextricable link between<BR>\n&nbsp;frequency response, phase response and transient response, as they<BR>\n&nbsp;are all merely transforms of one another.  This combined with<BR>\n&nbsp;minimalization of open-loop errors in output amplifiers and correct<BR>\n&nbsp;compensation for non-linear passive crossover network loading can<BR>\n&nbsp;lead to a significant decrease in system resolution lost.  However,<BR>\n&nbsp;of course, this all means jack when you listen to Pink Floyd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Duty, n:<BR>\n&nbsp;What one expects from others.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Die, v.:<BR>\n&nbsp;To stop sinning suddenly.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','design, v.:<BR>\n&nbsp;What you regret not doing later on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Deja vu:<BR>\n&nbsp;French., already seen; unoriginal; trite.<BR>\n&nbsp;Psychol., The illusion of having previously experienced<BR>\n&nbsp;something actually being encountered for the first time.<BR>\n&nbsp;Psychol., The illusion of having previously experienced<BR>\n&nbsp;something actually being encountered for the first time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Decision maker, n.:<BR>\n&nbsp;The person in your office who was unable to form a task force<BR>\n&nbsp;before the music stopped.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Data, n.:<BR>\n&nbsp;An accrual of straws on the backs of theories.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Documentation:<BR>\n&nbsp;Instructions translated from Swedish by Japanese for English<BR>\n&nbsp;speaking persons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bore, n.:<BR>\n&nbsp;A guy who wraps up a two-minute idea in a two-hour vocabulary.<BR>\n&nbsp;-- Walter Winchell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','filibuster, n.:<BR>\n&nbsp;Throwing your wait around.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fifth Law of Applied Terror:<BR>\n&nbsp;If you are given an open-book exam, you will forget your book.<BR>\n&nbsp;Corollary:<BR>\n&nbsp;If you are given a take-home exam, you will forget where you live.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fidelity, n.:<BR>\n&nbsp;A virtue peculiar to those who are about to be betrayed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fairy Tale, n.:<BR>\n&nbsp;A horror story to prepare children for the newspapers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','File cabinet:<BR>\n&nbsp;A four drawer, manually activated trash compactor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Famous last words:');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fifth Law of Procrastination:<BR>\n&nbsp;Procrastination avoids boredom; one never has the feeling that<BR>\n&nbsp;there is nothing important to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fakir, n:<BR>\n&nbsp;A psychologist whose charismatic data have inspired almost<BR>\n&nbsp;religious devotion in his followers, even though the sources<BR>\n&nbsp;seem to have shinnied up a rope and vanished.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','falsie salesman, n:<BR>\n&nbsp;Fuller bust man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Extract from Official Sweepstakes Rules:<BR>\n&nbsp;NO PURCHASE REQUIRED TO CLAIM YOUR PRIZE<BR>\n&nbsp;To claim your prize without purchase, do the following: (a) Carefully<BR>\ncut out your computer-printed name and address from upper right hand<BR>\ncorner of the Prize Claim Form. (b) Affix computer-printed name and<BR>\naddress -- with glue or cellophane tape (no staples or paper clips) --<BR>\nto a 3x5 inch index card.  (c) Also cut out the \"No\" paragraph (lower<BR>\nleft hand corner of Prize Claim Form) and affix it to the 3x5 card<BR>\nbelow your address label. (d) Then print on your 3x5 card, above your<BR>\ncomputer-printed name and address the words \"CARTER & VAN PEEL<BR>\nSWEEPSTAKES\" (Use all capital letters.)  (e) Finally place 3x5 card<BR>\n(without bending) into a plain envelope [NOTE: do NOT use the the<BR>\nOfficial Prize Claim and CVP Perfume Reply Envelope or you may be<BR>\ndisqualified], and mail to: CVP, Box 1320, Westbury, NY 11595.  Print<BR>\nthis address correctly.  Comply with above instructions carefully and<BR>\ncompletely or you may be disqualified from receiving your prize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Expense Accounts, n.:<BR>\n&nbsp;Corporate food stamps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Expert, n.:<BR>\n&nbsp;Someone who comes from out of town and shows slides.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','flannister, n.:<BR>\n&nbsp;The plastic yoke that holds a six-pack of beer together.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Entreprenuer, n.:<BR>\n&nbsp;A high-rolling risk taker who would rather<BR>\n&nbsp;be a spectacular failure than a dismal success.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Elephant, n.:<BR>\n&nbsp;A mouse built to government specifications.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Etymology, n.:<BR>\n&nbsp;Some early etymological scholars came up with derivations that<BR>\n&nbsp;were hard for the public to believe.  The term \"etymology\" was formed<BR>\n&nbsp;from the Latin \"etus\" (\"eaten\"), the root \"mal\" (\"bad\"), and \"logy\"<BR>\n&nbsp;(\"study of\").  It meant \"the study of things that are hard to swallow.\"<BR>\n&nbsp;-- Mike Kellen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','enhance, v.:<BR>\n&nbsp;To tamper with an image, usually to its detriment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Emacs, n.:<BR>\n&nbsp;A slow-moving parody of a text editor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Endless Loop, n.:<BR>\n&nbsp;see Loop, Endless.<BR>\nLoop, Endless, n.:<BR>\n&nbsp;see Endless Loop.<BR>\n&nbsp;-- Random Shack Data Processing Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','FORTUNE EXPLAINS WHAT JOB REVIEW CATCH PHRASES MEAN:	#1<BR>\nskilled oral communicator:<BR>\n&nbsp;Mumbles inaudibly when attempting to speak.  Talks to self.<BR>\n&nbsp;Argues with self.  Loses these arguments.<BR>\n&nbsp;skilled written communicator:<BR>\n&nbsp;Scribbles well.  Memos are invariable illegible, except for<BR>\n&nbsp;the portions that attribute recent failures to someone else.<BR>\n&nbsp;growth potential:<BR>\n&nbsp;With proper guidance, periodic counselling, and remedial training,<BR>\n&nbsp;the reviewee may, given enough time and close supervision, meet<BR>\n&nbsp;the minimum requirements expected of him by the company.<BR>\n&nbsp;key company figure:<BR>\n&nbsp;Serves as the perfect counter example.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','FORTUNE EXPLAINS WHAT JOB REVIEW CATCH PHRASES MEAN:	#9<BR>\nhas management potential:<BR>\n&nbsp;Because of his intimate relationship with inanimate objects, the<BR>\n&nbsp;reviewee has been appointed to the critical position of department<BR>\n&nbsp;pencil monitor.<BR>\n&nbsp;inspirational:<BR>\n&nbsp;A true inspiration to others.  (\"There, but for the grace of God,<BR>\n&nbsp;go I.\")<BR>\n&nbsp;adapts to stress:<BR>\n&nbsp;Passes wind, water, or out depending upon the severity of the<BR>\n&nbsp;situation.<BR>\n&nbsp;goal oriented:<BR>\n&nbsp;Continually sets low goals for himself, and usually fails<BR>\n&nbsp;to meet them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Forecast, n.:<BR>\n&nbsp;A prediction of the future, based on the past, for<BR>\n&nbsp;which the forecaster demands payment in the present.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Forgetfulness, n.:<BR>\n&nbsp;A gift of God bestowed upon debtors in compensation for<BR>\n&nbsp;their destitution of conscience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Foolproof Operation:<BR>\n&nbsp;No provision for adjustment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','First Law of Socio-Genetics:<BR>\n&nbsp;Celibacy is not hereditary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fishbowl, n.:<BR>\n&nbsp;A glass-enclosed isolation cell where newly promoted managers are<BR>\n&nbsp;kept for observation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','First law of debate:<BR>\n&nbsp;Never argue with a fool.  People might not know the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','honeymoon, n.:<BR>\n&nbsp;A short period of doting between dating and debting.<BR>\n&nbsp;-- Ray C. Bandy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','First Law of Procrastination:<BR>\n&nbsp;Procrastination shortens the job and places the responsibility<BR>\n&nbsp;for its termination on someone else (i.e., the authority who<BR>\n&nbsp;imposed the deadline).<BR>\n&nbsp;Fifth Law of Procrastination:<BR>\n&nbsp;Procrastination avoids boredom; one never has the feeling that<BR>\n&nbsp;there is nothing important to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','genlock, n.:<BR>\n&nbsp;Why he stays in the bottle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Genderplex, n.:<BR>\n&nbsp;The predicament of a person in a restaurant who is unable to<BR>\n&nbsp;determine his or her designated restroom (e.g., turtles and tortoises).<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Genius, n.:<BR>\n&nbsp;A chemist who discovers a laundry additive that rhymes with \"bright.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','genius, n.:<BR>\n&nbsp;Person clever enough to be born in the right place at the right<BR>\n&nbsp;time of the right sex and to follow up this advantage by saying<BR>\n&nbsp;all the right things to all the right people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Getting the job done is no excuse for not following the rules.<BR>\n&nbsp;Corollary:<BR>\n&nbsp;Following the rules will not get the job done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fun Facts, #63:<BR>\n&nbsp;The name California was given to the state by Spanish conquistadores.<BR>\n&nbsp;It was the name of an imaginary island, a paradise on earth, in the<BR>\n&nbsp;Spanish romance, \"Les Serges de Esplandian\", written by Montalvo in<BR>\n&nbsp;1510.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Gnagloot, n.:<BR>\n&nbsp;A person who leaves all his ski passes on his jacket just to<BR>\n&nbsp;impress people.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Friends, n.:<BR>\n&nbsp;People who borrow your books and set wet glasses on them.<BR>\n&nbsp;People who know you well, but like you anyway.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fun experiments:<BR>\n&nbsp;Get a can of shaving cream, throw it in a freezer for about a week.<BR>\n&nbsp;Then take it out, peel the metal off and put it where you want...<BR>\n&nbsp;bedroom, car, etc.  As it thaws, it expands an unbelievable amount.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fourth Law of Thermodynamics:<BR>\n&nbsp;If the probability of success is not almost one, it is damn near zero.<BR>\n&nbsp;-- David Ellis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Famous quotations:<BR>\n&nbsp;\" \"<BR>\n&nbsp;-- Charlie Chaplin<BR>\n&nbsp;\" \"<BR>\n&nbsp;-- Harpo Marx<BR>\n&nbsp;\" \"<BR>\n&nbsp;-- Marcel Marceau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','fenderberg, n.:<BR>\n&nbsp;The large glacial deposits that form on the insides<BR>\n&nbsp;of car fenders during snowstorms.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','hard, adj.:<BR>\n&nbsp;The quality of your own data; also how it is to believe those<BR>\n&nbsp;of other people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Hardware, n.:<BR>\n&nbsp;The parts of a computer system that can be kicked.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Hangover, n.:<BR>\n&nbsp;The burden of proof.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','handshaking protocol, n:<BR>\n&nbsp;A process employed by hostile hardware devices to initate a<BR>\n&nbsp;terse but civil dialogue, which, in turn, is characterized by<BR>\n&nbsp;occasional misunderstanding, sulking, and name-calling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Hollerith, v.:<BR>\n&nbsp;What thou doest when thy phone is on the fritzeth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','guru, n:<BR>\n&nbsp;A computer owner who can read the manual.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','gurmlish, n.:<BR>\n&nbsp;The red warning flag at the top of a club sandwich which<BR>\n&nbsp;prevents the person from biting into it and puncturing the roof<BR>\n&nbsp;of his mouth.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','guru, n.:<BR>\n&nbsp;A person in T-shirt and sandals who took an elevator ride with<BR>\n&nbsp;a senior vice-president and is ultimately responsible for the<BR>\n&nbsp;phone call you are about to receive from your boss.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Guillotine, n.:<BR>\n&nbsp;A French chopping center.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Hale Mail Rule, The:<BR>\n&nbsp;When you are ready to reply to a letter, you will lack at least<BR>\n&nbsp;one of the following:<BR>\n&nbsp;(a) A pen or pencil or typewriter.<BR>\n&nbsp;(b) Stationery.<BR>\n&nbsp;(c) Postage stamp.<BR>\n&nbsp;(d) The letter you are answering.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Goto, n.:<BR>\n&nbsp;A programming tool that exists to allow structured programmers<BR>\n&nbsp;to complain about unstructured programmers.<BR>\n&nbsp;-- Ray Simard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','grasshopotomaus:<BR>\n&nbsp;A creature that can leap to tremendous heights... once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Great American Axiom:<BR>\n&nbsp;Some is good, more is better, too much is just right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','index, n.:<BR>\n&nbsp;Alphabetical list of words of no possible interest where an<BR>\n&nbsp;alphabetical list of subjects with references ought to be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','incentive program, n.:<BR>\n&nbsp;The system of long and short-term rewards that a corporation uses<BR>\n&nbsp;to motivate its people.  Still, despite all the experimentation with<BR>\n&nbsp;profit sharing, stock options, and the like, the most effective<BR>\n&nbsp;incentive program to date seems to be \"Do a good job and you get to<BR>\n&nbsp;keep it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','innovate, v.:<BR>\n&nbsp;To annoy people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Infancy, n.:<BR>\n&nbsp;The period of our lives when, according to Wordsworth, \"Heaven lies<BR>\n&nbsp;about us.\"  The world begins lying about us pretty soon afterward.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','hangover, n.:<BR>\n&nbsp;The wrath of grapes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Immutability, Three Rules of:<BR>\n&nbsp;(1)  If a tarpaulin can flap, it will.<BR>\n&nbsp;(2)  If a small boy can get dirty, he will.<BR>\n&nbsp;(3)  If a teenager can go out, he will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','idleness, n.:<BR>\n&nbsp;Leisure gone to seed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','ignisecond, n:<BR>\n&nbsp;The overlapping moment of time when the hand is locking the car<BR>\n&nbsp;door even as the brain is saying, \"my keys are in there!\"<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','IBM Pollyanna Principle:<BR>\n&nbsp;Machines should work.  People should think.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','heavy, adj.:<BR>\n&nbsp;Seduced by the chocolate side of the force.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Krogt, n. (chemical symbol: Kr):<BR>\n&nbsp;The metallic silver coating found on fast-food game cards.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','blithwapping:<BR>\n&nbsp;Using anything BUT a hammer to hammer a nail into the<BR>\n&nbsp;wall, such as shoes, lamp bases, doorstops, etc.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Atlanta:<BR>\n&nbsp;An entire city surrounded by an airport.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','ASCII:<BR>\n&nbsp;The control code for all beginning programmers and those who would<BR>\n&nbsp;become computer literate.  Etymologically, the term has come down as<BR>\n&nbsp;a contraction of the often-repeated phrase \"ascii and you shall<BR>\n&nbsp;receive.\"<BR>\n&nbsp;-- Robb Russon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','jogger, n.:<BR>\n&nbsp;An odd sort of person with a thing for pain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Armadillo:<BR>\n&nbsp;To provide weapons to a Spanish pickle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','italic, adj:<BR>\n&nbsp;Slanted to the right to emphasize key phrases.  Unique to<BR>\n&nbsp;Western alphabets; in Eastern languages, the same phrases<BR>\n&nbsp;are often slanted to the left.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Amoebit:<BR>\n&nbsp;Amoeba/rabbit cross; it can multiply and divide at the same time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Ambition, n:<BR>\n&nbsp;An overmastering desire to be vilified by enemies while<BR>\n&nbsp;living and made ridiculous by friends when dead.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','It is fruitless:<BR>\n&nbsp;to become lachrymose over precipitately departed lactate fluid.<BR>\n&nbsp;to attempt to indoctrinate a superannuated canine with<BR>\n&nbsp;innovative maneuvers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','ink, n.:<BR>\n&nbsp;A villainous compound of tannogallate of iron, gum-arabic,<BR>\n&nbsp;and water, chiefly used to facilitate the infection of<BR>\n&nbsp;idiocy and promote intellectual crime.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Information Center, n.:<BR>\n&nbsp;A room staffed by professional computer people whose job it is to<BR>\n&nbsp;tell you why you cannot have the information you require.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Ingrate, n.:<BR>\n&nbsp;A man who bites the hand that feeds him, and then complains of<BR>\n&nbsp;indigestion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Household hint:<BR>\n&nbsp;If you are out of cream for your coffee, mayonnaise makes a<BR>\n&nbsp;dandy substitute.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Law of Communications:<BR>\n&nbsp;The inevitable result of improved and enlarged communications<BR>\n&nbsp;between different levels in a hierarchy is a vastly increased<BR>\n&nbsp;area of misunderstanding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','furbling, v.:<BR>\n&nbsp;Having to wander through a maze of ropes at an airport or bank<BR>\n&nbsp;even when you are the only person in line.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','laser, n.:<BR>\n&nbsp;Failed death ray.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Laws of Serendipity:<BR>\n&nbsp;(1) In order to discover anything, you must be looking for something.<BR>\n&nbsp;(2) If you wish to make an improved product, you must already<BR>\n&nbsp;be engaged in making an inferior one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Lactomangulation, n.:<BR>\n&nbsp;Manhandling the \"open here\" spout on a milk carton so badly<BR>\n&nbsp;that one has to resort to using the \"illegal\" side.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Fourth Law of Revision:<BR>\n&nbsp;It is usually impractical to worry beforehand about<BR>\n&nbsp;interferences -- if you have none, someone will make one for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','double-blind experiment, n:<BR>\n&nbsp;An experiment in which the chief researcher believes he is<BR>\n&nbsp;fooling both the subject and the lab assistant.  Often accompanied<BR>\n&nbsp;by a strong belief in the tooth fairy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','divorce, n:<BR>\n&nbsp;A change of wife.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Distinctive, adj.:<BR>\n&nbsp;A different color or shape than our competitors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','disbar, n:<BR>\n&nbsp;As distinguished from some other bar.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Law of the Jungle:<BR>\n&nbsp;He who hesitates is lunch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','diplomacy, n:<BR>\n&nbsp;Lying in state.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','kernel, n.:<BR>\n&nbsp;A part of an operating system that preserves the medieval<BR>\n&nbsp;traditions of sorcery and black art.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Death wish, n.:<BR>\n&nbsp;The only wish that always comes true, whether or not one wishes it to.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Deadwood, n.:<BR>\n&nbsp;Anyone in your company who is more senior than you are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Justice, n.:<BR>\n&nbsp;A decision in your favor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Data, n.:<BR>\n&nbsp;Computerspeak for \"information\".  Properly pronounced<BR>\n&nbsp;the way Bostonians pronounce the word for a female child.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','life, n.:<BR>\n&nbsp;A whim of several billion cells to be you for a while.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','interest, n.:<BR>\n&nbsp;What borrowers pay, lenders receive, stockholders own, and<BR>\n&nbsp;burned out employees must feign.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','life, n.:<BR>\n&nbsp;Learning about people the hard way -- by being one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','hacker, n.:<BR>\n&nbsp;A master byter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Gravity:<BR>\n&nbsp;What you get when you eat too much and too fast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Law of Procrastination:<BR>\n&nbsp;Procrastination avoids boredom; one never has<BR>\n&nbsp;the feeling that there is nothing important to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Laws of Computer Programming:<BR>\n&nbsp;(1) Any given program, when running, is obsolete.<BR>\n&nbsp;(2) Any given program costs more and takes longer.<BR>\n&nbsp;(3) If a program is useful, it will have to be changed.<BR>\n&nbsp;(4) If a program is useless, it will have to be documented.<BR>\n&nbsp;(5) Any given program will expand to fill all available memory.<BR>\n&nbsp;(6) The value of a program is proportional the weight of its output.<BR>\n&nbsp;(7) Program complexity grows until it exceeds the capability of<BR>\n&nbsp;the programmer who must maintain it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','gleemites, n.:<BR>\n&nbsp;Petrified deposits of toothpaste found in sinks.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','knowledge, n.:<BR>\n&nbsp;Things you believe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Kludge, n.:<BR>\n&nbsp;An ill-assorted collection of poorly-matching parts, forming a<BR>\n&nbsp;distressing whole.<BR>\n&nbsp;-- Jackson Granholm, \"Datamation\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Liar:<BR>\n&nbsp;one who tells an unpleasant truth.<BR>\n&nbsp;-- Oliver Herford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','lisp, v.:<BR>\n&nbsp;To call a spade a thpade.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Kin, n.:<BR>\n&nbsp;An affliction of the blood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','kern, v.:<BR>\n&nbsp;1. To pack type together as tightly as the kernels on an ear<BR>\n&nbsp;of corn.  2. In parts of Brooklyn and Queens, N.Y., a small,<BR>\n&nbsp;metal object used as part of the monetary system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Lunatic Asylum, n.:<BR>\n&nbsp;The place where optimism most flourishes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Everything I am today I owe to people, whom it is now<BR>\n&nbsp;to late to punish.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Do you smell something burning or is it me?\"<BR>\n&nbsp;-- Joan of Arc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"A child of 5 could understand this!  Fetch me a child of 5.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Modesty:<BR>\n&nbsp;The gentle art of enhancing your charm by pretending not to be<BR>\n&nbsp;aware of it.<BR>\n&nbsp;-- Oliver Herford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','modesty, n.:<BR>\n&nbsp;Being comfortable that others will discover your greatness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Please take note:');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','mixed emotions:<BR>\n&nbsp;Watching a bus-load of lawyers plunge off a cliff.<BR>\n&nbsp;With five empty seats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','paycheck:<BR>\n&nbsp;The weekly $5.27 that remains after deductions for federal<BR>\n&nbsp;withholding, state withholding, city withholding, FICA,<BR>\n&nbsp;medical/dental, long-term disability, unemployment insurance,<BR>\n&nbsp;Christmas Club, and payroll savings plan contributions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Talk about willing people... over half of them are willing to work<BR>\n&nbsp;and the others are more than willing to watch them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Talent does what it can, genius what it must.<BR>\n&nbsp;I do what I get paid to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Office Automation:<BR>\n&nbsp;The use of computers to improve efficiency in the office<BR>\n&nbsp;by removing anyone you would want to talk with over coffee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Silence is the only virtue he has left.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Sacred cows make great hamburgers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Official Project Stages:<BR>\n&nbsp;(1) Uncritical Acceptance<BR>\n&nbsp;(2) Wild Enthusiasm<BR>\n&nbsp;(3) Dejected Disillusionment<BR>\n&nbsp;(4) Total Confusion<BR>\n&nbsp;(5) Search for the Guilty<BR>\n&nbsp;(6) Punishment of the Innocent<BR>\n&nbsp;(7) Promotion of the Non-participants');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;My mother was the travel agent for guilt trips.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;I love your outfit, does it come in your size?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Flash!  Flash!  I love you! ...but we only have fourteen hours to<BR>\n&nbsp;save the earth!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;All I want is more than my fair share.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Penguin Trivia #46:<BR>\n&nbsp;Animals who are not penguins can only wish they were.<BR>\n&nbsp;-- Chicago Reader 10/15/82');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"You want me to put *holes* in my ears and hang things from them?<BR>\n&nbsp;How...  tribal.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Who?  Me?  No, no, NO!!  But I do sell rugs.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"When she hauled ass, it took three trips.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Ninety-Ninety Rule of Project Schedules:<BR>\n&nbsp;The first ninety percent of the task takes ninety percent of<BR>\n&nbsp;the time, and the last ten percent takes the other ninety percent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"The elder gods went to Suggoth and all I got was this lousy T-shirt.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','no brainer:<BR>\n&nbsp;A decision which, viewed through the retrospectoscope,<BR>\n&nbsp;is \"obvious\" to those who failed to make it originally.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Say, you look pretty athletic.  What say we put a pair of tennis<BR>\n&nbsp;shoes on you and run you into the wall?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','nominal egg:<BR>\n&nbsp;New Yorkerese for expensive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Our parents were never our age.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Non-Reciprocal Laws of Expectations:<BR>\n&nbsp;Negative expectations yield negative results.<BR>\n&nbsp;Positive expectations yield negative results.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"My shampoo lasts longer than my relationships.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"He eats like a bird... five times his own weight each day.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','polygon:<BR>\n&nbsp;Dead parrot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Power, n.:<BR>\n&nbsp;The only narcotic regulated by the SEC instead of the FDA.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','&nbsp;Phases of a Project:<BR>\n(1)	Exultation.<BR>\n(2)	Disenchantment.<BR>\n(3)	Confusion.<BR>\n(4)	Search for the Guilty.<BR>\n(5)	Punishment for the Innocent.<BR>\n(6)	Distinction for the Uninvolved.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Pedaeration, n.:<BR>\n&nbsp;The perfect body heat achieved by having one leg under the<BR>\n&nbsp;sheet and one hanging off the edge of the bed.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','poverty, n.:<BR>\n&nbsp;An unfortunate state that persists as long<BR>\n&nbsp;as anyone lacks anything he would like to have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','phosflink:<BR>\n&nbsp;To flick a bulb on and off when it burns out (as if, somehow, that<BR>\n&nbsp;will bring it back to life).<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','philosophy:<BR>\n&nbsp;The ability to bear with calmness the misfortunes of our friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','pixel, n.:<BR>\n&nbsp;A mischievous, magical spirit associated with screen displays.<BR>\n&nbsp;The computer industry has frequently borrowed from mythology:<BR>\n&nbsp;Witness the sprites in computer graphics, the demons in artificial<BR>\n&nbsp;intelligence, and the trolls in the marketing department.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','philosophy:<BR>\n&nbsp;Unintelligible answers to insoluble problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','prairies, n.:<BR>\n&nbsp;Vast plains covered by treeless forests.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','pension:<BR>\n&nbsp;A federally insured chain letter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','pediddel:<BR>\n&nbsp;A car with only one working headlight.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Golden Rule of Arts and Sciences:<BR>\n&nbsp;He who has the gold makes the rules.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Prejudice:<BR>\n&nbsp;A vagrant opinion without visible means of support.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','petribar:<BR>\n&nbsp;Any sun-bleached prehistoric candy that has been sitting in<BR>\n&nbsp;the window of a vending machine too long.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Painting, n.:<BR>\n&nbsp;The art of protecting flat surfaces from the weather, and<BR>\n&nbsp;exposing them to the critic.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','One-Shot Case Study, n.:<BR>\n&nbsp;The scientific equivalent of the four-leaf clover, from which it is<BR>\n&nbsp;concluded all clovers possess four leaves and are sometimes green.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','patent:<BR>\n&nbsp;A method of publicizing inventions so others can copy them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','One Page Principle:<BR>\n&nbsp;A specification that will not fit on one page of 8.5x11 inch<BR>\n&nbsp;paper cannot be understood.<BR>\n&nbsp;-- Mark Ardis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Optimism, n.:<BR>\n&nbsp;The belief that everything is beautiful, including what is ugly, good,<BR>\n&nbsp;bad, and everything right that is wrong.  It is held with greatest<BR>\n&nbsp;tenacity by those accustomed to falling into adversity, and most<BR>\n&nbsp;acceptably expounded with the grin that apes a smile.  Being a blind<BR>\n&nbsp;faith, it is inaccessible to the light of disproof -- an intellectual<BR>\n&nbsp;disorder, yielding to no treatment but death.  It is hereditary, but<BR>\n&nbsp;not contagious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Poverty Lurks:<BR>\n&nbsp;Financial paranoia instilled in offspring by depression-era<BR>\nparents.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Quality control, n.:<BR>\n&nbsp;Assuring that the quality of a product does not get out of hand<BR>\n&nbsp;and add to the cost of its manufacture or design.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Old timer, n.:<BR>\n&nbsp;One who remembers when charity was a virtue and not an organization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I used to jog, but the ice kept bouncing out of my glass.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I used to be lost in the shuffle, now I just shuffle along with<BR>\n&nbsp;the lost.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I only touch base with reality on an as-needed basis!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I may not be able to walk, but I drive from the sitting posistion.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I thought I saw a unicorn on the way over, but it was just a<BR>\n&nbsp;horse with one of the horns broken off.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I drive my car quietly, for it goes without saying.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','love,  n.:<BR>\n&nbsp;Love ties in a knot in the end of the rope.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I used to be an idealist, but I got mugged by reality.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"A university faculty is 500 egotists with a common parking problem.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Even the Statue of Liberty shaves her pits.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','poisoned coffee, n.:<BR>\n&nbsp;Grounds for divorce.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','politics, n.:<BR>\n&nbsp;A strife of interests masquerading as a contest of principles.<BR>\n&nbsp;The conduct of public affairs for private advantage.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','prototype, n.:<BR>\n&nbsp;First stage in the life cycle of a computer product, followed by<BR>\n&nbsp;pre-alpha, alpha, beta, release version, corrected release version,<BR>\n&nbsp;upgrade, corrected upgrade, etc.  Unlike its successors, the<BR>\n&nbsp;prototype is not expected to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Portable, adj.:<BR>\n&nbsp;Survives system reboot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Programming Department:<BR>\n&nbsp;Mistakes made while you wait.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','problem drinker, n.:<BR>\n&nbsp;A man who never buys.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','progress, n.:<BR>\n&nbsp;Medieval man thought disease was caused by invisible demons<BR>\n&nbsp;invading the body and taking possession of it.<BR>\n&nbsp;Modern man knows disease is caused by microscopic bacteria<BR>\n&nbsp;and viruses invading the body and causing it to malfunction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','revolutionary, adj.:<BR>\n&nbsp;Repackaged.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Reputation, adj.:<BR>\n&nbsp;What others are not thinking about you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Revolution, n.:<BR>\n&nbsp;In politics, an abrupt change in the form of misgovernment.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','senility, n.:<BR>\n&nbsp;The state of mind of elderly persons with whom one happens to disagree.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Regression analysis:<BR>\n&nbsp;Mathematical techniques for trying to understand why things are<BR>\n&nbsp;getting worse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','rugged, adj.:<BR>\n&nbsp;Too heavy to lift.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;The only easy way to tell a hamster from a gerbil is that the<BR>\n&nbsp;gerbil has more dark meat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Random, n.:<BR>\n&nbsp;As in number, predictable.  As in memory access, unpredictable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;Ludwig Boltzmann, who spend much of his life studying statistical<BR>\n&nbsp;mechanics died in 1906 by his own hand.  Paul Ehrenfest, carrying<BR>\n&nbsp;on the work, died similarly in 1933.  Now it is our turn.<BR>\n&nbsp;-- Goodstein, States of Matter ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"The baby was so ugly they had to hang a pork chop around its<BR>\n&nbsp;neck to get the dog to play with it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"What do you mean, you had the dog fixed?   Just what made you<BR>\n&nbsp;think he was broken!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"This is a one line proof... if we start sufficiently far to the<BR>\n&nbsp;left.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"My life is a soap opera, but who gets the movie rights?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Real Time, adj.:<BR>\n&nbsp;Here and now, as opposed to fake time, which only occurs there and then.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"If you keep an open mind people will throw a lot of garbage in it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','sushi, n.:<BR>\n&nbsp;When that-which-may-still-be-alive is put on top of rice and<BR>\n&nbsp;strapped on with electrical tape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Re: Graphics:<BR>\n&nbsp;A picture is worth 10K words -- but only those to describe<BR>\n&nbsp;the picture.  Hardly any sets of 10K words can be adequately<BR>\n&nbsp;described with pictures.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','scenario, n.:<BR>\n&nbsp;An imagined sequence of events that provides the context in<BR>\n&nbsp;which a business decision is made.  Scenarios always come in<BR>\n&nbsp;sets of three: best case, worst case, and just in case.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Satellite Safety Tip #14:<BR>\n&nbsp;If you see a bright streak in the sky coming at you, duck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Reception area, n.:<BR>\n&nbsp;The purgatory where office visitors are condemned to spend<BR>\n&nbsp;innumerable hours reading dog-eared back issues of trade<BR>\n&nbsp;magazines like Modern Plastics, Chain Saw Age, and Chicken World,<BR>\n&nbsp;while the receptionist blithely reads her own trade magazine --<BR>\n&nbsp;Cosmopolitan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Reformed, n.:<BR>\n&nbsp;A synagogue that closes for the Jewish holidays.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Recursion n.:<BR>\n&nbsp;See Recursion.<BR>\n&nbsp;-- Random Shack Data Processing Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Revolution, n.:<BR>\n&nbsp;A form of government abroad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Reappraisal, n.:<BR>\n&nbsp;An abrupt change of mind after being found out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Reliable source, n.:<BR>\n&nbsp;The guy you just met.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Senate, n.:<BR>\n&nbsp;A body of elderly gentlemen charged with high duties and misdemeanors.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rules for driving in New York:<BR>\n&nbsp;(1) Anything done while honking your horn is legal.<BR>\n&nbsp;(2) You may park anywhere if you turn your four-way flashers on.<BR>\n&nbsp;(3) A red light means the next six cars may go through the<BR>\n&nbsp;intersection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rules for Academic Deans:<BR>\n&nbsp;(1)  HIDE!!!!<BR>\n&nbsp;(2)  If they find you, LIE!!!!<BR>\n&nbsp;-- Father Damian C. Fandal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rule of Feline Frustration:<BR>\n&nbsp;When your cat has fallen asleep on your lap and looks utterly<BR>\n&nbsp;content and adorable, you will suddenly have to go to the<BR>\n&nbsp;bathroom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rule of Creative Research:<BR>\n&nbsp;(1) Never draw what you can copy.<BR>\n&nbsp;(2) Never copy what you can trace.<BR>\n&nbsp;(3) Never trace what you can cut out and paste down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rule of the Great:<BR>\n&nbsp;When people you greatly admire appear to be thinking deep<BR>\n&nbsp;thoughts, they probably are thinking about lunch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Robot, n.:<BR>\n&nbsp;University administrator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rule #1:<BR>\n&nbsp;The Boss is always right.<BR>\n&nbsp;Rule #2:<BR>\n&nbsp;If the Boss is wrong, see Rule #1.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Rule of Defactualization:<BR>\n&nbsp;Information deteriorates upward through bureaucracies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Teutonic:<BR>\n&nbsp;Not enough gin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Briggs-Chase Law of Program Development:<BR>\n&nbsp;To determine how long it will take to write and debug a<BR>\n&nbsp;program, take your best estimate, multiply that by two, add<BR>\n&nbsp;one, and convert to the next higher units.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The 357.73 Theory:<BR>\n&nbsp;Auditors always reject expense accounts<BR>\n&nbsp;with a bottom line divisible by 5.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','teamwork, n.:<BR>\n&nbsp;Having someone to blame.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','tax office, n.:<BR>\n&nbsp;Den of inequity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','taxidermist, n.:<BR>\n&nbsp;A man who mounts animals.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','TCP/IP Slang Glossary, #1:<BR>\n&nbsp;Gong, n: Medieval term for privy, or what pased for them in that era.<BR>\nToday used whimsically to describe the aftermath of a bogon attack. Think<BR>\nof our community as the Galapagos of the English language.<BR>\n&nbsp;\"Vogons may read you bad poetry, but bogons make you study obsolete RFCs.\"<BR>\n&nbsp;-- Dave Mills');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Swahili, n.:<BR>\n&nbsp;The language used by the National Enquirer to print their retractions.<BR>\n&nbsp;-- Johnny Hart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Stupid, n.:<BR>\n&nbsp;Losing $25 on the game and $25 on the instant replay.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','sunset, n.:<BR>\n&nbsp;Pronounced atmospheric scattering of shorter wavelengths,<BR>\n&nbsp;resulting in selective transmission below 650 nanometers with<BR>\n&nbsp;progressively reducing solar elevation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','spagmumps, n.:<BR>\n&nbsp;Any of the millions of Styrofoam wads that accompany mail-order items.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Spirtle, n.:<BR>\n&nbsp;The fine stream from a grapefruit that always lands right in your eye.<BR>\n&nbsp;-- Sniglets, \"Rich Hall & Friends\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','SUN Microsystems:<BR>\n&nbsp;The Network IS the Load Average.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','share, n.:<BR>\n&nbsp;To give in, endure humiliation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Snacktrek, n.:<BR>\n&nbsp;The peculiar habit, when searching for a snack, of constantly<BR>\n&nbsp;returning to the refrigerator in hopes that something new will have<BR>\n&nbsp;materialized.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','serendipity, n.:<BR>\n&nbsp;The process by which human knowledge is advanced.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Gordian Maxim:<BR>\n&nbsp;If a string has one end, it has another.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Illiterati Programus Canto 1:<BR>\n&nbsp;A program is a lot like a nose: Sometimes it runs, and<BR>\n&nbsp;sometimes it blows.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Second Law of Thermodynamics:<BR>\n&nbsp;If you think things are in a mess now, just wait!<BR>\n&nbsp;-- Jim Warner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Official MBA Handbook on business cards:<BR>\n&nbsp;Avoid overly pretentious job titles such as \"Lord of the Realm,<BR>\n&nbsp;Defender of the Faith, Emperor of India\" or \"Director of Corporate<BR>\n&nbsp;Planning.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Seventh Commandments for Technicians:<BR>\n&nbsp;Work thou not on energized equipment, for if thou dost, thy fellow<BR>\n&nbsp;workers will surely buy beers for thy widow and console her in other<BR>\n&nbsp;ways.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Roman Rule:<BR>\n&nbsp;The one who says it cannot be done should never interrupt the<BR>\n&nbsp;one who is doing it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Phone Booth Rule:<BR>\n&nbsp;A lone dime always gets the number nearly right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Sixth Commandment of Frisbee:<BR>\n&nbsp;The greatest single aid to distance is for the disc to be going in a<BR>\n&nbsp;direction you did not want.   (Goes the wrong way = Goes a long way.)<BR>\n&nbsp;-- Dan Roddick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Law of the Letter:<BR>\n&nbsp;The best way to inspire fresh thoughts is to seal the envelope.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Marines:<BR>\n&nbsp;The few, the proud, the dead on the beach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The most dangerous organization in America today is:<BR>\n&nbsp;(a) The KKK<BR>\n&nbsp;(b) The American Nazi Party<BR>\n&nbsp;(c) The Delta Frequent Flyer Club');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Modelski Chain Rule:<BR>\n(1)	Look intently at the problem for several minutes.  Scratch your<BR>\n&nbsp;head at 20-30 second intervals.  Try solving the problem on your<BR>\n&nbsp;Hewlett-Packard.<BR>\n(2)	Failing this, look around at the class.  Select a particularly<BR>\n&nbsp;bright-looking individual.<BR>\n(3)	Procure a large chain.<BR>\n(4)	Walk over to the selected student and threaten to beat him severely<BR>\n&nbsp;with the chain unless he gives you the answer to the problem.<BR>\n&nbsp;Generally, he will.  It may also be a good idea to give him a sound<BR>\n&nbsp;thrashing anyway, just to show you mean business.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','take forceful action:<BR>\n&nbsp;Do something that should have been done a long time ago.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','telepression, n.:<BR>\n&nbsp;The deep-seated guilt which stems from knowing that you did not try<BR>\n&nbsp;hard enough to look up the number on your own and instead put the<BR>\n&nbsp;burden on the directory assistant.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Marines:<BR>\n&nbsp;The few, the proud, the not very bright.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Official MBA Handbook on doing company business on an airplane:<BR>\n&nbsp;Do not work openly on top-secret company cost documents unless<BR>\n&nbsp;you have previously ascertained that the passenger next to you<BR>\n&nbsp;is blind, a rock musician on mood-ameliorating drugs, or the<BR>\n&nbsp;unfortunate possessor of a forty-seventh chromosome.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Underlying Principle of Socio-Genetics:<BR>\n&nbsp;Superiority is recessive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Sweater, n.:<BR>\n&nbsp;A garment worn by a child when its mother feels chilly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Official MBA Handbook on the use of sunlamps:<BR>\n&nbsp;Use a sunlamp only on weekends.  That way, if the office wise guy<BR>\n&nbsp;remarks on the sudden appearance of your tan, you can fabricate<BR>\n&nbsp;some story about a sun-stroked weekend at some island Shangri-La<BR>\n&nbsp;like Caneel Bay.  Nothing is more transparent than leaving the<BR>\n&nbsp;office at 11:45 on a Tuesday night, only to return an Aztec sun<BR>\n&nbsp;god at 8:15 the next morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Heineken Uncertainty Principle:<BR>\n&nbsp;You can never be sure how many beers you had last night.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','T-shirt:<BR>\n&nbsp;Life is *not* a Cabaret, and stop calling me chum!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Fifth Rule:<BR>\n&nbsp;You have taken yourself too seriously.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','volcano, n.:<BR>\n&nbsp;A mountain with hiccups.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Vanilla, adj.:<BR>\n&nbsp;Ordinary flavor, standard.  See FLAVOR.  When used of food,<BR>\n&nbsp;very often does not mean that the food is flavored with vanilla<BR>\n&nbsp;extract!  For example, \"vanilla-flavored won ton soup\" (or simply<BR>\n&nbsp;\"vanilla won ton soup\") means ordinary won ton soup, as opposed to hot<BR>\n&nbsp;and sour won ton soup.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','work, n.:<BR>\n&nbsp;The blessed respite from screaming kids and<BR>\n&nbsp;soap operas for which you actually get paid.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','User n.:<BR>\n&nbsp;A programmer who will believe anything you tell him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','union, n.:<BR>\n&nbsp;A dues-paying club workers wield to strike management.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','untold wealth, n.:<BR>\n&nbsp;What you left out on April 15th.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Universe, n.:<BR>\n&nbsp;The problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','user, n.:<BR>\n&nbsp;The word computer professionals use when they mean \"idiot.\"<BR>\n&nbsp;-- Dave Barry, \"Claw Your Way to the Top\"<BR>\n&nbsp;[I always thought \"computer professional\" was the phrase hackers used<BR>\n&nbsp;when they meant \"idiot.\"  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','understand, v.:<BR>\n&nbsp;To reach a point, in your investigation of some subject, at which<BR>\n&nbsp;you cease to examine what is really present, and operate on the<BR>\n&nbsp;basis of your own internal model instead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Unfair animal names:<BR>\n&nbsp;-- tsetse fly			-- bullhead<BR>\n-- booby			-- duck-billed platypus<BR>\n-- sapsucker			-- Clarence<BR>\n&nbsp;-- Gary Larson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','unfair competition, n.:<BR>\n&nbsp;Selling cheaper than we do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Unnamed Law:<BR>\n&nbsp;If it happens, it must be possible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','timesharing, n:<BR>\n&nbsp;An access method whereby one computer abuses many people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','theory, n.:<BR>\n&nbsp;System of ideas meant to explain something, chosen with a view to<BR>\n&nbsp;originality, controversialism, incomprehensibility, and how good<BR>\n&nbsp;it will look in print.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Three rules for sounding like an expert:<BR>\n&nbsp;(1) Oversimplify your explanations to the point of uselessness.<BR>\n&nbsp;(2) Always point out second-order effects, but never point out<BR>\n&nbsp;when they can be ignored.<BR>\n&nbsp;(3) Come up with three rules of your own.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','The Third Law of Photography:<BR>\n&nbsp;If you did manage to get any good shots, they will be ruined<BR>\n&nbsp;when someone inadvertently opens the darkroom door and all of<BR>\n&nbsp;the dark leaks out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Theorem: All positive integers are equal.<BR>\nProof: Sufficient to show that for any two positive integers, A and B, A = B.<BR>\n&nbsp;Further, it is sufficient to show that for all N > 0, if A and B<BR>\n&nbsp;(positive integers) satisfy (MAX(A, B) = N) then A = B.<BR>\n&nbsp;Proceed by induction:<BR>\n&nbsp;If N = 1, then A and B, being positive integers, must both be 1.<BR>\n&nbsp;So A = B.<BR>\n&nbsp;Assume that the theorem is true for some value k.  Take A and B with<BR>\n&nbsp;MAX(A, B) = k+1.  Then  MAX((A-1), (B-1)) = k.  And hence<BR>\n&nbsp;(A-1) = (B-1).  Consequently, A = B.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','vacation, n.:<BR>\n&nbsp;A two-week binge of rest and relaxation so intense that<BR>\n&nbsp;it takes another 50 weeks of your restrained workaday<BR>\n&nbsp;life-style to recuperate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','wok, n.:<BR>\n&nbsp;Something to thwow at a wabbit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','wolf, n.:<BR>\n&nbsp;A man who knows all the ankles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','\"Trust me\":<BR>\n&nbsp;Translation of the Latin \"caveat emptor.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','well-adjusted, adj.:<BR>\n&nbsp;The ability to play bridge or golf as if they were games.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','When asked the definition of \"pi\":<BR>\nThe Mathematician:<BR>\n&nbsp;Pi is the number expressing the relationship between the<BR>\n&nbsp;circumference of a circle and its diameter.<BR>\nThe Physicist:<BR>\n&nbsp;Pi is 3.1415927, plus or minus 0.000000005.<BR>\nThe Engineer:<BR>\n&nbsp;Pi is about 3.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Telephone, n.:<BR>\n&nbsp;An invention of the devil which abrogates some of the advantages<BR>\n&nbsp;of making a disagreeable person keep his distance.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','transfer, n.:<BR>\n&nbsp;A promotion you receive on the condition that you leave town.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Wedding, n:<BR>\n&nbsp;A ceremony at which two persons undertake to become one, one undertakes<BR>\n&nbsp;to become nothing and nothing undertakes to become supportable.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','weapon, n.:<BR>\n&nbsp;An index of the lack of development of a culture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','we:<BR>\n&nbsp;The single most important word in the world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Volley Theory:<BR>\n&nbsp;It is better to have lobbed and lost than never to have lobbed at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Historical Slumming:<BR>\n&nbsp;The act of visiting locations such as diners, smokestack<BR>\nindustrial sites, rural villages -- locations where time appears to<BR>\nhave been frozen many years back -- so as to experience relief when<BR>\none returns back to \"the present.\"<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','system-independent, adj.:<BR>\n&nbsp;Works equally poorly on all systems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Theorem: a cat has nine tails.<BR>\nProof:<BR>\n&nbsp;No cat has eight tails. A cat has one tail more than no cat.<BR>\n&nbsp;Therefore, a cat has nine tails.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Recurving:<BR>\n&nbsp;Leaving one job to take another that pays less but places one<BR>\nback on the learning curve.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','McJob:<BR>\n&nbsp;A low-pay, low-prestige, low-benefit, no-future job in the<BR>\nservice sector.  Frequently considered a satisfying career choice by<BR>\nthose who have never held one.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Theory of Selective Supervision:<BR>\n&nbsp;The one time in the day that you lean back and relax is<BR>\n&nbsp;the one time the boss walks through the office.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Historic Underdosing:<BR>\n&nbsp;To live in a period of time when nothing seems to happen.<BR>\nMajor symptoms include addiction to newspapers, magazines, and TV news<BR>\nbroadcasts.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','There are three ways to get something done:<BR>\n&nbsp;(1) Do it yourself.<BR>\n&nbsp;(2) Hire someone to do it for you.<BR>\n&nbsp;(3) Forbid your kids to do it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Historic Overdosing:<BR>\n&nbsp;To live in a period of time when too much seems to happen.<BR>\nMajor symptoms include addiction to newspapers, magazines, and TV news<BR>\nbroadcasts.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Worst Vegetable of the Year:<BR>\n&nbsp;The brussels sprout.  This is also the worst vegetable of next year.<BR>\n&nbsp;-- Steve Rubenstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Yinkel, n.:<BR>\n&nbsp;A person who combs his hair over his bald spot, hoping no one<BR>\n&nbsp;will notice.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Zero Defects, n.:<BR>\n&nbsp;The result of shutting down a production line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','WYSIWYG:<BR>\n&nbsp;What You See Is What You Get.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','TIPS FOR PERFORMERS:<BR>\n&nbsp;Playing cards have the top half upside-down to help cheaters.<BR>\n&nbsp;There are a finite number of jokes in the universe.<BR>\n&nbsp;Singing is a trick to get people to listen to music longer than<BR>\n&nbsp;they would ordinarily.<BR>\n&nbsp;There is no music in space.<BR>\n&nbsp;People will pay to watch people make sounds.<BR>\n&nbsp;Everything on stage should be larger than in real life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','XIIdigitation, n.:<BR>\n&nbsp;The practice of trying to determine the year a movie was made<BR>\n&nbsp;by deciphering the Roman numerals at the end of the credits.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','write-protect tab, n.:<BR>\n&nbsp;A small sticker created to cover the unsightly notch carelessly left<BR>\n&nbsp;by disk manufacturers.  The use of the tab creates an error message<BR>\n&nbsp;once in a while, but its aesthetic value far outweighs the momentary<BR>\n&nbsp;inconvenience.<BR>\n&nbsp;-- Robb Russon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Poverty Jet Set:<BR>\n&nbsp;A group of people given to chronic traveling at the expense of<BR>\nlong-term job stability or a permanent residence.  Tend to have doomed<BR>\nand extremely expensive phone-call relationships with people named<BR>\nSerge or Ilyana.  Tend to discuss frequent-flyer programs at parties.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Worst Month of 1981 for Downhill Skiing:<BR>\n&nbsp;August.  The lift lines are the shortest, though.<BR>\n&nbsp;-- Steve Rubenstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bleeding Ponytail:<BR>\n&nbsp;An elderly, sold-out baby boomer who pines for hippie or<BR>\npresellout days.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','yo-yo, n.:<BR>\n&nbsp;Something that is occasionally up but normally down.<BR>\n&nbsp;(see also Computer).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Woolsey-Swanson Rule:<BR>\n&nbsp;People would rather live with a problem they cannot<BR>\n&nbsp;solve rather than accept a solution they cannot understand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Work Rule: Leave of Absence (for an Operation):<BR>\n&nbsp;We are no longer allowing this practice.  We wish to discourage any<BR>\nthoughts that you may not need all of whatever you have, and you should not<BR>\nconsider having anything removed.  We hired you as you are, and to have<BR>\nanything removed would certainly make you less than we bargained for.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','sugar daddy, n.:<BR>\n&nbsp;A man who can afford to raise cain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','18th Rule of Friendship:<BR>\n&nbsp;A friend will let you hold the ladder while he goes up on the roof<BR>\n&nbsp;to install your new aerial, which is the biggest son-of-a-bitch you<BR>\n&nbsp;ever saw.<BR>\n&nbsp;-- Esquire, May 1977');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','A Law of Computer Programming:<BR>\n&nbsp;Make it possible for programmers to write in English<BR>\n&nbsp;and you will find that programmers cannot write in English.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','broad-mindedness, n:<BR>\n&nbsp;The result of flattening high-mindedness out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Power Mist:<BR>\n&nbsp;The tendency of hierarchies in office environments to be diffuse<BR>\nand preclude crisp articulation.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','667:<BR>\n&nbsp;The neighbor of the beast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','17th Rule of Friendship:<BR>\n&nbsp;A friend will refrain from telling you he picked up the same amount of<BR>\n&nbsp;life insurance coverage you did for half the price when yours is<BR>\n&nbsp;noncancellable.<BR>\n&nbsp;-- Esquire, May 1977');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Strategy:<BR>\n&nbsp;A long-range plan whose merit cannot be evaluated until sometime<BR>\n&nbsp;after those creating it have left the organization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Consensus Terrorism:<BR>\n&nbsp;The process that decides in-office attitudes and behavior.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Sick Building Migration:<BR>\n&nbsp;The tendency of younger workers to leave or avoid jobs in<BR>\nunhealthy office environments or workplaces affected by the Sick<BR>\nBuilding Syndrome.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Decade Blending:<BR>\n&nbsp;In clothing: the indiscriminate combination of two or more<BR>\nitems from various decades to create a personal mood: Sheila =<BR>\nMary Quant earrings (1960s) + cork wedgie platform shows (1970s) +<BR>\nblack leather jacket (1950s and 1980s).<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Veal-Fattening Pen:<BR>\n&nbsp;Small, cramped office workstations built of<BR>\nfabric-covered disassemblable wall partitions and inhabited by junior<BR>\nstaff members.  Named after the small preslaughter cubicles used by<BR>\nthe cattle industry.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Boomer Envy:<BR>\n&nbsp;Envy of material wealth and long-range material security<BR>\naccrued by older members of the baby boom generation by virtue of<BR>\nfortunate births.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Emotional Ketchup Burst:<BR>\n&nbsp;The bottling up of opinions and emotions inside oneself so<BR>\nthat they explosively burst forth all at once, shocking and confusing<BR>\nemployers and friends -- most of whom thought things were fine.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Brazilification:<BR>\n&nbsp;The widening gulf between the rich and the poor and the<BR>\naccompanying disappearance of the middle classes.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Vaccinated Time Travel:<BR>\n&nbsp;To fantasize about traveling backward in time, but only<BR>\nwith proper vaccinations.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','T-shirt of the Day:<BR>\n&nbsp;Head for the Mountains<BR>\n&nbsp;-- courtesy Anheuser-Busch beer<BR>\n&nbsp;Followup T-shirt of the Day (on the same scenic background):<BR>\n&nbsp;If you liked the mountains, head for the Busch!<BR>\n&nbsp;-- courtesy someone else');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','ADA:<BR>\n&nbsp;Something you need only know the name of to be an Expert in<BR>\n&nbsp;Computing.  Useful in sentences like, \"We had better develop<BR>\n&nbsp;an ADA awareness.<BR>\n&nbsp;-- \"Datamation\", January 15, 1984');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bambification:<BR>\n&nbsp;The mental conversion of flesh and blood living creatures into<BR>\ncartoon characters possessing bourgeois Judeo-Christian attitudes and<BR>\nmorals.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Accuracy, n.:<BR>\n&nbsp;The vice of being right');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Now Denial:<BR>\n&nbsp;To tell oneself that the only time worth living in is the past and<BR>\nthat the only time that may ever be interesting again is the future.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Academy:<BR>\n&nbsp;A modern school where football is taught.<BR>\nInstitute:<BR>\n&nbsp;An archaic school where football is not taught.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Accident, n.:<BR>\n&nbsp;A condition in which presence of mind is good, but absence of<BR>\n&nbsp;body is better.<BR>\n&nbsp;-- Foolish Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','squatcho, n.:<BR>\n&nbsp;The button at the top of a baseball cap.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Accordion, n.:<BR>\n&nbsp;A bagpipe with pleats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Anti-Sabbatical:<BR>\n&nbsp;A job taken with the sole intention of staying only for a<BR>\nlimited period of time (often one year).  The intention is usually to<BR>\nraise enough funds to partake in another, more meaningful activity<BR>\nsuch as watercolor sketching in Crete, or designing computer knit<BR>\nsweaters in Hong Kong.  Employers are rarely informed of intentions.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Absent, adj.:<BR>\n&nbsp;Exposed to the attacks of friends and acquaintances; defamed; slandered.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','statistics, n.:<BR>\n&nbsp;A system for expressing your political prejudices in convincing<BR>\n&nbsp;scientific guise.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Acceptance testing:<BR>\n&nbsp;An unsuccessful attempt to find bugs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','job Placement, n.:<BR>\n&nbsp;Telling your boss what he can do with your job.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','job interview, n.:<BR>\n&nbsp;The excruciating process during which personnel officers<BR>\n&nbsp;separate the wheat from the chaff -- then hire the chaff.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Machine-Independent, adj.:<BR>\n&nbsp;Does not run on any existing machine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','ISO applications:<BR>\n&nbsp;A solution in search of a problem!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Iron Law of Distribution:<BR>\n&nbsp;Them that has, gets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','love, n.:<BR>\n&nbsp;When you like to think of someone on days that begin with a morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','intoxicated, adj.:<BR>\n&nbsp;When you feel sophisticated without being able to pronounce it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','mophobia, n.:<BR>\n&nbsp;Fear of being verbally abused by a Mississippian.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Moon, n.:<BR>\n&nbsp;1. A celestial object whose phase is very important to hackers.  See <BR>\n&nbsp;PHASE OF THE MOON.  2. Dave Moon (MOON@MC).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Marxist Law of Distribution of Wealth:<BR>\n&nbsp;Shortages will be divided equally among the peasants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','MIPS:<BR>\n&nbsp;Meaningless Indicator of Processor Speed');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Minicomputer:<BR>\n&nbsp;A computer that can be afforded on the budget of a middle-level manager.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','micro:<BR>\n&nbsp;Thinker toys.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Micro Credo:<BR>\n&nbsp;Never trust a computer bigger than you can lift.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','manic-depressive, adj.:<BR>\n&nbsp;Easy glum, easy glow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','marriage, n.:<BR>\n&nbsp;An old, established institution, entered into by two people deeply<BR>\n&nbsp;in love and desiring to make a committment to each other expressing<BR>\n&nbsp;that love.  In short, committment to an institution.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','manual, n.:<BR>\n&nbsp;A unit of documentation.  There are always three or more on a given<BR>\n&nbsp;item.  One is on the shelf; someone has the others.  The information<BR>\n&nbsp;you need is in the others.<BR>\n&nbsp;-- Ray Simard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Marriage, n.:<BR>\n&nbsp;The evil aye.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','marriage, n.:<BR>\n&nbsp;Convertible bonds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','like:<BR>\n&nbsp;When being alive at the same time is a wonderful coincidence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','lighthouse, n.:<BR>\n&nbsp;A tall building on the seashore in which the government<BR>\n&nbsp;maintains a lamp and the friend of a politician.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Magnocartic, adj.:<BR>\n&nbsp;Any automobile that, when left unattended, attracts shopping carts.<BR>\n&nbsp;-- Sniglets, \"Rich Hall & Friends\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','malpractice, n.:<BR>\n&nbsp;The reason surgeons wear masks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','life, n.:<BR>\n&nbsp;That brief interlude between nothingness and eternity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Majority, n.:<BR>\n&nbsp;That quality that distinguishes a crime from a law.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Lie, n.:<BR>\n&nbsp;A very poor substitute for the truth, but the only one<BR>\n&nbsp;discovered to date.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','management, n.:<BR>\n&nbsp;The art of getting other people to do all the work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','lawsuit, n.:<BR>\n&nbsp;A machine which you go into as a pig and come out as a sausage.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Law of Continuity:<BR>\n&nbsp;Experiments should be reproducible.  They should all fail the same way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Performance:<BR>\n&nbsp;A statement of the speed at which a computer system works.  Or<BR>\n&nbsp;rather, might work under certain circumstances.  Or was rumored<BR>\n&nbsp;to be working over in Jersey about a month ago.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','mixed emotions:<BR>\n&nbsp;Watching your mother-in-law back off a cliff...<BR>\n&nbsp;in your brand new Mercedes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Patageometry, n.:<BR>\n&nbsp;The study of those mathematical properties that are invariant<BR>\n&nbsp;under brain transplants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','MIT:<BR>\n&nbsp;The Georgia Tech of the North');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Password:');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Pascal:<BR>\n&nbsp;A programming language named after a man who would turn over<BR>\n&nbsp;in his grave if he knew about it.<BR>\n&nbsp;-- Datamation, January 15, 1984');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','mittsquinter, adj.:<BR>\n&nbsp;A ballplayer who looks into his glove after missing the ball, as<BR>\n&nbsp;if, somehow, the cause of the error lies there.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Pascal Users:<BR>\n&nbsp;To show respect for the 313th anniversary (tomorrow) of the<BR>\n&nbsp;death of Blaise Pascal, your programs will be run at half speed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Pascal Users:<BR>\n&nbsp;The Pascal system will be replaced next Tuesday by Cobol.<BR>\n&nbsp;Please modify your programs accordingly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','memo, n.:<BR>\n&nbsp;An interoffice communication too often written more for the benefit<BR>\n&nbsp;of the person who sends it than the person who receives it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','millihelen, n.:<BR>\n&nbsp;The amount of beauty required to launch one ship.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','momentum, n.:<BR>\n&nbsp;What you give a person when they are going away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','paranoia, n.:<BR>\n&nbsp;A healthy understanding of the way the universe works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','meterologist, n.:<BR>\n&nbsp;One who doubts the established fact that it is<BR>\n&nbsp;bound to rain if you forget your umbrella.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Paprika Measure:<BR>\n&nbsp;2 dashes    ==  1smidgen<BR>\n&nbsp;2 smidgens  ==  1 pinch<BR>\n&nbsp;3 pinches   ==  1 soupcon<BR>\n&nbsp;2 soupcons  ==  2 much paprika');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Menu, n.:<BR>\n&nbsp;A list of dishes which the restaurant has just run out of.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Oregano, n.:<BR>\n&nbsp;The ancient Italian art of pizza folding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','optimist, n:<BR>\n&nbsp;A bagpiper with a beeper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','meeting, n.:<BR>\n&nbsp;An assembly of people coming together to decide what person or<BR>\n&nbsp;department not represented in the room must solve a problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','On-line, adj.:<BR>\n&nbsp;The idea that a human being should always be accessible to a computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','meetings, n.:<BR>\n&nbsp;A place where minutes are kept and hours are lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','On ability:<BR>\n&nbsp;A dwarf is small, even if he stands on a mountain top;<BR>\n&nbsp;a colossus keeps his height, even if he stands in a well.<BR>\n&nbsp;-- Lucius Annaeus Seneca, 4BC - 65AD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Old Japanese proverb:<BR>\n&nbsp;There are two kinds of fools -- those who never climb Mt. Fuji,<BR>\n&nbsp;and those who climb it twice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','mummy, n.:<BR>\n&nbsp;An Egyptian who was pressed for time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Like this rose, our love will wilt and die.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','no maintenance:<BR>\n&nbsp;Impossible to fix.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"Just how much can I get away with and still go to heaven?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"It was so cold last winter that I saw a lawyer with his<BR>\n&nbsp;hands in his own pockets.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','neutron bomb, n.:<BR>\n&nbsp;An explosive device of limited military value because, as<BR>\n&nbsp;it only destroys people without destroying property, it<BR>\n&nbsp;must be used in conjunction with bombs that destroy property.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Mustgo, n.:<BR>\n&nbsp;Any item of food that has been sitting in the refrigerator so<BR>\n&nbsp;long it has become a science project.<BR>\n&nbsp;-- Sniglets, \"Rich Hall & Friends\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','My father taught me three things:<BR>\n&nbsp;(1) Never mix whiskey with anything but water.<BR>\n&nbsp;(2) Never try to draw to an inside straight.<BR>\n&nbsp;(3) Never discuss business with anyone who refuses to give his name.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','narcolepulacyi, n.:<BR>\n&nbsp;The contagious action of yawning, causing everyone in sight<BR>\n&nbsp;to also yawn.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QOTD:<BR>\n&nbsp;\"I used to go to UCLA, but then my Dad got a job.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','perfect guest:<BR>\n&nbsp;One who makes his host feel at home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','new, adj.:<BR>\n&nbsp;Different color from previous model.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','A new koan:<BR>\n&nbsp;If you have some ice cream, I will give it to you.<BR>\n&nbsp;If you have no ice cream, I will take it away from you.<BR>\nIt is an ice cream koan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Spectacularism:<BR>\n&nbsp;A fascination with extreme situations.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','A musician, an artist, an architect:<BR>\n&nbsp;the man or woman who is not one of these is not a Christian.<BR>\n&nbsp;-- William Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','strategy, n.:<BR>\n&nbsp;A comprehensive plan of inaction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','3rd Law of Computing:<BR>\n&nbsp;Anything that can go wr<BR>\nfortune: Segmentation violation -- Core dumped');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','2180, U.S. History question:<BR>\n&nbsp;What 20th Century U.S. President was almost impeached and what<BR>\n&nbsp;office did he later hold?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Ultra Short Term Nostalgia:<BR>\n&nbsp;Homesickness for the extremely recent past: \"God, things seemed<BR>\nso much better in the world last week.\"<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Armanism:<BR>\n&nbsp;After Giorgio Armani; an obsession with mimicking the seamless<BR>\nand (more importantly) *controlled* ethos of Italian couture.  Like<BR>\nJapanese Minimalism, Armanism reflects a profound inner need for<BR>\ncontrol.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Musical Hairsplitting:<BR>\n&nbsp;The act of classifying music and musicians into pathologically<BR>\npicayune categories: \"The Vienna Franks are a good example of urban<BR>\nwhite acid fold revivalism crossed with ska.\"<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Poorochrondria:<BR>\n&nbsp;Hypochrondria derived from not having medical insurance.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','101-ism:<BR>\n&nbsp;The tendency to pick apart, often in minute detail, all<BR>\naspects of life using half-understood pop psychology as a tool.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Japanese Minimalism:<BR>\n&nbsp;The most frequently offered interior design aesthetic used by<BR>\nrootless career-hopping young people.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Personal Tabu:<BR>\n&nbsp;A small rule for living, bordering on a superstition, that<BR>\nallows one to cope with everyday life in the absence of cultural or<BR>\nreligious dictums.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Poor Buoyancy:<BR>\n&nbsp;The realization that one was a better person when one had less<BR>\nmoney.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Alaska:<BR>\n&nbsp;A prelude to \"No.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','algorithm, n.:<BR>\n&nbsp;Trendy dance for hip programmers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bread and Circuits:<BR>\n&nbsp;The electronic era tendency to view party politics as corny --<BR>\nno longer relevant of meaningful or useful to modern societal issues,<BR>\nand in many cases dangerous.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Mental Ground Zero:<BR>\n&nbsp;The location where one visualizes oneself during the dropping<BR>\nof the atomic bomb; frequently, a shopping mall.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cult of Aloneness:<BR>\n&nbsp;The need for autonomy at all costs, usually at the expense of<BR>\nlong-term relationships.  Often brought about by overly high<BR>\nexpectations of others.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Age, n.:<BR>\n&nbsp;That period of life in which we compound for the vices that we<BR>\n&nbsp;still cherish by reviling those that we no longer have the enterprise<BR>\n&nbsp;to commit.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Platonic Shadow:<BR>\n&nbsp;A nonsexual friendship with a member of the opposite sex.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Afternoon, n.:<BR>\n&nbsp;That part of the day we spend worrying about how we wasted the morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Slurm, n.:<BR>\n&nbsp;The slime that accumulates on the underside of a soap bar when<BR>\n&nbsp;it sits in the dish too long.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Advertising Rule:<BR>\n&nbsp;In writing a patent-medicine advertisement, first convince the<BR>\n&nbsp;reader that he has the disease he is reading about; secondly, <BR>\n&nbsp;that it is curable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Architectural Indigestion:<BR>\n&nbsp;The almost obsessive need to live in a \"cool\"<BR>\narchitectural environment.  Frequently related objects of fetish<BR>\ninclude framed black-and-white art photography (Diane Arbus a<BR>\nfavorite); simplistic pine furniture; matte black high-tech items such<BR>\nas TVs, stereos, and telephones; low-wattage ambient lighting; a lamp,<BR>\nchair, or table that alludes to the 1950s; cut flowers with complex<BR>\nnames.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Adult, n.:<BR>\n&nbsp;One old enough to know better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Yuppie Wannabes:<BR>\n&nbsp;An X generation subgroup that believes the myth of a yuppie<BR>\nlife-style being both satisfying and viable.  Tend to be highly in<BR>\ndebt, involved in some form of substance abuse, and show a willingness<BR>\nto talk about Armageddon after three drinks.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Air Force Inertia Axiom:<BR>\n&nbsp;Consistency is always easier to defend than correctness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Software, n.:<BR>\n&nbsp;Formal evening attire for female computer analysts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Diseases for Kisses (Hyperkarma):<BR>\n&nbsp;A deeply rooted belief that punishment will somehow always be<BR>\nfar greater than the crime: ozone holes for littering.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Auction:<BR>\n&nbsp;A gyp off the old block.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Schlattwhapper, n.:<BR>\n&nbsp;The window shade that allows itself to be pulled down,<BR>\n&nbsp;hesitates for a second, then snaps up in your face.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','audophile, n:<BR>\n&nbsp;Someone who listens to the equipment instead of the music.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Black Holes:<BR>\n&nbsp;An X generation subgroup best known for their possession of<BR>\nalmost entirely black wardrobes.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Squirming:<BR>\n&nbsp;Discomfort inflicted on young people by old people who see no<BR>\nirony in their gestures.  \"Karen died a thousand deaths as her father<BR>\nmade a big show of tasting a recently manufactured bottle of wine<BR>\nbefore allowing it to be poured as the family sat in Steak Hut.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Applause, n:<BR>\n&nbsp;The echo of a platitude from the mouth of a fool.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Androphobia:<BR>\n&nbsp;Fear of men.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Appendix:<BR>\n&nbsp;A portion of a book, for which nobody yet has discovered any use.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Aphasia:<BR>\n&nbsp;Loss of speech in social scientists when asked<BR>\n&nbsp;at parties, \"But of what use is your research?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Conversational Slumming:<BR>\n&nbsp;The self-conscious enjoyment of a given conversation<BR>\nprecisely for its lack of intellectual rigor.  A major spin-off<BR>\nactivity of Recreational Slumming.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Air Family:<BR>\n&nbsp;Describes the false sense of community experienced among coworkers<BR>\nin an office environment.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Conspicuous Minimalism:<BR>\n&nbsp;A life-style tactic similar to Status Substitution.  The<BR>\nnonownership of material goods flaunted as a token of moral and<BR>\nintellectual superiority.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','alimony, n:<BR>\n&nbsp;Having an ex you can bank on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Arbitrary systems, pl.n.:<BR>\n&nbsp;Systems about which nothing general can be said, save \"nothing<BR>\n&nbsp;general can be said.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','All new:<BR>\n&nbsp;Parts not interchangeable with previous model.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Celebrity Schadenfreude:<BR>\n&nbsp;Lurid thrills derived from talking about celebrity deaths.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Squires:<BR>\n&nbsp;The most common X generation subgroup and the only subgroup<BR>\ngiven to breeding.  Squires exist almost exclusively in couples and<BR>\nare recognizable by their frantic attempts to create a semblance of<BR>\nEisenhower-era plenitude in their daily lives in the face of<BR>\nexorbitant housing prices and two-job life-styles.  Squires tend to be<BR>\ncontinually exhausted from their voraciously acquisitive pursuit of<BR>\nfurniture and knickknacks.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','quark:<BR>\n&nbsp;The sound made by a well bred duck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Banectomy, n.:<BR>\n&nbsp;The removal of bruises on a banana.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Me-ism:<BR>\n&nbsp;A search by an individual, in the absence of training in<BR>\ntraditional religious tenets, to formulate a personally tailored<BR>\nreligion by himself.  Most frequently a mishmash of reincarnation,<BR>\npersonal dialogue with a nebulously defined god figure, naturalism,<BR>\nand karmic eye-for-eye attitudes.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Paper Rabies:<BR>\n&nbsp;Hypersensitivity to littering.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bachelor:<BR>\n&nbsp;A guy who is footloose and fiancee-free.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bradyism:<BR>\n&nbsp;A multisibling sensibility derived from having grown up in<BR>\nlarge families.  A rarity in those born after approximately 1965,<BR>\nsymptoms of Bradyism include a facility for mind games, emotional<BR>\nwithdrawal in situations of overcrowding, and a deeply felt need for a<BR>\nwell-defined personal space.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','QFD:<BR>\n&nbsp;Quelle fucking drag.  \"Jamie got stuck at Rome airport for<BR>\nthirty-six hours and it was, like, totally QFD.\"<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Anti-Victim Device:<BR>\n&nbsp;A small fashion accessory worn on an otherwise<BR>\nconservative outfit which announces to the world that one still has a<BR>\nspark of individuality burning inside: 1940s retro ties and earrings<BR>\n(on men), feminist buttons, noserings (women), and the now almost<BR>\ncompletely extinct teeny weeny \"rattail\" haircut (both sexes).<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Nutritional Slumming:<BR>\n&nbsp;Food whose enjoyment stems not from flavor but from a<BR>\ncomplex mixture of class connotations, nostalgia signals, and<BR>\npackaging semiotics: Katie and I bought this tub of Multi-Whip instead<BR>\nof real whip cream because we thought petroleum distillate whip<BR>\ntopping seemed like the sort of food that air force wives stationed in<BR>\nPensacola back in the early sixties would feed their husbands to<BR>\ncelebrate a career promotion.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Automobile, n.:<BR>\n&nbsp;A four-wheeled vehicle that runs up hills and down pedestrians.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bachelor:<BR>\n&nbsp;A man who chases women and never Mrs. one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Second Law of Final Exams:<BR>\n&nbsp;In your toughest final -- for the first time all year -- the most<BR>\n&nbsp;distractingly attractive student in the class will sit next to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bizoos, n.:<BR>\n&nbsp;The millions of tiny individual bumps that make up a basketball.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','bit, n:<BR>\n&nbsp;A unit of measure applied to color.  Twenty-four-bit color<BR>\n&nbsp;refers to expensive $3 color as opposed to the cheaper 25<BR>\n&nbsp;cent, or two-bit, color that use to be available a few years ago.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bipolar, adj.:<BR>\n&nbsp;Refers to someone who has homes in Nome, Alaska, and Buffalo, New York.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','belief, n:<BR>\n&nbsp;Something you do not believe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Binary, adj.:<BR>\n&nbsp;Possessing the ability to have friends of both sexes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Pull-the-Plug, Slice the Pie:<BR>\n&nbsp;A fantasy in which an offspring mentally tallies up the<BR>\nnet worth of his parents.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Option Paralysis:<BR>\n&nbsp;The tendency, when given unlimited choices, to make none.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Jack-and-Jill Party:<BR>\n&nbsp;A Squire tradition; baby showers to which both men and<BR>\nwomen friends are invited as opposed to only women.  Doubled<BR>\npurchasing power of bisexual attendance brings gift values up to<BR>\nEisenhower-era standards.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bathquake, n.:<BR>\n&nbsp;The violent quake that rattles the entire house when the water<BR>\n&nbsp;faucet is turned on to a certain point.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Down-Nesting:<BR>\n&nbsp;The tendency of parents to move to smaller, guest-room-free<BR>\nhouses after the children have moved away so as to avoid children aged<BR>\n20 to 30 who have boomeranged home.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Quality Control, n.:<BR>\n&nbsp;The process of testing one out of every 1,000 units coming off<BR>\n&nbsp;a production line to make sure that at least one out of 100 works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Battle, n.:<BR>\n&nbsp;A method of untying with the teeth a political knot that<BR>\n&nbsp;will not yield to the tongue.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Beauty, n.:<BR>\n&nbsp;The power by which a woman charms a lover and terrifies a husband.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Strangelove Reproduction:<BR>\n&nbsp;Having children to make up for the fact that one no longer<BR>\nbelieves in the future.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','BASIC, n.:<BR>\n&nbsp;A programming language.  Related to certain social diseases in<BR>\n&nbsp;that those who have it will not admit it in polite company.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Underdogging:<BR>\n&nbsp;The tendency to almost invariably side with the underdog in a<BR>\ngiven situation.  The consumer expression of this trait is the<BR>\npurchasing of less successful, \"sad,\" or failing products: \"I know<BR>\nthese Vienna franks are heart failure on a stick, but they were so sad<BR>\nlooking up against all the other yuppie food items that I just had to<BR>\nbuy them.\"<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Black Dens:<BR>\n&nbsp;Where Black Holes live; often unheated warehouses with Day-Glo<BR>\nspray painting, mutilated mannequins, Elvis references, dozens of<BR>\noverflowing ashtrays, mirror sculptures, and Velvet Underground music<BR>\nplaying in background.<BR>\n&nbsp;-- Douglas Coupland, \"Generation X: Tales for an Accelerated<BR>\n&nbsp;Culture\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Chemicals, n.:<BR>\n&nbsp;Noxious substances from which modern foods are made.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cat, n.:<BR>\n&nbsp;Lapwarmer with built-in buzzer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cache:<BR>\n&nbsp;A very expensive part of the memory system of a computer that no one<BR>\n&nbsp;is supposed to know is there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','buzzword, n:<BR>\n&nbsp;The fly in the ointment of computer literacy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','byob, v:<BR>\n&nbsp;Believing Your Own Bull');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','bug, n:<BR>\n&nbsp;A son of a glitch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Burbulation:<BR>\n&nbsp;The obsessive act of opening and closing a refrigerator door in<BR>\n&nbsp;an attempt to catch it before the automatic light comes on.<BR>\n&nbsp;-- \"Sniglets\", Rich Hall & Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Consent decree:<BR>\n&nbsp;A document in which a hapless company consents never to commit<BR>\n&nbsp;in the future whatever heinous violations of Federal law it<BR>\n&nbsp;never admitted to in the first place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bumper sticker:<BR>\n&nbsp;All the parts falling off this car are of the very finest<BR>\n&nbsp;British manufacture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','bug, n:<BR>\n&nbsp;An elusive creature living in a program that makes it incorrect.<BR>\n&nbsp;The activity of \"debugging\", or removing bugs from a program, ends<BR>\n&nbsp;when people get tired of doing it, not when the bugs are removed.<BR>\n&nbsp;-- \"Datamation\", January 15, 1984');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bugs, pl. n.:<BR>\n&nbsp;Small living things that small living boys throw on small living girls.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bureau Termination, Law of:<BR>\n&nbsp;When a government bureau is scheduled to be phased out,<BR>\n&nbsp;the number of employees in that bureau will double within<BR>\n&nbsp;12 months after the decision is made.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bug, n.:<BR>\n&nbsp;An aspect of a computer program which exists because the<BR>\n&nbsp;programmer was thinking about Jumbo Jacks or stock options when s/he<BR>\n&nbsp;wrote the program.<BR>\n&nbsp;Fortunately, the second-to-last bug has just been fixed.<BR>\n&nbsp;-- Ray Simard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Brontosaurus Principle:<BR>\n&nbsp;Organizations can grow faster than their brains can manage them<BR>\n&nbsp;in relation to their environment and to their own physiology:  when<BR>\n&nbsp;this occurs, they are an endangered species.<BR>\n&nbsp;-- Thomas K. Connellan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','brokee, n:<BR>\n&nbsp;Someone who buys stocks on the advice of a broker.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','brain-damaged, generalization of \"Honeywell Brain Damage\" (HBD), a<BR>\ntheoretical disease invented to explain certain utter cretinisms in<BR>\nMultics, adj:<BR>\n&nbsp;Obviously wrong; cretinous; demented.  There is an implication<BR>\n&nbsp;that the person responsible must have suffered brain damage,<BR>\n&nbsp;because he/she should have known better.  Calling something<BR>\n&nbsp;brain-damaged is bad; it also implies it is unusable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','briefcase, n:<BR>\n&nbsp;A trial where the jury gets together and forms a lynching party.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','boy, n:<BR>\n&nbsp;A noise with dirt on it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','boss, n:<BR>\n&nbsp;According to the Oxford English Dictionary, in the Middle Ages the<BR>\n&nbsp;words \"boss\" and \"botch\" were largely synonymous, except that boss,<BR>\n&nbsp;in addition to meaning \"a supervisor of workers\" also meant \"an<BR>\n&nbsp;ornamental stud.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','College:<BR>\n&nbsp;The fountains of knowledge, where everyone goes to drink.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cold, adj.:<BR>\n&nbsp;When the politicians walk around with their hands in their own pockets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','COBOL:<BR>\n&nbsp;Completely Over and Beyond reason Or Logic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Collaboration, n.:<BR>\n&nbsp;A literary partnership based on the false assumption that the<BR>\n&nbsp;other fellow can spell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','COBOL:<BR>\n&nbsp;An exercise in Artificial Inelegance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Cinemuck, n.:<BR>\n&nbsp;The combination of popcorn, soda, and melted chocolate which<BR>\n&nbsp;covers the floors of movie theaters.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','clone, n:<BR>\n&nbsp;1. An exact duplicate, as in \"our product is a clone of their<BR>\n&nbsp;product.\"  2. A shoddy, spurious copy, as in \"their product<BR>\n&nbsp;is a clone of our product.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','aquadextrous, adj.:<BR>\n&nbsp;Possessing the ability to turn the bathtub faucet on and off<BR>\n&nbsp;with your toes.<BR>\n&nbsp;-- Rich Hall, \"Sniglets\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','character density, n.:<BR>\n&nbsp;The number of very weird people in the office.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Christmas:<BR>\n&nbsp;A day set apart by some as a time for turkey, presents, cranberry <BR>\n&nbsp;salads, family get-togethers; for others, noted as having the best<BR>\n&nbsp;response time of the entire year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Chef, n.:<BR>\n&nbsp;Any cook who swears in French.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Charity, n.:<BR>\n&nbsp;A thing that begins at home and usually stays there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Confirmed bachelor:<BR>\n&nbsp;A man who goes through life without a hitch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Concept, n.:<BR>\n&nbsp;Any \"idea\" for which an outside consultant billed you more than<BR>\n&nbsp;$25,000.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Computer, n.:<BR>\n&nbsp;An electronic entity which performs sequences of useful steps in a<BR>\n&nbsp;totally understandable, rigorously logical manner.  If you believe<BR>\n&nbsp;this, see me about a bridge I have for sale in Manhattan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','bureaucracy, n:<BR>\n&nbsp;A method for transforming energy into solid waste.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','compuberty, n:<BR>\n&nbsp;The uncomfortable period of emotional and hormonal changes a<BR>\n&nbsp;computer experiences when the operating system is upgraded and<BR>\n&nbsp;a sun4 is put online sharing files.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Computer science:<BR>\n&nbsp;(1) A study akin to numerology and astrology, but lacking the<BR>\n&nbsp;precision of the former and the success of the latter.<BR>\n&nbsp;(2) The protracted value analysis of algorithms.<BR>\n&nbsp;(3) The costly enumeration of the obvious.<BR>\n&nbsp;(4) The boring art of coping with a large number of trivialities.<BR>\n&nbsp;(5) Tautology harnessed in the service of Man at the speed of light.<BR>\n&nbsp;(6) The Post-Turing decline in formal systems theory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Complex system:<BR>\n&nbsp;One with real problems and imaginary profits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Bureaucrat, n.:<BR>\n&nbsp;A person who cuts red tape sideways.<BR>\n&nbsp;-- J. McCabe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Committee, n.:<BR>\n&nbsp;A group of men who individually can do nothing but as a group<BR>\n&nbsp;decide that nothing can be done.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','bureaucrat, n:<BR>\n&nbsp;A politician who has tenure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Command, n.:<BR>\n&nbsp;Statement presented by a human and accepted by a computer in<BR>\n&nbsp;such a manner as to make the human feel as if he is in control.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Commitment, n.:<BR>\n&nbsp;[The difference between involvement and] Commitment can be<BR>\n&nbsp;illustrated by a breakfast of ham and eggs.  The chicken was<BR>\n&nbsp;involved, the pig was committed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('definitions','Sushido, n.:<BR>\n&nbsp;The way of the tuna.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Work is the curse of the drinking classes.<BR>\n&nbsp;-- Mike Romanoff');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','When I heated my home with oil, I used an average of 800 gallons a year.  I<BR>\nhave found that I can keep comfortably warm for an entire winter with<BR>\nslightly over half that quantity of beer.<BR>\n&nbsp;-- Dave Barry, \"Postpetroleum Guzzler\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','What scoundrel stole the cork from my lunch?<BR>\n&nbsp;-- J.D. Farley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Vermouth always makes me brilliant unless it makes me idiotic.<BR>\n&nbsp;-- E.F. Benson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Toothpaste never hurts the taste of good scotch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Too ripped.  Gotta go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','To one large turkey add one gallon of vermouth and a demijohn of Angostura<BR>\nbitters.  Shake.<BR>\n&nbsp;-- F. Scott Fitzgerald, recipe for turkey cocktail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','There will always be beer cans rolling on the floor of your car when<BR>\nthe boss asks for a lift home from the office.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','There is nothing wrong with abstinence, in moderation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','There are only two kinds of tequila.  Good and better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','\"The whole world is about three drinks behind.\"<BR>\n&nbsp;-- Humphrey Bogart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The water was not fit to drink.  To make it palatable, we had to add whiskey.<BR>\nBy diligent effort, I learned to like it.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I have to think hard to name an interesting man who does not drink.<BR>\n&nbsp;-- Richard Burton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I gave up Smoking, Drinking and Sex.  It was the most *__________horrifying* 20<BR>\nminutes of my life!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I drink to make other people interesting.<BR>\n&nbsp;-- George Jean Nathan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Excellent day for drinking heavily.  Spike the office water cooler.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Drunks are rarely amusing unless they know some good songs and lose a<BR>\nlot a poker.<BR>\n&nbsp;-- Karyl Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Drinking is not a spectator sport.<BR>\n&nbsp;-- Jim Brosnan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Drink Somewhere Dry!  You might not succeed, but it *__is* fun trying.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Brandy-and-water spoils two good things.<BR>\n&nbsp;-- Charles Lamb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Come quickly, I am tasting stars!<BR>\n&nbsp;-- Dom Perignon, upon discovering champagne.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Beer & Pretzels -- Breakfast of Champions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Fishing, with me, has always been an excuse to drink in the daytime.<BR>\n&nbsp;-- Jimmy Cannon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Because the wine remembers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','1/2 oz. gin<BR>\n1/2 oz. vodka<BR>\n1/2 oz. rum (preferably dark)<BR>\n3/4 oz. tequilla<BR>\n1/2 oz. triple sec<BR>\n1/2 oz. orange juice<BR>\n3/4 oz. sour mix<BR>\n1/2 oz. cola<BR>\nshake with ice and strain into frosted glass.<BR>\n&nbsp;Long Island Iced Tea');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','A beer delayed is a beer denied.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Be wary of strong drink.  It can make you shoot at tax collectors and miss.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Alcohol, hashish, prussic acid, strychnine are weak dilutions. The surest<BR>\npoison is time.<BR>\n&nbsp;-- Emerson, \"Society and Solitude\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Glogg (a traditional Scandinavian holiday drink):<BR>\n&nbsp;fifth of dry red wine<BR>\n&nbsp;fifth of Aquavit<BR>\n&nbsp;1 and 1/2 inch piece of cinnamon<BR>\n&nbsp;10 cardamom seeds<BR>\n&nbsp;1 cup raisins<BR>\n&nbsp;4 dried figs<BR>\n&nbsp;1 cup blanched or flaked almonds<BR>\n&nbsp;a few pieces of dried orange peel<BR>\n&nbsp;5 cloves<BR>\n&nbsp;1/2 lb. sugar cubes<BR>\n&nbsp;Heat up the wine and hard stuff (which may be substituted with wine<BR>\nfor the faint of heart) in a big pot after adding all the other stuff EXCEPT<BR>\nthe sugar cubes.  Just when it reaches boiling, put the sugar in a wire<BR>\nstrainer, moisten it in the hot brew, lift it out and ignite it with a match.<BR>\nDip the sugar several times in the liquid until it is all dissolved.  Serve<BR>\nhot in cups with a few raisins and almonds in each cup.<BR>\n&nbsp;N.B. Aquavit may be hard to find and expensive to boot.  Use it only<BR>\nif you really have a deep-seated desire to be fussy, or if you are of Swedish<BR>\nextraction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Claret is the liquor for boys; port for men; but he who aspires to be a hero<BR>\n... must drink brandy.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Said the attractive, cigar-smoking housewife to her girl-friend: \"I got<BR>\nstarted one night when George came home and found one burning in the ashtray.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Always store beer in a dark place.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','In vino veritas.<BR>\n&nbsp;[In wine there is truth.]<BR>\n&nbsp;-- Pliny');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Every morning is a Smirnoff morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Beggar to well-dressed businessman:<BR>\n&nbsp;\"Could you spare $20.95 for a fifth of Chivas?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Kiss a non-smoker; taste the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','My mother drinks to forget she drinks.<BR>\n&nbsp;-- Crazy Jimmy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','My uncle was the town drunk -- and we lived in Chicago.<BR>\n&nbsp;-- George Gobel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Never drink from your finger bowl -- it contains only water.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Keep America beautiful.  Swallow your beer cans.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','If God had intended Man to Smoke, He would have set him on Fire.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','In 1967, the Soviet Government minted a beautiful silver ruble with Lenin<BR>\nin a very familiar pose -- arms raised above him, leading the country to<BR>\nrevolution.  But, it was clear to everybody, that if you looked at it from<BR>\nbehind, it was clear that Lenin was pointing to 11:00, when the Vodka<BR>\nshops opened, and was actually saying, \"Comrades, forward to the Vodka shops.<BR>\n&nbsp;It became fashionable, when one wanted to have a drink, to take out the<BR>\nruble and say, \"Oh my goodness, Comrades, Lenin tells me we should go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','If God had intended Men to Smoke, He would have put Chimneys in their Heads.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I will not drink!<BR>\nBut if I do...<BR>\nI will not get drunk!<BR>\nBut if I do...<BR>\nI will not in public!<BR>\nBut if I do...<BR>\nI will not fall down!<BR>\nBut if I do...<BR>\nI will fall face down so that they cannot see my company badge.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','If I knew what brand [of whiskey] he drinks, I would send a barrel or<BR>\nso to my other generals.<BR>\n&nbsp;-- Abraham Lincoln, on General Grant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','A guy walks into a bar, orders a beer, carries it to the bathroom and dumps it<BR>\ninto a urinal.  Over the course of the next few hours, he goes back to the bar<BR>\nand repeats this sequence -- several times.  Finally the bartender got so<BR>\ncurious that he leaned over the bar and asked him what he was doing.<BR>\n&nbsp;Replied the customer, \"Avoiding the middleman.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','6 oz. orange juice<BR>\n1 oz. vodka<BR>\n1/2 oz. Galliano<BR>\n&nbsp;Harvey Wallbangers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Alcohol is the anesthesia by which we endure the operation of life.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I have just had eighteen whiskeys in a row.  I do believe that is a record.<BR>\n&nbsp;-- Dylan Thomas, his last words');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','It has been said that Public Relations is the art of winning friends<BR>\nand getting people under the influence.<BR>\n&nbsp;-- Jeremy Tunstall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Absinthe makes the tart grow fonder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','He knew the tavernes well in every toun.<BR>\n&nbsp;-- Geoffrey Chaucer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Having a wonderful wine, wish you were beer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','\"Hey!  Who took the cork off my lunch??!\"<BR>\n&nbsp;-- W. C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Only Irish coffee provides in a single glass all four essential food groups --<BR>\nalcohol, caffeine, sugar, and fat.<BR>\n&nbsp;-- Alex Levine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','One difference between a man and a machine is that a machine is quiet<BR>\nwhen well oiled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Old Grandad is dead but his spirits live on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Once ... in the wilds of Afghanistan, I lost my corkscrew, and we were<BR>\nforced to live on nothing but food and water for days.<BR>\n&nbsp;-- W. C. Fields, \"My Little Chickadee\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Now is the time for drinking; now the time to beat the earth with<BR>\nunfettered foot.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','NOTICE:<BR>\n&nbsp;Anyone seen smoking will be assumed to be on fire and will<BR>\n&nbsp;be summarily put out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Life, like beer, is merely borrowed.<BR>\n&nbsp;-- Don Reed');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Kissing a smoker is like licking an ashtray.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Never delay the ending of a meeting or the beginning of a cocktail hour.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I must get out of these wet clothes and into a dry Martini.<BR>\n&nbsp;-- Alexander Woolcott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I wish you were a Scotch on the rocks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Symptom:		Feet cold and wet, glass empty.<BR>\nFault:			Glass being held at incorrect angle.<BR>\nAction Required:	Turn glass other way up so that open end points<BR>\n&nbsp;toward ceiling.<BR>\n&nbsp;Symptom:		Feet warm and wet.<BR>\nFault:			Improper bladder control.<BR>\nAction Required:	Go stand next to nearest dog.  After a while complain<BR>\n&nbsp;to the owner about its lack of house training and<BR>\n&nbsp;demand a beer as compensation.<BR>\n&nbsp;-- Bar Troubleshooting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Symptom:		Everything has gone dark.<BR>\nFault:			The Bar is closing.<BR>\nAction Required:	Panic.<BR>\n&nbsp;Symptom:		You awaken to find your bed hard, cold and wet.<BR>\n&nbsp;You cannot see the bathroom light.<BR>\nFault:			You have spent the night in the gutter.<BR>\nAction Required:	Check your watch to see if bars are open yet.  If not,<BR>\n&nbsp;treat yourself to a lie-in.<BR>\n&nbsp;-- Bar Troubleshooting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Show respect for age.  Drink good Scotch for a change.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I used to have a drinking problem.  Now I love the stuff.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Symptom:		Drinking fails to give taste and satisfaction, beer is<BR>\n&nbsp;unusually pale and clear.<BR>\nProblem:		Glass empty.<BR>\nAction Required:	Find someone who will buy you another beer.<BR>\n&nbsp;Symptom:		Drinking fails to give taste and satisfaction,<BR>\n&nbsp;and the front of your shirt is wet.<BR>\nFault:			Mouth not open when drinking or glass applied to<BR>\n&nbsp;wrong part of face.<BR>\nAction Required:	Buy another beer and practice in front of mirror.<BR>\n&nbsp;Drink as many as needed to perfect drinking technique.<BR>\n&nbsp;-- Bar Troubleshooting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Smoking Prohibited.  Absolutely no ifs, ands, or butts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','So, is the glass half empty, half full, or just twice as<BR>\nlarge as it needs to be?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','SMOKING IS NOW ALLOWED !!!<BR>\n&nbsp;Anyone wishing to smoke, however, must file, in triplicate, the<BR>\n&nbsp;U.S. government Environmental Impact Narrative Statement (EINS),<BR>\n&nbsp;describing in detail the type of combustion proposed, impact on<BR>\n&nbsp;the environment, and anticipated opposition.  Statements must be<BR>\n&nbsp;filed 30 days in advance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Smoking is one of the leading causes of statistics.<BR>\n&nbsp;-- Fletcher Knebel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Sleep -- the most beautiful experience in life -- except drink.<BR>\n&nbsp;-- W.C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Romance, like alcohol, should be enjoyed, but should not be allowed to<BR>\nbecome necessary.<BR>\n&nbsp;-- Edgar Friedenberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','&nbsp;Split		1/4 bottle	.187 liters<BR>\n&nbsp;Half		1/2 bottle<BR>\n&nbsp;Bottle		750 milliliters<BR>\n&nbsp;Magnum		2 bottles	1.5 liters<BR>\n&nbsp;Jeroboam	4 bottles<BR>\n&nbsp;Rehoboam	6 bottles	Not available in the US<BR>\n&nbsp;Methuselah	8 bottles<BR>\n&nbsp;Salmanazar	12 bottles<BR>\n&nbsp;Balthazar	16 bottles<BR>\n&nbsp;Nebuchadnezzar	20 bottles	15 liters<BR>\n&nbsp;Sovereign	34 bottles	26 liters<BR>\n&nbsp;The Sovereign is a new bottle, made for the launching of the<BR>\nlargest cruise ship in the world.  The bottle alone cost 8,000 dollars<BR>\nto produce and they only made 8 of them.<BR>\n&nbsp;Most of the funny names come from Biblical people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I never take work home with me; I always leave it in some bar along the way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Two friends were out drinking when suddenly one lurched backward off his <BR>\nbarstool and lay motionless on the floor.<BR>\n&nbsp;\"One thing about Jim,\" the other said to the bartender, \"he sure<BR>\nknows when to stop.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','In a gathering of two or more people, when a lighted cigarette is<BR>\nplaced in an ashtray, the smoke will waft into the face of the non-smoker.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','In a bottle, the neck is always at the top.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Preserve Wildlife!  Throw a party today!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Riffle West Virginia is so small that the Boy Scout had to double as the<BR>\ntown drunk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Why on earth do people buy old bottles of wine when they can get a<BR>\nfresh one for a quarter of the price?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Woman on Street:	Sir, you are drunk; very, very drunk.<BR>\nWinston Churchill:	Madame, you are ugly; very, very ugly.<BR>\n&nbsp;I shall be sober in the morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','When I drink, *everybody* drinks!\" a man shouted to the assembled bar patrons.<BR>\nA loud general cheer went up.  After downing his whiskey, he hopped onto a<BR>\nbarstool and shouted \"When I take another drink, *everybody* takes another<BR>\ndrink!\"  The announcement produced another cheer and another round of drinks.<BR>\n&nbsp;As soon as he had downed his second drink, the fellow hopped back<BR>\nonto the stool.  \"And when I pay,\" he bellowed, slapping five dollars onto<BR>\nthe bar, \"*everybody* pays!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','When all else fails, pour a pint of Guinness in the gas tank, advance<BR>\nthe spark 20 degrees, cry \"God Save the Queen!\", and pull the starter knob.<BR>\n&nbsp;-- MG \"Series MGA\" Workshop Manual');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','When the cup is full, carry it level.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','There are more old drunkards than old doctors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The verdict of a jury is the a priori opinion of that juror who smokes<BR>\nthe worst cigars.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','They took some of the Van Goghs, most of the jewels, and all of the Chivas!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The search for the perfect martini is a fraud.  The perfect martini is<BR>\na belt of gin from the bottle; anything else is the decadent trappings<BR>\nof civilization.<BR>\n&nbsp;-- T.K.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The telephone is a good way to talk to people without having to offer<BR>\nthem a drink.<BR>\n&nbsp;-- Fran Lebowitz, \"Interview\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The mark of a good party is that you wake up the next morning wanting to<BR>\nchange your name and start a new life in different city.<BR>\n&nbsp;-- Vance Bourjaily, \"Esquire\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','To be intoxicated is to feel sophisticated but not be able to say it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The Celts invented two things, Whiskey and self-destruction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The church is near but the road is icy; the bar is far away but I will<BR>\nwalk carefully.<BR>\n&nbsp;-- Russian Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The best way to preserve a right is to exercise it, and the right to<BR>\nsmoke is a right worth dying for.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I may not be able to walk, but I drive from a sitting position.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The best audience is intelligent, well-educated and a little drunk.<BR>\n&nbsp;-- Maurice Baring');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','The cost of living has just gone up another dollar a quart.<BR>\n&nbsp;-- W.C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','I never said all Democrats were saloonkeepers; what I said was all<BR>\nsaloonkeepers were Democrats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Symptom:		Floor swaying.<BR>\nFault:			Excessive air turbulence, perhaps due to air-hockey<BR>\n&nbsp;game in progress.<BR>\nAction Required:	Insert broom handle down back of jacket.<BR>\n&nbsp;Symptom:		Everything has gone dim, strange taste of peanuts<BR>\n&nbsp;and pretzels or cigarette butts in mouth.<BR>\nFault:			You have fallen forward.<BR>\nAction Required:	See above.<BR>\n&nbsp;Symptom:		Opposite wall covered with acoustic tile and several<BR>\n&nbsp;flourescent light strips.<BR>\nFault:			You have fallen over backward.<BR>\nAction Required:	If your glass is full and no one is standing on your<BR>\n&nbsp;drinking arm, stay put.  If not, get someone to help<BR>\n&nbsp;you get up, lash yourself to bar.<BR>\n&nbsp;-- Bar Troubleshooting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Symptom:		Floor blurred.<BR>\nFault:			You are looking through bottom of empty glass.<BR>\nAction Required:	Find someone who will buy you another beer.<BR>\n&nbsp;Symptom:		Floor moving.<BR>\nFault:			You are being carried out.<BR>\nAction Required:	Find out if you are taken to another bar.  If not,<BR>\n&nbsp;complain loudly that you are being kidnapped.<BR>\n&nbsp;-- Bar Troubleshooting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Who needs friends when you can sit alone in your room and drink?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','Wonderful day.  Your hangover just makes it seem terrible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('drugs','When the going gets tough, the tough go grab a beer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune','And that day dawned when Arrakis lay at the hub of the universe with the wheel <BR>\npoised to spin.<BR>\n&nbsp;-from \"Arrakis Awakening\" by the Princess Irulan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','Every civilization must contend with an unconscious force which can block, <BR>\nbetray or countermand almost any conscious intention of the collectivity.<BR>\n&nbsp;-Tleilaxu Theorem (unproven)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','Oh, worm of many teeth,<BR>\nCanst thou deny what has no cure? <BR>\nThe flesh and breath which lure thee <BR>\nTo the ground of all beginnings <BR>\nFeed on monsters twisting in a door of fire! <BR>\nThou hast no robe in all thy attire <BR>\nTo cover intoxications of divinity <BR>\nOr hide the burnings of desire!<BR>\n&nbsp;-Wormsong from the Dunebook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','Tibana was an apologist for Socratic Christianity, probably a native of IV <BR>\nAnbus who lived between the eight and ninth centuries before Corrino, likely in <BR>\nthe second reign of Dalamak. Of his writings, only a portion survives from <BR>\nwhich this fragment is taken: \"The hearts of all men dwell in the same <BR>\nwilderness.\"<BR>\n&nbsp;-from The Dunebuk of Irulan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','Here lies a toppled god --  <BR>\nHis fall was not a small one. <BR>\nWe did but build his pedestal, <BR>\nA narrow and a tall one.<BR>\n&nbsp;-Tleilaxu Epigram');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','No matter how exotic human civilization becomes, no matter the developments of <BR>\nlife and society nor the complexity of the machine / human interface, there <BR>\nalways come interludes of lonely power when the course of humankind, the very <BR>\nfuture of humankind, depends upon the relatively simple actions of single <BR>\nindividuals.<BR>\n&nbsp;-from The Tlielaxu Godbuk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','Truth suffers from too much analysis.<BR>\n&nbsp;-Ancient Fremen Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('dune-messiah','The Fremen see her as the Earth Figure, a demigoddess whose special charge is <BR>\nto protect the tribes through her powers of violence. She is Reverend Mother to <BR>\ntheir Reverend Mothers. To pilgrims who seek her out with demands that she <BR>\nrestore virility or make the barren fruitful, she is a form of antimentat. She <BR>\nfeeds on that proof that the \"analytic\" has limits. She represents ultimate <BR>\ntension. She is the virgin-harlot -- witty, vulgar, cruel, as destructive in <BR>\nher whims as a coriolis storm.<BR>\n&nbsp;-St. Alia of the Knife as taken from The Irulan Report');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If he had only learnt a little less, how infinitely better he might have<BR>\ntaught much more!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If truth is beauty, how come no one has their hair done in the library?<BR>\n&nbsp;-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','No matter who you are, some scholar can show you the great idea you had<BR>\nwas had by someone before you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If you are too busy to read, then you are too busy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If little else, the brain is an educational toy.<BR>\n&nbsp;-- Tom Robbins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I think your opinions are reasonable, except for the one about my mental<BR>\ninstability.<BR>\n&nbsp;-- Psychology Professor, Farifield University');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If the colleges were better, if they really had it, you would need to get<BR>\nthe police at the gates to keep order in the inrushing multitude.  See in<BR>\ncollege how we thwart the natural love of learning by leaving the natural<BR>\nmethod of teaching what each wishes to learn, and insisting that you shall<BR>\nlearn what you have no taste or capacity for.  The college, which should<BR>\nbe a place of delightful labor, is made odious and unhealthy, and the<BR>\nyoung men are tempted to frivolous amusements to rally their jaded spirits.<BR>\nI would have the studies elective.  Scholarship is to be created not<BR>\nby compulsion, but by awakening a pure interest in knowledge.  The wise<BR>\ninstructor accomplishes this by opening to his pupils precisely the<BR>\nattractions the study has for himself.  The marking is a system for schools,<BR>\nnot for the college; for boys, not for men; and it is an ungracious work to<BR>\nput on a professor.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If someone had told me I would be Pope one day, I would have studied harder.<BR>\n&nbsp;-- Pope John Paul I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I respect faith, but doubt is what gives you an education.<BR>\n&nbsp;-- Wilson Mizner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If we spoke a different language, we would perceive a somewhat different world.<BR>\n&nbsp;-- Wittgenstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I came to MIT to get an education for myself and a diploma for my mother.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I have made this letter longer than usual because I lack the time to<BR>\nmake it shorter.<BR>\n&nbsp;-- Blaise Pascal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','History books which contain no lies are extremely dull.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I am a bookaholic.  If you are a decent person, you will not sell me<BR>\nanother book.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I am returning this otherwise good typing paper to you because someone<BR>\nhas printed gibberish all over it and put your name at the top.<BR>\n&nbsp;-- Professor Lowd, English, Ohio University');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I heard a definition of an intellectual, that I thought was very interesting:<BR>\na man who takes more words than are necessary to tell more than he knows.<BR>\n&nbsp;-- Dwight D. Eisenhower');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','I appreciate the fact that this draft was done in haste, but some of the<BR>\nsentences that you are sending out in the world to do your work for you are<BR>\nloitering in taverns or asleep beside the highway.<BR>\n&nbsp;-- Dr. Dwight Van de Vate, Professor of Philosophy,<BR>\n&nbsp;University of Tennessee at Knoxville');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"He was a modest, good-humored boy.  It was Oxford that made him insufferable.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','He who writes with no misspelled words has prevented a first suspicion<BR>\non the limits of his scholarship or, in the social world, of his general<BR>\neducation and culture.<BR>\n&nbsp;-- Julia Norton McCorkle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','He that teaches himself has a fool for a master.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Fourteen years in the professor dodge has taught me that one can argue<BR>\ningeniously on behalf of any theory, applied to any piece of literature.<BR>\nThis is rarely harmful, because normally no-one reads such essays.<BR>\n&nbsp;-- Robert Parker, quoted in \"Murder Ink\",  ed. D. Wynn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','f u cn rd ths, itn tyg h myxbl cd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Going to church does not make a person religious, nor does going to school<BR>\nmake a person educated, any more than going to a garage makes a person a car.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Good day to avoid cops.  Crawl to school.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','f u cn rd ths, u r prbbly a lsy spllr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','History is nothing but a collection of fables and useless trifles,<BR>\ncluttered up with a mass of unnecessary figures and proper names.<BR>\n&nbsp;-- Leo Tolstoy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Educational television should be absolutely forbidden.  It can only lead<BR>\nto unreasonable disappointment when your child discovers that the letters<BR>\nof the alphabet do not leap up out of books and dance around with<BR>\nroyal-blue chickens.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Encyclopedia for sale by father.  Son knows everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','f u cn rd ths, u cn gt a gd jb n cmptr prgrmmng.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','How do you explain school to a higher intelligence?<BR>\n&nbsp;-- Elliot, \"E.T.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Higher education helps your earning capacity.  Ask any college professor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"I have to convince you, or at least snow you ...\"<BR>\n&nbsp;-- Prof. Romas Aleliunas, CS 435');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','[He] took me into his library and showed me his books, of which he had<BR>\na complete set.<BR>\n&nbsp;-- Ring Lardner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Learning without thought is labor lost;<BR>\nthought without learning is perilous.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If you think education is expensive, try ignorance.<BR>\n&nbsp;-- Derek Bok, president of Harvard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','&nbsp;It is a profoundly erroneous truism, repeated by all copy-books and<BR>\nby eminent people when they are making speeches, that we should cultivate<BR>\nthe habit of thinking about what we are doing.  The precise opposite is the<BR>\ncase.  Civilization advances by extending the numbers of important operations<BR>\nwhich we can perform without thinking about them.  Operations of thought are<BR>\nlike cavalry charges in battle -- they are strictly limited in number, they<BR>\nrequire fresh horses, and must only be made at decisive moments.<BR>\n&nbsp;-- Alfred North Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If any man wishes to be humbled and mortified, let him become president<BR>\nof Harvard.<BR>\n&nbsp;-- Edward Holyoke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Iowa State -- the high school after high school!<BR>\n&nbsp;-- Crow T. Robot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','It has been said [by Anatole France], \"it is not by amusing oneself<BR>\nthat one learns,\" and, in reply: \"it is *____only* by amusing oneself that<BR>\none can learn.\"<BR>\n&nbsp;-- Edward Kasner and James R. Newman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','It has long been an article of our folklore that too much knowledge or skill,<BR>\nor especially consummate expertise, is a bad thing.  It dehumanizes those who<BR>\nachieve it, and makes difficult their commerce with just plain folks, in whom<BR>\ngood old common sense has not been obliterated by mere book learning or fancy<BR>\nnotions.  This popular delusion flourishes now more than ever, for we are all<BR>\ninfected with it in the schools, where educationists have elevated it from<BR>\nfolklore to Article of Belief.  It enhances their self-esteem and lightens<BR>\ntheir labors by providing theoretical justification for deciding that<BR>\nappreciation, or even simple awareness, is more to be prized than knowledge,<BR>\nand relating (to self and others), more than skill, in which minimum<BR>\ncompetence will be quite enough.<BR>\n&nbsp;-- The Underground Grammarian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','In California, Bill Honig, the Superintendent of Public Instruction, said he<BR>\nthought the general public should have a voice in defining what an excellent<BR>\nteacher should know.  \"I would not leave the definition of math,\" Dr. Honig<BR>\nsaid, \"up to the mathematicians.\"<BR>\n&nbsp;-- The New York Times, October 22, 1985');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Illiterate?  Write today, for free help!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Experience is the worst teacher.  It always gives the test first and<BR>\nthe instruction afterward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Even if you do learn to speak correct English, whom are you going to speak<BR>\nit to?<BR>\n&nbsp;-- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','F u cn rd ths u cnt spl wrth a dm!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Education is the process of casting false pearls before real swine.<BR>\n&nbsp;-- Irwin Edman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','If you resist reading what you disagree with, how will you ever acquire<BR>\ndeeper insights into what you believe?  The things most worth reading<BR>\nare precisely those that challenge our convictions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Ignorance is never out of style.  It was in fashion yesterday, it is the<BR>\nrage today, and it will set the pace tomorrow.<BR>\n&nbsp;-- Franklin K. Dane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Practice is the best of all instructors.<BR>\n&nbsp;-- Publilius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"A University without students is like an ointment without a fly.\"<BR>\n&nbsp;-- Ed Nather, professor of astronomy at UT Austin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','One cannot make an omelette without breaking eggs -- but it is amazing<BR>\nhow many eggs one can break without making a decent omelette.<BR>\n&nbsp;-- Professor Charles P. Issawi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A university is what a college becomes when the faculty loses interest<BR>\nin students.<BR>\n&nbsp;-- John Ciardi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Education is an admirable thing, but it is well to remember from time to<BR>\ntime that nothing that is worth knowing can be taught.<BR>\n&nbsp;-- Oscar Wilde, \"The Critic as Artist\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Engineering:    \"How will this work?\"<BR>\nScience:        \"Why will this work?\"<BR>\nManagement:     \"When will this work?\"<BR>\nLiberal Arts:   \"Do you want fries with that?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Eloquence is logic on fire.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Comparing information and knowledge is like asking whether the fatness<BR>\nof a pig is more or less green than the designated hitter rule.\"<BR>\n&nbsp;-- David Guaspari');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Joe Cool always spends the first two weeks at college sailing his frisbee.<BR>\n&nbsp;-- Snoopy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The only thing that experience teaches us is that experience teaches us nothing.<BR>\n&nbsp;-- Andre Maurois (Emile Herzog)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Never have so many understood so little about so much.<BR>\n&nbsp;-- James Burke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Never let your schooling interfere with your education.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','No discipline is ever requisite to force attendance upon lectures which are<BR>\nreally worth the attending.<BR>\n&nbsp;-- Adam Smith, \"The Wealth of Nations\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','My father, a good man, told me, \"Never lose your ignorance; you cannot<BR>\nreplace it.\"<BR>\n&nbsp;-- Erich Maria Remarque');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Learned men are the cisterns of knowledge, not the fountainheads.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Learning at some schools is like drinking from a firehose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Good teaching is one-fourth preparation and three-fourths good theatre.<BR>\n&nbsp;-- Gail Godwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Examinations are formidable even to the best prepared, for<BR>\neven the greatest fool may ask more the the wisest man can answer.<BR>\n&nbsp;-- C.C. Colton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','There are no answers, only cross-references.<BR>\n&nbsp;-- Weiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The USA is so enormous, and so numerous are its schools, colleges and religious<BR>\nseminaries, many devoted to special religious beliefs ranging from the<BR>\nunorthodox to the dotty, that we can hardly wonder at its yielding a more<BR>\nbounteous harvest of gobbledegook than the rest of the world put together.<BR>\n&nbsp;-- Sir Peter Medawar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','This is the sort of English up with which I will not put.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The world is full of people who have never, since childhood, met an<BR>\nopen doorway with an open mind.<BR>\n&nbsp;-- E.B. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','We know next to nothing about virtually everything.  It is not necessary<BR>\nto know the origin of the universe; it is necessary to want to know.<BR>\nCivilization depends not on any particular knowledge, but on the disposition<BR>\nto crave knowledge.<BR>\n&nbsp;-- George Will');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The sum of the intelligence of the world is constant.  The population is,<BR>\nof course, growing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The sunlights differ, but there is only one darkness.<BR>\n&nbsp;-- Ursula K. LeGuin, \"The Dispossessed\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The three best things about going to school are June, July, and August.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"The student in question is performing minimally for his peer group and<BR>\nis an emerging underachiever.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The problem with graduate students, in general, is that they have<BR>\nto sleep every few days.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The ratio of literacy to illiteracy is a constant, but nowadays the<BR>\nilliterates can read.<BR>\n&nbsp;-- Alberto Moravia');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The world is coming to an end!  Repent and return those library books!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The real purpose of books is to trap the mind into doing its own thinking.<BR>\n&nbsp;-- Christopher Morley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"We demand rigidly defined areas of doubt and uncertainty!\"<BR>\n&nbsp;-- Vroomfondel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The college graduate is presented with a sheepskin to cover his<BR>\nintellectual nakedness.<BR>\n&nbsp;-- Robert M. Hutchins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The end of the world will occur at three p.m., this Friday, with<BR>\nsymposium to follow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Suddenly, Professor Liebowitz realizes he has come to the seminar<BR>\nwithout his duck ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The brain is a wonderful organ; it starts working the moment you get up<BR>\nin the morning, and does not stop until you get to school.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The avocation of assessing the failures of better men can be turned<BR>\ninto a comfortable livelihood, providing you back it up with a Ph.D.<BR>\n&nbsp;-- Nelson Algren, \"Writers at Work\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Teachers have class.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The average Ph.D thesis is nothing but the transference of bones from<BR>\none graveyard to another.<BR>\n&nbsp;-- J. Frank Dobie, \"A Texan in England\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The future is a race between education and catastrophe.<BR>\n&nbsp;-- H.G. Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A Parable of Modern Research:<BR>\n&nbsp;Bob has lost his keys in a room which is dark except for one<BR>\nbrightly lit corner.<BR>\n&nbsp;\"Why are you looking under the light, you lost them in the dark!\"<BR>\n&nbsp;\"I can only see here.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Reporter:   \"How did you like school when you were growing up, Yogi?\"<BR>\nYogi Berra: \"Closed.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A tautology is a thing which is tautological.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Reading is to the mind what exercise is to the body.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Department chairmen never die, they just lose their faculties.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Education is what survives when what has been learnt has been forgotten.<BR>\n&nbsp;-- B.F. Skinner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"You should, without hesitation, pound your typewriter into a plowshare,<BR>\nyour paper into fertilizer, and enter agriculture\"<BR>\n&nbsp;-- Business Professor, University of Georgia');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','You may have heard that a dean is to faculty as a hydrant is to a dog.<BR>\n&nbsp;-- Alfred Kahn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Where do I find the time for not reading so many books?<BR>\n&nbsp;-- Karl Kraus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Whenever anyone says, \"theoretically,\" they really mean, \"not really.\"<BR>\n&nbsp;-- Dave Parnas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','When I was in school, I cheated on my metaphysics exam: I looked into<BR>\nthe soul of the boy sitting next to me.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','What we do not understand we do not possess.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','What passes for optimism is most often the effect of an intellectual error.<BR>\n&nbsp;-- Raymond Aron, \"The Opium of the Intellectuals\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','What makes you think graduate school is supposed to be satisfying?<BR>\n&nbsp;-- Erica Jong, \"Fear of Flying\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','To craunch a marmoset.<BR>\n&nbsp;-- Pedro Carolino, \"English as She is Spoke\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Time is a great teacher, but unfortunately it kills all its pupils.<BR>\n&nbsp;-- Hector Berlioz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Those who educate children well are more to be honored than parents, for<BR>\nthese only gave life, those the art of living well.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The Tree of Learning bears the noblest fruit, but noble fruit tastes bad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The test of a first-rate intelligence is the ability to hold two opposed<BR>\nideas in the mind at the same time and still retain the ability to function.<BR>\n&nbsp;-- F. Scott Fitzgerald');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The man who has never been flogged has never been taught.<BR>\n&nbsp;-- Menander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','The important thing is not to stop questioning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Spelling is a lossed art.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"Speed is subsittute fo accurancy.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Some scholars are like donkeys, they merely carry a lot of books.<BR>\n&nbsp;-- Folk saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Smartness runs in my family.  When I went to school I was so smart my<BR>\nteacher was in my class for five years.<BR>\n&nbsp;-- George Burns');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A good question is never answered.  It is not a bolt to be tightened<BR>\ninto place but a seed to be planted and to bear more seed toward the<BR>\nhope of greening the landscape of idea.<BR>\n&nbsp;-- John Ciardi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Your education begins where what is called your education is over.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','To teach is to learn.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','To teach is to learn twice.<BR>\n&nbsp;-- Joseph Joubert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','&nbsp;What I Did During My Fall Semester<BR>\nOn the first day of my fall semester, I got up.<BR>\nThen I went to the library to find a thesis topic.<BR>\nThen I hung out in front of the Dover.<BR>\n&nbsp;On the second day of my fall semester, I got up.<BR>\nThen I went to the library to find a thesis topic.<BR>\nThen I hung out in front of the Dover.<BR>\n&nbsp;On the third day of my fall semester, I got up.<BR>\nThen I went to the library to find a thesis topic.<BR>\nI found a thesis topic:<BR>\n&nbsp;How to keep people from hanging out in front of the Dover.<BR>\n&nbsp;-- Sister Mary Elephant, \"Student Statement for Black Friday\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Try not to have a good time ... This is supposed to be educational.<BR>\n&nbsp;-- Charles Schulz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','\"Whom are you?\" said he, for he had been to night school.<BR>\n&nbsp;-- George Ade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','What does education often do?  It makes a straight cut ditch of a<BR>\nfree meandering brook.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Universities are places of knowledge.  The freshman each bring a little<BR>\nin with them, and the seniors take none away, so knowledge accumulates.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','University politics are vicious precisely because the stakes are so small.<BR>\n&nbsp;-- C. P. Snow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Trying to get an education here is like trying to get a drink from a fire hose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','About all some men accomplish in life is to send a son to Harvard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','... But if we laugh with derision, we will never understand.  Human<BR>\nintellectual capacity has not altered for thousands of years so far as<BR>\nwe can tell.  If intelligent people invested intense energy in issues<BR>\nthat now seem foolish to us, then the failure lies in our understanding<BR>\nof their world, not in their distorted perceptions.  Even the standard<BR>\nexample of ancient nonsense -- the debate about angels on pinheads --<BR>\nmakes sense once you realize that theologians were not discussing<BR>\nwhether five or eighteen would fit, but whether a pin could house a<BR>\nfinite or an infinite number.<BR>\n&nbsp;-- S. J. Gould, \"Wide Hats and Narrow Minds\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A student who changes the course of history is probably taking an exam.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','An investment in knowledge always pays the best interest.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Education and religion are two things not regulated by supply and<BR>\ndemand.  The less of either the people have, the less they want.<BR>\n&nbsp;-- Charlotte Observer, 1897');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Do you think that illiterate people get the full effect of alphabet soup?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Did you know the University of Iowa closed down after someone stole the book?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A great many people think they are thinking when they are merely<BR>\nrearranging their prejudices.<BR>\n&nbsp;-- William James');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','&nbsp;A Plan for the Improvement of English Spelling<BR>\n&nbsp;by Mark Twain<BR>\n&nbsp;For example, in Year 1 that useless letter \"c\" would be dropped<BR>\nto be replased either by \"k\" or \"s\", and likewise \"x\" would no longer<BR>\nbe part of the alphabet.  The only kase in which \"c\" would be retained<BR>\nwould be the \"ch\" formation, which will be dealt with later.  Year 2<BR>\nmight reform \"w\" spelling, so that \"which\" and \"one\" would take the<BR>\nsame konsonant, wile Year 3 might well abolish \"y\" replasing it with<BR>\n\"i\" and Iear 4 might fiks the \"g/j\" anomali wonse and for all.<BR>\n&nbsp;Jenerally, then, the improvement would kontinue iear bai iear<BR>\nwith Iear 5 doing awai with useless double konsonants, and Iears 6-12<BR>\nor so modifaiing vowlz and the rimeining voist and unvoist konsonants.<BR>\nBai Iear 15 or sou, it wud fainali bi posibl tu meik ius ov thi<BR>\nridandant letez \"c\", \"y\" and \"x\" -- bai now jast a memori in the maindz<BR>\nov ould doderez -- tu riplais \"ch\", \"sh\", and \"th\" rispektivli.<BR>\n&nbsp;Fainali, xen, aafte sam 20 iers ov orxogrefkl riform, wi wud<BR>\nhev a lojikl, kohirnt speling in ius xrewawt xe Ingliy-spiking werld.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Campus sidewalks never exist as the straightest line between two points.<BR>\n&nbsp;-- M. M. Johnston');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A definition of teaching: casting fake pearls before real swine.<BR>\n&nbsp;-- Bill Cain, \"Stand Up Tragedy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','As long as the answer is right, who cares if the question is wrong?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Briefly stated, the findings are that when presented with an array of<BR>\ndata or a sequence of events in which they are instructed to discover<BR>\nan underlying order, subjects show strong tendencies to perceive order<BR>\nand causality in random arrays, to perceive a pattern or correlation<BR>\nwhich seems a priori intuitively correct even when the actual correlation<BR>\nin the data is counterintuitive, to jump to conclusions about the correct<BR>\nhypothesis, to seek and to use only positive or confirmatory evidence, to<BR>\nconstrue evidence liberally as confirmatory, to fail to generate or to<BR>\nassess alternative hypotheses, and having thus managed to expose themselves<BR>\nonly to confirmatory instances, to be fallaciously confident of the validity<BR>\nof their judgments (Jahoda, 1969; Einhorn and Hogarth, 1978).  In the<BR>\nanalyzing of past events, these tendencies are exacerbated by failure to<BR>\nappreciate the pitfalls of post hoc analyses.<BR>\n&nbsp;-- A. Benjamin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','As Gen. de Gaulle occassionally acknowledges America to be the daughter<BR>\nof Europe, so I am pleased to come to Yale, the daughter of Harvard.<BR>\n&nbsp;-- J.F. Kennedy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Abstract:<BR>\n&nbsp;This study examined the incidence of neckwear tightness among a group<BR>\nof 94 white-collar working men and the effect of a tight business-shirt collar<BR>\nand tie on the visual performance of 22 male subjects.  Of the white-collar<BR>\nmen measured, 67% were found to be wearing neckwear that was tighter than<BR>\ntheir neck circumference.  The visual discrimination of the 22 subjects was<BR>\nevaluated using a critical flicker frequency (CFF) test.  Results of the CFF<BR>\ntest indicated that tight neckwear significantly decreased the visual<BR>\nperformance of the subjects and that visual performance did not improve<BR>\nimmediately when tight neckwear was removed.<BR>\n&nbsp;-- Langan, L.M. and Watkins, S.M. \"Pressure of Menswear on the<BR>\n&nbsp;Neck in Relation to Visual Performance.\"  Human Factors 29,<BR>\n&nbsp;#1 (Feb. 1987), pp. 67-71.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','=============== ALL FRESHMEN PLEASE NOTE ===============<BR>\n&nbsp;To minimize scheduling confusion, please realize that if you are taking one<BR>\ncourse which is offered at only one time on a given day, and another which is<BR>\noffered at all times on that day, the second class will be arranged as to <BR>\nafford maximum inconvenience to the student.  For example, if you happen<BR>\nto work on campus, you will have 1-2 hours between classes.  If you commute,<BR>\nthere will be a minimum of 6 hours between the two classes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Any two philosophers can tell each other all they know in two hours.<BR>\n&nbsp;-- Oliver Wendell Holmes, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','Academic politics is the most vicious and bitter form of politics,<BR>\nbecause the stakes are so low.<BR>\n&nbsp;-- Wallace Sayre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('education','A pencil with no point needs no eraser.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The British are coming!  The British are coming!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Fortune presents:<BR>\n&nbsp;USEFUL PHRASES IN ESPERANTO, #2.<BR>\n&nbsp;^Cu tiu loko estas okupita?		Is this seat taken?<BR>\n^Cu vi ofte venas ^ci-tien?		Do you come here often?<BR>\n^Cu mi povas havi via telelonnumeron?	May I have your phone number?<BR>\nMi estas komputilisto.			I work with computers.<BR>\nMi legas multe da scienca fikcio.	I read a lot of science fiction.<BR>\n^Cu necesas ke vi eliras?		Do you really have to be going?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Historians have now definitely established that Juan Cabrillo, discoverer<BR>\nof California, was not looking for Kansas, thus setting a precedent that<BR>\ncontinues to this day.<BR>\n&nbsp;-- Wayne Shannon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','An American is a man with two arms and four wheels.<BR>\n&nbsp;-- A Chinese child');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Anything anybody can say about America is true.<BR>\n&nbsp;-- Emmett Grogan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','&nbsp;A German, a Pole and a Czech left camp for a hike through the woods.<BR>\nAfter being reported missing a day or two later, rangers found two bears,<BR>\none a male, one a female, looking suspiciously overstuffed.  They killed<BR>\nthe female, autopsied her, and sure enough, found the German and the Pole.<BR>\n&nbsp;\"What do you think?\" said the the first ranger.<BR>\n&nbsp;\"The Czech is in the male,\" replied the second.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Bond reflected that good Americans were fine people and that most of them<BR>\nseemed to come from Texas.<BR>\n&nbsp;-- Ian Fleming, \"Casino Royale\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','An Englishman never enjoys himself, except for a noble purpose.<BR>\n&nbsp;-- A.P. Herbert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','I have defined the hundred per cent American as ninety-nine per cent an idiot.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Detroit is Cleveland without the glitter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Do you know the difference between a yankee and a damyankee?<BR>\n&nbsp;A yankee comes south to *_____visit*.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Do you know Montana?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Do Miami a favor.  When you leave, take someone with you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Hear about the young Chinese woman who just won the lottery?<BR>\nOne fortunate cookie...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Decemba, n:	The 12th month of the year.<BR>\nerra, n:	A mistake.<BR>\nfaa, n:		To, from, or at considerable distance.<BR>\nLinder, n:	A female name.<BR>\nmemba, n:	To recall to the mind; think of again.<BR>\nNew Hampsha, n:	A state in the northeast United States.<BR>\nNew Yaak, n:	Another state in the northeast United States.<BR>\nNovemba, n:	The 11th month of the year.<BR>\nOctoba, n:	The 10th month of the year.<BR>\nova, n:		Location above or across a specified position.  What the<BR>\n&nbsp;season is when the Knicks quit playing.<BR>\n&nbsp;-- Massachewsetts Unabridged Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Likewise, the national appetizer, brine-cured herring with raw onions,<BR>\nwins few friends, Germans excepted.<BR>\n&nbsp;-- Darwin Porter \"Scandinavia On $50 A Day\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Climate and Surgery<BR>\n&nbsp;R C Gilchrist, who was shot by J Sharp twelve days ago, and who<BR>\nreceived a derringer ball in the right breast, and who it was supposed at<BR>\nthe time could not live many hours, was on the street yesterday and the<BR>\nday before -- walking several blocks at a time.  To those who design to be<BR>\nriddled with bullets or cut to pieces with Bowie-knives, we cordially<BR>\nrecommend our Sacramento climate and Sacramento surgery.<BR>\n&nbsp;-- Sacramento Daily Union, September 11, 1861');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','New York is real.  The rest is done with mirrors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','No matter what other nations may say about the United States,<BR>\nimmigration is still the sincerest form of flattery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','\"Now the Lord God planted a garden East of Whittier in a place called<BR>\nYorba Linda, and out of the ground he made to grow orange trees that<BR>\nwere good for food and the fruits thereof he labeled SUNKIST ...\"<BR>\n&nbsp;-- \"The Begatting of a President\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Seattle is so wet that people protect their property with watch-ducks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Monterey... is decidedly the pleasantest and most civilized-looking place<BR>\nin California ... [it] is also a great place for cock-fighting, gambling<BR>\nof all sorts, fandangos, and various kinds of amusements and knavery.<BR>\n&nbsp;-- Richard Henry Dama, \"Two Years Before the Mast\", 1840');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Most Texans think Hanukkah is some sort of duck call.<BR>\n&nbsp;-- Richard Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Learning French is trivial: the word for horse is cheval, and everything else<BR>\nfollows in the same way.<BR>\n&nbsp;-- Alan J. Perlis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Like so many Americans, she was trying to construct a life that made<BR>\nsense from things she found in gift shops.<BR>\n&nbsp;-- Kurt Vonnegut, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','My godda bless, never I see sucha people.<BR>\n&nbsp;-- Signor Piozzi, quoted by Cecilia Thrale');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The big cities of America are becoming Third World countries.<BR>\n&nbsp;-- Nora Ephron');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','If all the Chinese simultaneously jumped into the Pacific off a 10 foot<BR>\nplatform erected 10 feet off their coast, it would cause a tidal wave<BR>\nthat would destroy everything in this country west of Nebraska.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Living in LA is like not having a date on Saturday night.<BR>\n&nbsp;-- Candice Bergen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Inglish Spocken Hier: some mangled translations<BR>\n&nbsp;Sign on a cathedral in Spain:<BR>\n&nbsp;It is forbidden to enter a woman, even a foreigner if<BR>\n&nbsp;dressed as a man.<BR>\n&nbsp;Above the enterance to a Cairo bar:<BR>\n&nbsp;Unaccompanied ladies not admitted unless with husband<BR>\n&nbsp;or similar.<BR>\n&nbsp;On a Bucharest elevator:<BR>\n&nbsp;The lift is being fixed for the next days.<BR>\n&nbsp;During that time we regret that you will be unbearable.<BR>\n&nbsp;-- Colin Bowles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Living in New York City gives people real incentives to want things that<BR>\nnobody else wants.<BR>\n&nbsp;-- Andy Warhol');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Inglish Spocken Hier: some mangled translations<BR>\n&nbsp;Sign on a cabin door of a Soviet Black Sea cruise liner:<BR>\n&nbsp;Helpsavering apparata in emergings behold many whistles!<BR>\n&nbsp;Associate the stringing apparata about the bosums and meet<BR>\n&nbsp;behind, flee then to the indifferent lifesaveringshippen<BR>\n&nbsp;obedicing the instructs of the vessel.<BR>\n&nbsp;On the door in a Belgrade hotel:<BR>\n&nbsp;Let us know about any unficiency as well as leaking on<BR>\n&nbsp;the service. Our utmost will improve it.<BR>\n&nbsp;-- Colin Bowles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Indiana is a state dedicated to basketball.  Basketball, soybeans, hogs and<BR>\nbasketball.  Berkeley, needless to say, is not nearly as athletic.  Berkeley<BR>\nis dedicated to coffee, angst, potholes and coffee.<BR>\n&nbsp;-- Carolyn Jones');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','I am just a nice, clean-cut Mongolian boy.<BR>\n&nbsp;-- Yul Brynner, 1956');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The English have no respect for their language, and will not teach<BR>\ntheir children to speak it.<BR>\n&nbsp;-- G. B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The best thing that comes out of Iowa is I-80.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The Czechs announced after Sputnik that they, too, would launch a satellite.<BR>\nOf course, it would orbit Sputnik, not Earth!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The Almighty in His infinite wisdom did not see fit to create Frenchmen<BR>\nin the image of Englishmen.<BR>\n&nbsp;-- Winston Churchill, 1942');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The American nation in the sixth ward is a fine people; they love the<BR>\neagle -- on the back of a dollar.<BR>\n&nbsp;-- Finlay Peter Dunne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The Anglo-Saxon conscience does not prevent the Anglo-Saxon from<BR>\nsinning, it merely prevents him from enjoying his sin.<BR>\n&nbsp;--Salvador De Madariaga');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','How many priests are needed for a Boston Mass?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The best case:	   Get salary from America, build a house in England,<BR>\n&nbsp;live with a Japanese wife, and eat Chinese food.<BR>\nPretty good case:  Get salary from England, build a house in America,<BR>\n&nbsp;live with a Chinese wife, and eat Japanese food.<BR>\nThe worst case:    Get salary from China, build a house in Japan,<BR>\n&nbsp;live with a British wife, and eat American food.<BR>\n&nbsp;--Bungei Shunju, a popular Japanese magazine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','paak, n:	A stadium or inclosed playing field. To put or leave (a<BR>\n&nbsp;a vehicle) for a time in a certain location.<BR>\npatato, n:	The starchy, edible tuber of a widely cultivated plant.<BR>\nSeptemba, n:	The 9th month of the year.<BR>\nshua, n:	Having no doubt; certain.<BR>\nsista, n:	A female having the same mother and father as the speaker.<BR>\ntamato, n:	A fleshy, smooth-skinned reddish fruit eaten in salads<BR>\n&nbsp;or as a vegetable.<BR>\ntroopa, n:	A state policeman.<BR>\nWista, n:	A city in central Masschewsetts.<BR>\nyaad, n:	A tract of ground adjacent to a building.<BR>\n&nbsp;-- Massachewsetts Unabridged Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Philadelphia is not dull -- it just seems so because it is next to<BR>\nexciting Camden, New Jersey.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Perhaps, after all, America never has been discovered.  I myself would<BR>\nsay that it had merely been detected.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Houdini escaping from New Jersey!<BR>\n&nbsp;Film at eleven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','One of the rules of Busmanship, New York style, is never surrender your<BR>\nseat to another passenger.  This may seem callous, but it is the best<BR>\nway, really.  If one passenger were to give a seat to someone who fainted<BR>\nin the aisle, say, the others on the bus would become disoriented and<BR>\nimagine they were in Topeka Kansas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Providence, New Jersey, is one of the few cities where Velveeta cheese<BR>\nappears on the gourmet shelf.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','To a Californian, all New Yorkers are cold; even in heat they rarely go<BR>\nabove fifty-eight degrees.  If you collapse on a street in New York, plan<BR>\nto spend a few days there.<BR>\n&nbsp;-- From \"East vs. West: The War Between the Coasts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','There *__is* intelligent life on Earth, but I leave for Texas on Monday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','There are people who find it odd to eat four or five Chinese meals<BR>\nin a row; in China, I often remind them, there are a billion or so<BR>\npeople who find nothing odd about it.<BR>\n&nbsp;-- Calvin Trillin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Hear about the Californian terrorist that tried to blow up a bus?<BR>\nBurned his lips on the exhaust pipe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','\"His great aim was to escape from civilization, and, as soon as he had<BR>\nmoney, he went to Southern California.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Have you seen the latest Japanese camera?  Apparently it is so fast it can<BR>\nphotograph an American with his mouth shut!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Hating the Yankees is as American as pizza pie, unwed mothers and<BR>\ncheating on your income tax.<BR>\n&nbsp;-- Mike Royko');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','To a New Yorker, the only California houses on the market for less than a<BR>\nmillion dollars are those on fire.  These generally go for six hundred<BR>\nthousand.<BR>\n&nbsp;-- From \"East vs. West: The War Between the Coasts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The San Diego Freeway.  Official Parking Lot of the 1984 Olympics!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The trouble is, there is an endless supply of White Men, but there has<BR>\nalways been a limited number of Human Beings.<BR>\n&nbsp;-- Little Big Man');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The only cultural advantage LA has over NY is that you can make a right<BR>\nturn on a red light.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The goys have proven the following theorem...<BR>\n&nbsp;-- Physicist John von Neumann, at the start of a classroom<BR>\n&nbsp;lecture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The mosquito is the state bird of New Jersey.<BR>\n&nbsp;-- Andy Warhol');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The most common given name in the world is Mohammad; the most common<BR>\nfamily name in the world is Chang.  Can you imagine the enormous number<BR>\nof people in the world named Mohammad Chang?<BR>\n&nbsp;-- Derek Wills');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The geographical center of Boston is in Roxbury.  Due north of the<BR>\ncenter we find the South End.  This is not to be confused with South<BR>\nBoston which lies directly east from the South End.  North of the South<BR>\nEnd is East Boston and southwest of East Boston is the North End.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The English country gentleman galloping after a fox -- the unspeakable<BR>\nin full pursuit of the uneatable.<BR>\n&nbsp;-- Oscar Wilde, \"A Woman of No Importance\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The English instinctively admire any man who has no talent and is modest<BR>\nabout it.<BR>\n&nbsp;-- James Agate, British film and drama critic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The difference between America and England is that the English think 100<BR>\nmiles is a long distance and the Americans think 100 years is a long time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The egg cream is psychologically the opposite of circumcision -- it<BR>\n*pleasurably* reaffirms your Jewishness.<BR>\n&nbsp;-- Mel Brooks');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','[The French Riviera is] a sunny place for shady people.<BR>\n&nbsp;-- Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','The climate of Bombay is such that its inhabitants have to live elsewhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Aberdeen was so small that when the family with the car went<BR>\non vacation, the gas station and drive-in theatre had to close.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','alta, v:	To change; make or become different; modify.<BR>\nansa, v:	A spoken or written reply, as to a question.<BR>\nbaa, n:		A place people meet to have a few drinks.<BR>\nBaaston, n:	The capital of Massachusetts.<BR>\nbaaba, n:	One whose business is to cut or trim hair or beards.<BR>\nbeea, n:	An alcoholic beverage brewed from malt and hops, often<BR>\n&nbsp;found in baas.<BR>\ncaaa, n:	An automobile.<BR>\ncenta, n:	A point around which something revolves; axis.  (Or<BR>\n&nbsp;someone involved with the Knicks.)<BR>\nchouda, n:	A thick seafood soup, often in a milk base.<BR>\ndada, n:	Information, esp. information organized for analysis or<BR>\n&nbsp;computation.<BR>\n&nbsp;-- Massachewsetts Unabridged Dictionary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Also, the Scots are said to have invented golf.  Then they had<BR>\nto invent Scotch whiskey to take away the pain and frustration.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','\"All snakes who wish to remain in Ireland will please raise their right hands.\"<BR>\n&nbsp;-- Saint Patrick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','American by birth; Texan by the grace of God.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','America, how can I write a holy litany in your silly mood?<BR>\n&nbsp;-- Allen Ginsberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Welcome to Lake Wobegon, where all the men are strong, the women are pretty,<BR>\nand the children are above-average.<BR>\n&nbsp;-- Garrison Keillor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','What kind of sordid business are you on now?  I mean, man, whither<BR>\ngoest thou?  Whither goest thou, America, in thy shiny car in the night?<BR>\n&nbsp;-- Jack Kerouac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','When you become used to never being alone, you may consider yourself<BR>\nAmericanized.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','You always have the option of pitching baseballs at empty spray paint cans<BR>\nin a cul-de-sac in a Cleveland suburb.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Would the last person to leave Michigan please turn out the lights?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','When does summertime come to Minnesota, you ask?  Well, last year, I<BR>\nthink it was a Tuesday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','When I first arrived in this country I had only fifteen cents in my pocket<BR>\nand a willingness to compromise.<BR>\n&nbsp;-- Weber cartoon caption');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','When a man is tired of London, he is tired of life.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Visit beautiful Wisconsin Dells.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Visit beautiful Vergas, Minnesota.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Americans are people who insist on living in the present, tense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Good night, Austin, Texas, wherever you are!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Then there was the Formosan bartender named Taiwan-On.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Traffic signals in New York are just rough guidelines.<BR>\n&nbsp;-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','To know Edina is to reject it.<BR>\n&nbsp;-- Dudley Riggs, \"The Year the Grinch Stole the Election\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','There must be at least 500,000,000 rats in the United States; of course,<BR>\nI never heard the story before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','To a New Yorker, all Californians are blond, even the blacks.  There are,<BR>\nin fact, whole neighborhoods that are zoned only for blond people.  The<BR>\nonly way to tell the difference between California and Sweden is that the<BR>\nSwedes speak better English.\"<BR>\n&nbsp;-- From \"East vs. West: The War Between the Coasts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','Tip the world over on its side and everything loose will land in Los Angeles.<BR>\n&nbsp;-- Frank Lloyd Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('ethnic','To a Californian, a person must prove himself criminally insane before he<BR>\nis allowed to drive a taxi in New York.  For New York cabbies, honesty and<BR>\nstopping at red lights are both optional.<BR>\n&nbsp;-- From \"East vs. West: The War Between the Coasts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Yes, I know it hurts. Do you want it not to hurt? Next time, HOLD ON TO THE FRELLING WALL!\" 						-- Aeryn, Look At The Princess, 2 <BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"I thought we might even pull this off. But you and me, Chiana, not lying? Are you mad?\" <BR>\n&nbsp;-- Rygel, Dream A Little Dream<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"They spit fire? How come no one tells me this stuff? How come no one tells me they spit fire? Aeryn!\"<BR>\n&nbsp;-- Crichton, PK Tech Girl<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"There. I woke him up. Now I hope he drops dead.\" <BR>\n&nbsp;-- Jool, Fractures<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"..Because as you know, Peacekeeper high command has very clear parameters regarding contact with unclassified alien life forms. You may have very well exceeded those parameters, Officer Sun-\"<BR>\n\"No, sir.\"<BR>\n\"Which makes you irreversibly contaminated.\"<BR>\n\"No, sir!\"<BR>\n\"Take them away! Take them all away.\"<BR>\n&nbsp;-- Crais and Aeryn, Premiere<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Cross my heart, strike me dead, slap a lobster on my head.\" <BR>\n&nbsp;-- Crichton, Thanks For Sharing<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"John Crichton, Wizard of Oz.\"<BR>\n&nbsp;-- Crichton, Thanks for Sharing<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"If you try anything when I am gonem whatever you have in the place of mivonks and wherever they are, they will be gone when I get back.\"<BR>\n&nbsp;-- Aeryn, Eat Me<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Jirl power\"<BR>\n\"Girl. Girl power. Would you quit speaking English?\"<BR>\n&nbsp;-- Aeryn and Crichton, Coup By Clam<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"What the hell is the MATTER with you people?\"<BR>\n&nbsp;-- Crichton, Premiere<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Boy, was Spielberg ever wrong. Close Encounters my ass.\"<BR>\n&nbsp;-- Crichton, Premiere<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Your seat belt is loose.\"<BR>\n\"Not half as loose as Chiana\" <BR>\n&nbsp;-- Stark and Rygel, Relativity<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Stark you listen to me now. You try anything like that again and I will personally take you to the other side.\" <BR>\n&nbsp;-- Aeryn, Meltdown<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"The magnetics. You see how the color is fading from everything, the walls, your clothes.\"<BR>\n\"I never had much color, Princess.\" <BR>\n&nbsp;-- Jool and Chiana, What Was Lost, 2<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"My side, your side, my side, your side, my side, your side!\" <BR>\n&nbsp;-- Stark, A Hidden Memory<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Everything I have seen so far is despicable.\"<BR>\n\"Welcome to the Federation Starship SS Buttcrack\"<BR>\n&nbsp;-- Jool and Crichton, Self-Inflicted Wounds 2<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"You have some nerve to talk to me that way.\"<BR>\n\"One of my very best friends has just gone. Right now I am nothing but nerve. You want someone to like you? Invest in a mirror.\" <BR>\n&nbsp;-- Chiana and Jool, Self-Inflicted Wounds 2<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"How can you not be angry? Insanely angry?\"<BR>\n\"When one of my species is bonded to a Leviathan, we give our lives to the services of others. Ship first, then those that travel aboard her.\"<BR>\n\"No matter what those aboard do to you?\"<BR>\n\"My species is incapable of space flight on our own. If we wish to journey beyond our home planet, this is the tradeoff we make for the chance to see the galaxy. I consider it a perfectly equitable arrangement.\"<BR>\n&nbsp;-- Crichton and Pilot, DNA Mad Scientist<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Hiya, Braca. Tell me is the rematch ever better than the original fight?\"<BR>\n&nbsp;--Crichton, Liars, Guns and Money, 1<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Where is Winona?\" <BR>\n\"What?\" <BR>\n\"Wi-no-na.\"<BR>\n&nbsp;-- Crichton and Crais, Green Eyed Monster<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"The instant I committed murder I sacrificed my right to exist. Since then, I view every microt as a generous yet undeserved gift from the goddess.\" <BR>\n&nbsp;-- Zhaan, Family Ties<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"What the frell was that?\" <BR>\n\"Sorry about the mess.\"<BR>\n&nbsp;-- Chiana, Aeryn and Crichton, Beware of Dog<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('farscape','\"Why are you wearing an eyepatch?\"<BR>\n\"Boolite in my eye. Why are you a moron?\" <BR>\n&nbsp;-- Rygel and Jool, Fractures<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Actually, my goal is to have a sandwich named after me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','No man in the world has more courage than the man who can stop after<BR>\neating one peanut.<BR>\n&nbsp;-- Channing Pollock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The most remarkable thing about my mother is that for thirty years she served<BR>\nthe family nothing but leftovers.  The original meal has never been found.<BR>\n&nbsp;-- Calvin Trillin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','A waist is a terrible thing to mind.<BR>\n&nbsp;-- Ziggy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Carob works on the principle that, when mixed with the right combination of<BR>\nfats and sugar, it can duplicate chocolate in color and texture.  Of course,<BR>\nthe same can be said of dirt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;A new chef from India was fired a week after starting the job.  He<BR>\nkept favoring curry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;A wife started serving chopped meat, Monday hamburger, Tuesday meat<BR>\nloaf, Wednesday tartar steak, and Thursday meatballs.  On Friday morning her<BR>\nhusband snarled, \"How now, ground cow?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Actor:	So what do you do for a living?<BR>\nDoris:	I work for a company that makes deceptively shallow serving<BR>\n&nbsp;dishes for Chinese restaurants.<BR>\n&nbsp;-- Woody Allen, \"Without Feathers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;A farm in the country side had several turkeys, it was known as the<BR>\nhouse of seven gobbles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;A couple of kids tried using pickles instead of paddles for a Ping-Pong<BR>\ngame.  They had the volley of the Dills.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','As he had feared, his orders had been forgotten and everyone had brought<BR>\nthe potato salad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','As with most fine things, chocolate has its season.  There is a simple<BR>\nmemory aid that you can use to determine whether it is the correct time<BR>\nto order chocolate dishes: any month whose name contains the letter A,<BR>\nE, or U is the proper time for chocolate.<BR>\n&nbsp;-- Sandra Boynton, \"Chocolate: The Consuming Passion\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Anything that is good and useful is made of chocolate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Be careful when you bite into your hamburger.<BR>\n&nbsp;-- Derek Bok');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Boycott meat -- suck your thumb.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','To see the butcher slap the steak, before he laid it on the block,<BR>\nand give his knife a sharpening, was to forget breakfast instantly.  It was<BR>\nagreeable, too -- it really was -- to see him cut it off, so smooth and juicy.<BR>\nThere was nothing savage in the act, although the knife was large and keen;<BR>\nit was a piece of art, high art; there was delicacy of touch, clearness of<BR>\ntone, skilful handling of the subject, fine shading.  It was the triumph of<BR>\nmind over matter; quite.<BR>\n&nbsp;-- Dickens, \"Martin Chuzzlewit\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Has anyone ever tasted an \"end\"?  Are they really bitter?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Never eat more than you can lift.<BR>\n&nbsp;-- Miss Piggy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Eat drink and be merry!  Tommorrow you may be in Utah.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Eat right, stay fit, and die anyway.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Fat Liberation: because a waist is a terrible thing to mind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Eating chocolate is like being in love without the aggravation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','\"Eat, drink, and be merry, for tomorrow you may work.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Even a cabbage may look at a king.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Everything is worth precisely as much as a belch, the difference being<BR>\nthat a belch is more satisfying.<BR>\n&nbsp;-- Ingmar Bergman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Food for thought is no substitute for the real thing.<BR>\n&nbsp;-- Walt Kelly, \"Potluck Pogo\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Everything I like is either illegal, immoral or fattening.<BR>\n&nbsp;-- Alexander Woollcott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Eat drink and be merry, for tomorrow we diet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Eat drink and be merry, for tomorrow they may make it illegal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Even a blind pig stumbles upon a few acorns.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Every time I lose weight, it finds me again!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Do not worry about which side your bread is buttered on: you eat BOTH sides.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Dieters live life in the fasting lane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Do not drink coffee in early A.M.  It will keep you awake until noon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Death before dishonor.  But neither before breakfast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Did you hear that Captain Crunch, Sugar Bear, Tony the Tiger, and<BR>\nSnap, Crackle and Pop were all murdered recently...<BR>\n&nbsp;Police suspect the work of a cereal killer!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Dinner is ready when the smoke alarm goes off.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','A gourmet who thinks of calories is like a tart that looks at her watch.<BR>\n&nbsp;-- James Beard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;During the American Revolution, a Britisher tried to raid a farm.  He<BR>\nstumbled across a rock on the ground and fell, whereupon an agressive Rhode<BR>\nIsland Red hopped on top.  Seeing this, the farmer commented, \"Chicken catch<BR>\na Tory!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','BOO!  We changed Coke again!  BLEAH!  BLEAH! ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;\"And what will you do when you grow up to be as big as me?\"<BR>\nasked the father of his little son.<BR>\n&nbsp;\"Diet.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Chinese saying: \"He who speak with forked tongue, not need chopsticks.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','MOCK APPLE PIE (No Apples Needed)<BR>\n&nbsp;Pastry to two crust 9-inch pie	36 RITZ Crackers<BR>\n2 cups water				 2 cups sugar<BR>\n2 teaspoons cream of tartar		 2 tablespoons lemon juice<BR>\n&nbsp;Grated rind of one lemon		   Butter or margarine<BR>\n&nbsp;Cinnamon<BR>\n&nbsp;Roll out bottom crust of pastry and fit into 9-inch pie plate.  Break<BR>\nRITZ Crackers coarsely into pastry-lined plate.  Combine water, sugar<BR>\nand cream of tartar in saucepan, boil gently for 15 minutes.  Add lemon<BR>\njuice and rind.  Cool.  Pour this syrup over Crackers, dot generously<BR>\nwith butter or margarine and sprinkle with cinnamon.  Cover with top<BR>\ncrust.  Trim and flute edges together.  Cut slits in top crust to let<BR>\nsteam escape.  Bake in a hot oven (425 F) 30 to 35 minutes, until crust<BR>\nis crisp and golden.  Serve warm.  Cut into 6 to 8 slices.<BR>\n&nbsp;-- Found lurking on a Ritz Crackers box');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Most people eat as though they were fattening themselves for market.<BR>\n&nbsp;-- E.W. Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Nothing takes the taste out of peanut butter quite like unrequited love.<BR>\n&nbsp;-- Charlie Brown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Pete:	Waiter, this meat is bad.<BR>\nWaiter:	Who told you?<BR>\nPete:	A little swallow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','My weight is perfect for my height -- which varies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','My favorite sandwich is peanut butter, baloney, cheddar cheese, lettuce<BR>\nand mayonnaise on toasted bread with catsup on the side.<BR>\n&nbsp;-- Senator Hubert Humphrey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Mountain Dew and doughnuts...  because breakfast is the most important meal<BR>\nof the day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','My doctor told me to stop having intimate dinners for four.  Unless there<BR>\nare three other people.<BR>\n&nbsp;-- Orson Welles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Never eat anything bigger than your head.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','It is a hard matter, my fellow citizens, to argue with the belly,<BR>\nsince it has no ears.<BR>\n&nbsp;-- Marcus Porcius Cato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If puns were deli meat, this would be the wurst.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','I have never been one to sacrifice my appetite on the altar of appearance.<BR>\n&nbsp;-- A.M. Readyhough');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Last night I dreamed I ate a ten-pound marshmallow, and when I woke up<BR>\nthe pillow was gone.<BR>\n&nbsp;-- Tommy Cooper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Home on the Range was originally written in beef-flat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;\"How did you spend the weekend?\" asked the pretty brunette secretary<BR>\nof her blonde companion.<BR>\n&nbsp;\"Fishing through the ice,\" she replied.<BR>\n&nbsp;\"Fishing through the ice?   Whatever for?\"<BR>\n&nbsp;\"Olives.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','It was a brave man that ate the first oyster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Is there life before breakfast?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','\"The National Association of Theater Concessionaires reported that in<BR>\n1986, 60% of all candy sold in movie theaters was sold to Roger Ebert.\"<BR>\n&nbsp;-- D. Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The number of feet in a yard is directly proportional to the success<BR>\nof the barbecue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The men sat sipping their tea in silence.  After a while the klutz said,<BR>\n&nbsp;\"Life is like a bowl of sour cream.\"<BR>\n&nbsp;\"Like a bowl of sour cream?\" asked the other.  \"Why?\"<BR>\n&nbsp;\"How should I know?  What am I, a philosopher?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The early bird gets the coffee left over from the night before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','&nbsp;THE DAILY PLANET<BR>\n&nbsp;SUPERMAN SAVES DESSERT!<BR>\n&nbsp;Plans to \"Eat it later\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Sacred cows make great hamburgers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','So much food; so little time!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The cow is nothing but a machine which makes grass fit for us people to eat.<BR>\n&nbsp;-- John McNulty');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Some circumstantial evidence is very strong, as when you find a trout in<BR>\nthe milk.<BR>\n&nbsp;-- Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Put cats in the coffee and mice in the tea!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The number of licorice gumballs you get out of a gumball machine<BR>\nincreases in direct proportion to how much you hate licorice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Preserve wildlife -- pickle a squirrel today!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','There are times when truth is stranger than fiction and lunch time is one<BR>\nof them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The black bear used to be one of the most commonly seen large animals<BR>\nbecause in Yosemite and Sequoia national parks they lived off of garbage<BR>\nand tourist handouts.  This bear has learned to open car doors in<BR>\nYosemite, where damage to automobiles caused by bears runs into the tens<BR>\nof thousands of dollars a year.  Campaigns to bearproof all garbage<BR>\ncontainers in wild areas have been difficult, because as one biologist<BR>\nput it, \"There is a considerable overlap between the intelligence levels<BR>\nof the smartest bears and the dumbest tourists.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','There are twenty-five people left in the world, and twenty-seven of<BR>\nthem are hamburgers.<BR>\n&nbsp;-- Ed Sanders');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','There is more simplicity in the man who eats caviar on impulse than in the<BR>\nman who eats Grape-Nuts on principle.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Prunes give you a run for your money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Put a pot of chili on the stove to simmer.  Let it simmer.  Meanwhile,<BR>\nbroil a good steak.  Eat the steak.  Let the chili simmer.  Ignore it.<BR>\n&nbsp;-- Recipe for chili from Allan Shrivers, former governor<BR>\n&nbsp;of Texas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','There is no sincerer love than the love of food.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Man who arrives at party two hours late will find he has been beaten<BR>\nto the punch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','In Mexico we have a word for sushi: bait.<BR>\n&nbsp;-- Josi Simon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If your bread is stale, make toast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If you stew apples like cranberries, they taste more like prunes than<BR>\nrhubarb does.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If you see an onion ring -- answer it!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If you put your supper dish to your ear you can hear the sounds of a<BR>\nrestaurant.<BR>\n&nbsp;-- Snoopy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If you are what you eat, does that mean Euell Gibbons really was a nut?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If food be the music of love, eat up, eat up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','If at first you fricasee, fry, fry again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','When a person goes on a diet, the first thing he loses is his temper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','I just ate a whole package of Sweet Tarts and a can of Coke. I think I saw God.<BR>\n&nbsp;-- B. Hathrume Duk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','I have no doubt that it is a part of the destiny of the human race, <BR>\nin its gradual improvement, to leave off eating animals.    <BR>\n&nbsp;-- Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','When my brain begins to reel from my literary labors, I make an occasional<BR>\ncheese dip.<BR>\n&nbsp;-- Ignatius Reilly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','I brake for chezlogs!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Have a taco.<BR>\n&nbsp;-- P.S. Beagle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','What foods these morsels be!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Whoever tells a lie cannot be pure in heart -- and only the pure in heart<BR>\ncan make a good soup.<BR>\n&nbsp;-- Ludwig Van Beethoven');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','GREAT MOMENTS IN HISTORY (#7):  November 23, 1915<BR>\n&nbsp;Pancake make-up is invented; most people continue to prefer syrup.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','God must have loved calories, she made so many of them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Wake up and smell the coffee.<BR>\n&nbsp;-- Ann Landers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Why do they call a fast a fast, when it goes so slow?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','What is food to one, is to others bitter poison.<BR>\n&nbsp;-- Titus Lucretius Carus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','This is National Non-Dairy Creamer Week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Thirteen at a table is unlucky only when the hostess has only twelve chops.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The only thing better than love is milk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','You must dine in our cafeteria.  You can eat dirt cheap there!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','You know you have a small apartment when Rice Krispies echo.<BR>\n&nbsp;-- S. Rickly Christian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','You first parents of the human race... who ruined yourself for an apple,<BR>\nwhat might you have done for a truffled turkey?<BR>\n&nbsp;-- Brillat-savarin, \"Physiologie du Gout\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Vegeterians beware!  You are what you eat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','When all else fails, EAT!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','You can always tell the Christmas season is here when you start getting<BR>\nincredibly dense, tinfoil-and-ribbon- wrapped lumps in the mail. Fruitcakes<BR>\nmake ideal gifts because the Postal Service has been unable to find a way to<BR>\ndamage them.  They last forever, largely because nobody ever eats them.  In<BR>\nfact, many smart people save the fruitcakes they receive and send them back<BR>\nto the original givers the next year; some fruitcakes have been passed back<BR>\nand forth for hundreds of years.<BR>\n&nbsp;The easiest way to make a fruitcake is to buy a darkish cake, then pound<BR>\nsome old, hard fruit into it with a mallet.  Be sure to wear safety glasses.<BR>\n&nbsp;-- Dave Barry, \"Simple, Homespun Gifts\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Two peanuts were walking through the New York.  One was assaulted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','The most exquisite peak in culinary art is conquered when you do right by a<BR>\nham, for a ham, in the very nature of the process it has undergone since last<BR>\nit walked on its own feet, combines in its flavor the tang of smoky autumnal<BR>\nwoods, the maternal softness of earthy fields delivered of their crop children,<BR>\nthe wineyness of a late sun, the intimate kiss of fertilizing rain, and the<BR>\nbite of fire.  You must slice it thin, almost as thin as this page you hold<BR>\nin your hands.  The making of a ham dinner, like the making of a gentleman,<BR>\nstarts a long, long time before the event.<BR>\n&nbsp;-- W.B. Courtney, \"Reflections of Maryland Country Ham\",<BR>\n&nbsp;from \"Congress Eate It Up\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Life without caffeine is stimulating enough.<BR>\n&nbsp;-- Sanka Ad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Life is too short to stuff a mushroom.<BR>\n&nbsp;-- Storm Jameson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Life is like an onion: you peel off layer after layer and then you find<BR>\nthere is nothing in it.<BR>\n&nbsp;-- James Huneker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Life is like an onion: you peel it off one layer at a time, and sometimes<BR>\nyou weep.<BR>\n&nbsp;-- Carl Sandburg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Without ice cream life and fame are meaningless.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Without coffee he could not work, or at least he could not have worked in the<BR>\nway he did.  In addition to paper and pens, he took with him everywhere as an<BR>\nindispensable article of equipment the coffee machine, which was no less<BR>\nimportant to him than his table or his white robe.<BR>\n&nbsp;-- Stefan Zweigs, Biography of Balzac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Life is like a bowl of soup with hairs floating on it.  You have to<BR>\neat it nevertheless.<BR>\n&nbsp;-- Flaubert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Kitchen activity is highlighted.  Butter up a friend.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Killing turkeys causes winter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Where do you go to get anorexia?<BR>\n&nbsp;-- Shelley Winters');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','It would be nice if the Food and Drug Administration stopped issuing warnings<BR>\nabout toxic substances and just gave me the names of one or two things still<BR>\nsafe to eat.<BR>\n&nbsp;-- Robert Fuoss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('food','Let not the sands of time get in your lunch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will pass away very quickly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your aim is high and to the right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your boss climbed the corporate ladder, wrong by wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your boss is a few sandwiches short of a picnic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your boyfriend takes chocolate from strangers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Domestic happiness and faithful friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will engage in a profitable business activity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will contract a rare disease.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Do what comes naturally.  Seethe and fume and throw a tantrum.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Do something unusual today.  Pay a bill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be winged by an anti-aircraft battery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Do nothing unless you must, and when you must act -- hesitate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Do not overtax your powers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Day of inquiry.  You will be subpoenaed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Courage is your greatest present need.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will forget that you ever knew me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Cold hands, no gloves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Chicken Little only has to be right once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Chess tonight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Cheer Up!  Things are getting worse at a slower rate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will gain money by a fattening action.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Celebrate Hannibal Day this year.  Take an elephant to lunch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Caution: breathing may be hazardous to your health.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Bridge ahead.  Pay troll.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Blow it out your ear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware of low-flying butterflies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware of a tall blond man with one black shoe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware of a tall black man with one blond shoe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware of a dark-haired man with a loud tie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will experience a strong urge to do good; but it will pass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Best of all is never to have been born.  Second best is to die soon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will gain money by a speculation or lottery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be surprised by a loud noise.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beauty and harmony are as necessary to you as the very breath of life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be security conscious -- National defense is at stake.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will have a long and unpleasant discussion with your supervisor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be different: conform.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will have a long and boring life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be cautious in your daily affairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be careful!  UGLY strikes 9 out of 10!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be careful!  Is it classified?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Bank error in your favor.  Collect $200.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will have good luck and overcome many hardships.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Avoid reality at all costs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Avoid gunfire in the bathroom tonight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will inherit millions of dollars.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Avert misunderstanding by calm, poise, and balance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Are you sure the back door is locked?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will live a long, healthy, happy life and make bags of money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will have long and healthy life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Another good night not to sleep in a eucalyptus tree.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','An exotic journey in downtown Newark is in your future.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','An avocado-tone refrigerator would look good on your resume.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','All the troubles you have will pass away very quickly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will live to see your grandchildren.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','After your lover has gone you will still have PEANUT BUTTER!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Accent on helpful side of your nature.  Drain the moat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Abandon the search for Truth; settle for a good fantasy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A vivid and creative mind characterizes you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A visit to a fresh place will bring strange work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A gift of a flower will soon be made to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A day for firm decisions!!!!!  Or is it?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will meet an important person who will help you advance professionally.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will outgrow your usefulness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will not be elected to public office this year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A few hours grace before the madness begins again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be successful in love.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will lose your present job and have to become a door to door mayonnaise<BR>\nsalesman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will gain money by an immoral action.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will pay for your sins.  If you have already paid, please disregard<BR>\nthis message.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will probably marry after a very brief courtship.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will reach the highest possible point in your business or profession.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will remember something that you should not have forgotten.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will receive a legacy which will place you above want.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will soon forget this.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will triumph over your enemy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will step on the night soil of many countries.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will visit the Dung Pits of Glive soon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will win success in whatever calling you adopt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You worry too much about your job.  Stop it.  You are not paid enough to worry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A long-forgotten loved one will appear soon.<BR>\n&nbsp;Buy the negatives at any price.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good day to let down old friends who need help.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Be cheerful while you are alive.<BR>\n&nbsp;-- Phathotep, 24th Century B.C.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Someone is speaking well of you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Slow day.  Practice crawling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Questionable day.<BR>\n&nbsp;Ask somebody something.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','People are beginning to notice you.  Try dressing before you leave the house.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Of course you have a purpose -- to find a purpose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Never reveal your best argument.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Are you making all this up as you go along?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Never give an inch!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Never commit yourself!  Let someone else commit you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Never be led astray onto the path of virtue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Make a wish, it might come true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Look afar and see the end from the beginning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Live in a world of your own, but always welcome visitors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Artistic ventures highlighted.  Rob a museum.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Let me put it this way: today is going to be a learning experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Are you ever going to do the dishes?  Or will you change your major to biology?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Break into jail and claim police brutality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Learn to pause -- or nothing worthwhile can catch up to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Lady Luck brings added income today.  Lady friend takes it away tonight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Keep it short for pithy sake.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Just to have it is enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Just because the message may never be received does not mean it is<BR>\nnot worth sending.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','It may or may not be worthwhile, but it still has to be done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Is this really happening?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Alimony and bribes will engage a large share of your wealth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Is that really YOU that is reading this?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good news.  Ten weeks from Friday will be a pretty good day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good news from afar can bring you a welcome visitor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Among the lucky, you are the chosen one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good day for overcoming obstacles.  Try a steeplechase.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Go to a movie tonight.  Darkness becomes you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Afternoon very favorable for romance.  Try a single person for a change.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Give him an evasive answer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be held hostage by a radical group.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Generosity and perfection are your everlasting goals.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Future looks spotty.  You will spill soup in late evening.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be married within a year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Fine day for friends.<BR>\nSo-so day for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Expect a letter from a friend who will ask a favor of you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be singled out for promotion in your work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Exercise caution in your daily affairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Excellent time to become a missing person.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A visit to a strange place will bring fresh work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be recognized and honored as a community leader.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Excellent day to have a rotten day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Excellent day for putting Slinkies on an escalator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good day to deal with people in high places; particularly lonely stewardesses.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Everything will be just tickety-boo today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Everything that you know is wrong, but you can be straightened out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Caution: Keep out of reach of children.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Advancement in position.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','A tall, dark stranger will have more fun than you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Are you a turtle?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be the victim of a bizarre joke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be traveling and coming into a fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be Told about it Tomorrow.  Go Home and Prepare Thyself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be the last person to buy a Chrysler.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You like to form new friendships and make new acquaintances.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have taken yourself too seriously.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have no real enemies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have many friends and very few living enemies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have an unusual understanding of the problems of human relationships.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have an unusual equipment for success.  Be sure to use it properly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have an ambitious nature and may make a name for yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have an ability to sense and know higher truth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Executive ability is prominent in your make-up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a will that can be influenced by all with whom you come in contact.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a truly strong individuality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Give thought to your reputation.  Consider changing name and moving to<BR>\na new town.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a strong appeal for members of your own sex.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a deep interest in all that is artistic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You had some happiness once, but your parents moved away, and you had to<BR>\nleave it behind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You get along very well with everyone except animals and people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You fill a much-needed gap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have literary talent that you should take pains to develop.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You feel a whole lot more like you do now than you did when you used to.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You enjoy the company of other people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have the body of a 19 year old.  Please return it before it gets wrinkled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You display the wonderful traits of charm and courtesy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You dialed 5483.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You could live a better life, if you had a better mind and a better body.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You can rent this space for only $5 a week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You may get an opportunity for advancement today.  Watch it!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You can create your own opportunities this week.  Blackmail a senior executive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You attempt things that you do not even plan because of your extreme stupidity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are the only person to ever get this message.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You own a dog, but you can only feed a cat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You seek to shield those you love and you like the role of the provider.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are taking yourself far too seriously.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Do not sleep in a eucalyptus tree tonight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are standing on my toes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are sick, twisted and perverted.  I like that in a person.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are number 6!  Who is number one?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are magnetic in your bearing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are fighting for survival in your own sweet and gentle way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are farsighted, a good planner, an ardent lover, and a faithful friend.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be a winner today.  Pick a fight with a four-year-old.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are dishonest, but never to the point of hurting a friend.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are deeply attached to your friends and acquaintances.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Chicken Little was right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are capable of planning your future.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are always busy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be called upon to help a friend in trouble.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Write yourself a threatening letter and pen a defiant reply.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Tuesday is the Wednesday of the rest of your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Good day for a change of scene.  Repaper the bedroom wall.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Try to value useful qualities in one who loves you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Try to relax and enjoy the crisis.<BR>\n&nbsp;-- Ashleigh Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Try to get all of your posthumous medals in advance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Try the Moo Shu Pork.  It is especially good today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Change your thoughts and you change your world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Truth will out this morning.  (Which may really mess things up.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Tomorrow will be cancelled due to lack of interest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is what happened to yesterday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is the tomorrow you worried about yesterday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is the first day of the rest of your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is the first day of the rest of the mess.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is National Existential Ennui Awareness Day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Things will be bright in P.M.  A cop will shine a light in your face.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','There will be big changes for you but you will be happy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','There was a phone call for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','There is a fly on your nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Stay the curse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Stay away from hurricanes for a while.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware the one behind you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Stay away from flying saucers today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Someone is speaking well of you.<BR>\n&nbsp;How unusual!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have had a long-term stimulation relative to business.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are going to have a new love affair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are not dead yet.  But watch for further reports.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are destined to become the commandant of the fighting men of the<BR>\ndepartment of transportation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are fairminded, just and loving.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are only young once, but you can stay immature indefinitely.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are a fluke of the universe; you have no right to be here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are as I am with You.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are confused; but this is your normal state.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are a bundle of energy, always on the go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are scrupulously honest, frank, and straightforward.  Therefore you<BR>\nhave few friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Troubled day for virgins over 16 who are beautiful and wealthy and live<BR>\nin eucalyptus trees.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Try to have as good a life as you can under the circumstances.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Tomorrow, you can be anywhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Tuesday After Lunch is the cosmic time of the week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Today is the last day of your life so far.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','What happened last night can happen again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Tomorrow, this will be part of the unchangeable past but fortunately,<BR>\nit can still be changed today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','This will be a memorable month -- no matter how hard you try to forget it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You learn to write as if to someone else because NEXT YEAR YOU WILL BE<BR>\n\"SOMEONE ELSE.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Time to be aggressive.  Go after a tattooed Virgo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','The time is right to make new friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Someone whom you reject today, will reject you tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Snow Day -- stay home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Ships are safe in harbor, but they were never meant to stay there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','The whole world is a tuxedo and you are a pair of brown shoes.<BR>\n&nbsp;-- George Gobel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Perfect day for scrubbing the floor and other exciting things.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Reply hazy, ask again later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Never look up when dragons fly overhead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Love is in the offing.  Be affectionate to one who adores you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','There is a 20% chance of tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Many changes of mind and mood; do not hesitate too long.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Long life is in store for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Save energy: be apathetic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Keep emotionally active.  Cater to your favorite neurosis.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','It is so very hard to be an <BR>\non-your-own-take-care-of-yourself-because-there-is-no-one-else-to-do-it-for-you<BR>\ngrown-up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','It was all so different before everything changed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Life is to you a dashing and bold adventure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','If you think last Tuesday was a drag, wait till you see what happens tomorrow!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','If you stand on your head, you will get footprints in your hair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','If you sow your wild oats, hope for a crop failure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Green light in A.M. for new projects.  Red light in P.M. for traffic tickets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','This life is yours.  Some of it was given to you; the rest, you made yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Living your life is a task so difficult, it has never been attempted before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Hope that the day after you die is a nice day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be given a post of trust and responsibility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be divorced within a year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be awarded the Nobel Peace Prize... posthumously.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be awarded some great honor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be aided greatly by a person whom you thought to be unimportant.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your love life will be happy and harmonious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your true value depends entirely on what you are compared with.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your life would be very empty if you had nothing to regret.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your lover will never wish to leave you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will never know hunger.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will obey or molten silver will be poured into your ears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will hear good news from one you thought unfriendly to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will inherit some money or a small piece of land.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will overcome the attacks of jealous associates.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will get what you deserve.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will gain money by an illegal action.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will give someone a piece of your mind, which you can ill afford.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will have domestic happiness and faithful friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will feel hungry again in another hour.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will pioneer the first Martian colony.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be run over by a beer truck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be run over by a bus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be misunderstood by everyone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be reincarnated as a toad; and you will be much happier.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be surrounded by luxury.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be honored for contributing your time and skill to a worthy cause.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be awarded a medal for disregarding safety in saving someone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be imprisoned for contributing your time and skill to a bank robbery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be married within a year, and divorced within two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be audited by the Internal Revenue Service.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will soon meet a person who will play an important role in your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You two ought to be more careful--your love could drag on for years and years.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will always get the greatest recognition for the job you least like.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You single-handedly fought your way into this hopeless mess.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You too can wear a nose mitten.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will attract cultured and artistic people to your home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You possess a mind not merely twisted, but actually sprained.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You recoil from the crude; you tend naturally toward the exquisite.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You shall be rewarded for a dastardly deed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You prefer the company of the opposite sex, but are well liked by your own.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be advanced socially, without any special effort on your part.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You may worry about your hair-do today, but tomorrow much peanut butter will<BR>\nbe sold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You never hesitate to tackle the most difficult problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You look tired.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You never know how many friends you have until you rent a house on the beach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You love peace.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have the power to influence all with whom you come in contact.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You love your home and want it to be beautiful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You plan things that you do not even attempt because of your extreme caution.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will be attacked by a beast who has the body of a wolf, the tail of<BR>\na lion, and the face of Donald Duck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will stop at nothing to reach your objective, but only because your<BR>\nbrakes are defective.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a strong desire for a home and your family interests come first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a deep appreciation of the arts and music.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have a strong appeal for members of the opposite sex.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You have been selected for a secret mission.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You can do very well in speculation where land or anything to do with dirt<BR>\nis concerned.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are wise, witty, and wonderful, but you spend too much time reading<BR>\nthis sort of trash.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You definitely intend to start living sometime soon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You are so boring that when I see you my feet go to sleep.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You will always have good luck in your personal affairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your business will assume vast proportions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your business will go through a period of considerable expansion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your heart is pure, and your mind clear, and your soul devout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your domestic life may be harmonious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your love life will be... interesting.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your present plans will be successful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your step will soil many countries.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your society will be sought by people of taste and refinement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your supervisor is thinking about you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your temporary financial embarrassment will be relieved in a surprising manner.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your sister swims out to meet troop ships.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your own qualities will help prevent your advancement in the world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your talents will be recognized and suitably rewarded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your reasoning powers are good, and you are a fairly good planner.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your mode of life will be changed for the better because of new developments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your motives for doing whatever good deed you may have in mind will be<BR>\nmisinterpreted by somebody.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your nature demands love and your happiness depends on it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your lucky number is 3552664958674928.  Watch for it everywhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your lucky color has faded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your lucky number has been disconnected.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your object is to save the world, while still leading a pleasant life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your mode of life will be changed for the better because of good news soon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your depth of comprehension may tend to make you lax in worldly ways.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your goose is cooked.<BR>\n(Your current chick is burned up too!)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your aims are high, and you are capable of much.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You teach best what you most need to learn.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You should go home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Fine day to work off excess energy.  Steal something heavy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You now have Asian Flu.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You need more time; and you probably always will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You may be recognized soon.  Hide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','You look like a million dollars.  All green and wrinkled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Your ignorance cramps my conversation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('fortunes','Beware of Bigfoot!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','The realization of what I am occurs in the timeless awareness which does not <BR>\nstimulate nor delude. I create a field without self or center, a field where <BR>\neven death becomes only analogy. I desire no results. I merely permit this <BR>\nfield which has no goals nor desires, no perfections nor even visions of <BR>\nachievements. In that field, omnipresent primal awareness is all. It is the <BR>\nlight which pours through the windows of my universe.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Let there be no doubt that I am the assemblage of our ancestors, the arena in <BR>\nwhich they exercise my moments. They are my cells and I am their body. This is <BR>\nthe favrashi of which I speak, the soul, the collective unconscious, the source <BR>\nof archetypes, the repository of all trauma and joy. I am the choice of their <BR>\nawakening. My samhadi is their samhadi. Their experiences are mine! Their <BR>\nknowledge distilled is mfr inheritance. Those billions are my one.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Memory has a curious meaning to me, a meaning I have hoped others might share. <BR>\nIt continually astonished me how people hide from their ancestral memories, <BR>\nshielding themselves behind a thick barrier of mythos. Ohhh, I do not expect <BR>\nthem to seek the terrible immediacy of every living moment which I must <BR>\nexperience. I can understand that they might not want to be submerged in a mush <BR>\nof petty ancestral details. You have reason to fear that your living moments <BR>\nmight be taken over by others. Yet, the meaning is there within those memories. <BR>\nWe carry all of our ancestry forward like a living wave, all of the hopes and <BR>\njoys and griefs, the agonies and the exultations of our past. Nothing within <BR>\nthose memories remains completely without meaning or influence, not as long as <BR>\nthere is a humankind somewhere. We have that bright Infinity all around us, <BR>\nthat Golden Path of forever to which we can continually pledge our puny but <BR>\ninspired allegiance.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Groups tend to condition their surroundings for group survival. When they <BR>\ndeviate from this it may be taken as a sign of group sickness. There are many <BR>\ntelltale symptoms. I watch the sharing of food. This is a form of <BR>\ncommunication, an inescapable sign of mutual aid which also contains a deadly <BR>\nsignal of dependency. It is interesting that men are the ones who usually tend <BR>\nthe landscape today. They are husband-men. Once, that was the sole province of <BR>\nwomen.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','You think power may be the most unstable of all human achievements? Then what <BR>\nof the apparent exceptions to this inherent instability? Some families endure. <BR>\nVery powerful religious bureaucracies have been known to endure. Consider the <BR>\nrelationship between faith and power. Are they mutually exclusive when each <BR>\ndepends upon the other? The Bene Gesserit have been reasonably secure within <BR>\nthe loyal walls of faith for thousands of years. But where has their power gone?<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','In the cradle of our past, I lay upon my back in a cave so shallow I could <BR>\npenetrate it only by squirming, not by crawling. There, by the dancing light of <BR>\na resin torch, I drew upon walls and ceiling the creatures of the hunt and the <BR>\nsouls of my people. How illuminating it is to peer backward through a perfect <BR>\ncircle at that ancient struggle for the visible moment of the soul. All time <BR>\nvibrates to that call: \"Here I am!\" With a mind informed by artist-giants who <BR>\ncame afterward, I peer at handprints and flowing muscles drawn upon the rock <BR>\nwith charcoal and vegetable dyes. How much more we are than mere mechanical <BR>\nevents! And my anti-civil self demands: \"Why is it that they do not want to <BR>\nleave the cave?\"<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','I know the evil of my ancestors because I am those people. The balance is <BR>\ndelicate in the extreme. I know that few of you who read my words have ever <BR>\nthought about your ancestors this way. It has not occurred to you that your <BR>\nancestors were survivors and that the survival itself sometimes involved savage <BR>\ndecisions, a kind of wanton brutality which civilized humankind works very hard <BR>\nto suppress. What price will you pay for that suppression? Will you accept your <BR>\nown extinction?<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','The female sense of sharing originated as familial sharing-care of the young, <BR>\nthe gathering and preparation of food, sharing joys, love and sorrows. Funeral <BR>\nlamentation originated with women. Religion began as a female monopoly, wrested <BR>\nfrom them only after its social power became too dominant. Women were the first <BR>\nmedical researchers and Practitioners. There has never been any clear balance <BR>\nbetween the sexes because power goes with certain roles as it certainly goes <BR>\nwith knowledge.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','From that welter of memories which I can tap at will, patterns emerge. They are <BR>\nlike another language which I see so clearly The social-alarm signals which put <BR>\nsocieties into the postures of defense attack are like shouted words to me. As <BR>\na people. you react against threats to innocence and the peril of the helpless <BR>\nyoung. Unexplained sounds, visions and smells raise the hackles you have <BR>\nforgotten you possess. When alarmed, you cling to your native language because <BR>\nall the other patterned sounds are strange. You demand acceptable dress because <BR>\na strange costume is threatening. This is system feedback at its most primitive <BR>\nlevel. Your cells remember<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','If you know all of your ancestors, you were a personal witness to the events <BR>\nwhich created the myths and religions of our past. Recognizing this, you must <BR>\nthink of me as a myth-maker.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','The pattern of monarchies and similar systems has a message of value for all <BR>\npolitical forms. My memories assure me that governments of any kind could <BR>\nprofit from this message. Governments can be useful to the governed only so <BR>\nlong as inherent tendencies toward tyranny are restrained. Monarchies have some <BR>\ngood features beyond their star qualities. They can reduce the size and <BR>\nparasitic nature of the management bureaucracy. They can make speedy decisions <BR>\nwhen necessary. They fit an ancient human demand for a parental (tribal/feudal) <BR>\nhierarchy where every person knows his place. It is valuable to know your <BR>\nplace, even if that place is temporary. It is galling to be held in place <BR>\nagainst your will. This is why I teach about tyranny in the best possible way <BR>\nby example. Even though you read these words after a passage of eons, my <BR>\ntyranny will not be forgotten. My Golden Path assures this. Knowing my message, <BR>\nI expect you to be exceedingly careful about the powers you delegate to any <BR>\ngovernment.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Our ancestor, Assur-nasir-apli, who was known as the cruelest of the cruel, <BR>\nseized the throne by slaying his own father and starting the reign of the <BR>\nsword. His conquests included the Ururnia Lake region. which led him to <BR>\nCommagene and Khabur. His son received tribute from the Shuites, from Tyre, <BR>\nSidon, Gebel and even from Jehu, son of Omri whose very name struck terror into <BR>\nthousands. The conquests which began with Assur-nasirapli carried arms into <BR>\nMedia and later into Israel, Damascus, Edom, Arpad, Babylon and Umlias. Does <BR>\nanyone remember these names and places now? I have given you enough clues: Try <BR>\nto name the planet.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Some say I have no conscience. How false they are, even to themselves. I am the <BR>\nonly conscience which has ever existed. As wine retains the perfume of its <BR>\ncask, I retain the essence of my most ancient genesis, and that is the seed of <BR>\nconscience. That is what makes me holy. I am God because I am the only one who <BR>\nreally knows his heredity!<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Sometimes I indulge myself in safaris which no other being may take. I strike <BR>\ninward along the axis of my memories. Like a schoolchild reporting on a <BR>\nvacation trip, I take up my subject. Let it be . . . female intellectuals! I <BR>\ncourse backward into the ocean which is my ancestors. I am a great winged fish <BR>\nin the depths. The mouth of my awareness opens and I scoop them up! <BR>\nSometimes... sometimes I hunt out specific persons recorded in our histories. <BR>\nWhat a private joy to relive the life of such a one while I mock the academic <BR>\npretentions which supposedly formed a biography.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Your Lord knows very well what is in your heart. Your soul suffices this day as <BR>\na reckoner against you. I need no witnesses. You do not listen to your soul, <BR>\nbut listen instead to your anger and your rage.<BR>\n&nbsp;-Lord Leto to a Penitent,<BR>\nFrom the Oral History');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','You must remember that I have at my internal demand every expertise known to <BR>\nour history. This is the fund of energy I -draw upon when I address the <BR>\nmentality of war. If you have not heard the moaning cries of the wounded and <BR>\nthe dying, you do not know about war. I have heard those cries in such numbers <BR>\nthat they haunt me. I have cried out myself in the aftermath of battle. I have <BR>\nsuffered wounds in every epoch-wounds from fist and club and rock, from <BR>\nshell-studded limb and bronze sword, from the mace and the cannon, from arrows <BR>\nand lasguns and the silent smothering of atomic dust, from biological invasions <BR>\nwhich blacken the tongue and drown the lungs, from the swift gush of flame and <BR>\nthe silent working of slow poisons. . . and more I will not recount! I have <BR>\nseen and felt them all. To those who dare ask why I behave as I do, I say: With <BR>\nmy memories, I can do nothing else. I am not a coward and once I was human.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','I am beginning to hate water. The sandtrout skin which impels my metamorphosis <BR>\nhas learned the sensitivities of the worm. Moneo and many of my guards know my <BR>\naversion, Only Moneo suspects the truth, that this marks an important waypoint. <BR>\nI can feel my ending in it, not soon as Moneo measures time, but soon enough as <BR>\nI endure it. Sandtrout swarmed to water in the Dune days, a problem during the <BR>\nearly stages of our symbiosis. The enforcement of my will power controlled the <BR>\nurge then, and until we reached a time of balance. Now, I must avoid water <BR>\nbecause there are no other sandtrout, only the half dormant creatures of my <BR>\nskin. Without sandtrout to bring this world back to desert, Shai-Hulud will not <BR>\nemerge; the sandworm cannot evolve until the land is parched. I am their only <BR>\nhope.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Oh, the landscapes I have seen! And the people! The far wanderings of the <BR>\nFremen and all the rest of it. Even back through the myths to Terra. Oh, the <BR>\nlessons in astronomy and intrigue, the migrations, the disheveled flights, the <BR>\nleg aching and lung-aching runs through so many nights on all of those cosmic <BR>\nspecks where we have defended our transient possession. I tell you we are a <BR>\nmarvel and my memories leave no doubt of this.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','You, the first person to encounter my chronicles for at least four thousand <BR>\nyears, beware. Do not feel honored by your primacy in reading the revelations <BR>\nof my Ixian storehouse. You will find much pain in it. Other than the few <BR>\nglimpses required to assure me that the Golden Path continued. I never wanted <BR>\nto peer beyond those four millennia. Therefore, I am not sure what the events <BR>\nin my journals may signify to your times. I only know that my journals have <BR>\nsuffered oblivion and that the events which I recount have undoubtedly been <BR>\nsubmitted to historical distortion for eons. I assure you that the ability to <BR>\nview our futures can become a bore. Even to be thought of as a god, as I <BR>\ncertainly was, can become ultimately boring. It has occurred to me more than <BR>\nonce that holy boredom is good and sufficient reason for the invention of free <BR>\nwill.<BR>\n&nbsp;-Inscription on the storehouse at bar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','\"Make no heroes,\" my father said.<BR>\n&nbsp;-The voice of Ghanima,<BR>\nFrom the Oral History');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','The singular multiplicity of this universe draws my deepest attention. It is a <BR>\nthing of ultimate beauty.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','I tell you this in the hope that it will help you understand why I ad as I do <BR>\nin the full knowledge that great forces accumulate in my Empire with but one <BR>\nwish-the wish to destroy me. You who read these words may know full well what <BR>\nactually happened, but I doubt that you understand it.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','I have isolated the city-experience within me and have examined it closely. The <BR>\nidea of a city fascinates me. The formation of a biological community without a <BR>\nfunctioning, supportive social community leads to havoc. Whole worlds have <BR>\nbecome single biological communities without an interrelated social structure <BR>\nand this has always led to ruin. It becomes dramatically instructive under <BR>\novercrowded conditions. The ghetto is lethal. Psychic stresses of overcrowding <BR>\ncreate pressures which will erupt. The city is an attempt to manage these <BR>\nforces. The social forms by which cities make the attempt are worth study. <BR>\nRemember that there exists a certain malevolence about the formation of any <BR>\nsocial order. It is the struggle for existence by an artificial entity. <BR>\nDespotism and slavery hover at the edges. Many injuries occur and, thus, the <BR>\nneed for laws. The law develops its own power structure, creating more wounds <BR>\nand new injustices. Such trauma can be healed by cooperation, not by <BR>\nconfrontation. The summons to cooperate identifies the healer.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','I am both father and mother to my people. I have known the ecstasy of birth and <BR>\nthe ecstasy of death and I know the patterns that you must team. Have I not <BR>\nwandered intoxicated through the universe of shapes? Yes! I have seen you <BR>\noutlined in light. That universe which you say you see and feel, that universe <BR>\nis my dream. My energies focus upon it and I am in any realm and every realm. <BR>\nThus, you are born.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','As each day passes, you become increasingly unreal, more alien and remote from <BR>\nwhat I find myself to be on that new day. I am the only reality and, as you <BR>\ndiffer from me, you lose reality. The more curious I become, the less curious <BR>\nare those who worship me. Religion suppresses curiosity. What I do subtracts <BR>\nfrom the worshipper. Thus it is that eventually I will do nothing, giving it <BR>\nall back to frightened people who will ,find themselves on that day alone and <BR>\nforced to act for themselves.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','The trance-state of prophecy is like no other visionary experience. It is not a <BR>\nretreat from the raw exposure of the senses (as are many trance-states) but an <BR>\nimmersion in a multitude of new movements. Things moue. It is an ultimate <BR>\npragmatism in the midst of Infinity, a demanding consciousness where you come <BR>\nat last into the unbroken awareness that the universe moves of itself, that it <BR>\nchanges, that its rules change. that nothing remains permanent or absolute <BR>\nthroughout all such movement, that mechanical explanations for anything can <BR>\nwork only within precise confinements and, once the walls are broken down, the <BR>\nold explanations shatter and dissolve, blown away by new movements. The things <BR>\nyou see in this trance are sobering, often shattering They demand your utmost <BR>\neffort to remain whole and. even so, you emerge from that state profoundly <BR>\nchanged.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Think of it as plastic memory, this force within you which trends you and your <BR>\nfellows toward tribal forms. This plastic memory seeks to return to its ancient <BR>\nshape, the tribal society. It is all around you-the feudatory, the diocese, the <BR>\ncorporation, the platoon, the sports club, the dance troupes, the rebel cell, <BR>\nthe planning council, the prayer group . . . each with its master and servants, <BR>\nits host and parasites. And the swarms of alienating devices (including these <BR>\nvery words!) tend eventually to be enlisted in the argument for a return to <BR>\n\"those better rimes.\" I despair of teaching you other ways. You have square <BR>\nthoughts which resist circles.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','What is the most immediate danger to my stewardship? I will tell you. It is a <BR>\ntrue visionary, a person who has stood in the presence of God with the full <BR>\nknowledge of where he stands. Visionary ecstasy releases energies which are <BR>\nlike the energies of sex-uncaring for anything except creation. One act of <BR>\ncreation can be much like another. Everything depends upon the vision.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Given enough time for the generations to evolve, the predator produces <BR>\nparticular survival adaptations in its prey which, through the circular <BR>\noperation of feedback, produce changes in the predator which again change the <BR>\nprey etcetera, etcetera, etcetera .... Many powerful forces do the same thing. <BR>\nYou can count religions among such forces.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','Do you know what guerrillas often say? They claim that their rebellions are <BR>\ninvulnerable to economic warfare because they have no economy, that they are <BR>\nparasitic on those they would overthrow. The fools merely fail to assess the <BR>\ncoin in which they must inevitably pay. The pattern is inexorable in its <BR>\ndegenerative failures. You see it repeated in the systems of slavery, of <BR>\nwelfare states, of caste-ridden religions, of socializing bureaucracies-in any <BR>\nsystem which creates and maintains dependencies. Too long a parasite and you <BR>\ncannot exist without a host.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('god-emperor','One of the most terrible words in any language is Soldier. The synonyms parade <BR>\nthrough our history: yogahnee, trooper, hussar, kareebo, cossack, deranzeef, <BR>\nlegionnaire, sardaukar, fish speaker... I know them all. They stand there in <BR>\nthe ranks of my memory to remind me: Always make sure you have the army with <BR>\nyou.<BR>\n&nbsp;-The Stolen Journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Chocolate chip.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Did you know about the -o option of the fortune program?  It makes a<BR>\nselection from a set of offensive and/or obscene fortunes.  Why not<BR>\ntry it, and see how offended you are?  The -a (\"all\") option will<BR>\nselect a fortune at random from either the offensive or inoffensive<BR>\nset, and it is suggested that \"fortune -a\" is the command that you<BR>\nshould have in your .profile or .cshrc. file.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune intentionally says nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','=======================================================================<BR>\n||								     ||<BR>\n|| The FORTUNE-COOKIE program is soon to be a Major Motion Picture!  ||<BR>\n||	   Watch for it at a theater near you next summer!	     ||<BR>\n||								     ||<BR>\n=======================================================================<BR>\n&nbsp;Francis Ford Coppola presents a George Lucas Production:<BR>\n&nbsp;\"Fortune Cookie\"<BR>\n&nbsp;Directed by Steven Spielberg.<BR>\n&nbsp;Starring  Harrison Ford  Bette Midler  Marlon Brando<BR>\n&nbsp;Christopher Reeves  Marilyn Chambers<BR>\n&nbsp;and Bob Hope as \"The Waiter\".<BR>\n&nbsp;Costumes Designed by Pierre Cardin.<BR>\n&nbsp;Special Effects by Timothy Leary.<BR>\n&nbsp;Read the Warner paperback!<BR>\n&nbsp;Invoke the Unix program!<BR>\n&nbsp;Soundtrack on XTC Records.<BR>\n&nbsp;In 70mm and Dolby Stereo at selected theaters and terminal<BR>\n&nbsp;centers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Ginger snap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Generic Fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Ignore previous fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','If you wish to live wisely, ignore sayings -- including this one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','In which level of metalanguage are you now speaking?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Vanilla wafer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Very few profundities can be expressed in less than 80 characters.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','WARNING:<BR>\n&nbsp;Reading this fortune can affect the dimensionality of your<BR>\n&nbsp;mind, change the curvature of your spine, cause the growth<BR>\n&nbsp;of hair on your palms, and make a difference in the outcome<BR>\n&nbsp;of your favorite war.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','There is no such thing as fortune.  Try again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune intentionally not included.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune intentionally left blank.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This is your fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This Fortune Examined By INSPECTOR NO. 2-14');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune would be seven words long if it were six words shorter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune is false.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune soaks up 47 times its own weight in excess memory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune is encrypted -- get your decoder rings ready!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune is inoperative.  Please try another.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune is dedicated to your mother, without whose invaluable assistance<BR>\nlast night would never have been possible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune was brought to you by the people at Hewlett-Packard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','What does it mean if there is no fortune for you?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','If there are epigrams, there must be meta-epigrams.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Since before the Earth was formed and before the sun burned hot in space,<BR>\ncosmic forces of inexorable power have been working relentlessly toward<BR>\nthis moment in space-time -- your receiving this fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Has anyone realized that the purpose of the fortune cookie program is to<BR>\ndefuse project tensions?  When did you ever see a cheerful cookie, a<BR>\nnon-cynical, or even an informative cookie?<BR>\n&nbsp;Perhaps inadvertently, we have a channel for our aggressions.  This<BR>\nstill begs the question of whether the cookie releases the pressure or only<BR>\nserves to blunt the warning signs.<BR>\n&nbsp;Long live the revolution!<BR>\n&nbsp;Have a nice day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Do not read this fortune under penalty of law.<BR>\nViolators will be prosecuted.<BR>\n(Penal Code sec. 2.3.2 (II.a.))');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','For some reason, this fortune reminds everyone of Marvin Zelkowitz.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','This fortune cookie program out of order.  For those in desperate need,<BR>\nplease use the program \"________randchar\".  This program generates random<BR>\ncharacters, and, given enough time, will undoubtedly come up with<BR>\nsomething profound.  It will, however, take it no time at all to be<BR>\nmore profound than THIS program has ever been.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','The fortune program is supported, in part, by user contributions and by<BR>\na major grant from the National Endowment for the Inanities.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Pardon this fortune.  Database under reconstruction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','You will think of something funnier than this to add to the fortunes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','We interrupt this fortune for an important announcement...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Beware of computerized fortune-tellers!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Pick another fortune cookie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Please ignore previous fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Sorry, no fortune this time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Oatmeal raisin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('goedel','Oreo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The world is for the living.  Who are they?<BR>\nWe dared the dark to reach the white and warm.<BR>\nShe was the wind when the wind was in my way.<BR>\nAlive at noon, I perished in her form.<BR>\nWho rise from the flesh to spirit know the fall:<BR>\nThe word outleaps the world and light is all.<BR>\n&nbsp;-Theodore Roethke (Historical Quotations:  Dar-es-Balat)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Historians exercise great power and some of them know it.  They recreate the p<BR>\nast, changing it to fit their own interpretations.  Thus, they change the futu<BR>\nre as well.<BR>\n&nbsp;-Leto II, His Voice, from Dar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The worst potential competition for any organism can come from its own kind.  <BR>\nThe species consumes necessities.  Growth is limited by that necessity which i<BR>\ns present in the least amount.  The least favorable condition controls the rat<BR>\ne of growth.  (Law of the Minimum)<BR>\n&nbsp;-From \"Lessons of Arrakis\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Our fathers ate manna in the desert,<BR>\nIn the burning place where whirlwinds came.<BR>\nLord, save us from that horrible land!<BR>\nSave us, oh-h-h-h-h save us<BR>\nFrom that dry and thirsty land.<BR>\n&nbsp;-Songs of Gurney Halleck, Museum of Dar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','There was a man who sat each day looking out through a narrow vertical opening<BR>\n&nbsp;where a single board had been removed from a tall wooden fence.  Each day a w<BR>\nild ass of the desert passed outside the fence and across the narrow opening -<BR>\n- first the nose, then the head, the forelegs, the long brown back, the hindle<BR>\ngs, and lastly the tail.  One day, the man leaped to his feet with the light o<BR>\nf discovery in his eyes and he shouted for all who could hear him:  \"It is obv<BR>\nious!  The nose causes the tail!\"<BR>\n&nbsp;-Stories of the Hidden Wisdom, from the Oral History of Rakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','O you who know what we suffer here, do not forget us in your prayers.<BR>\n&nbsp;-Sign over Arrakeen Landing Field (Historical Records:  Dar-es-Balat)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','All organized religions face a common problem, a tender spot through which we <BR>\nmay enter and shift them to our designs:  How do they distinguish hubris from <BR>\nrevelation?<BR>\n&nbsp;-Missionaria Protectiva, the Inner Teachings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','I remember friends from wars all but we forgot.<BR>\nAll of them distilled into each wound we caught.<BR>\nThose wounds are all the painful places where we fought.<BR>\nBattles better left behind, ones we never sought.<BR>\nWhat is it that we spent and what was it we bought?<BR>\n&nbsp;-Songs of the Scattering');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','This is the awe-inspiring universe of magic:  There are no atoms, only waves a<BR>\nnd motions all around.  Here, you discard all belief in barriers to understand<BR>\ning.  You put aside understanding itself.  This universe cannot be seen, canno<BR>\nt be heard, cannot be detected in any way by fixed perceptions.  It is the ult<BR>\nimate void where no preordained screens occur upon which forms may be projecte<BR>\nd.  You have only one awareness here -- the screen of the magi:  Imagination! <BR>\n&nbsp;Here, you learn what it is to be human.  You are a creator of order, of beaut<BR>\niful shapes and systems, an organizer of chaos.<BR>\n&nbsp;-The Atreides Manifesto, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','By your belief in singularities, in granular absolutes, you deny movement, eve<BR>\nn the movement of evolution!  While you cause a granular universe to persist i<BR>\nn your awareness, you are blind to movement.  When things change, your absolut<BR>\ne universe vanishes, no longer accessible to your self-limiting perceptions.  <BR>\nThe universe has moved beyond you.<BR>\n&nbsp;-First Draft, Atreides Manifesto, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','It is your fate, forgetfulness.  All of the old lessons of life, you lose and <BR>\ngain and lose and gain again.<BR>\n&nbsp;-Leto II, the Voice of Dar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','People always want something more than immediate joy or that deeper sense call<BR>\ned happiness.  This is one of the secrets by which we shape the fulfillment of<BR>\n&nbsp;our designs.  The something more assumes amplified power with people who cann<BR>\not give it a name or who (most often the case) do not even suspect its existen<BR>\nce.  Most people only react unconsciously to such hidden forces.  Thus, we hav<BR>\ne only to call a calculated something more into existence, define it and give <BR>\nit shape, then people will follow.<BR>\n&nbsp;-Leadership Secrets of the Bene Gesserit');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','We have long known that the objects of our palpable sense experiences can be i<BR>\nnfluenced by choice -- both conscious choice and unconscious.  This is a demon<BR>\nstrated fact that does not require that we believe some force within us reache<BR>\ns out and touches the universe.  I address a pragmatic relationship between be<BR>\nlief and what we identify as \"real.\"  All of our judgments carry a heavy burde<BR>\nn of ancestral beliefs to which we of the Bene Gesserit tend to be more suscep<BR>\ntible than most.  It is not enough that we are aware of this and guard against<BR>\n&nbsp;it.  Alternative interpretations must always receive our attention.<BR>\n&nbsp;-Mother Superior Taraza:  Argument in Council');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The long table on the right is set for a banquet of roast desert hare in sauce<BR>\n&nbsp;cepeda.  The other dishes, clockwise to the right from the far end of the tab<BR>\nle, are aplomage sirian, chukka under glass, coffee with melange (note the haw<BR>\nk crest of the Atreides on the urn), pot-a-oie and, in the Balut crystal bottl<BR>\ne, sparkling Caladan wine.  Note the ancient poison detector concealed in the <BR>\nchandelier.<BR>\n&nbsp;-Dar-es-Balat, Description at a Museum Display');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','This room reconstructs a bit of the desert of Dune.  The sandcrawler directly <BR>\nin front of you dates from the Atreides times.  Grouped around it, moving cloc<BR>\nkwise from your left, are a small harvester, a carryall, a primitive spice fac<BR>\ntory and the other support equipment.  All are explained at each station.  Not<BR>\ne the illuminated quotation above the display:  \"FOR THEY SHALL SUCK OF THE AB<BR>\nUNDANCE OF THE SEAS AND OF THE TREASURE IN THE SAND.\"  This ancient religious <BR>\nquotation was oft repeated by the famous Gurney Halleck.<BR>\n&nbsp;-Guide Announcement, Museum of Dar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Survival of self, of species, and of environment, these are what drive humans.<BR>\n&nbsp;You can observe how the order of importance changes in a lifetime.  What are<BR>\n&nbsp;the things of immediate concern at a given age?  Weather?  The state of the d<BR>\nigestion?  Does she (or he) really care?  All of those various hungers that fl<BR>\nesh can sense and hope to satisfy.  What else could possibly matter?<BR>\n&nbsp;-Leto II to Hwi Noree, His Voice:  Dar-es-Balat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Technology, in common with many other activities, tends toward avoidance of ri<BR>\nsks by investors.  Uncertainty is ruled out if possible.  Capital investment f<BR>\nollows this rule, since people generally prefer the predictable.  Few recogniz<BR>\ne how destructive this can be, how it imposes severe limits on variability and<BR>\n&nbsp;thus makes whole populations fatally vulnerable to the shocking ways our univ<BR>\nerse can throw the dice.<BR>\n&nbsp;-Assessment of Ix, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The failure of CHOAM?  Quite simple:  They ignore the fact that larger commerc<BR>\nial powers wait at the edges of their activities, powers that could swallow th<BR>\nem the way a slig swallows garbage.  This is the true threat of the Scattering<BR>\n&nbsp;-- to them and to us all.<BR>\n&nbsp;-Bene Gesserit Council notes, Archives #SXX90CH');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Humans live best when each has his place to stand, when each knows where he be<BR>\nlongs in the scheme of things and what he may achieve.  Destroy the place and <BR>\nyou destroy the person.<BR>\n&nbsp;-Bene Gesserit Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Explosions are also compressions of time.  Observable changes in the natural u<BR>\nniverse all are explosive to some degree and from some point of view; otherwis<BR>\ne you would not notice them.  Smooth Continuity of change, if slowed sufficien<BR>\ntly, goes without notice by observers whose time/attention span is too short. <BR>\n&nbsp;Thus, I tell you, I have seen changes you would never have marked.<BR>\n&nbsp;-Leto II');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','At the quantum level our universe can be seen as an indeterminate place, predi<BR>\nctable in a statistical way only when you employ large enough numbers.  Betwee<BR>\nn that universe and a relatively predictable one where the passage of a single<BR>\n&nbsp;planet can be timed to a picosecond, other forces come into play.  For the in<BR>\n-between universe where we find our daily lives, that which you believe is a d<BR>\nominant force.  Your beliefs order the unfolding of daily events.  If enough o<BR>\nf us believe, a new thing can be made to exist.  Belief structure creates a fi<BR>\nlter through which chaos is sifted into order.<BR>\n&nbsp;-Analysis of the Tyrant, the Taraza File:  BG Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Bureaucracy destroys initiative.  There is little that bureaucrats hate more t<BR>\nhan innovation, especially innovation that produces better results than the ol<BR>\nd routines.  Improvements always make those at the top of the heap look inept.<BR>\n&nbsp;Who enjoys appearing inept?<BR>\n&nbsp;-A Guide to Trial and Error in Government, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Most discipline is hidden discipline, designed not to liberate but to limit.  <BR>\nDo not ask Why?  Be cautious with How?  Why? leads inexorably to paradox.  How<BR>\n? traps you in a universe of cause and effect.  Both deny the infinite.<BR>\n&nbsp;-The Apocrypha of Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','There was this drylander who was asked which was more important, a literjon of<BR>\n&nbsp;water or a vast pool of water?  The drylander thought a moment and then said:<BR>\n&nbsp;\"The literjon is more important.  No single person could own a great pool of<BR>\n&nbsp;water.  But a literjon you could hide under your cloak and run away with it. <BR>\n&nbsp;No one would know.\"<BR>\n&nbsp;-The Jokes of Ancient Dune, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','\"I must rule with eye and claw -- as the hawk among lesser birds.\"<BR>\n&nbsp;-Atreides assertion (Ref:  BG Archives)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The trouble with some kinds of warfare (and be certain the Tyrant knew this, <BR>\nbecause it is implicit in his lesson) is that they destroy all moral decency i<BR>\nn susceptible types.  Warfare of these kinds will dump the destroyed survivors<BR>\n&nbsp;back into an innocent population that is incapable of even imagining what suc<BR>\nh returned soldiers might do.<BR>\n&nbsp;-Teachings of the Golden Path, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Law always chooses sides on the basis of enforcement power.  Morality and lega<BR>\nl niceties have little to do with it when the real question is:  Who has the c<BR>\nlout?<BR>\n&nbsp;-Bene Gesserit Council Proceedings:  Archives #XOX232');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Life cannot find reasons to sustain it, cannot be a source of decent mutual re<BR>\ngard, unless each of us resolves to breathe such qualities into it.<BR>\n&nbsp;-Chenoeh:  \"Conversations with Leto II\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','May you die on Caladan!<BR>\n&nbsp;-Ancient Drinking Toast');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Memory never recaptures reality.  Memory reconstructs.  All reconstructions ch<BR>\nange the original, becoming external frames of reference that inevitably fall <BR>\nshort.<BR>\n&nbsp;-Mentat Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','When strangers meet, great allowance should be made for differences of custom <BR>\nand training.<BR>\n&nbsp;-The Lady Jessica, from \"Wisdom of Arrakis\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Concealed behind strong barriers the heart becomes ice.<BR>\n&nbsp;-Darwi Odrade, Argument in Council');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Justice?  Who asks for justice.  We make our own justice.  We make it here on <BR>\nArrakis -- win or die.  Let us not rail about justice as long as we have arms <BR>\nand the freedom to use them.<BR>\n&nbsp;-Leto I:  Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','We are not looking at a new state of matter but at a newly recognized relation<BR>\nship between consciousness and matter, which provides a more penetrating insig<BR>\nht into the workings of prescience.  The oracle shapes a projected inner unive<BR>\nrse to produce new external probabilities out of forces that are not understoo<BR>\nd.  There is no need to understand these forces before using them to shape the<BR>\n&nbsp;physical universe.  Ancient metal workers had no need to understand the molec<BR>\nular and submolecular complexities of their steel, bronze, copper, gold, and t<BR>\nin.  They invented mystical powers to describe the unknown while they continue<BR>\nd to operate their forges and wield their hammers.<BR>\n&nbsp;-Mother Superior Taraza, Argument in Council');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Quite naturally, holders of power wish to suppress wild research.  Unrestricte<BR>\nd questing after knowledge has a long history of producing unwanted competitio<BR>\nn.  The powerful want a \"safe line of investigations,\" which will develop only<BR>\n&nbsp;those products and ideas that can be controlled and, most important, that wil<BR>\nl allow the larger part of the benefits to be captured by inside investors.  U<BR>\nnfortunately, a random universe full of relative variables does not insure suc<BR>\nh a \"safe line of investigations.\"<BR>\n&nbsp;-Assessment of Ix, Bene Gesserit Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','What social inheritances went outward with the Scattering?  We know those time<BR>\ns intimately.  We know both the mental and physical settings.  The Lost Ones t<BR>\nook with them a consciousness confined mostly to manpower and hardware.  There<BR>\n&nbsp;was a desperate need for room to expand driven by the myth of Freedom.  Most <BR>\nhad not learned the deeper lesson of the Tyrant, that violence builds its own <BR>\nlimits.  The Scattering was wild and random movement interpreted as growth (ex<BR>\npansion).  It was goaded by a profound fear (often unconscious) of stagnation <BR>\nand death.<BR>\n&nbsp;-The Scattering:  Bene Gesserit Analysis (Archives)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Liberty and Freedom are complex concepts.  They go back to religious ideas of <BR>\nFree Will and are related to the Ruler Mystique implicit in absolute monarchs.<BR>\n&nbsp;Without absolute monarchs patterned after the Old Gods and ruling by the gra<BR>\nce of a belief in religious indulgence, Liberty and Freedom would never have g<BR>\nained their present meaning.  These ideals owe their very existence to past ex<BR>\namples of oppression.  And the forces that maintain such ideas will erode unle<BR>\nss renewed by dramatic teaching or new oppressions.  This is the most basic ke<BR>\ny to my life.<BR>\n&nbsp;-Leto II, God Emperor of Dune:  Dar-es-Balat Records');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The significant fact is this:  No Bene Tleilax female has ever been seen away <BR>\nfrom the protection of their core planets.  (Face Dancer mules who simulate fe<BR>\nmales do not count in this analysis.  They cannot be breeders.)  The Tleilaxu <BR>\nsequester their females to keep them from our hands.  This is our primary dedu<BR>\nction.  It must also be in the eggs that the Tleilaxu Masters conceal their mo<BR>\nst essential secrets.<BR>\n&nbsp;-Bene Gesserit Analysis -- Archives #XOXTM99 ..... 041');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Nothing surpasses the complexity of the human mind.<BR>\n&nbsp;-Leto II:  Dar-es-Balat Records');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The basic rule is this:  Never support weakness; always support strength.<BR>\n&nbsp;-The Bene Gesserit Coda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The Tleilaxu secret must be in their sperm.  Our tests prove that their sperm <BR>\ndoes not carry forward in a straight genetic fashion.  Gaps occur.  Every Tlei<BR>\nlaxu we have examined has hidden his inner self from us.  They are naturally i<BR>\nmmune to an Ixian Probe!  Secrecy at the deepest levels, that is their ultimat<BR>\ne armor and their ultimate weapon.<BR>\n&nbsp;-Bene Gesserit Analysis, Archives Code:  BTXX441WOR');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','In my estimation, more misery has been created by reformers than by any other <BR>\nforce in human history.  Show me someone who says \"Something must be done!\" an<BR>\nd I will show you a head full of vicious intentions that have no other outlet.<BR>\n&nbsp;What we must strive for always! is to find the natural flow and go with it.<BR>\n&nbsp;-The Reverend Mother Taraza, Conversational Record, BG File GSXXMAT9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','Ten thousand years since Leto II began his metamorphosis from human into the s<BR>\nandworm of Rakis and historians still argue over his motives.  Was he driven b<BR>\ny the desire for long life?  He lived more than ten times the normal span of t<BR>\nhree hundred SY, but consider the price he paid.  Was it the lure of power?  H<BR>\ne is called the Tyrant for good reason but what did power bring him that a hum<BR>\nan might want?  Was he driven to save humankind from itself?  We have only his<BR>\n&nbsp;own words about his Golden Path to answer this and I cannot accept the self-s<BR>\nerving records of Dar-es-Balat.  Might there have been other gratifications, w<BR>\nhich only his experiences would illuminate?  Without better evidence the quest<BR>\nion is moot.  We are reduced to saying only that \"He did it!\" The physical fac<BR>\nt alone is undeniable.<BR>\n&nbsp;-The Metamorphosis of Leto II, 10,000th Anniversary Peroration by Gaus Andaud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('heretics-of-dun','The existence of no-ships raises the possibility of destroying entire planets <BR>\nwithout retaliation.  A large object, asteroid or equivalent, may be sent agai<BR>\nnst the planet.  Or the people can be set against each other by sexual subvers<BR>\nion, and then can be armed to destroy themselves.  These Honored Matres appear<BR>\n&nbsp;to favor this latter technique.<BR>\n&nbsp;-Bene Gesserit Analysis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;Pictures for Schools, take 8.<BR>\nDIRECTOR:  Action! <BR>\nNARRATOR:  Defeat at the castle seems to have utterly disheartened King Arthur.<BR>\n&nbsp;The ferocity of the French taunting took him completely by surprise,<BR>\n&nbsp;and Arthur became convinced that a new strategy was required if the<BR>\n&nbsp;quest for the Holy Grail were to be brought to a successful<BR>\n&nbsp;conclusion.  Arthur, having consulted his closest knights, decided<BR>\n&nbsp;that they should separate, and search for the Grail individually.<BR>\n&nbsp;Now, this is what they did--<BR>\n&nbsp;[clop clop]<BR>\n&nbsp;[An unknown knight rides in and stabs the narrator]<BR>\nWOMAN:  Greg!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;NARRATOR:  The Tale of Sir Robin....     So each of the knights went their<BR>\n&nbsp;separate ways.  Sir Robin rode north, through the dark forest of<BR>\n&nbsp;Ewing, accompanied by his favourite minstrels.<BR>\nMINSTREL (singing):<BR>\n&nbsp;Bravely bold Sir Robin, rode forth from Camelot.<BR>\n&nbsp;He was not afraid to die, oh Brave Sir Robin. <BR>\n&nbsp;He was not at all afraid to be killed in nasty ways. <BR>\n&nbsp;Brave, brave, brave, brave Sir Robin! <BR>\n&nbsp;He was not in the least bit scared to be mashed into a pulp, <BR>\n&nbsp;Or to have his eyes gouged out, and his elbows broken. <BR>\n&nbsp;To have his kneecaps split, and his body burned away, <BR>\n&nbsp;And his limbs all hacked and mangled, brave Sir Robin! <BR>\n&nbsp;His head smashed in, and his heart cut out, <BR>\n&nbsp;And his liver removed, and his bowels unplugged, <BR>\n&nbsp;And his nostrils raped, and his bottom burned off, <BR>\n&nbsp;And his penis split ... and his ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;GALAHAD:  You are the keepers of the Holy Grail?<BR>\nZOOT:  The what?<BR>\nGALAHAD:  The Grail -- it is here?<BR>\nZOOT:  Oh, but you are tired, and you must rest awhile.  Midget! Crepper!<BR>\nMIDGET and CREPPER:  Yes, oh Zoot!<BR>\nZOOT:  Prepare a bed for our guest.<BR>\nMIDGET and CREPPER:  Oh thank you thank you thank you--<BR>\nZOOT:  Away away vile peasents!  The beds here are warm and soft -- and very,<BR>\n&nbsp;very big.<BR>\nGALAHAD:  Well, look, I-I-uh--');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;LAUNCELOT:  Well taken, Concorde!<BR>\nCONCORDE:  Thank you, sir!  Most kind.<BR>\nLAUNCELOT:  And again... Over we go!  Good.  Steady!  And now, the big<BR>\n&nbsp;one...Ooof!  Come on, Concorde!<BR>\n&nbsp;[thwonk]<BR>\nCONCORDE:  Message for you, sir.<BR>\n&nbsp;[fwump]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;ARTHUR:  O Knights of Nee, you are just and fair, and we will return with a<BR>\n&nbsp;shrubbery.<BR>\nHEAD KNIGHT:  One that looks nice.<BR>\nARTHUR:  Of course.<BR>\nHEAD KNIGHT:  And not too expensive.<BR>\nARTHUR:  Yes.<BR>\nHEAD KNIGHTS:  Now... go!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;OLD MAN:  Ah, hee he he ha!<BR>\nARTHUR:  And this enchanter of whom you speak, he has seen the grail?<BR>\nOLD MAN:  Ha ha he he he he!<BR>\nARTHUR:  Where does he live?  Old man, where does he live?<BR>\nOLD MAN:  He knows of a cave, a cave which no man has entered.<BR>\nARTHUR:  And the Grail... The Grail is there?<BR>\nOLD MAN:  Very much danger, for beyond the cave lies the Gorge of Eternal Peril,<BR>\n&nbsp;which no man has ever crossed.<BR>\nARTHUR:  But the Grail!  Where is the Grail!?<BR>\nOLD MAN:  Seek you the Bridge of Death.<BR>\nARTHUR:  The Bridge of Death, which leads to the Grail?<BR>\nOLD MAN:  Hee hee ha ha!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;BLACK KNIGHT:  None shall pass.<BR>\nARTHUR:  I have no quarrel with you, good Sir knight, but I must cross this<BR>\n&nbsp;bridge.<BR>\nBLACK KNIGHT:  Then you shall die.<BR>\nARTHUR:  I command you as King of the Britons to stand aside!<BR>\nBLACK KNIGHT:  I move for no man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;CROWD:  Burn!  Burn her!<BR>\nBEDEMIR:  Quiet, quiet.  Quiet!  There are ways of telling whether she is a<BR>\n&nbsp;witch.<BR>\nCROWD:  Are there?  What are they?<BR>\nBEDEMIR:  Tell me, what do you do with witches?<BR>\nVILLAGER #2:  Burn!<BR>\nCROWD:  Burn, burn them up!<BR>\nBEDEMIR:  And what do you burn apart from witches?<BR>\nVILLAGER #1:  More witches!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\" <BR>\n&nbsp;ARTHUR:  Knights!  Forward!<BR>\n&nbsp;[boom boom boom boom BOOM boom boom boom boom]<BR>\n&nbsp;What manner of man are you that can summon up fire without flint or<BR>\n&nbsp;tinder?<BR>\nTIM:  I... am an enchanter.<BR>\nARTHUR:  By what name are you known?<BR>\nTIM:  There are some who call me... Tim?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;ROGER:  Yes, shrubberies are my trade -- I am a shrubber.  My name is Roger the<BR>\n&nbsp;Shrubber.  I arrange, design, and sell shrubberies.<BR>\nBEDEMIR:  Nee!<BR>\nARTHUR:  No!  No, no, no!  No!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;FATHER:  Hold it, please!  Hold it!  This is Sir Launcelot from the gorge of<BR>\n&nbsp;Camelot -- a very brave and influential knight, and my special guest<BR>\n&nbsp;here today.<BR>\nLAUNCELOT:  Hello.<BR>\nRANDOM:  He killed my auntie!<BR>\n&nbsp;[yelling]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;[battle sounds]<BR>\n&nbsp;[Black Knight defeats a worthless-piece-of-shit-knight]<BR>\nARTHUR:  You fight with the strength of many men, Sir knight. I am Arthur, King<BR>\n&nbsp;of the Britons.<BR>\n&nbsp;[pause]<BR>\n&nbsp;I seek the finest and the bravest knights in the land to <BR>\n&nbsp;join me in my Court of Camelot.<BR>\n&nbsp;[pause]<BR>\n&nbsp;You have proved yourself worthy; will you join me?<BR>\n&nbsp;[pause]<BR>\n&nbsp;You make me sad.  So be it.  Come, Patsy.<BR>\nBLACK KNIGHT:  None shall pass.<BR>\nARTHUR:  What?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;DINGO:  Oh, wicked, bad, naughty, evil Zoot!  Oh, she is a naughty person, and<BR>\n&nbsp;she must pay the penalty -- and here in Castle Anthrax, we have but one<BR>\n&nbsp;punishment for setting alight the grail-shaped beacon.  You must tie her<BR>\n&nbsp;down on a bed and spank her!<BR>\nGIRLS:  A spanking!  A spanking!<BR>\nDINGO:  You must spank her well.  And after you have spanked her, you may deal<BR>\n&nbsp;with her as you like.  And then, spank me.<BR>\nVARIOUS GIRLS:  And spank me.     And me.     And me.<BR>\nDINGO:  Yes, yes, you must give us all a good spanking!<BR>\nGIRLS:  A spanking!  A spanking!<BR>\nDINGO:  And after the spanking, the oral sex.<BR>\nGIRLS:  Oral sex!  Oral sex!<BR>\nGALAHAD:  Well, I could stay a BIT longer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;BEDEMIR:  Who are you who are so wise in the ways of science?<BR>\nARTHUR:  I am Arthur, King of the Britons.<BR>\nBEDEMIR:  My liege!<BR>\nARTHUR:  Good Sir knight, will you come with me to Camelot, and join us at the<BR>\n&nbsp;Round Table?<BR>\nBEDEMIR:  My liege!  I would be honoured.<BR>\nARTHUR:  What is your name?<BR>\nBEDEMIR:  Bedemir, my liege.<BR>\nARTHUR:  Then I dub you Sir Bedemir, Knight of the Round Table.  ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;BEDEMIR:  Does wood sink in water?<BR>\nVILLAGER #1:  No, no.<BR>\nVILLAGER #2:  It floats!  It floats!<BR>\nVILLAGER #1:  Throw her into the pond!<BR>\nCROWD:  The pond!<BR>\nBEDEMIR:  What also floats in water?<BR>\nVILLAGER #1:  Bread!<BR>\nVILLAGER #2:  Apples!<BR>\nVILLAGER #3:  Very small rocks!<BR>\nVILLAGER #1:  Cider!<BR>\nVILLAGER #2:  Great gravy!<BR>\nVILLAGER #1:  Cherries!<BR>\nVILLAGER #2:  Mud!<BR>\nVILLAGER #3:  Churches -- churches!<BR>\nVILLAGER #2:  Lead -- lead!<BR>\nARTHUR:  A duck.<BR>\nCROWD:  Oooh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;VILLAGER #1:  She has got a wart.<BR>\nBEDEMIR:  What makes you think she is a witch?<BR>\nVILLAGER #3:  Well, she turned me into a newt.<BR>\nBEDEMIR:  A newt?<BR>\nVILLAGER #3:  I got better.<BR>\nVILLAGER #2:  Burn her anyway!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;BEDEMIR:  Well?<BR>\nVILLAGER #1:  Well, we did do the nose.<BR>\nBEDEMIR:  The nose?<BR>\nVILLAGER #1:  And the hat -- but she is a witch!<BR>\nCROWD:  Burn her!  Witch!  Witch!  Burn her!<BR>\nBEDEMIR:  Did you dress her up like this?<BR>\nCROWD:  No, no... no ... yes.  Yes, yes, a bit, a bit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\" <BR>\n&nbsp;KEEPER:  Stop!  What is your name?<BR>\nGALAHAD:  Sir Galahad of Camelot.<BR>\nKEEPER:  What is your quest?<BR>\nGALAHAD:  I seek the Holy Grail.<BR>\nKEEPER:  What is your favourite colour?<BR>\nGALAHAD:  Blue.  No yel--  Aaaaaaargh!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;[wind]<BR>\n&nbsp;[clop clop]<BR>\nARTHUR:  Whoa there!<BR>\n&nbsp;[clop clop] <BR>\nGUARD #1:  Halt!  Who goes there? <BR>\nARTHUR:  It is I, Arthur, son of Uther Pendragon, from the castle of Camelot.<BR>\n&nbsp;King of the Britons, defeater of the Saxons, sovereign of all England!<BR>\nGUARD #1:  Pull the other one!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;ROBIN:  Would it help to confuse it if we run away more?<BR>\nARTHUR:  Oh, shut up and go and change your armour.<BR>\nGALAHAD:  Let us taunt it!  It may become so cross that it will make a mistake.<BR>\nARTHUR:  Like what?<BR>\nGALAHAD:  Have we got bows?<BR>\nARTHUR:  No.<BR>\nLAUNCELOT:  We have the Holy Hand Grenade.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\" <BR>\n&nbsp;NARRATOR:  As the horrendous Black Beast lunged forward, escape for Arthur and<BR>\n&nbsp;his knights seemed hopeless.  When, suddenly, the animator suffered a<BR>\n&nbsp;fatal heart attack.  <BR>\nANIMATOR:  Aaarrrrgh!<BR>\nVOICE OVER:  The cartoon peril was no more.  The Quest for Holy Grail could<BR>\n&nbsp;continue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\" <BR>\n&nbsp;ARTHUR:  Greetings, Tim the Enchanter.<BR>\nTIM:  Greetings, King Arthur!<BR>\nARTHUR:  You know my name?<BR>\nTIM:  I do.<BR>\n&nbsp;[zoosh]<BR>\n&nbsp;You seek the Holy Grail!<BR>\nARTHUR:  That is our quest.  You know much that is hidden, O Tim.<BR>\nTIM:  Quite.<BR>\n&nbsp;[pweeng boom]<BR>\n&nbsp;[clap clap clap]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;LAUNCELOT:  Well, I can explain.  I was in the forest, um, riding north from<BR>\n&nbsp;Camelot, when I got this note, you see--<BR>\nFATHER:  Camelot?  Are you from, uh, Camelot?<BR>\nHERBERT:  Hurry, Sir Launcelot!<BR>\nLAUNCELOT:  Uh, I am a Knight of King Arthur, sir.<BR>\nFATHER:  Pretty nice castle, Camelot.  Uh, pretty good pig country....<BR>\nLAUNCELOT:  Yes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;ARTHUR:  O, Knights of Nee, we have brought you your shrubbery.  May we go now?<BR>\nHEAD KNIGHT:  It is a good shrubbery.  I like the laurels particularly. But<BR>\n&nbsp;there is one small problem.<BR>\nARTHUR:  What is that?<BR>\nHEAD KNIGHT:  We are now... no longer the Knights Who Say Nee.<BR>\nRANDOM:  Nee!<BR>\nHEAD KNIGHT:  Shh shh.  We are now the Knights Who Say <BR>\n&nbsp;Ecky-ecky-ecky-ecky-pikang-zoom-boing-mumble-mumble.<BR>\nRANDOM:  Nee!<BR>\nHEAD KNIGHT:  Therefore, we must give you a test.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;BEDEMIR:  Who are they?<BR>\nHEAD KNIGHT:  We are the keepers of the sacred words:  Nee, Pang, and Nee-wom!<BR>\nRANDOM:  Nee-wom!<BR>\nARTHUR:  Those who hear them seldom live to tell the tale!<BR>\nHEAD KNIGHT:  The Knights Who Say Nee demand a sacrifice!<BR>\nARTHUR:  Knights of Nee, we are but simple travellers who seek the enchanter who<BR>\n&nbsp;lives beyond these woods.<BR>\nHEAD KNIGHT:  Nee!  Nee!  Nee!  Nee!<BR>\nARTHUR and PARTY:  Oh, ow!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('holygrail','From \"Monty Python and the Holy Grail\"<BR>\n&nbsp;HEAD KNIGHT:  Nee!     Nee!     Nee!     Nee!<BR>\nARTHUR:  Who are you?<BR>\nHEAD KNIGHT:  We are the Knights Who Say... Nee!<BR>\nARTHUR:  No!  Not the Knights Who Say Nee!<BR>\nHEAD KNIGHT:  The same!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','We all live in the shadows of our predecessors for a time.  But we who <BR>\ndetermine the fate of planets eventually reach the point at which we become not <BR>\nthe shadows, but the light itself.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO,<BR>\nDiscourses on Leadership');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Hatred is as dangerous an emotion as love.  The capacity for either one is the <BR>\ncapacity for its opposite.<BR>\n&nbsp;-Cautionary Instructions for the Sisterhood, Bene Gesserit Archives, Wallach IX');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The Spacing Guild has worked for centuries to surround our elite Navigators <BR>\nwith mystique.  They are revered, from the lowest Pilot to the most talented <BR>\nSteersman.  They live in tanks of spice gas, see all paths through space and <BR>\ntime, guide ships to the far reaches of the Imperium.  But no one knows the <BR>\nhuman cost of becoming a Navigator.  We must keep this a secret, for if they <BR>\nreally knew the truth, they would pity us.<BR>\n&nbsp;-Spacing Guild Training Manual Handbook for Steersmen (Classified)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Like many culinary delicacies, revenge is a dish best savored slowly, after <BR>\nlong and delicate preparation.<BR>\n&nbsp;-EMPEROR ELROOD IX,<BR>\nDeathbed Insights');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','We do what we must.  Friendship and loyalty be damned.  We do what we must!<BR>\n&nbsp;-LADY HELENA ATREIDES,<BR>\nher personal journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Hope can be the greatest weapon of a downtrodden people, or the greatest enemy <BR>\nof those who are about to fail.  We must remain aware of its advantages and its <BR>\nlimitations.<BR>\n&nbsp;-LADY HELENA ATREIDES,<BR>\nher personal journals<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','We consider the various worlds as gene pools, sources of teachings and <BR>\nteachers, sources of the possible.<BR>\n&nbsp;-Bene Gesserit Analysis,<BR>\nWallach IX Archives');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','We must do a thing on Arrakis never before attempted for an entire planet.  We <BR>\nmust use man as a constructive ecological force -- inserting adapted terraform <BR>\nlife:  a plant here, an animal there, a man in that place -- to transform the <BR>\nwater cycle, to build a new kind of landscape.<BR>\n&nbsp;-Report from Imperial Planetologist PARDOT KYNES, directed to Padishah EMPEROR <BR>\nELROOD IX (unsent)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The populace must think their ruler is a greater man than they, else why should <BR>\nthey follow him?  Above all a leader must be a showman, giving his people the <BR>\nbread and circuses they require.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','History allows us to see the obvious -- but unfortunately, not until it is too <BR>\nlate.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','No outsider has ever seen a Tleilaxu female and lived to tell about it.  <BR>\nConsidering the Tleilaxu penchant for genetic manipulation -- see, e.g., <BR>\nrelated memos on clones and gholas -- this simple observation raises a wealth <BR>\nof additional questions.<BR>\n&nbsp;-Bene Gesserit Analysis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Many elements of the Imperium believe they hold the ultimate power:  the <BR>\nSpacing Guild with their monopoly on interstellar travel, CHOAM with its <BR>\neconomic stranglehold, the Bene Gesserit with their secrets, the Mentats with <BR>\ntheir control of mental processes, House Corrino with their throne, the Great <BR>\nand Minor Houses of the Landsraad with their extensive holdings.  Woe to us on <BR>\nthe day that one of those factions decides to prove the point.<BR>\n&nbsp;-COUNT HASIMIR FENRING,<BR>\nDispatches from Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The basic rule is this:   Never support weakness; always support strength.<BR>\n&nbsp;-The Bene Gesserit Azhar Book,<BR>\nCompilation of Great Secrets');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Four things cannot be hidden -- Love, smoke, a pillar of fire, and a man <BR>\nstriding across the open bled.<BR>\n&nbsp;-Fremen Wisdom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','One observes the survivors, and learns from them.<BR>\n&nbsp;-Bene Gesserit Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Who can know whether Ix has gone too far?  They hide their facilities, keep <BR>\ntheir workers enslaved, and claim the right of secrecy.  Under such <BR>\ncircumstances, how can they not be tempted to step beyond the restrictions of <BR>\nthe Butlerian Jihad?<BR>\n&nbsp;-COUNT ILBAN RICHESE, third appeal to the Landsraad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Among the responsibilities of command is the necessity to punish . . . but only <BR>\nwhen the victim demands it.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO, Discourses on Leadership in a Galactic Imperium, 12th <BR>\nEdition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The haughty do but build castle walls behind which they seek to hide their <BR>\ndoubts and fears.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Kwisatz Haderach:   \"Shortening of the Way.\"  This is the label applied by the <BR>\nBene Gesserit to the unknown for which they sought a genetic solution:   a male <BR>\nBene Gesserit whose organic mental powers would bridge space and time.<BR>\n&nbsp;-Terminology of the Imperium');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The working Planetologist has access to many resources, data, and projections.  <BR>\nHowever, his most important tools are human beings.  Only by cultivating <BR>\necological literacy among the people themselves can he save an entire planet.<BR>\n&nbsp;-PARDOT KYNES, The Case for Bela Tegeuse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','How simple things were when our Messiah was only a dream.<BR>\n&nbsp;-STILGAR, Naib of Sietch Tabr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Speak the truth.  That is always much easier, and is often the most powerful <BR>\nargument.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Any path that narrows future possibilities may become a lethal trap.  Humans do <BR>\nnot thread their way through a maze; they scan a vast horizon filled with <BR>\nunique opportunities.<BR>\n&nbsp;-The Spacing Guild Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','One who rules assumes irrevocable responsibility for the ruled.  You are a <BR>\nhusbandman.  This demands, at times, a selfless act of love which may be <BR>\namusing only to those you rule.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Two hundred thirty-eight planets searched, many of only marginal habitability.  <BR>\n(See star charts attached in separate file.) Resource surveys list valuable raw <BR>\nmaterials.  Many of these planets deserve a second look, either for mineral <BR>\nexploitation or possible colonization.  As in previous reports, however, no <BR>\nspice found.<BR>\n&nbsp;-Independent scout survey, third expedition, delivered to EMPEROR FONDIL <BR>\nCORRINO III');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Blindness can take many forms other than the inability to see.  Fanatics are <BR>\noften blinded in their thoughts.  Leaders are often blinded in their hearts.<BR>\n&nbsp;-The Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Truth is a chameleon.<BR>\n&nbsp;-Zensunni Aphorism');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','What matters more, the form of justice or the actual outcome?  No matter how a <BR>\ncourt may dissect the evidence, the foundation of genuine truth remains <BR>\nunblemished.  Unfortunately for many of the accused, such genuine truth is <BR>\noften known only to the victim and the perpetrator.  All others must make up <BR>\ntheir own minds.<BR>\n&nbsp;-Landsraad Law, codicils and analyses');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Even innocents carry within them their own guilt in their own way.  No one <BR>\nmakes it through life without paying, in one fashion or another.<BR>\n&nbsp;-LADY HELENA ATREIDES,<BR>\nher personal journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Innovations seem to have a life and a sentience of their own.  When conditions <BR>\nare right, a radical new idea -- a paradigm shift -- may appear simultaneously <BR>\nfrom many minds at once.  Or it may remain secret in the thoughts of one man <BR>\nfor years, decades, centuries . . . until someone else thinks of the same <BR>\nthing.  How many brilliant discoveries die stillborn, or lie dormant, never to <BR>\nbe embraced by the Imperium as a whole?<BR>\n&nbsp;-OMBUDSMEN OF RICHESE, Rebuttal to the Landsraad, The True Domain of the <BR>\nIntellect -- Private Property, or Resources for the Galaxy?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','No one but a Tleilaxu may set foot in Bandalong, holiest city of the Bene <BR>\nTleilax, for it is fanatically guarded hallowed ground, purified by their God.<BR>\n&nbsp;-Diplomacy in the Imperium,<BR>\na Landsraad publication');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Memory and History are two sides of the same coin.  In time, however, History <BR>\ntends to slant itself toward a favorable impression of events, while Memory is <BR>\ndoomed to preserve the worst aspects.<BR>\n&nbsp;-LADY HELENA ATREIDES,<BR>\nher personal journals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','What senses do we lack that we cannot see or hear another world all around us?<BR>\n&nbsp;-The Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','History demonstrates that the advancement of technology is not a steady upward <BR>\ncurve.  There are flat periods, upward spurts, and even reversals.<BR>\n&nbsp;-Technology of the Imperium, 532nd Edition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The surest way to keep a secret is to make people believe they already know the <BR>\nanswer.<BR>\n&nbsp;-Ancient Fremen Wisdom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Perceptions rule the universe.<BR>\n-Bene Gesserit Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Imperfections, if viewed in the proper light, can be extremely valuable.  The <BR>\nGreat Schools, with their incessant questing for perfection, often find this <BR>\npostulate difficult to understand, until it is proven to them that nothing in <BR>\nthe universe is random.<BR>\n&nbsp;-From The Philosophies of Old Terra, one of the recovered manuscripts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','In adverse circumstances, every creature becomes something else, evolving or <BR>\ndevolving.  What makes us human is that we know what we once were, and -- let <BR>\nus hope -- we remember how to change back.<BR>\n&nbsp;-AMBASSADOR CAMMAR PILRU,<BR>\nDispatches in Defense of Ix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Like the knowledge of your own being, the sietch forms a firm base from which <BR>\nyou move out into the world and into the universe.<BR>\n&nbsp;-Fremen Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Only God can make living, sentient creatures.<BR>\n&nbsp;-The Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','In plotting any course of revenge, one must savor the anticipation phase and <BR>\nall its moments, for the actual execution often differs widely from the <BR>\noriginal plan.<BR>\n&nbsp;-HASIMIR FENRING,<BR>\nDispatches from Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','You of fearful heart, be strong and fear not.  Behold, your God will come with <BR>\na vengeance; He will come and save you from the worshipers of machines.<BR>\n&nbsp;-The Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','History has seldom been good to those who must be punished.  Bene Gesserit <BR>\npunishments cannot be forgotten.<BR>\n&nbsp;-Bene Gesserit Dictum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Man is but a pebble dropped in a pool.  And if man is but a pebble, then all <BR>\nhis works can be no more.<BR>\n&nbsp;-Zensunni Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Even the poorest House can be rich in loyalty.  Allegiance that must be <BR>\npurchased by bribes or wages is hollow and flawed, and could break at the worst <BR>\npossible moment.  Allegiance that comes from the heart, though, is stronger <BR>\nthan adamantium and more valuable than purest melange.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','In the Imperium there exists the \"principle of the individual,\" noble but <BR>\nrarely utilized, whereby a person who violates a written law in a situation of <BR>\nextreme peril or need can request a special session of the court of <BR>\njurisdiction in order to explain and support the necessity of his actions.  A <BR>\nnumber of legal procedures derive from this principle, among them the Drey <BR>\nJury, the Blind Tribunal, and the Trial by Forfeiture.<BR>\n&nbsp;-Law of the Imperium:  Commentaries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The worst sort of alliances are those which weaken us.  Worse still is when an <BR>\nEmperor fails to recognize such an alliance for what it is.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO,<BR>\nDiscourses on Leadership');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','All persons are contained within a single individual, just as all time is in a <BR>\nmoment, and the entire universe is in a grain of sand.<BR>\n&nbsp;-Fremen Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','When faced with necessary actions, there are always choices.  So long as the <BR>\njob gets done.<BR>\n&nbsp;-COUNT HASIMIR FENRING,<BR>\nDispatches from Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Only fools leave witnesses.<BR>\n&nbsp;-HASIMIR FENRING');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','As seen from orbit, the world of Ix is pristine and placid.  But beneath its <BR>\nsurface, immense projects are undertaken and great works are achieved.  In this <BR>\nway, our planet is a metaphor for the Imperium itself.<BR>\n&nbsp;-DOMINIC VERNIUS,<BR>\nThe Secret Workings of Ix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','A requirement of creativity is that it contributes to change.  Creativity keeps <BR>\nthe creator alive.<BR>\n&nbsp;-FRANK HERBERT, unpublished notes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Thou shalt not make a machine in the likeness of a human mind.<BR>\n&nbsp;-Chief commandment resulting from the Butlerian Jihad, found in the Orange <BR>\nCatholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','There are weapons you cannot hold in your hand.  You can only hold them in your <BR>\nmind.<BR>\n&nbsp;-Bene Gesserit Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The human body is a machine, a system of organic chemicals, fluid conduits, <BR>\nelectrical impulses; a government is likewise a machine of interacting <BR>\nsocieties, laws, cultures, rewards and punishments, patterns of behavior.   <BR>\nUltimately, the universe itself is a machine, planets around suns, stars <BR>\ngathered into clusters, clusters and other suns forming entire galaxies . . . . <BR>\n&nbsp;Our job is to keep the machinery functioning.<BR>\n&nbsp;-Suk Inner School, Primary Doctrine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The leaders of the Butlerian Jihad did not adequately define artificial <BR>\nintelligence, failing to foresee all possibilities of an imaginative society.  <BR>\nTherefore, we have substantial gray areas in which to maneuver.<BR>\n&nbsp;-Confidential Ixian Legal Opinion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','They demonstrate subtle, highly effective skills in the aligned arts of <BR>\nobservation and data collection.  Information is their stock-in-trade.<BR>\n&nbsp;-Imperial Report on the Bene Gesserit, used for tutoring purposes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','When the center of the storm does not move, you are in its path.<BR>\n&nbsp;-Ancient Fremen Wisdom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Machine-vaccine principle:  Every technological device contains within it the <BR>\ntools of its opposite, and of its own destruction.<BR>\n&nbsp;-GIAN KANA,<BR>\n&nbsp;Imperial Patent Czar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','I must rule with eye and claw -- as the hawk among lesser birds.<BR>\n&nbsp;-DUKE PAULUS ATREIDES,<BR>\nThe Atreides Assertion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Melange is the financial crux of CHOAM activities.  Without this spice, Bene <BR>\nGesserit Reverend Mothers could not perform feats of observation and human <BR>\ncontrol, Guild Navigators could not see safe pathways across space, and <BR>\nbillions of Imperial citizens would die of addictive withdrawal.  Any simpleton <BR>\nknows that such dependence upon a single commodity leads to abuse.  We are all <BR>\nat risk.<BR>\n&nbsp;-CHOAM Economic Analysis of Materiel Flow Patterns');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Spacing Guild:   one leg of the political tripod maintaining the Great <BR>\nConvention.  The Guild was the second mental-physical training school (see Bene <BR>\nGesserit) after the Butlerian Jihad.  The Guild monopoly on space travel and <BR>\ntransport and upon international banking is taken as the beginning point of the <BR>\nImperial Calendar.<BR>\n&nbsp;-Terminology of the Imperium');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The highest function of ecology is the understanding of consequences.<BR>\n&nbsp;-PARDOT KYNES, Ecology of Bela Tegeuse, Initial Report to the Imperium');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The universe contains untapped and heretofore unimagined energy sources.  They <BR>\nare before your very eyes, yet you cannot see them.  They are in your mind, yet <BR>\nyou cannot think them.  But I can!<BR>\n&nbsp;-TIO HOLTZMAN,<BR>\nCollected Lectures');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Progress and profit require a substantial investment in personnel, equipment, <BR>\nand capital funding.  However, the resource most often overlooked, yet which <BR>\ncan often provide the greatest payoff, is an investment in time.<BR>\n&nbsp;-DOMINIC VERNIUS,<BR>\nThe Secret Workings of Ix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','A world is supported by four things:  the teaming of the wise, the justice of <BR>\nthe great, the prayers of the righteous, and the valor of the brave.  But all <BR>\nof these are as nothing without a ruler who knows the art of ruling.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO,<BR>\nDiscourses on Galactic Leadership');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The paintbrush of history has depicted Abulurd Harkonnen in a most unfavorable <BR>\nlight.  Judged by the standards of his older half brother, Baron Vladimir, and <BR>\nhis own children Glossu Rabban and Feyd-Rautha Rabban, Abulurd was a different <BR>\nsort of man entirely.  We must, however, assess the frequent descriptions of <BR>\nhis weakness, incompetence, and foolhardy decisions in light of the ultimate <BR>\nfailure of House Harkonnen.  Though exiled to Lankiveil and stripped of any <BR>\nreal power, Abulurd secured a victory unmatched by anyone else in his extended <BR>\nfamily:  He learned how to be happy with his life.<BR>\n&nbsp;-Landsraad Encyclopedia of Great Houses, post-Jihad edition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Tio Holtzman was one of the most productive Ixian inventors on record.  He <BR>\noften went on creative binges, locking himself up for months on end so that he <BR>\ncould work without interruption.  Sometimes upon emerging he required <BR>\nhospitalization, and there were constant concerns over his sanity and <BR>\nwell-being.  Holtzman died young -- barely past thirty Standard Years -- but <BR>\nthe results of his efforts changed the galaxy forever.<BR>\n&nbsp;-Biographical Capsules, an Imperial filmbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The written Law of the Imperium cannot be changed, no matter which Great House <BR>\nholds dominion or which Emperor sits on the Golden Lion Throne.  The documents <BR>\nof the Imperial Constitution have been established for thousands of years.  <BR>\nThis is not to say that each regime is legally identical; the variations stem <BR>\nfrom subtleties of interpretation and from microscopic loopholes that become <BR>\nlarge enough to drive a Heighliner through.<BR>\n&nbsp;-Law of the Imperium:  Commentaries and Rebuttals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','Storms beget storms.  Rage begets rage.  Revenge begets revenge.  Wars beget <BR>\nwars.<BR>\n&nbsp;-Bene Gesserit Conundrum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','In the long history of our House, we have been constantly shadowed by <BR>\nMisfortune, as if we were its prey.  One might almost believe the curse of <BR>\nAtreus from ancient Greek times on Old Terra.<BR>\n&nbsp;-DUKE PAULUS ATREIDES,<BR>\nfrom a speech to his generals');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-atreides','The worst sort of protection is confidence.  The best defense is suspicion.<BR>\n&nbsp;-HASIMIR FENRING');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','There is no reality -- only our own order imposed on everything.<BR>\n&nbsp;-Basic Bene Gesserit Dictum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Immobility is often mistaken for peace.<BR>\n&nbsp;-EMPEROR ELROOD CORRINO IX');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Thinking, and the methods by which thoughts are communicated, inevitably create <BR>\na system permeated by illusions.<BR>\n&nbsp;-Zensunni Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Some lies are easier to believe than the truth.<BR>\n&nbsp;-Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The Unknown surrounds us at any given moment.  That is where we seek knowledge.<BR>\n&nbsp;-MOTHER SUPERIOR RAQUELLA BERTO-ANIRUL:  Oratory Against Fear');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','When you ask a question, do you truly want to know the answer, or are you <BR>\nmerely flaunting your power?<BR>\n&nbsp;-DMITRI HARKONNEN, Notes to My Sons');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Humiliation is a thing never forgotten.<BR>\n&nbsp;-REBEC of Ginaz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Too much knowledge never makes for simple decisions.<BR>\n&nbsp;-CROWN PRINCE RAPHAEL CORRINO, Discourses on Leadership');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The purpose of argument is to change the nature of truth.<BR>\n&nbsp;-Bene Gesserit Precept');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Special knowledge can be a terrible disadvantage if it leads you too far along <BR>\na path that you cannot explain anymore.<BR>\n&nbsp;-Mentat Admonition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','To learn about this universe, one must embark on a course of discovery where <BR>\nreal dangers exist.  Education cannot impart this discovery; it is not a thing <BR>\nto be taught and used or put away.  It has no goals.  In our universe, we <BR>\nconsider goals to be end products, and they are deadly if one becomes fixated <BR>\non them.<BR>\n&nbsp;-FRIEDRE GINAZ, Philosophy of the Swordmaster');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The desert is a surgeon cutting away the skin to expose what is underneath.<BR>\n&nbsp;-Fremen Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The strictest limits are self-imposed.<BR>\n&nbsp;-FRIEDRE GINAZ, Philosophy of the Swordmaster');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Military victories are meaningless unless they reflect the wishes of the <BR>\npopulace.  An Emperor exists only to clarify those wishes.  He executes the <BR>\npopular will, or his time is short.<BR>\n&nbsp;-Principium, Imperial Leadership Academy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','A center for the coordination of rebellion can be mobile; it does not need to <BR>\nbe a permanent place where people meet.<BR>\n&nbsp;-CAMMAR PILRU, Ixian Ambassador in Exile:  Treatise on the Downfall of Unjust <BR>\nGovernments');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Discovery is dangerous . . . but so is life.  A man unwilling to take risk is <BR>\ndoomed never to learn, never to grow, never to live.<BR>\n&nbsp;-PLANETOLOGIST PARDOT KYNES, An Arrakis Primer, written for his son Liet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Secrets are an important aspect of power. The effective leader spreads them in <BR>\norder to keep men in line.<BR>\n&nbsp;-PRINCE RAPHAEL CORRINO, Discourses on Leadership in a Galactic Imperium, <BR>\nTwelfth Edition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','It is said that there is nothing firm, nothing balanced, nothing durable in all <BR>\nthe universe -- that nothing remains in its original state, that each day, each <BR>\nhour, each moment, there is change.<BR>\n&nbsp;-Panoplia Propheticus of the Bene Gesserit');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','No one has yet determined the power of the human species . . . what it may <BR>\nperform by instinct, and what it may accomplish with rational determination.<BR>\n&nbsp;-Mentat Objective Analysis of Human Capabilities');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The man who gives in to adrenaline addiction turns against all humanity.  He <BR>\nturns against himself.  He runs away from the workable issues of life and <BR>\nadmits a defeat which his own violent actions help to create.<BR>\n&nbsp;-CAMMAR PILRU, Ixian Ambassador in Exile:  Treatise on the Downfall of Unjust <BR>\nGovernments');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Never be in the company of anyone with whom you would not want to die.<BR>\n&nbsp;-Fremen Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','It requires a desperate and lonely sort of courage to challenge the accepted <BR>\nwisdom upon which social peace of mind rests.<BR>\n&nbsp;-CROWN PRINCE RAPHAEL CORRINO, In Defense of Change in the Face of Tradition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Power and deceit are tools of statecraft, yes.  But remember that power deludes <BR>\nthe ones who wield it -- making them believe it can overcome the defects of <BR>\ntheir ignorance.<BR>\n&nbsp;-COUNT FLAMBERT MUTELLI, early speech in Landsraad Hall of Oratory');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','A man may fight the greatest enemy, take the longest journey, survive the most <BR>\ngrievous wound -- and still be helpless in the hands of the woman he loves.<BR>\n&nbsp;-Zensunni Wisdom from the Wandering');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Enemies strengthen you; allies weaken.<BR>\n&nbsp;-EMPEROR ELROOD IX, Deathbed Insights');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The mystery of life is not a problem to be solved, but a reality to be <BR>\nexperienced.<BR>\n&nbsp;-Meditations from Bifrost Eyrie, Buddislamic Text');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Unceasing warfare gives rise to its own social conditions, which have been <BR>\nsimilar throughout the ages.  One such condition is a permanent state of <BR>\nalertness to ward off attack.  Another is the rule of the autocrat.<BR>\n&nbsp;-CAMMAR PILRU, Ixian Ambassador in Exile:  Treatise on the Downfall of Unjust <BR>\nGovernments');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','There exists no way of exchanging information without making judgments.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Infinity attracts us like a floodlight in the night, blinding us to the <BR>\nexcesses it can inflict upon the finite.<BR>\n&nbsp;-Meditations from Bifrost Eyrie, Buddislamic Text');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Dreams are as simple or as complicated as the dreamer.<BR>\n&nbsp;-LIET-KYNES, In the Footsteps of My Father');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Look inside yourself and you can see the universe.<BR>\n&nbsp;-Zensunni Aphorism');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','If you surrender, you have already lost.  If you refuse to give up, though, no <BR>\nmatter the odds against you, at least you have succeeded in trying.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Nature commits no errors; right and wrong are human categories.<BR>\n&nbsp;-PARDOT KYNES, Arrakis Lectures');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Before us, all methods of learning were tainted by instinct.  Before us, <BR>\ninstinct-ridden researchers possessed a limited attention span -- often no <BR>\nlonger than a single lifetime.  Projects stretching across fifty or more <BR>\ngenerations never occurred to them.  The concept of total muscle/nerve training <BR>\nhad not entered their awareness.  We learned how to learn.<BR>\n&nbsp;-Bene Gesserit Azhar Book');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Water is the image of life.  We came from water, adapted from its <BR>\nall-encompassing presence . . . and we continue to adapt.<BR>\n&nbsp;-IMPERIAL PLANETOLOGIST PARDOT KYNES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','A Duke must always take control of his household, for if he does not rule those <BR>\nclosest to him, he cannot hope to govern a planet.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Organizational structure is crucial to the success of a movement.  It is, as <BR>\nwell, a prime target for attack.<BR>\n&nbsp;-CAMMAR PILRU, Ixian Ambassador in Exile:  Treatise on the Downfall of Unjust <BR>\nGovernments');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The universe is our picture.  Only the immature imagine the cosmos to be what <BR>\nthey think it is.<BR>\n&nbsp;-SIGAN VISEE, First Head Instructor, Guild Navigator School');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','What is this Love that so many speak of with such apparent familiarity?  Do <BR>\nthey truly comprehend how unattainable it is?  Are there not as many <BR>\ndefinitions of Love as there are stars in the universe?<BR>\n&nbsp;-The Bene Gesserit Question Book');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','What is each man but a memory for those who follow?<BR>\n&nbsp;-DUKE LETO ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','To know what one ought to do is not enough.<BR>\n&nbsp;-PRINCE RHOMBUR VERNIUS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The increasing variety and abundance of life itself vastly multiplies the <BR>\nnumber of niches available for life.  The resulting system is a web of makers <BR>\nand users, eaters and eaten, collaborators and competitors.<BR>\n&nbsp;-PARDOT KYNES, Report to Emperor Shaddam IV');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The effective ruler punishes opposition while rewarding assistance; he shifts <BR>\nhis forces in random fashion; he conceals major elements of his power; he sets <BR>\nup a rhythm of counter movement that keeps opponents off balance.<BR>\n&nbsp;-WESTHEIMER ATREIDES, Elements of Leadership');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The Universe operates on a basic principle of economics:  everything has its <BR>\ncost.  We pay to create our future, we pay for the mistakes of the past.  We <BR>\npay for every change we make . . . and we pay just as dearly if we refuse to <BR>\nchange.<BR>\n&nbsp;-Guild Bank Annals, Philosophical Register');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','A man who persists in stalking game in a place where there is none may wait <BR>\nforever without finding any success.  Persistence in search is not enough.<BR>\n&nbsp;-Zensunni Wisdom of the Wanderings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Facts mean nothing when they are preempted by appearances.  Do not <BR>\nunderestimate the power of impression over reality.<BR>\n&nbsp;-CROWN PRINCE RAPHAEL CORRINO, The Rudiments of Power');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','It is true that one may become rich through practicing evil, but the power of <BR>\nTruth and Justice is that they endure . . . and that a man can say of them, <BR>\n\"They are a heritage from my father.\"<BR>\n&nbsp;-Fifth Dynasty (Old Terra) calendar:  The Wisdom of Ptahhotep');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','I stand in the sacred human presence.  As I do now, so should you stand some <BR>\nday.  I pray to your presence that this be so.  Let the future remain uncertain <BR>\nfor that is the canvas to receive our desires.  Thus the human condition faces <BR>\nits perpetual tabula rasa.  We possess no more than this moment where we <BR>\ndedicate ourselves continuously to the sacred presence we share and create.<BR>\n&nbsp;-Bene Gesserit Benediction');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','We create our own future by our own beliefs, which control our actions.  A <BR>\nstrong enough belief system, a sufficiently powerful conviction, can make <BR>\nanything happen.  This is how we create our consensus reality, including our <BR>\ngods.<BR>\n&nbsp;-REVEREND MOTHER RAMALLO, Sayyadina of the Fremen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','It is the Atreides way to be examples of honor for our children, so that they <BR>\nmay be the same for their own progeny.<BR>\n&nbsp;-DUKE LETO ATREIDES, First Speech to the Caladan Assembly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The ego is only a bit of consciousness swimming upon the ocean of dark things.  <BR>\nWe are an enigma unto ourselves.<BR>\n&nbsp;-The Mentat Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','How will I be remembered by my children?  This is the true measure of a man.<BR>\n&nbsp;-ABULURD HARKONNEN');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','No one person can ever know everything that is in the heart of another.  We are <BR>\nall Face Dancers in our souls.<BR>\n&nbsp;-Tleilaxu Secret Handbook');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','We as humans tend to make pointless demands of our universe, asking meaningless <BR>\nquestions.  Too often we make such queries after developing an expertise within <BR>\na frame of reference which has little or no relationship to the context in <BR>\nwhich the question is asked.<BR>\n&nbsp;-Zensunni Observation');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','To keep from dying is not the same as \"to live.\"<BR>\n&nbsp;-Bene Gesserit Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','We are always human and carry the whole burden of being human.<BR>\n&nbsp;-DUKE LETO ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Why look for meaning where there is none?  Would you follow a path you know <BR>\nleads nowhere?<BR>\n&nbsp;-Query of the Mentat School');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Humans must never submit to animals.<BR>\n&nbsp;-Bene Gesserit Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Body and mind are two phenomena, observed under different conditions, but of <BR>\none and the same ultimate reality.  Body and mind are aspects of the living <BR>\nbeing.  They operate within a peculiar principle of synchronicity wherein <BR>\nthings happen together and behave as if they are the same . . . yet can be <BR>\nconceived of as separate.<BR>\n&nbsp;-Staff Medical Manual, Ginaz School');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Every man dreams of the future, though not all of us will be there to see it.<BR>\n&nbsp;-TIO HOLTZMAN, Speculations on Time and Space');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','You carve wounds upon my flesh and write there in salt!<BR>\n&nbsp;-Fremen Lament');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Beware the seeds you sow and the crops you reap.  Do not curse God for the <BR>\npunishment you inflict upon yourself.<BR>\n&nbsp;-Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','War, as the foremost ecological disaster of any age, merely reflects the larger <BR>\nstate of human affairs in which the total organism called \"humanity\" finds its <BR>\nexistence.<BR>\n&nbsp;-PARDOT KYNES, Reflections on the Disaster at Salusa Secundus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','How easily grief becomes anger, and revenge gains arguments.<BR>\n&nbsp;-PADISHAH EMPEROR HASSIK III, Lament for Salusa Secundus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Knowledge is pitiless.<BR>\n&nbsp;-Orange Catholic Bible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','If God wishes thee to perish, He causes thy steps to lead thee to the place of <BR>\nthy demise.<BR>\n&nbsp;-Cant of the Shariat');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','How to define the Kwisatz Haderach?  The male who is everywhere simultaneously, <BR>\nthe only man who can truly become the greatest human of all of us, mingling <BR>\nmasculine and feminine ancestry with inseparable power.<BR>\n&nbsp;-Bene Gesserit Azhar Book');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Treachery and quick-thinking will defeat hard-and-fast rules any day.  Why <BR>\nshould we be afraid to seize the opportunities we see?<BR>\n&nbsp;-VISCOUNT HUNDRO MORITANI, Response to Landsraad Court Summons');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','If a man can accept his sin, he can live with it.  If a man cannot accept <BR>\npersonal sin, he suffers unbearable consequences.<BR>\n&nbsp;-Meditations from Bifrost Eyrie, Buddislamic Text');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Love is the highest achievement to which any human may aspire.  It is an <BR>\nemotion that encompasses the full depth of heart, mind, and soul.<BR>\n&nbsp;-Zensunni Wisdom from the Wandering');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The Bene Gesserit tell no casual lies.  Truth serves us better.<BR>\n&nbsp;-BENE GESSERIT CODA');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Heaven must be the sound of running water.<BR>\n&nbsp;-Fremen Saying');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Freedom is an elusive concept.  Some men hold themselves prisoner even when <BR>\nthey have the power to do as they please and go where they choose, while others <BR>\nare free in their hearts, even as shackles restrain them.<BR>\n&nbsp;-Zensunni Wisdom from the Wandering');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','One uses power by grasping it lightly.  To grasp with too much force is to be <BR>\ntaken over by power, thus becoming its victim.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The Universe is a place inaccessible, unintelligible, completely absurd . . . <BR>\nfrom which life -- especially rational life -- is estranged.  There is no place <BR>\nof safety, or basic principle upon which the Universe depends.  There are only <BR>\ntransitory, masked relationships, confined within limited dimensions, and bound <BR>\nfor inevitable change.<BR>\n&nbsp;-Meditations from Bifrost Eyrie, Buddislamic Text');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The greatest and most important problems of life cannot be solved.  They can <BR>\nonly be outgrown.<BR>\n&nbsp;-SISTER JESSICA, private journal entry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Challenge:  Time?<BR>\nAnswer:  A brilliant, many-faceted gem.<BR>\n&nbsp;Challenge:  Time?<BR>\nAnswer:  A dark stone, reflecting no visible light.<BR>\n&nbsp;-Fremen wisdom, from The Riddle Game');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The capacity to learn is a gift; The ability to learn is a skill; The <BR>\nwillingness to learn is a choice.<BR>\n&nbsp;-REBEC OF GINAZ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Nature has moved inexplicably backward and forward to produce this marvelous, <BR>\nsubtle Spice.  One is tempted to suggest that only divine intervention could <BR>\npossibly have produced a substance which in one aspect extends human life and <BR>\nin another opens the inner doors of the psyche to the wonders of Time and <BR>\nCreation.<BR>\n&nbsp;-HIDAR FEN AJIDICA, Laboratory Notes on the Nature of Melange');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The seats of power inevitably try to harness any new knowledge to their own <BR>\ndesires.  But knowledge can have no fixed desires -- neither in the past nor in <BR>\nthe future.<BR>\n&nbsp;-DMITRI HARKONNEN, Lessons for My Sons');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Innovation and daring create heroes.  Mindless adherence to outdated rules <BR>\ncreates only politicians.<BR>\n&nbsp;-VISCOUNT HUNDRO MORITANI');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The haughty do but build castle walls behind which they try to hide their <BR>\ndoubts and fears.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','All technology is suspect, and must be considered potentially dangerous.<BR>\n&nbsp;-BUTLERIAN JIHAD, Handbook for Our Grandchildren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The individual is the key, the final effective unit of all biological processes.<BR>\n&nbsp;-PARDOT KYNES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Learn to recognize the future the way a Steersman identifies guiding stars and <BR>\ncorrects the course of his vessel.  Learn from the past; never use it as an <BR>\nanchor.<BR>\n&nbsp;-SIGAN VISEE, First Head Instructor, Guild Navigator School');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Paradise on my right, Hell on my left, and the Angel of Death behind me.<BR>\n&nbsp;-Fremen Conundrum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','War is a form of organic behavior.  The army is a means of survival for the <BR>\nall-male group.  The all-female group, on the other hand, is traditionally <BR>\nreligion-oriented.  They are the keepers of sacred mysteries.<BR>\n&nbsp;-Bene Gesserit Teaching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','\"Xuttuh\" is a word that means many things.  Every Bene Tleilax knows it was the <BR>\nname of the first Master.  But just as that man was more than a mere mortal, so <BR>\nthere are depths and complexities in the appellation.  Depending upon tone and <BR>\nvocal inflection, \"Xuttuh\" can mean \"hello\" or \"blessings be upon you.\"  Or it <BR>\ncan constitute a prayer encompassed in a single word, as a devotee prepares to <BR>\ndie for the Great Belief.  For such reasons, we have chosen this as our new <BR>\nname for the conquered planet formerly known as Ix.<BR>\n&nbsp;-Tleilaxu Training Disk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','In the days of Old Terra there were experts in poisons, deviously clever <BR>\npersons who dealt in what were known as \"the powders of inheritance.\"<BR>\n&nbsp;-Filmbook excerpt, Royal Library of Kaitain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','It is said that the Fremen has no conscience, having lost it in a burning <BR>\ndesire for revenge.  This is foolish.  Only the rawest primitive and the <BR>\nsociopath have no conscience.  The Fremen possesses a highly evolved worldview <BR>\ncentered on the welfare of his people.  His sense of belonging to the community <BR>\nis almost stronger than his sense of self.  It is only to outsiders that these <BR>\ndesert dwellers seem brutish . . . just as outsiders appear to them.<BR>\n&nbsp;-PARDOT KYNES, The People of Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Behold, O Man, you can create life.  You can destroy life.  But, lo, you have <BR>\nno choice but to experience life.  And therein lies both your greatest strength <BR>\nand your greatest weakness.<BR>\n&nbsp;-Orange Catholic Bible, Book of Kimla Septima, 5:3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Never underestimate the power of the human mind to believe what it wants to <BR>\nbelieve, no matter the conflicting evidence.<BR>\n&nbsp;-CAEDMON ERB, Politics and Reality');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','The individual is shocked by the overwhelming discovery of his own mortality.  <BR>\nThe species, however, is different.  It need not die.<BR>\n&nbsp;-PARDOT KYNES, An Arrakis Primer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Love is an ancient force, one that served its purpose in its day but is no <BR>\nlonger essential for the survival of the species.<BR>\n&nbsp;-Bene Gesserit Axiom');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Some say that the anticipation of a thing is better than the thing itself.  In <BR>\nmy view, this is utter nonsense.  Any fool can imagine a prize.  I desire the <BR>\ntangible.<BR>\n&nbsp;-HASIMIR FENRING, Letters from Arrakis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('house-harkonnen','Though death will cancel it, life in this world is a glorious thing.<BR>\n&nbsp;-DUKE PAULUS ATREIDES');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"A power so great, it can only be used for Good or Evil!\"<BR>\n&nbsp;-- Firesign Theatre, \"The Giant Rat of Summatra\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Decorate your home.  It gives the illusion that your life is more<BR>\ninteresting than it really is.<BR>\n&nbsp;-- C. Schulz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','A black cat crossing your path signifies that the animal is going somewhere.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','&nbsp;\"What shall we do?\" said Twoflower.<BR>\n&nbsp;\"Panic?\" said Rincewind hopefully.  He always held that panic was<BR>\nthe best means of survival; back in the olden days, his theory went, people<BR>\nfaced with hungry sabretoothed tigers could be divided very simply into<BR>\nthose who panicked and those who stood there saying \"What a magnificent<BR>\nbrute!\" and \"Here, pussy.\"<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Twenty Percent of Zero is Better than Nothing.<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Where humor is concerned there are no standards -- no one can say what<BR>\nis good or bad, although you can be sure that everyone will.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Things will get better despite our efforts to improve them.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Comedy, like Medicine, was never meant to be practiced by the general public.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"Boy, life takes a long time to live.\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Bernard Shaw is an excellent man; he has not an enemy in the world, and<BR>\nnone of his friends like him either.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','But I always fired into the nearest hill or, failing that, into blackness.<BR>\nI meant no harm;  I just liked the explosions.  And I was careful never to<BR>\nkill more than I could eat.<BR>\n&nbsp;-- Raoul Duke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','All men are mortal.  Socrates was mortal.  Therefore, all men are Socrates.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','And now for something completely different.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','A possum must be himself, and being himself he is honest.<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I bought some used paint. It was in the shape of a house.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I am getting into abstract painting.  Real abstract -- no brush, no canvas,<BR>\nI just think about it.  I just went to an art museum where all of the art<BR>\nwas done by children.  All the paintings were hung on refrigerators.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','If you live to the age of a hundred you have it made because very few<BR>\npeople die past the age of a hundred.<BR>\n&nbsp;-- George Burns');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I had no shoes and I pitied myself.  Then I met a man who had no feet,<BR>\nso I took his shoes.<BR>\n&nbsp;-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I am two with nature.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','He asked me if I knew what time it was -- I said yes, but not right now.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','For my birthday I got a humidifier and a de-humidifier...  I put them in<BR>\nthe same room and let them fight it out.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','High Priest:	Armaments Chapter One, verses nine through twenty-seven:<BR>\nBro. Maynard:	And Saint Attila raised the Holy Hand Grenade up on high<BR>\n&nbsp;saying, \"Oh Lord, Bless us this Holy Hand Grenade, and with it<BR>\n&nbsp;smash our enemies to tiny bits.\"  And the Lord did grin, and the<BR>\n&nbsp;people did feast upon the lambs, and stoats, and orangutans, and<BR>\n&nbsp;breakfast cereals, and lima bean-<BR>\nHigh Priest:	Skip a bit, brother.<BR>\nBro. Maynard:	And then the Lord spake, saying: \"First, shalt thou take<BR>\n&nbsp;out the holy pin.  Then shalt thou count to three.  No more, no less.<BR>\n&nbsp;*Three* shall be the number of the counting, and the number of the<BR>\n&nbsp;counting shall be three.  *Four* shalt thou not count, and neither<BR>\n&nbsp;count thou two, excepting that thou then goest on to three.  Five is<BR>\n&nbsp;RIGHT OUT.  Once the number three, being the third number be reached,<BR>\n&nbsp;then lobbest thou thy Holy Hand Grenade towards thy foe, who, being<BR>\n&nbsp;naughty in my sight, shall snuff it.  Amen.<BR>\nAll:	Amen.<BR>\n&nbsp;-- Monty Python, \"The Holy Hand Grenade\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','From the moment I picked your book up until I put it down I was convulsed<BR>\nwith laughter.  Some day I intend reading it.<BR>\n&nbsp;-- Groucho Marx, from \"The Book of Insults\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Hey, what do you expect from a culture that *drives* on *parkways* and<BR>\n*parks* on *driveways*?<BR>\n&nbsp;-- Gallagher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Faster, faster, you fool, you fool!<BR>\n&nbsp;-- Bill Cosby');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Early to rise, early to bed, makes a man healthy, wealthy and dead.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Eternal nothingness is fine if you happen to be dressed for it.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Do you think that when they asked George Washington for ID that he<BR>\njust whipped out a quarter?<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I saw a subliminal advertising executive, but only for a second.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I stayed up all night playing poker with tarot cards.  I got a full<BR>\nhouse and four people died.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I just got out of the hospital after a speed reading accident.<BR>\nI hit a bookmark.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I have an existential map.  It has \"You are here\" written all over it.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I have a rock garden.  Last week three of them died.<BR>\n&nbsp;-- Richard Diran');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I finally went to the eye doctor.  I got contacts.  I only need them to<BR>\nread, so I got flip-ups.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"I changed my headlights the other day. I put in strobe lights instead! Now<BR>\nwhen I drive at night, it looks like everyone else is standing still ...\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I cannot overemphasize the importance of good grammar.<BR>\n&nbsp;What a crock.  I could easily overemphasize the importance of good<BR>\ngrammar.  For example, I could say: \"Bad grammar is the leading cause<BR>\nof slow, painful death in North America,\" or \"Without good grammar, the<BR>\nUnited States would have lost World War II.\"<BR>\n&nbsp;-- Dave Barry, \"An Utterly Absurd Look at Grammar\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','If you want to make God laugh, tell him about your plans.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Is it weird in here, or is it just me?<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','If only God would give me some clear sign!  Like making a large deposit<BR>\nin my name at a Swiss bank.<BR>\n&nbsp;-- Woody Allen, \"Without Feathers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','If only Dionysus were alive!  Where would he eat?<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','If God had wanted us to be concerned for the plight of the toads, he would<BR>\nhave made them cute and furry. <BR>\n&nbsp;-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I thought there was something fishy about the butler.  Probably a Pisces,<BR>\nworking for scale.<BR>\n&nbsp;-- Firesign Theatre, \"The Further Adventures of Nick Danger\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','&nbsp;The Three Major Kind of Tools<BR>\n&nbsp;* Tools for hittings things to make them loose or to tighten them up or<BR>\njar their many complex, sophisticated electrical parts in such a<BR>\nmanner that they function perfectly.  (These are your hammers, maces,<BR>\nbludgeons, and truncheons.)<BR>\n&nbsp;* Tools that, if dropped properly, can penetrate your foot.  (Awls)<BR>\n&nbsp;* Tools that nobody should ever use because the potential danger is far<BR>\ngreater than the value of any project that could possibly result.<BR>\n(Power saws, power drills, power staplers, any kind of tool that uses<BR>\nany kind of power more advanced than flashlight batteries.)<BR>\n&nbsp;-- Dave Barry, \"The Taming of the Screw\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I was in Vegas last week. I was at the roulette table, having a lengthy<BR>\nargument about what I considered an Odd number.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I worked in a health food store once.  A guy came in and asked me,<BR>\n\"If I melt dry ice, can I take a bath without getting wet?\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I was at this restaurant.  The sign said \"Breakfast Anytime.\"  So I<BR>\nordered French Toast in the Rennaissance.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I was the best I ever had.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"I went to the museum where they had all the heads and arms from the<BR>\nstatues that are in all the other museums.\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Now is the time for all good men to come to.<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Man 1:	Ask me the what the most important thing about telling a good joke is.<BR>\n&nbsp;Man 2:	OK, what is the most impo --<BR>\n&nbsp;Man 1:	______TIMING!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"I love Saturday morning cartoons, what classic humour!  This is what<BR>\nentertainment is all about ... Idiots, explosives and falling anvils.\"<BR>\n&nbsp;-- Calvin and Hobbes, Bill Watterson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I met my latest girl friend in a department store.  She was looking at<BR>\nclothes, and I was putting Slinkys on the escalators.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Life is divided into the horrible and the miserable.<BR>\n&nbsp;-- Woody Allen, \"Annie Hall\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','My brother sent me a postcard the other day with this big satellite photo<BR>\nof the entire earth on it. On the back it said: \"Wish you were here\".<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Life is wasted on the living.<BR>\n&nbsp;-- The Restaurant at the Edge of the Universe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','It looked like something resembling white marble, which was<BR>\nprobably what it was: something resembling white marble.<BR>\n&nbsp;-- Douglas Adams, \"The Hitchhikers Guide to the Galaxy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','\"I was drunk last night, crawled home across the lawn.  By accident I<BR>\nput the car key in the door lock.  The house started up.  So I figured<BR>\nwhat the hell, and drove it around the block a few times.  I thought I<BR>\nshould go park it in the middle of the freeway and yell at everyone to<BR>\nget off my driveway.\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Last night the power went out.  Good thing my camera had a flash....<BR>\nThe neighbors thought it was lightning in my house, so they called the cops.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','In like a dimwit, out like a light.<BR>\n&nbsp;-- Pogo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','In America today ... we have Woody Allen, whose humor has become so<BR>\nsophisticated that nobody gets it any more except Mia Farrow.  All those who<BR>\nthink Mia Farrow should go back to making movies where the devil gets her<BR>\npregnant and Woody Allen should go back to dressing up as a human sperm,<BR>\nplease raise your hands.  Thank you.<BR>\n&nbsp;-- Dave Barry, \"Why Humor is Funny\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','The best cure for insomnia is to get a  lot of sleep.<BR>\n&nbsp;-- W. C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','The grand leap of the whale up the Fall of Niagara is esteemed, by all<BR>\nwho have seen it, as one of the finest spectacles in nature.<BR>\n&nbsp;-- Benjamin Franklin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Thank goodness modern convenience is a thing of the remote future.<BR>\n&nbsp;-- Pogo, by Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','I put instant coffee in a microwave and almost went back in time.<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','The best way to make a fire with two sticks is to make sure one of them<BR>\nis a match.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Sharks are as tough as those football fans who take their shirts off<BR>\nduring games in Chicago in January, only more intelligent.<BR>\n&nbsp;-- Dave Barry, \"Sex and the Single Amoeba: What Every<BR>\n&nbsp;Teen Should Know\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Showing up is 80% of life.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','NOBODY EXPECTS THE SPANISH INQUISITION!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Rincewind formed a mental picture of some strange entity living in a castle<BR>\nmade of teeth.  It was the kind of mental picture you tried to forget.<BR>\nUnsuccessfully.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Puns are little \"plays on words\" that a certain breed of person loves to<BR>\nspring on you and then look at you in a certain self-satisfied way to<BR>\nindicate that he thinks that you must think that he is by far the cleverest<BR>\nperson on Earth now that Benjamin Franklin is dead, when in fact what you<BR>\nare thinking is that if this person ever ends up in a lifeboat, the other<BR>\npassengers will hurl him overboard by the end of the first day even if they<BR>\nhave plenty of food and water.<BR>\n&nbsp;-- Dave Barry, \"Why Humor is Funny\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Many years ago in a period commonly know as Next Friday Afternoon,<BR>\nthere lived a King who was very Gloomy on Tuesday mornings because he<BR>\nwas so Sad thinking about how Unhappy he had been on Monday and how<BR>\ncompletely Mournful he would be on Wednesday....<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Why is the alphabet in that order?  Is it because of that song?<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Will Rogers never met you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Would you *______really* want to get on a non-stop flight?<BR>\n&nbsp;-- George Carlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','When I was crossing the border into Somewhere, they asked if<BR>\nI had any firearms with me.  I said, \"Well, what do you need?\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','When I woke up this morning, my girlfriend asked if I had slept well.<BR>\nI said, \"No, I made a few mistakes.\"<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','Winny and I lived in a house that ran on static electricity...<BR>\nIf you wanted to run the blender, you had to rub balloons on your<BR>\nhead... if you wanted to cook, you had to pull off a sweater real quick...<BR>\n&nbsp;-- Steven Wright');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','What is comedy?  Comedy is the art of making people laugh without making<BR>\nthem puke.<BR>\n&nbsp;-- Steve Martin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','We is confronted with insurmountable opportunities.<BR>\n&nbsp;-- Walt Kelly, \"Pogo\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','What if everything is an illusion and nothing exists?  In that case, I<BR>\ndefinitely overpaid for my carpet.<BR>\n&nbsp;-- Woody Allen, \"Without Feathers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','We have met the enemy, and he is us.<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','There comes a time in the affairs of a man when he has to take the bull<BR>\nby the tail and face the situation.<BR>\n&nbsp;-- W.C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','This land is full of trousers!<BR>\nthis land is full of mausers!<BR>\n&nbsp;And pussycats to eat them when the sun goes down!<BR>\n&nbsp;-- Firesign Theater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','You may already be a loser.<BR>\n&nbsp;-- Form letter received by Rodney Dangerfield.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('humorists','And now for something completely the same.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','About the only thing we have left that actually discriminates in favor of<BR>\nthe plain people is the stork.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Literature is mostly about having sex and not much about having children.<BR>\nLife is the other way around.<BR>\n&nbsp;-- David Lodge, \"The British Museum is Falling Down\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Adopted kids are such a pain -- you have to teach them how to look like you ...<BR>\n&nbsp;-- Gilda Radner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','A baby is an alimentary canal with a loud voice at one end and no<BR>\nresponsibility at the other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','It must have been some unmarried fool that said \"A child can ask questions<BR>\nthat a wise man cannot answer\"; because, in any decent house, a brat that<BR>\nstarts asking questions is promptly packed off to bed.<BR>\n&nbsp;-- Arthur Binstead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Beat your son every day; you may not know why, but he will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Catproof is an oxymoron, childproof nearly so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Children are natural mimics who act like their parents despite every<BR>\neffort to teach them good manners.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Do not handicap your children by making their lives easy.<BR>\n&nbsp;-- Robert Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Having children is like having a bowling alley installed in your brain.<BR>\n&nbsp;-- Martin Mull');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Give your child mental blocks for Christmas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Get Revenge!  Live long enough to be a problem for your children!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Give a small boy a hammer and he will find that everything he encounters<BR>\nneeds pounding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','FORTUNE REMEMBERS THE GREAT MOTHERS: #5<BR>\n&nbsp;\"And, and, and, and, but, but, but, but!\"<BR>\n&nbsp;-- Mrs. Janice Markowsky, April 8, 1965');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','For adult education nothing beats children.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','I love children.  Especially when they cry -- for then someone takes them away.<BR>\n&nbsp;-- Nancy Mitford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Billy:	Mom, you know that vase you said was handed down from<BR>\n&nbsp;generation to generation?<BR>\nMom:	Yes?<BR>\nBilly:	Well, this generation dropped it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Children begin by loving their parents.  After a time they judge them.<BR>\nRarely, if ever, do they forgive them.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','It is so soon that I am done for, I wonder what I was begun for.<BR>\n&nbsp;-- Epitaph, Cheltenham Churchyard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Life does not begin at the moment of conception or the moment of birth.<BR>\nIt begins when the kids leave home and the dog dies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Kids always brighten up a house; mostly by leaving the lights on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Anyone who uses the phrase \"easy as taking candy from a baby\" has never<BR>\ntried taking candy from a baby.<BR>\n&nbsp;-- Robin Hood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','A child of five could understand this!  Fetch me a child of five.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Youth is such a wonderful thing.  What a crime to waste it on children.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Your responsibility as a parent is not as great as you might imagine.  You<BR>\nneed not supply the world with the next conqueror of disease or major motion<BR>\npicture star.  If your child simply grows up to be someone who does not use<BR>\nthe word \"collectible\" as a noun, you can consider yourself an unqualified<BR>\nsuccess.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Microwaves frizz your heir.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Nature makes boys and girls lovely to look upon so they can be<BR>\ntolerated until they acquire some sense.<BR>\n&nbsp;-- William Phelps');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Never have children, only grandchildren.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My family history begins with me, but yours ends with you.<BR>\n&nbsp;-- Iphicrates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My parents went to Niagara Falls and all I got was this crummy life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My mother was a test tube; my father was a knife.<BR>\n&nbsp;-- Friday');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Never lend your car to anyone to whom you have given birth.<BR>\n&nbsp;-- Erma Bombeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My mother wants grandchildren, so I said, \"Mom, go for it!\"<BR>\n&nbsp;-- Sue Murphy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My mother once said to me, \"Elwood,\" (she always called me Elwood)<BR>\n\"Elwood, in this world you must be oh so smart or oh so pleasant.\"<BR>\nFor years I tried smart.  I recommend pleasant.<BR>\n&nbsp;-- Elwood P. Dowde, \"Harvey\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','My mother loved children -- she would have given anything if I had been one.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','No matter how old a mother is, she watches her middle-aged children for<BR>\nsigns of improvement.<BR>\n&nbsp;-- Florida Scott-Maxwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Youth is when you blame all your troubles on your parents; maturity is<BR>\nwhen you learn that everything is the fault of the younger generation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Never raise your hand to your children -- it leaves your midsection<BR>\nunprotected.<BR>\n&nbsp;-- Robert Orben');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The idea is to die young as late as possible.<BR>\n&nbsp;-- Ashley Montague');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','If parents would only realize how they bore their children.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','If pregnancy were a book they would cut the last two chapters.<BR>\n&nbsp;-- Nora Ephron, \"Heartburn\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','If the very old will remember, the very young will listen.<BR>\n&nbsp;-- Chief Dan George');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','It now costs more to amuse a child than it once did to educate his father.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','I used to think I was a child; now I think I am an adult -- not because<BR>\nI no longer do childish things, but because those I call adults are no<BR>\nmore mature than I am.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Why do they call it baby-SITTING when all you do is run after them?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','When childhood dies, its corpses are called adults.<BR>\n&nbsp;-- Brian Aldiss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','When I was 16, I thought there was no hope for my father.  By the time I was<BR>\n20, he had made great improvement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','We are the people our parents warned us about.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','When you were born, a big chance was taken for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Toddlers are the stormtroopers of the Lord of Entropy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The problem with the gene pool is that there is no lifeguard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','\"There was a boy called Eustace Clarence Scrubb, and he almost deserved it.\"<BR>\n&nbsp;-- C. S. Lewis, \"The Chronicles of Narnia\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The years of peak mental activity are undoubtedly between the ages of four<BR>\nand eighteen.  At four we know all the questions, at eighteen all the answers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Troubles are like babies; they only grow by nursing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The denunciation of the young is a necessary part of the hygiene of older<BR>\npeople, and greatly assists in the circulation of the blood.<BR>\n&nbsp;-- Logan Pearsall Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The fact that boys are allowed to exist at all is evidence of a remarkable<BR>\nChristian forbearance among men.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The first half of our lives is ruined by our parents and the second half<BR>\nby our children.<BR>\n&nbsp;-- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Remember that as a teenager you are in the last stage of your life when<BR>\nyou will be happy to hear that the phone is for you.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Somewhere on this globe, every ten seconds, there is a woman giving birth<BR>\nto a child.  She must be found and stopped.<BR>\n&nbsp;-- Sam Levenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','One of the disadvantages of having children is that they eventually get old<BR>\nenough to give you presents they make at school.<BR>\n&nbsp;-- Robert Byrne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Only adults have difficulty with childproof caps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','One father is more than a hundred schoolmasters.<BR>\n&nbsp;-- George Herbert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Snow and adolescence are the only problems that disappear if you ignore<BR>\nthem long enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','No house is childproofed unless the little darlings are in straitjackets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Nobody suffers the pain of birth or the anguish of loving a child in order<BR>\nfor presidents to make wars, for governments to feed on the substance of<BR>\ntheir people, for insurance companies to cheat the young and rob the old.<BR>\n&nbsp;-- Lewis Lapham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Out of the mouths of babes does often come cereal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','That all men should be brothers is the dream of people who have no brothers.<BR>\n&nbsp;-- Charles Chincholles, \"Pensees de tout le monde\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The average income of the modern teenager is about 2 a.m.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','You can learn many things from children.  How much patience you have,<BR>\nfor instance.<BR>\n&nbsp;-- Franklin P. Jones');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','The future is a myth created by insurance salesmen and high school counselors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Youth is the trustee of posterity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','&nbsp;The courtroom was pregnant (pun intended) with anxious silence as the<BR>\njudge solemnly considered his verdict in the paternity suit before him.<BR>\nSuddenly, he reached into the folds of his robes, drew out a cigar and<BR>\nceremoniously handed it to the defendant.<BR>\n&nbsp;\"Congratulations!\" declaimed the jurist.  \"You have just become a<BR>\nfather!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','It is no wonder that people are so horrible when they start life as children.<BR>\n&nbsp;-- Kingsley Amis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','If you have never been hated by your child, you have never been a parent.<BR>\n&nbsp;-- Bette Davis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','It is better to remain childless than to father an orphan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Life is a sexually transmitted disease with 100% mortality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Insanity is hereditary.  You get it from your kids.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','May you have many beautiful and obedient daughters.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Maturity is only a short break in adolescence.<BR>\n&nbsp;-- Jules Feiffer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Never trust a child farther than you can throw it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','May you have many handsome and obedient sons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('kids','Life is like a diaper -- short and loaded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<BenC> -include ../../debian/el33t.h<BR>\n<BenC> sendmail build...strange header name :)<BR>\n<isildur> hahaha<BR>\n* netgod laffs<BR>\n<netgod> BenC: can u tell i used to maintain sendmail?  :P<BR>\n<BenC> heh :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Crow-> Manoj: well, i cant understand stuff like \"s/3#$%^% {]][ @ f245 <BR>\n&nbsp;}\"<BR>\n<Manoj> Crow: That is not quite legal ;-)<BR>\n<Knghtbrd> Manoj - how would one make \"s/3#$%^% {]][ @ f245 }\" legal<BR>\n&nbsp;anyway? (and what would it do?  hehe)<BR>\n<Manoj> Knghtbrd: You need to finish the s/// expression.<BR>\n<Knghtbrd> oh, is that all?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Shinobi> There are worse things than Perl....ASP comes to mind');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> Leave it to manoj to call procmail \"puny\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> you know, Linux needs a platform game starring Tux<BR>\n<Knghtbrd> kinda Super Marioish, but with Tux and things like little cyber<BR>\n&nbsp;bugs and borgs and that sort of thing ...<BR>\n<Knghtbrd> And you have to jump past billgatus and hit the key to drop him<BR>\n&nbsp;into the lava and then you see some guy that looks like a RMS<BR>\n&nbsp;or someone say \"Thank you for rescuing me Tux, but Linus<BR>\n&nbsp;Torvalds is in another castle!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I have also been a huge Unix fan ever since I realized that SCO was not<BR>\nUnix.           -- Dennis Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* joeyh_ runs ps and sees 10 lines of awk code<BR>\n* joeyh_ recoils in horror');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Due to the closed source development model of XFree it is impossible<BR>\nto support, or even speculate about, features in pre- or beta releases<BR>\nof XFree.<BR>\n&nbsp;-- Marcus Sundberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* o-o always like debmake because he knew exactly what it would do...<BR>\n<ibid> o-o: you would ;-)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<dpg> americans are wierd....<BR>\n<xtifr> californians even weirder<BR>\n<Knghtbrd> xtifr has a point ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> aggh!<BR>\n<Knghtbrd> MAKE IT STOP!<BR>\n<Knghtbrd> MAKE IT STOP!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Crow-> who gives a shit about US law<BR>\n<jim> anyone living in the US.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Moonchild without an opinion? Satan is skating to work tomorrow!<BR>\n&nbsp;-- Brett Manz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<kceee^> I hate users<BR>\n<knghtbrd> you sound like a sysadmin already!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<kira> is a surgical war where you go give the foreign troops nose jobs?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* knghtbrd can already envision:  \"Subject: [INTENT TO PREPARE TO PROPOSE<BR>\n&nbsp;FILING OF BUG REPORT] Typos in the policy document\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Simunye is on a oc3->oc12<BR>\n<daem0n> simmy: bite me. :)<BR>\n<Simunye> daemon: okay :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Overfiend> lilo: well then, you are probably a responsible thinker. <BR>\n&nbsp;Welcome to a very small club.<BR>\n<lilo> Overfiend: welcome me when you join :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<change_m2> Will LINUX ever overtake sliced bread as the #1 achievement<BR>\n&nbsp;of mankind?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<aph> manoj is going nuts on the bug fixing crusade!  woo woo!<BR>\n<Knghtbrd> manoj went nuts long time ago.  but the bug fixing is cool  =>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I am dyslexic of Borg.  Prepare to have your ass laminated.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Espy> tomorrow there will be a great disturbance in the workforce<BR>\n&nbsp;-- May 18, 1999');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> hardcopy is for wussies<BR>\n<Topher> computer program listings....next, on HardCopy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* wichert_ imagines master without a MTA<BR>\n<james> wichert: ehm?  that might hinder peformance of the BTS :p');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> shaleh - unclean is just WEIRD.<BR>\n<Espy> heh, unclean is cool<BR>\n<Knghtbrd> Espy - and weird.<BR>\n<Espy> yes, weird too');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Kensey> RMS for President???<BR>\n<RelDrgn> ...or ESR, he wants a new job ;)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<kira> Ada, the only language written to milspec.<BR>\n<Mikster> <shudder>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Oh no, not again.<BR>\n&nbsp;-- Manoj Srivastava');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> emacs sucks, literally, not a insult, just a comment that its<BR>\n&nbsp;large enough to have a noticeable gravitational pull...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Steal this tagline.  I did.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd pelts wichert with NERF darts<BR>\n* wichert notes there are no ICBM nerfs yet and ignores kngtbrd<BR>\n<Knghtbrd> wichert - just wait, after seeing the NERF gatling guns, ICBMs<BR>\n&nbsp;are not far off (just pump the damned thing for an hour or two<BR>\n&nbsp;is all...)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Given some of the recent threads, the interactive discussions might<BR>\nneed to be conducted on canvas, in the presence of a referee, while<BR>\nwearing padded gloves.  ;-)<BR>\n&nbsp;-- Phil Hands');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Operating Systems Installed:<BR>\n&nbsp;* Debian GNU/Linux 2.1 4 CD Set ($20 from www.chguy.net; price includes<BR>\n&nbsp;taxes, shipping, and a $3 donation to FSF). 2 CDs are binaries, 2 CDs<BR>\n&nbsp;complete source code;<BR>\n&nbsp;* Windows 98 Second Edition Upgrade Version ($136 through Megadepot.com,<BR>\n&nbsp;price does not include taxes/shipping). Surprisingly, no source code<BR>\n&nbsp;is included.<BR>\n&nbsp;-- Bill Stilwell, http://linuxtoday.com/stories/8794.html');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Since this database is not used for profit, and since entire works are not<BR>\npublished, it falls under fair use, as we understand it.  However, if any<BR>\nhalf-assed idiot decides to make a profit off of this, they will need to<BR>\ndouble check it all...<BR>\n&nbsp;-- Notes included with the default fortunes database');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Teller> where am I and what am I doing in this handbasket?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<aj> <Knghtbrd> the increase in tension worldwide (as evidenced by crime<BR>\n<aj>            and whatnot) over that time period looks a lot like Linux<BR>\n<aj>            growth since 1993<BR>\n<aj> \`\`Linux linked to worldwide crime epidemic!!\'');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Sanaya> you guys are all sick!  sick sick sick I tell ya ;)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* bma wonders if this will make the Knghtbrd .sig');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* bma is a yank<BR>\n* Knghtbrd is a Knghtbrd<BR>\n* dhd is also a yank<BR>\n* Espy is evil<BR>\n* Knghtbrd believes Espy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Kethryvis> Gruuk: UFies are above and beyond the human race :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<n3tg0d> has /usr/bin/emacs been put into /etc/shells yet?  :P');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* joeyh cvs commits his home directory. Aaaaaa<BR>\n<drow> eeeeeeek<BR>\n<drow> joeyh: That is simply evil.  Period.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Subject: Bug#42432: debian-policy: Proposal for CTV for Draft for Proof of<BR>\nConcept for Draft for Proposal for Proposal for CTV for a CTV to decide on<BR>\na proposal for a CTV for the CTV on whether or not we shoud have a CTV on<BR>\nthe /usr/doc to /usr/share/doc transition now, or later.<BR>\n&nbsp;-- Ed Lang');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Crow_> hmm, is there a --now-dammit option for exim?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<xtifr> direct brain implants :)<BR>\n<knghtbrd> xtifr - yah, then using computers would actually require some<BR>\n&nbsp;of these idiots to think!<BR>\n<knghtbrd> ;>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<netgod> my client has been owned severely<BR>\n<netgod> this guy got root, ran packet sniffers, installed .rhosts and<BR>\n&nbsp;backdoors, put a whole new dir in called /lib/\"   \", which has a<BR>\n&nbsp;full suite of smurfing and killing tools<BR>\n<netgod> the only mistake was not deleting the logfiles<BR>\n<netgod> question is how was root hacked, and that i couldnt tell u<BR>\n<netgod> it is, of course, not a debian box<BR>\n* netgod notes the debian box is the only one left untouched by the hacker<BR>\n&nbsp;-- wonder why');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Techical solutions are not a matter of voting. Two legislations in the US<BR>\nstates almost decided that the value of Pi be 3.14, exactly. Popular vote<BR>\ndoes not make for a correct solution.<BR>\n&nbsp;-- Manoj Srivastava');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<_Anarchy_> acf: maybe April 1 next year slashdot needs to run \"Rob Malda<BR>\n&nbsp;accepts new job as head of Debian project\" 8)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* netgod opens his mailbox and immediately wishes he hadnt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<wichert> 8am is an ungoldly hour to be awake :)<BR>\n* gorgo usually gets up at 11am');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* PerlGeek is really a space alien<BR>\n* Knghtktty believes PerlGeek');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> Subject: [GR PROPOSAL] Should we vote on trivial matters?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> mariab - I am a Debian developer.  Red Hat is \"the enemy\" or<BR>\n&nbsp;something like that I guess..  Still, typecasting RH users as<BR>\n&nbsp;idiots or their distribution as completely broken by default<BR>\n&nbsp;is complete and total FUD.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"As you journey through life take a minute every now and then to give a<BR>\nthought for the other fellow. He could be plotting something.\"<BR>\n&nbsp;-- Hagar the Horrible');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','There is no snooze button on a cat who wants breakfast.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* bma_home gropes you<BR>\n<bma_home> \"oups, wrong channel\"<BR>\n<bma_home> </acf><BR>\n<cerb> quit groping me<BR>\n<doogie> you know you like it.<BR>\n<bma_home> actually, it was \"grope me baby\"<BR>\n<gecko-> touch my son and you die, bma ;)<BR>\n<doogie> gecko-: but your wife is ok?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Reading computer manuals without the hardware is as frustrating as reading<BR>\nsex manuals without the software.<BR>\n&nbsp;- Arthur C Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> learn to love Window Maker.<BR>\n<Knghtbrd> a little NeXTStep is good for the soul.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Madax> ahh<BR>\n<Madax> a gathering of geeks....<BR>\n<Madax> I can smell it now');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> (tinc)<BR>\n<Espy> (ytitac)<BR>\n<knghtbrd> (ntinac)<BR>\n<Espy> (it)<BR>\n<knghtbrd> (in)<BR>\n* Espy notes talking in acr^Winitialisms is scary when the other side<BR>\n&nbsp;understands you');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<lilo> I can read the bloody *manual* as if it were some sort of<BR>\n&nbsp;religious tract describing forms of enlightenment you can achieve<BR>\n&nbsp;after 10 years on a mountain :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','If you are what you eat, I guess that makes me a cheese danish.<BR>\n&nbsp;-- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Joy> wow... simple maths show that Debian developers have closed more<BR>\n&nbsp;than *31* *thousand* bug reports since our BTS exists!<BR>\n<Joy> that is about 30999 more than Microsoft ;)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> NOTE THAT THE ABOVE IS JUST AN OPINION AND SHOULD NOT BE<BR>\n&nbsp;TAKEN TO INCLUDE ANY MEASURE OF FACTUAL INFORMATION.  THE<BR>\n&nbsp;SPEAKER DISCLAIMS EVERYTHING AND EVERYONE.  DEAL WITH IT.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Technology is a constand battle between manufacturers producing bigger and<BR>\nmore idiot-proof systems and nature producing bigger and better idiots.<BR>\n&nbsp;-- Slashdot signature');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus> Hhhmmmmmmmm<BR>\n<Culus> waterbeds for cows<BR>\n<Culus> eleet<BR>\n<cas> Culus: why would a cow need a waterbed?<BR>\n<Culus> cas:  To be comfy warm');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* BenC wonders why he has upgraded to 3.3.5-1 before teh X maintainer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* joeyh wonders why everyone wants to know how tall he is<BR>\n<james> joeyh: it helps the sniper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd notes he has mashed potatoes for brains tonight<BR>\n<Valkyrie> yum, can I have some?<BR>\n<Knghtbrd> um ...<BR>\n* Knghtbrd hides from Valkyrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Epsilon3> Knghtbrd, if we wanted a lameass remark we would have said:<BR>\n&nbsp;Hey, neckro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<tigah_-> i have 4gb for /tmp<BR>\n<Knghtbrd> What do you do with 4G /tmp?  Compile X?<BR>\n<tigah_-> yes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','For every vision there is an equal and opposite revision.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<KnaraKat> Bite me.<BR>\n* TheOne gets some salt, then proceeds to nibble on KnaraKat a little<BR>\n&nbsp;bit....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<james> but, then I used an Atari, I was more likely to win the lottery in ten<BR>\n&nbsp;countries simultaneously than get accelerated X');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','First off - Quake is simply incredible. It lets you repeatedly kill your<BR>\nboss in the office without being arrested. :)<BR>\n&nbsp;-- Signal 11, in a slashdot comment');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* gxam wonders if all these globals are really necessary<BR>\n<Knghtbrd> most of them at the moment yes<BR>\n<Knghtbrd> we REALLY need to clean them up at some point<BR>\n<Knghtbrd> gxam: the globals will have to go away as we migrate towards<BR>\n&nbsp;modularity and madness (ie, libtool)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Espy> you are baked<BR>\n<knghtbrd> Espy: only half so');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd crosses his toes<BR>\n<Knghtbrd> (if I crossed my fingers it would be hard to type)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Microsoft is a cross between the Borg and the Ferengi.  Unfortunately,<BR>\nthey use Borg to do their marketing and Ferengi to do their<BR>\nprogramming.<BR>\n&nbsp;-- Simon Slavin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> the problem with the GNU coding standards is they ASSUME that<BR>\n&nbsp;everyone in the world uses emacs..  If that were the case, free<BR>\n&nbsp;software would die because we would all have wrist problems<BR>\n&nbsp;like RMS by now and no longer be able to code.  ;>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus-> libc6 is not essential :|');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','*** Topic for #redhat:  ReDHaT is the answer to all your problems. It<BR>\n&nbsp;could be the start too!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* cesarb wonders if in less than a week Carmack will end up receiving in<BR>\n&nbsp;e-mail a courtesy copy of a version of the Quake source which is four<BR>\n&nbsp;times faster than what went out of his virtual hands...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','If I have trouble installing Linux, something is wrong. Very wrong.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','*** Knghtbrd is now known as SirKewLDooD<BR>\n*** Mercury kicked SirKewlDooD from #quakeforge (*WHACK*)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<SlayR> i just bought MS Office 2000 for only $20!!!<BR>\n<Knghtbrd> you got ripped off  ;><BR>\n<SlayR> i know ;)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','=== This letter is the Honor System Virus ====<BR>\nIf you are running a Macintosh, OS/2, Unix, or<BR>\nLinux computer, please randomly delete<BR>\nseveral files from your hard disk drive and<BR>\nforward this message to everyone you know.<BR>\n============================================== ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Manoj> shaleh: I am not, despite your implication, God');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','The Unixverse ends on Tue, 19 Jan 2038 03:14:07 +0000');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Connection reset by some moron with a backhoe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Feb  5 13:27:01 trinity lp0 on fire<BR>\n&nbsp;-- the Linux kernel, alerting me that there was some unknown<BR>\n&nbsp;problem with my printer (ie, it was out of ink)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> At that point it will compile, but segfault, as it should..');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<SilverStr> media ethics is an oxymoron, much like Jumbo Shrimp and<BR>\n&nbsp;Microsoft Works.<BR>\n<MonkAway> not to mention NT Security');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Espy> be careful, some twit might quote you<BR>\n<Espy> out of context...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Deek> you GPL your homework? :)<BR>\n<knghtbrd> yah  =D<BR>\n<knghtbrd> Anyone is permitted to use or modify my homework, but if they<BR>\n&nbsp;distribute changes they must include the full machine-readable<BR>\n&nbsp;source code ;>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Espy> we need to split main into\"core\" and \"wtf-uses-this\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<edLin> LWE?<BR>\n<edLin> Linux W?? E??<BR>\n<seeS> will eatyou<BR>\n<JHM> World Expo?<BR>\n<edLin> i see');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> <CJ|BiZKiT-0-> i can upload to linux server tho<BR>\n<Mercury> <CJ|BiZKiT-0-> i got a shell account on one<BR>\n<Mercury> <Mercury> Whats it running?<BR>\n<Mercury> <CJ|BiZKiT-0-> umm<BR>\n<Mercury> <CJ|BiZKiT-0-> apache i think<BR>\n<Mercury> Help, please help..<BR>\n* Omni chuckles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<doogie> cat /dev/random | perl ?<BR>\n<shaleh> doogie: it is also a valid sendmail.cf<BR>\n<doogie> :)<BR>\n* knghtbrd hands doogie a senseless-use-of-cat award<BR>\n* shaleh wants to try it but is afraid');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Tarzan> hey did you fall off your pirch or something?<BR>\n<knghtbrd> me?  heh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Dr^Nick> SGI_Multitexture is bad voodoo now<BR>\n<Dr^Nick> ARB is good voodoo<BR>\n<witten> no, voodoo rush is bad voodoo :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Hmm...  Which would do a better job at driving physicists crazy?  Travel<BR>\nfaster than light, or a floating-point boolean value?<BR>\n&nbsp;-- Michael Mol');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<doogie_> linux takes shit and turns it into something useful.<BR>\n<doogie_> windows takes something useful and turns it into shit');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> knghtbrd: Eww, find a better name, the movie sucked.. <G><BR>\n<Knghtbrd> Mercury: The engine is better than the movie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<calc> knghtbrd: gnome 2.0 will be out in a few months, not sure how it<BR>\n&nbsp;will compare to kde 2.0 though<BR>\n<knghtbrd> calc: Just as bloated, just as buggy, and every Gnome 2 app<BR>\n&nbsp;will depend on 30 libraries.<BR>\n<Slimer> knghtbrd: so what changes from 1.0 ?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Deek> \"A good programmer can write FORTRAN in any language.\"<BR>\n<Deek> knghtbrd has proven that you can write C++ in any language too.<BR>\n&nbsp;<grin><BR>\n<Mercury> We are currently considdering if we should give him or prize, or<BR>\n&nbsp;kill him..<BR>\n<Mercury> (Of course, by all rights, this means we should give him the<BR>\n&nbsp;prize, and then kill him.. <G>)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<WildTHing> ok guys .. so whens the next commit :PP<BR>\n<taniwha> when they come to get me');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','At some point, bits have to go into packets and routers need to make<BR>\ndecisions on them. Changes at that level is what I want to hear about, not<BR>\nstrategic company relationships.<BR>\n&nbsp;-- John Carmack');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> 2fort5 sucks enough to have its own gravity ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* CosmicRay wishes he had some strippers here....<BR>\n<CosmicRay> err, wire strippers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<evilkalla> heh, I never took a coding class<BR>\n<evilkalla> or a graphics class<BR>\n<evilkalla> or a software design class<BR>\n<vegan> and it shows :P');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<gorgo> what do you get when someone cracks your debian machine ?<BR>\n<gorgo> mashed potato...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Endy needs to consult coffee :P<BR>\n<Endy> coffee the bot person, not coffee the beverage :)<BR>\n<knghtbrd> consulting the beverage may help too  =>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* The_Answer_MD throws spaghetti at everyone<BR>\n* taniwha eats the spaghetti<BR>\n* Coderjoe tosses around some meatballs<BR>\n* Knghtbrd gets the cheese<BR>\n* taniwha grabs a red');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Endy> taniwha: Have you TESTED this one? :)<BR>\n<taniwha> Endy: of course not');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mongoose> knghtbrd: and the meek shall inherit k-mart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I am practicing a fine point of ethics.  It is acceptable to shoot back.<BR>\nIt is not acceptable to shoot first.<BR>\n&nbsp;-- Zed Pobre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','We reject: kings, presidents, and voting.<BR>\nWe believe in: rough consensus and working code.<BR>\n&nbsp;-- Dave Clark');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<devkev> yeah i saw the lightning gun and where you were going, thinking<BR>\n&nbsp;you were gonna kick some ass :)<BR>\n<devkev> didnt realise it would be your own :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"Otherwise, please speak to a doctor about removing your head from your<BR>\nass, I believe it would be beneficial to all involved.\"<BR>\n&nbsp;-- Zephaniah E. Hull, flaming someone on a mailing list');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Overfiend> The Unix way -- everything is a file<BR>\n<Overfiend> The Linux way -- everything is a filesystem :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Nothing is a problem once you debug the code.<BR>\n&nbsp;-- John Carmack');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Omnic looks at his 33.6k link and then looks at Joy<BR>\n* Mercury cuddles his cable modem.. (=:]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> this is college course in formal logic<BR>\n<devkev> knghtbrd: i hate that shit, much prefer fuzzy logic :)<BR>\n<knghtbrd> kev: fuzzy logic tickles.<BR>\n<taniwha> knghtbrd: lol<BR>\n<devkev> knghtbrd: fuzzy logic is so cool, it models the world really well');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Endy> taniwha: Quote material :)<BR>\n<taniwha> Endy: :)<BR>\n<knghtbrd> Endy: I already snipped it');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Change the Social Contract?  BWAHAHAHAHAHAHAHAHAHAHAHA.<BR>\n&nbsp;-- Branden Robinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> eek, not another one...<BR>\n<knghtbrd> Seems ever developer and their mother now has a random<BR>\n&nbsp;signature using irc quotes ...<BR>\n<knghtbrd> WHAT HAVE I STARTED HERE??');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"I have a bone to pick, and a few to break.\"<BR>\n&nbsp;-- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<BenC> CosmicRay: you complete me<BR>\n<BenC> err...<BR>\n<CosmicRay> heh<BR>\n* BenC goes back to coding<BR>\n* elmo looks at benc<BR>\n<elmo> something we should know about you and cosmicray, Ben? :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','All good ideas look like bad ideas to those who are losers.<BR>\n&nbsp;-- Dilbert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* weasel wonders how stupid one has to be to spam alt.anonymous.messages<BR>\n<knghtbrd> weasel: about half as stupid as one has to be to harvest it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"Debian: no hats or reptiles were harmed in the making of this distribution.\"<BR>\n&nbsp;-- Paul Slootman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<doogie> dpkg has bugs?  no way!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* knghtbrd ponders how to scare the living shit out of 87 people at once..<BR>\n<knghtbrd> AHH!  I can do it in 3 words!:<BR>\n<knghtbrd> Microsoft Visual COBOL.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','$you = new YOU;<BR>\nhonk() if $you->love(perl)<BR>\n&nbsp;-- Seen on Slashdot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* athener calls Amnesty International House of Pancakes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> Internet censorship.  Because your children need to be<BR>\n&nbsp;protected from naked women, medical procedures, diverse<BR>\n&nbsp;cultures, and violent video games.<BR>\n<knghtbrd> (but information on building bombs, stealing cable, and<BR>\n&nbsp;manufacturing drugs is okay...)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','We must know, we will know.<BR>\n&nbsp;-- David Hilbert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','A subversive is anyone who can out-argue their government.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','A friend of mine has a barcode on his arm.<BR>\nHe rings up as a $.35 pack of JuicyFruit.<BR>\n&nbsp;-- Seen on Slashdot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Z.O.I.D.: Zombie Optimized for Infiltration and Destruction');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Oskuro> Overfiend: many patches on top of 4.0.1 already?<BR>\n<Overfiend> Oskuro: a few<BR>\n<Overfiend> only 152 megs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<netgod> you know<BR>\n<netgod> its really sad when the internic itself cant configure DNS<BR>\n&nbsp;servers right<BR>\n<netgod> it just doesnt get any more pathetic than that');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','if (me != you)        // FIXME: probably always true, delete?<BR>\n&nbsp;for (n = 0; n < who_knows_what; n++) {<BR>\n&nbsp;answer = DoSomething (withthis[n]);<BR>\n&nbsp;if (answer == foobar) {<BR>\n&nbsp;GetLost (n);<BR>\n&nbsp;break;<BR>\n&nbsp;}<BR>\n&nbsp;}');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Why is it that all of the instruments seeking intelligent life in the<BR>\nuniverse are pointed away from Earth?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<tausq>         if (cb) ((cb->obj)->*(cb->ui_func))();<BR>\n<knghtbrd> tausq: who the HELL wrote that ?<BR>\n<tausq> me :)<BR>\n* knghtbrd flogs tausq');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<FrikaC> I should probably reboot...<BR>\n<FrikaC> ok brb<BR>\n<FrikaC> So, what apart form avoiding virii, memory leaks, and rampant<BR>\n&nbsp;crashing does Linux reallhy offer :)<BR>\n<LordHavoc> reliable multitasking?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','99 little bugs in the code, 99 bugs in the code,<BR>\n&nbsp;fix one bug, compile it again...<BR>\n&nbsp;101 little bugs in the code....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> glDisable (GL_BUGS);<BR>\n<Endy> heh<BR>\n<Endy> Is that in 1.2? :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd>     Europe Passes Pro-spam Law<BR>\n<Knghtbrd> I though only Americans were that fucking stupid  =><BR>\n<Espy> apparently americans are quite naive :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Last time I had intimate contact with another human being was rather a<BR>\npainful experience... I rather liked it... ;)<BR>\n&nbsp;-- Brett Manz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Crow-> these stupid head hunters want resumes in ms word format<BR>\n<Crow-> can you write shit in tex and convert it to word?<BR>\n<Overfiend> converttoword{shit}');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Never underestimate the power of somebody with source code, a text editor,<BR>\nand the willingness to totally hose their system.<BR>\n&nbsp;-- Rob Landley <telomerase@yahoo.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','The deafening silence taught me not to ask a bunch of geeks for advice<BR>\nfrom their girlfriends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Addi> Alter.net seems to have replaced one of its router with a zucchini.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* knghtbrd does the ET thing<BR>\n<knghtbrd> anybody got a speak-n-spell?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> *sigh*  My todo list is like the fucking energizer bunny<BR>\n<knghtbrd> It keeps growing and growing and growing and ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> This font is starting to come out very nicely<BR>\n<stu> Knghtbrd: oh dear, are you hacking up another quake font in vi? :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','This message was written with vi!  (not that anyone in the world cares)<BR>\n&nbsp;-- seen on an old message from an anon.penet.fi address');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus_> We are also hoping to release a version of linux where shell is<BR>\n&nbsp;replaced by perl to a large degree.  Adding to that, there are a<BR>\n&nbsp;few of us who would like to see a pure perl platform.. PerlOS :)<BR>\n* Culus_ looks on in horror<BR>\n<mstone> Culus_: on the up side, you can type damn near anything in at the<BR>\n&nbsp;command prompt :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<rebelpacket> hey, quick question, is there any way to speed up the <BR>\n&nbsp;performance of uquake-x11?<BR>\n<Deek> rebelpacket: If you want to accelerate it, throw it harder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> Windoze CEMeNT: Now with CrackGuard(TM)!  Never worry about<BR>\n&nbsp;unsightly cracks in Windoze CEMeNT again!  CrackGuard(TM) is<BR>\n&nbsp;so powerful that the entire thing will crumble before it will<BR>\n&nbsp;crack.  Order your $200 upgrade version today!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Dabb> hehe, I really hate bug reports which are like calling fire<BR>\n&nbsp;department and saying: \"There is fire here, come!\" :)<BR>\n<Dabb> (and hanging up)<BR>\n* Dabb kills off dozen bug reports.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> LordHavoc: The reason why GL has overdraw is because it is only<BR>\n&nbsp;using HALF of the system they designed for vis.<BR>\n<Mercury> LordHavoc: Shooting itself in the foot.<BR>\n* Dabb looks at all those bullet holes in his shoes - damn, lots :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<xtifr> wow, I think I just used libtool to solve a problem -- somebody<BR>\n&nbsp;help me! :><BR>\n<luca> xtifr, STEP AWAY FROM THE KEYBOARD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Omnic> another .sig addition');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<pretzelgod> knghtbrd: Quake should support xray vision, dammit<BR>\n<knghtbrd> pretzelgod: ftp://ftp.cdrom.com/pub/quake/partial_conversions/<BR>\n&nbsp;xrated/i_am_old_enough_to_look_at_this<BR>\n<knghtbrd> ... you asked ...<BR>\n<CosmicRay> haha, that is a real directory');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','RFC 882 put the dot in .com, not Sun Microsystems<BR>\n&nbsp;-- Seen on Slashdot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* joeyh_ wonders if linux is supposed to lock up when you ask 100<BR>\n&nbsp;processes to cat the entire cd drive');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Apple_IIe> anyone seen my 80 column card?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','0 7     * * *   echo \"...Linux is just a fad\" | mail billg@microsoft.com -s \"And remember...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtktty is not going to ask how zucchini got into the discussion ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<frogbert> its hard being a lesbian withoutn breasts...people dont take<BR>\n&nbsp;you seriously');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Perhaps Debian is concerned more about technical excellence rather than<BR>\nease of use by breaking software. In the former we may excel.  In the<BR>\nlatter we have to concede the field to Microsoft. Guess where I want to go<BR>\ntoday?<BR>\n&nbsp;-- Manoj Srivastava');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','There Is No Cabal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','do {<BR>\n&nbsp;:<BR>\n} until (HELL_FREEZES_OVER);');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<ahzz_> i figured 17G oughta be enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I stopped a long time ago to try to find anything in the bug list of dpkg.<BR>\nWe should run for an entry in the Guinness Book of Records.<BR>\n&nbsp;-- Stephane Bortzmeyer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<jgoerzen> doogie: you sound highly unstable :-)<BR>\n<Knghtbrd> jgoerzen - he is.<BR>\n* doogie bops Knghtbrd<BR>\n<Knghtbrd> see?  Resorting to violence =D');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<netgod> is it me, or is Knghtbrd snoring?<BR>\n<joeyh> they killed knghtbrd!<BR>\n<netgod> Kysh: wichert, gecko, joeyh, and I are in a room trying to ignore<BR>\n&nbsp;Knghtbrd<BR>\n<Kysh> netgod: Knghtbrd is hard to ignore.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','As a computer, I find your faith in technology amusing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd assigns 3 to Chris<BR>\n* variable wonders who else is named chris besides me<BR>\n<Knghtbrd> variable - you.  =><BR>\n* Knghtbrd waits for variable to dramatically say \"I feel SO used!\"<BR>\n<variable> Knghtbrd: :)<BR>\n* variable ++<BR>\n<variable> :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"I am ecstatic that some moron re-invented a 1995 windows fuckup.\" <BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Red Hat has recently released a Security Advisory (RHSA-1999:030-01)<BR>\ncovering a buffer overflow in the vixie cron package.  Debian has<BR>\ndiscovered this bug two years ago and fixed it.  Therefore versions in<BR>\nboth, the stable and the unstable, distributions of Debian are not<BR>\nvulnerable to this problem..');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"What are we going to do tonight, Bill?\"<BR>\n\"Same thing we do every night Steve, try to take over the world!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Joy> Flinny: black crontab magic kinda stuff :)<BR>\n<knghtbrd> Joy: does that mean people get to dance naked around bonfires<BR>\n&nbsp;chanting strange things and waving their arms about in a silly<BR>\n&nbsp;manner?<BR>\n<rcw> knghtbrd: what do you *think* people do at novare?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* knghtbrd is gone - zzz - messages will be snapped like wet towels at all<BR>\n&nbsp;of the people who have stolen the trademark knghtbrd away message<BR>\n<Coderjoe> ack<BR>\n* Coderjoe prepares to defend himself from wet messages');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<knghtbrd> *snipsnip*<BR>\n<rcw> oh dear, is that the sound of fortune-database editing?<BR>\n<Joy> uh oh<BR>\n<knghtbrd> Yes  =>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"I think that most debian developers are rather \"strong willed\" people<BR>\nwith a great degree of understanding and a high level of passion for what<BR>\nthey perceive as important in development of the debian system.\"<BR>\n&nbsp;--Bill Leach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* dark has changed the topic on channel #debian to: Later tonight: After<BR>\n&nbsp;months of careful refrigeration, Debian 2.0 is finally cool enough to<BR>\n&nbsp;release.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I sat laughing snidely into my notebook until they showed me a PC running<BR>\nLinux....  And did this PC choke?  Did it stutter?  Did it, even once,<BR>\nsay that this program has performed an illegal operation and must be shut<BR>\ndown?  No. And this is just on the client.<BR>\n&nbsp;-- LAN Times');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','While the year 2000 (y2k) problem is not an issue for us, all Linux<BR>\nimplementations will impacted by the year 2038 (y2.038k) issue. The<BR>\nDebian Project is committed to working with the industry on this issue<BR>\nand we will have our full plans and strategy posted by the first quarter<BR>\nof 2020.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"This is the element_data structure for elements whose *element_type =<BR>\nFORM_TYPE_SELECT_ONE, FORM_TYPE_SELECT_MULT. */ /* * nesting deeper<BR>\nand deeper, harder and harder, go, go, oh, OH, OHHHHH!! * Sorry, got<BR>\ncarried away there. */ struct lo_FormElementOptionData_struct.\"<BR>\n&nbsp;-- Mozilla source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','How many months are we going to be behind them [Redhat] with a glibc<BR>\nrelease?\"<BR>\n&nbsp;-- Jim Pick, 8 months before Debian 2.0 is finally released');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<joeyh> netgod: er, are these 2.2.0 packages 2.0.0pre9 or do you have a<BR>\n&nbsp;direct line with the gods?<BR>\n&nbsp;<netgod> joeyh: i have the direct line');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Overfiend> against stupidity the gods themselves contend in vain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','We the people of the Debian GNU/Linux distribution, in order to form a<BR>\nmore perfect operating system, establish quality, insure marketplace<BR>\ndiversity, provide for the common needs of computer users, promote<BR>\nsecurity and privacy, overthrow monopolistic forces in the computer<BR>\nsoftware industry, and secure the blessings of liberty to ourselves and<BR>\nour posterity, do ordain and establish this Constitution for the Debian<BR>\nGNU/Linux System.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<KatanaJ> Note on a chem lab fridge- \"This refrigerator is not explosion-<BR>\n&nbsp;proof\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<JHM> Being overloaded is the sign of a true Debian maintainer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* SynrG notes that the number of configuration questions to answer in<BR>\n&nbsp;sendmail is NON-TRIVIAL');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Microsoft DNS service terminates abnormally when it recieves a response<BR>\nto a DNS query that was never made.  Fix Information: Run your DNS<BR>\nservice on a different platform.<BR>\n&nbsp;-- BugTraq');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<sel> need help: my first packet to my provider gets lost :-(<BR>\n<netgod> sel:  dont send the first one, start with #2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Caytln slaps Lisa<BR>\n<Caytln> catfight :P<BR>\n<LisaHere> Watch it girl, I like that.<BR>\n<LisaHere> :)<BR>\n<Caytln> figures :D');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Silvrbear> Oxymorons?  I saw one yesterday - the pamphlet on \"Taco Bell<BR>\n&nbsp;Nutritional Information\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Overfiend sighs<BR>\n<Overfiend> Netscape sucks.<BR>\n<Overfiend> It is a house of cards resting on a bed of quicksand.<BR>\n<Espy> during an earthquake<BR>\n<Overfiend> in a tornado');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Anyone who stands out in the middle of a road looks like roadkill to me. <BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* aj thinks Kb^Zzz ought to pick different things to dream about than<BR>\n&nbsp;general resolutions and policy changes.<BR>\n<Kb^Zzz> aj - tell me about it, this is a Bad Sign');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I can just see it now: nomination-terrorism ;-)<BR>\n&nbsp;-- Manoj<BR>\n&nbsp;haha!  i nominate manoj.<BR>\n&nbsp;-- seeS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<marcus> dunham: You know how real numbers are constructed from rational<BR>\n&nbsp;numbers by equivalence classes of convergent sequences?<BR>\n<dunham> marcus: yes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<dark> Culus: Building a five-meter-high replica of the Empire State<BR>\n&nbsp;Building with paperclips is impressive.  Doing it blindfolded is<BR>\n&nbsp;eleet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<JHM> Somehow I have more respect for 14 year old Debian developers than<BR>\n&nbsp;14 year old Certified Microsoft Serfs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus> Ben: Do you solumly swear to read you debian email once a day and<BR>\n&nbsp;do not permit people to think you are MIA?<BR>\n<Ben> Culus: i do so swear');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Twilight1 will have to hang his Mozilla beanie dinosaur in effigy if<BR>\n&nbsp;Netscape sells-out to Alot Of Losers..');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"I wonder if this is the first constitution in the history of mankind<BR>\nwhere you have to calculate a square root to determine if a motion<BR>\npasses.  :-)\"<BR>\n&nbsp;-- Seen on Slashdot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<JHM> AIX - the Unix from the universe where Spock has a beard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<SirDibos> does Johnie Ingram hang out here on IRC?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','World Domination, of course.  And scantily clad females.  Who cares if<BR>\nits twenty below?        -- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* boren tosses matlab across the room and hopes it breaks into a number<BR>\n&nbsp;aproaching infinite peices');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"...It was a lot faster than I thought it was going to be, much faster<BR>\nthan NT.  If further speed increases are done to the server for the final<BR>\nrelease, Oracle is going to be able to wipe their ass with SQL SERVER and<BR>\nhand it back to M$ while the Oracle admins ... migrate their databases<BR>\nover to Linux!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Flood> can I write a unix-like kernel in perl?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<toor> netgod: what do you have in your kernel??? The compiled source for<BR>\n&nbsp;driving a space shuttle???<BR>\n&nbsp;<Spoo> time to make a zip drive your floppy drive then. if the kernel<BR>\n&nbsp;doesn fit on that, the kernel is an AI');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus> there is 150 meg in the /tmp dir! DEAR LORD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Now I can finally explain to everyone why I do this.  I just got $7 worth<BR>\nof free stuff for working on Debian !');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<zarkov> \"NT 5.0.  All the bugs and ten times the code size!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"In the event of a percieved failing of the project leadership #debian is<BR>\nempowered to take drastic and descisive action to correct the failing,<BR>\nincluding by not limited to expelling officials, apointing new officials<BR>\nand generally abusing power\"<BR>\n&nbsp;-- proposed amendment to Debian Constitution');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<ultima> netgod: My calculator has more registers than the x86, and<BR>\n&nbsp;-thats- sad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<doogie> Debian - All the power, without the silly hat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','NEW YORK (CNN) -- Internet users who spend even a few hours a week online<BR>\nat home experience higher levels of depression and loneliness than if<BR>\nthey had used the computer network less frequently, The New York Times<BR>\nreported Sunday.  The result ...  surprised both researchers and<BR>\nsponsors, which included Intel Corp., Hewlett Packard, AT&T Research and<BR>\nApple Computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"What is striking, however, is the general layout and integration of the<BR>\nsystem.  Debian is a truly elegant Linux distribution; great care has<BR>\nbeen taken in the preparation of packages and their placement within the<BR>\nsystem.  The sheer number of packages available is also impressive....\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<stu> you should be afraid to use KDE because RMS might come to your<BR>\n&nbsp;house and cleave your monitor with an axe or something :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"and i actually like debian 2.0 that much i completely revamped the<BR>\ndefault config of the linux systems our company sells and reinstalled any<BR>\nof the linux systems in the office and here at home..\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<xinkeT> \"Lord grant me the serenity to accept the things I cannot<BR>\n&nbsp;change, the courage to change the things I can, and the wisdom<BR>\n&nbsp;to hide the bodies of the people I had to kill because they<BR>\n&nbsp;pissed me off.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Davide> how bout a policy policing policy with a policy for changing the<BR>\n&nbsp;police policing policy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Culus fears perl - the language with optional errors');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Debian Linux is a solid, comprehensive product, and a genuine pleasure to<BR>\nuse.  It is also great to become involved with the Debian collective,<BR>\nwhose friendliness and spirit recalls the early days of the Internet and<BR>\nits sense of openness and global cooperation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','YES! YES! YES! Oh, YES! (ooops, I sound like Meg Ryan ;-)<BR>\n&nbsp;-- Ian Nandhra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<dark> \"Yes, your honour, I have RSA encryption code tattood on my<BR>\n&nbsp;penis.  Shall I show the jury?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Oryn> anyone know if there is a version of dpkg for redhat?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','acme-cannon (3.1415) unstable; urgency=low<BR>\n&nbsp;* Added safety to prevent operator dismemberment, closes: bug #98765,<BR>\n&nbsp;bug #98713, #98714.<BR>\n&nbsp;* Added manpage. closes: #98725.<BR>\n&nbsp;-- Wile E. Coyote <genius@debian.org>  Sun, 31 Jan 1999 07:49:57 -0600');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','&nbsp;[   ]  DOGBERT<BR>\n&nbsp;[ 2 ]  RICHARD STALLMAN<BR>\n&nbsp;[ 3 ]  BUFFY SUMMERS<BR>\n&nbsp;[ 1 ]  MANOJ SRIVASTAVA<BR>\n&nbsp;[ 4 ]  NONE of the above<BR>\n&nbsp;-- Debian Project Leader 1999 ballot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','!netgod:*! time flies when youre using linux<BR>\n!doogie:*! yeah, infinite loops in 5 seconds.<BR>\n!Teknix:*! has anyone re-tested that with 2.2.x ?<BR>\n!netgod:*! yeah, 4 seconds now');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus> OH MY GOD NOT A RANDOM QUOTE GENERATOR<BR>\n<netgod> surely you didnt think that was static? how lame would that be? <BR>\n&nbsp;:-)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Mere nonexistence is a feeble excuse for declaring a thing unseeable. You<BR>\n*can* see dragons.  You just have to look in the right direction.<BR>\n&nbsp;-- John Hasler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Manoj> I *like* the chicken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Reed> It is important to note that the primary reason the Roman Empire<BR>\n&nbsp;fail is that they had no concept of zero... thus they could not<BR>\n&nbsp;test the success or failure of their C programs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Since when has the purpose of debian been to appease the interests of the<BR>\nmass of unskilled consumers?        -- Steve Shorter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Overfiend ponders doing an NMU of asclock, in which he simply changes<BR>\n&nbsp;the extended description to \"If you bend over and put your head between<BR>\n&nbsp;your legs, you can read the time off your assclock.\"<BR>\n&nbsp;<doogie> Overfiend: go to bed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<lux> if macOS is for the computer illiterate, then windoze is for the<BR>\n&nbsp;computer masochists');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','2.3.1 has been released. Folks new to this game should remember that<BR>\n2.3.* releases are development kernels, with no guarantees that they<BR>\nwill not cause your system to do horrible things like corrupt its<BR>\ndisks, catch fire, or start running Mindcraft benchmarks.<BR>\n&nbsp;-- Slashdot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<woot> Put *that* in you .sig and smoke it, Knghtbrd.<BR>\n<Culus> You know he will read this :><BR>\n<woot> heheheheh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Teknix> our local telco has admitted that someone \"backed into a<BR>\n&nbsp;button on a switch\" and took the entire ATM network down<BR>\n&nbsp;<netgod> hopefully now routers are designed better, so the \"network<BR>\n&nbsp;off\" swtich is on the back');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<BenC> cerb: we subscribed you to debian-fight as the moderator<BR>\n<BenC> cerb: list rules are, 1) no nice emails, 2) no apologies');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','The purpose of having mailing lists rather than having newsgroups is to<BR>\nplace a barrier to entry which protects the lists and their users from<BR>\ninvasion by the general uneducated hordes.<BR>\n&nbsp;-- Ian Jackson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Culus thinks we should go to trade shows and see how many people we<BR>\n&nbsp;can kill by throwing debian cds at them');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Overfiend> xhost +localhost should only be done by people who would<BR>\n&nbsp;paint their hostname and root password on an interstate<BR>\n&nbsp;overpass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> Studies prove that research causes cancer in 43% of laboratory<BR>\n&nbsp;rats<BR>\n&nbsp;<CQ> knghtbrd- yeah, but 78% of those statistics are off by 52%...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* lilo hereby declares OPN a virtual pain in the ass :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','\"You have the right not to be an asshole.  If you give up that right<BR>\neverything you say and do in here will be held against you. If you cannot<BR>\nafford to stop being an asshole then someone will be appointed to kick<BR>\nyours outta here.\"<BR>\n&nbsp;-- Your rights as an irc addict');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Indifference will certainly be the downfall of mankind, but who cares?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Never underestimate the power of human stupidity.<BR>\n&nbsp;-- Robert A. Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Iambe> conning the most intellegent people on the planet is not easy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<RoboHak> hmm, lunch does sound like a good idea<BR>\n<Knghtbrd> would taste like a good idea too');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<dark> Knghtbrd: We have lots of whatevers.<BR>\n<Knghtbrd> dark - In Debian?  Hell yeah we do!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','I did it just to piss you off.  :-P<BR>\n&nbsp;-- Branden Robinson in a message to debian-devel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','We all know Linux is great... it does infinite loops in 5 seconds.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','10) there is no 10, but it sounded like a nice number :)<BR>\n&nbsp;-- Wichert Akkerman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Culus> Saens demonstrates no less than 3 tcp/ip bugs in 2.2.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Mercury> alexsh: Be /VERY/ cairful, you could, if your unlucky, fry your<BR>\n&nbsp;motherboards..<BR>\n&nbsp;<Knghtbrd> Mercury - sounds like fun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd unleashes a pair of double barreled snurf guns and covers<BR>\n&nbsp;jesus with snurf darts<BR>\n<jesus> meany :P');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<lilo> \"PLEASE RESPECT INTELLECTUAL RIGHTS!\"<BR>\n<lilo> \"Please demonstrate intellect.\" ;)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<DarthVadr> Kira: JOIN THE DARK SIDE, YOUNG ONE.<BR>\n<kira> darth, I *am* the dark side.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','knghtbrd: there may be no spoon, but can you spot the vulnerability in<BR>\neye_render_shiny_object.c?<BR>\n&nbsp;-- rcw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Flood> netgod: I also have a \"Evil Inside\" T-shirt (w/ Intel logo).. on<BR>\n&nbsp;the back it states: \"When the rapture comes, will you have root?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','Something must be Done<BR>\nThis is Something<BR>\nTherefore, This must be Done<BR>\n&nbsp;-- The Thatcherite Syllogism');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<Knghtbrd> If I start writing essays about Free Software for slashdot,<BR>\n&nbsp;please shoot me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<apt> it has been said that redhat is the thing Marc Ewing wears on<BR>\n&nbsp;his head.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','<netgod> Feanor: u have no idea of the depth of the stupidty of american law');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','* Knghtbrd is FAR too tempted to .sig this entire discussion...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('knghtbrd','The software required Win95 or better, so I installed Linux.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;A Los Angeles judge ruled that \"a citizen may snore with immunity in<BR>\nhis own home, even though he may be in possession of unusual and exceptional<BR>\nability in that particular field.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;A New York City judge ruled that if two women behind you at the<BR>\nmovies insist on discussing the probable outcome of the film, you have the<BR>\nright to turn around and blow a Bronx cheer at them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A New York City ordinance prohibits the shooting of rabbits from the<BR>\nrear of a Third Avenue street car -- if the car is in motion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','And then there was the lawyer that stepped in cow manure and thought<BR>\nhe was melting...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A small town that cannot support one lawyer can always support two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A jury consists of twelve persons chosen to decide who has the better lawyer.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','After 35 years, I have finished a comprehensive study of European<BR>\ncomparative law.  In Germany, under the law, everything is prohibited,<BR>\nexcept that which is permitted.  In France, under the law, everything<BR>\nis permitted, except that which is prohibited.  In the Soviet Union,<BR>\nunder the law, everything is prohibited, including that which is<BR>\npermitted.  And in Italy, under the law, everything is permitted,<BR>\nespecially that which is prohibited.<BR>\n&nbsp;-- Newton Minow,<BR>\n&nbsp;Speech to the Association of American Law Schools, 1985');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','According to Kentucky state law, every person must take a bath at least<BR>\nonce a year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  Did you ever stay all night with this man in New York?<BR>\nA.  I refuse to answer that question.<BR>\nQ.  Did you ever stay all night with this man in Chicago?<BR>\nA.  I refuse to answer that question.<BR>\nQ.  Did you ever stay all night with this man in Miami?<BR>\nA.  No.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A Riverside, California, health ordinance states that two persons may<BR>\nnot kiss each other without first wiping their lips with carbolized rosewater.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A countryman between two lawyers is like a fish between two cats.<BR>\n&nbsp;-- Ben Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A Los Angeles judge ruled that \"a citizen may snore with immunity in<BR>\nhis own home, even though he may be in possession of unusual and<BR>\nexceptional ability in that particular field.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','A doctor was stranded with a lawyer in a leaky life raft in shark-infested<BR>\nwaters. The doctor tried to swim ashore but was eaten by the sharks. The<BR>\nlawyer, however, swam safely past the bloodthirsty sharks.  \"Professional<BR>\ncourtesy,\" he explained.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','For certain people, after fifty, litigation takes the place of sex.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  And who is this person you are speaking of?<BR>\nA.  My ex-widow said it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','\"Gentlemen of the jury,\" said the defense attorney, now beginning<BR>\nto warm to his summation, \"the real question here before you is, shall this<BR>\nbeautiful young woman be forced to languish away her loveliest years in a <BR>\ndark prison cell?  Or shall she be set free to return to her cozy little <BR>\napartment at 4134 Mountain Ave. -- there to spend her lonely, loveless hours<BR>\nin her boudoir, lying beside her little Princess phone, 962-7873?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Fights between cats and dogs are prohibited by statute in Barber, North<BR>\nCarolina.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Doctors and lawyers must go to school for years and years, often with<BR>\nlittle sleep and with great sacrifice to their first wives.<BR>\n&nbsp;-- Roy G. Blount, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Divorce is a game played by lawyers.<BR>\n&nbsp;-- Cary Grant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','District of Columbia pedestrians who leap over passing autos to escape<BR>\ninjury, and then strike the car as they come down, are liable for any<BR>\ndamage inflicted on the vehicle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','[District Attorneys] learn in District Attorney School that there are<BR>\ntwo sure-fire ways to get a lot of favorable publicity:<BR>\n&nbsp;(1) Go down and raid all the lockers in the local high school and<BR>\n&nbsp;confiscate 53 marijuana cigarettes and put them in a pile and hold<BR>\n&nbsp;a press conference where you announce that they have a street value<BR>\n&nbsp;of $850 million.  These raids never fail, because ALL high schools,<BR>\n&nbsp;including brand-new, never-used ones, have at least 53 marijuana<BR>\n&nbsp;cigarettes in the lockers.  As far as anyone can tell, the locker<BR>\n&nbsp;factory puts them there.<BR>\n(2) Raid an \"adult book store\" and hold a press conference where you<BR>\n&nbsp;announce you are charging the owner with 850 counts of being a<BR>\n&nbsp;piece of human sleaze.  This also never fails, because you always<BR>\n&nbsp;get a conviction.  A juror at a pornography trial is not about to<BR>\n&nbsp;state for the record that he finds nothing obscene about a movie<BR>\n&nbsp;where actors engage in sexual activities with live snakes and a<BR>\n&nbsp;fire extinguisher.  He is going to convict the bookstore owner, and<BR>\n&nbsp;vote for the death penalty just to make sure nobody gets the wrong<BR>\n&nbsp;impression.<BR>\n&nbsp;-- Dave Barry, \"Pornography\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Chicago law prohibits eating in a place that is on fire.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Certain passages in several laws have always defied interpretation and the<BR>\nmost inexplicable must be a matter of opinion.  A judge of the Court of<BR>\nSession of Scotland has sent the editors of this book his candidate which<BR>\nreads, \"In the Nuts (unground), (other than ground nuts) Order, the expression<BR>\nnuts shall have reference to such nuts, other than ground nuts, as would<BR>\nbut for this amending Order not qualify as nuts (unground) (other than ground<BR>\nnuts) by reason of their being nuts (unground).\"<BR>\n&nbsp;-- Guiness Book of World Records, 1973');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Between grand theft and a legal fee, there only stands a law degree.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Getting kicked out of the American Bar Association is liked getting kicked<BR>\nout of the Book-of-the-Month Club.<BR>\n&nbsp;-- Melvin Belli on the occcasion of his getting kicked out<BR>\n&nbsp;of the American Bar Association');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Be frank and explicit with your lawyer ... it is his business to confuse<BR>\nthe issue afterwards.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Behold the warranty -- the bold print giveth and the fine print taketh away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Anti-trust laws should be approached with exactly that attitude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Atlanta makes it against the law to tie a giraffe to a telephone pole<BR>\nor street lamp.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;Horses are forbidden to eat fire hydrants in Marshalltown, Iowa.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;How do you insult a lawyer?<BR>\n&nbsp;You might as well not even try.  Consider: of all the highly<BR>\ntrained and educated professions, law is the only one in which the prime<BR>\nlesson is that *winning* is more important than *truth*.<BR>\n&nbsp;Once someone has sunk to that level, what worse can you say about them?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','He is no lawyer who cannot take two sides.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Good government never depends upon laws, but upon the personal qualities of<BR>\nthose who govern.  The machinery of government is always subordinate to the<BR>\nwill of those who administer that machinery.  The most important element of<BR>\ngovernment, therefore, is the method of choosing leaders.<BR>\n&nbsp;-- Frank Herbert, \"Children of Dune\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  And lastly, Gary, all your responses must be oral.  O.K.? What school do <BR>\n&nbsp;you go to?<BR>\nA.  Oral.<BR>\nQ.  How old are you?<BR>\nA.  Oral.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Fortune Documents the Great Legal Decisions:<BR>\n&nbsp;We can imagine no reason why, with ordinary care, human toes could not be<BR>\nleft out of chewing tobacco, and if toes are found in chewing tobacco, it<BR>\nseems to us that someone has been very careless.<BR>\n&nbsp;-- 78 So. 365.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Fortune Documents the Great Legal Decisions:<BR>\n&nbsp;We think that we may take judicial notice of the fact that the term \"bitch\"<BR>\nmay imply some feeling of endearment when applied to a female of the canine<BR>\nspecies but that it is seldom, if ever, so used when applied to a female<BR>\nof the human race. Coming as it did, reasonably close on the heels of two<BR>\nrevolver shots directed at the person of whom it was probably used, we think<BR>\nit carries every reasonable implication of ill-will toward that person.<BR>\n&nbsp;-- Smith v. Moran, 193 N.E. 2d 466.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Fortune Documents the Great Legal Decisions:<BR>\n&nbsp;It is a rule of evidence deduced from the experience of mankind and<BR>\nsupported by reason and authority that positive testimony is entitled to<BR>\nmore weight than negative testimony, but by the latter term is meant<BR>\nnegative testimony in its true sense and not positive evidence of a<BR>\nnegative, because testimony in support of a negative may be as positive<BR>\nas that in support of an affirmative.<BR>\n&nbsp;-- 254 Pac. Rep. 472.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','I suppose some of the variation between Boston drivers and the rest of the<BR>\ncountry is due to the progressive Massachusetts Driver Education Manual which<BR>\nI happen to have in my top desk drawer.  Some of the Tips for Better Driving<BR>\nare worth considering, to wit:<BR>\n&nbsp;[131.16d]:<BR>\n&nbsp;\"Directional signals are generally not used except during vehicle<BR>\n&nbsp;inspection; however, a left-turn signal is appropriate when making<BR>\n&nbsp;a U-turn on a divided highway.\"<BR>\n&nbsp;[96.7b]:<BR>\n&nbsp;\"When paying tolls, remember that it is necessary to release the<BR>\n&nbsp;quarter a full 3 seconds before passing the basket if you are<BR>\n&nbsp;traveling more than 60 MPH.\"<BR>\n&nbsp;[110.13]:<BR>\n&nbsp;\"When traveling on a one-way street, stay to the right, so as not<BR>\n&nbsp;to interfere with oncoming traffic.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','If a jury in a criminal trial stays out for more than twenty-four hours, it<BR>\nis certain to vote acquittal, save in those instances where it votes guilty.<BR>\n&nbsp;-- Joseph C. Goulden');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: What is the meaning of sperm being present?<BR>\nA: It indicates intercourse.<BR>\nQ: Male sperm?<BR>\nA. That is the only kind I know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: What is your relationship with the plaintiff?<BR>\nA: She is my daughter.<BR>\nQ: Was she your daughter on February 13, 1979?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','I need another lawyer like I need another hole in my head.<BR>\n&nbsp;-- Fratianno');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: Could you see him from where you were standing?<BR>\nA: I could see his head.<BR>\nQ: And where was his head?<BR>\nA: Just above his shoulders.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: Now, you have investigated other murders, have you not, where there was<BR>\n&nbsp;a victim?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: Are you qualified to give a urine sample?<BR>\nA: Yes, I have been since early childhood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: Are you sexually active?<BR>\nA: No, I just lie there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','I remember when legal used to mean lawful, now it means some<BR>\nkind of loophole.<BR>\n&nbsp;-- Leo Kessler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  Mrs. Jones, is your appearance this morning pursuant to a deposition <BR>\n&nbsp;notice which I sent to your attorney?<BR>\nA.  No.  This is how I dress when I go to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Blythe, California, a city ordinance declares that a person must own<BR>\nat least two cows before he can wear cowboy boots in public.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','HR 3128.  Omnibus Budget Reconciliation, Fiscal 1986.  Martin, R-Ill., motion<BR>\nthat the House recede from its disagreement to the Senate amendment making<BR>\nchanges in the bill to reduce fiscal 1986 deficits.  The Senate amendment<BR>\nwas an amendment to the House amendment to the Senate amendment to the House<BR>\namendment to the Senate amendment to the bill.  The original Senate amendment<BR>\nwas the conference agreement on the bill.  Agreed to.<BR>\n&nbsp;-- Albuquerque Journal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It has long been noticed that juries are pitiless for robbery and full of<BR>\nindulgence for infanticide.  A question of interest, my dear Sir!  The jury<BR>\nis afraid of being robbed and has passed the age when it could be a victim<BR>\nof infanticide.<BR>\n&nbsp;-- Edmond About');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In West Union, Ohio, No married man can go flying without his spouse<BR>\nalong at any time, unless he has been married for more than 12 months.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It is against the law for a monster to enter the corporate limits of<BR>\nUrbana, Illinois.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Tulsa, Oklahoma, it is against the law to open a soda bottle without<BR>\nthe supervision of a licensed engineer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Tennessee, it is illegal to shoot any game other than whales from a<BR>\nmoving automobile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Seattle, Washington, it is illegal to carry a concealed weapon that<BR>\nis over six feet in length.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Pocataligo, Georgia, it is a violation for a woman over 200 pounds<BR>\nand attired in shorts to pilot or ride in an airplane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Pocatello, Idaho, a law passed in 1912 provided that \"The carrying<BR>\nof concealed weapons is forbidden, unless same are exhibited to public view.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It is illegal to drive more than two thousand sheep down Hollywood<BR>\nBoulevard at one time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;In Memphis, Tennessee, it is illegal for a woman to drive a car unless<BR>\nthere is a man either running or walking in front of it waving a red<BR>\nflag to warn approaching motorists and pedestrians.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Lowes Crossroads, Delaware, it is a violation of local law for any<BR>\npilot or passenger to carry an ice cream cone in their pocket while<BR>\neither flying or waiting to board a plane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Greene, New York, it is illegal to eat peanuts and walk backwards on<BR>\nthe sidewalks when a concert is on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Devon, Connecticut, it is unlawful to walk backwards after sunset.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Columbia, Pennsylvania, it is against the law for a pilot to tickle<BR>\na female flying student under her chin with a feather duster in order<BR>\nto get her attention.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Boston, it is illegal to hold frog-jumping contests in nightclubs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','In Denver it is unlawful to lend your vacuum cleaner to your next-door neighbor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It is illegal to say \"Oh, Boy\" in Jonesboro, Georgia.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: ...and what did he do then?<BR>\nA: He came home, and next morning he was dead.<BR>\nQ: So when he woke up the next morning he was dead?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  Mrs. Smith, do you believe that you are emotionally unstable?<BR>\nA.  I should be.<BR>\nQ.  How many times have you comitted suicide?<BR>\nA.  Four times.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  Were you aquainted with the deceased?<BR>\nA.  Yes, sir.<BR>\nQ.  Before or after he died?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ: ...any suggestions as to what prevented this from being a murder trial <BR>\n&nbsp;instead of an attempted murder trial?<BR>\nA: The victim lived.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','\"If once a man indulges himself in murder, very soon he comes to think<BR>\nlittle of robbing; and from robbing he next comes to drinking and<BR>\nSabbath-breaking, and from that to incivility and procrastination.\"<BR>\n&nbsp;-- Thomas De Quincey (1785 - 1859)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','If a man stay away from his wife for seven years, the law presumes the<BR>\nseparation to have killed him; yet according to our daily experience,<BR>\nit might well prolong his life.<BR>\n&nbsp;-- Charles Darling, \"Scintillae Juris, 1877');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','If there were a school for, say, sheet metal workers, that after three<BR>\nyears left its graduates as unprepared for their careers as does law<BR>\nschool, it would be closed down in a minute, and no doubt by lawyers.<BR>\n&nbsp;-- Michael Levin, \"The Socratic Method');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;Idaho state law makes it illegal for a man to give his sweetheart<BR>\na box of candy weighing less than fifty pounds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','She cried, and the judge wiped her tears with my checkbook.<BR>\n&nbsp;-- Tommy Manville');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Men often believe -- or pretend -- that the \"Law\" is something sacred, or<BR>\nat least a science -- an unfounded assumption very convenient to governments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The difference between a lawyer and a rooster is that<BR>\nthe rooster gets up in the morning and clucks defiance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The District of Columbia has a law forbidding you to exert pressure on<BR>\na balloon and thereby cause a whistling sound on the streets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;Old Barlow was a crossing-tender at a junction where an express train<BR>\ndemolished an automobile and its occupants. Being the chief witness, his<BR>\ntestimony was vitally important. Barlow explained that the night was dark,<BR>\nand he waved his lantern frantically, but the driver of the car paid<BR>\nno attention to the signal.<BR>\n&nbsp;The railroad company won the case, and the president of the company<BR>\ncomplimented the old-timer for his story. \"You did wonderfully,\" he said,<BR>\n\"I was afraid you would waver under testimony.\"<BR>\n&nbsp;\"No sir,\" exclaimed the senior, \"but I sure was afraid that durned<BR>\nlawyer was gonna ask me if my lantern was lit.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','New Hampshire law forbids you to tap your feet, nod your head, or in<BR>\nany way keep time to the music in a tavern, restaurant, or cafe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The City of Palo Alto, in its official description of parking lot standards,<BR>\nspecifies the grade of wheelchair access ramps in terms of centimeters of<BR>\nrise per foot of run.  A compromise, I imagine...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','NEVER swerve to hit a lawyer riding a bicycle -- it might be your bicycle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','... Our second completely true news item was sent to me by Mr. H. Boyce<BR>\nConnell Jr. of Atlanta, Ga., where he is involved in a law firm.  One thing<BR>\nI like about the South is, folks there care about tradition.  If somebody<BR>\ngets handed a name like \"H. Boyce,\" he hangs on to it, puts it on his legal<BR>\nstationery, even passes it to his son, rather than do what a lesser person<BR>\nwould do, such as get it changed or kill himself.<BR>\n&nbsp;-- Dave Barry, \"This Column is Nothing but the Truth!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Never put off until tomorrow what you can do today.  There might be a<BR>\nlaw against it by that time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Loud burping while walking around the airport is prohibited in Halstead, Kansas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','... Logically incoherent, semantically incomprehensible, and legally ... <BR>\nimpeccable!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Let us remember that ours is a nation of lawyers and order.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Legislation proposed in the Illinois State Legislature, May, 1907:<BR>\n&nbsp;\"Speed upon county roads will be limited to ten miles an hour<BR>\nunless the motorist sees a bailiff who does not appear to have had a<BR>\ndrink in 30 days, when the driver will be permitted to make what he can.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Marijuana will be legal some day, because the many law students<BR>\nwho now smoke pot will someday become congressmen and legalize<BR>\nit in order to protect themselves.<BR>\n&nbsp;-- Lenny Bruce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Kirkland, Illinois, law forbids bees to fly over the village or through<BR>\nany of its streets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Know how to save 5 drowning lawyers?<BR>\n&nbsp;-- No?<BR>\n&nbsp;GOOD!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Kansas state law requires pedestrians crossing the highways at night to<BR>\nwear tail lights.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It is Texas law that when two trains meet each other at a railroad crossing,<BR>\neach shall come to a full stop, and neither shall proceed until the other<BR>\nhas gone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The lawgiver, of all beings, most owes the law allegiance.  He of all men<BR>\nshould behave as though the law compelled him.  But it is the universal<BR>\nweakness of mankind that what we are given to administer we presently imagine<BR>\nwe own.<BR>\n&nbsp;-- H.G. Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The penalty for laughing in a courtroom is six months in jail; if it<BR>\nwere not for this penalty, the jury would never hear the evidence.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The Law, in its majestic equality, forbids the rich, as well as the poor,<BR>\nto sleep under the bridges, to beg in the streets, and to steal bread.<BR>\n&nbsp;-- Anatole France');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The powers not delegated to the United States by the Constitution, nor<BR>\nprohibited by it to the States, are reserved to the States respectively,<BR>\nor to the people.<BR>\n&nbsp;-- U.S. Constitution, Amendment 10. (Bill of Rights)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;The judge fined the jaywalker fifty dollars and told him if he was<BR>\ncaught again, he would be thrown in jail.  Fine today, cooler tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','&nbsp;The Arkansas legislature passed a law that states that the Arkansas<BR>\nRiver can rise no higher than to the Main Street bridge in Little Rock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Texas law forbids anyone to have a pair of pliers in his possession.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The animals are not as stupid as one thinks -- they have neither<BR>\ndoctors nor lawyers.<BR>\n&nbsp;-- L. Docquier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Sometimes a man who deserves to be looked down upon because he is a<BR>\nfool is despised only because he is a lawyer.<BR>\n&nbsp;-- Montesquieu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Where it is a duty to worship the sun it is pretty sure to be a crime to<BR>\nexamine the laws of heat.<BR>\n&nbsp;-- Christopher Morley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Why does a hearse horse snicker, hauling a lawyer away?<BR>\n&nbsp;-- Carl Sandburg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Why does New Jersey have more toxic waste dumps and California have<BR>\nmore lawyers?<BR>\n&nbsp;New Jersey had first choice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','What do you have when you have six lawyers buried up to their necks in sand?<BR>\nNot enough sand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','We may not like doctors, but at least they doctor.  Bankers are not ever<BR>\npopular but at least they bank.  Policeman police and undertakers take<BR>\nunder.  But lawyers do not give us law.  We receive not the gladsome light<BR>\nof jurisprudence, but rather precedents, objections, appeals, stays,<BR>\nfilings and forms, motions and counter-motions, all at $250 an hour.<BR>\n&nbsp;-- Nolo News, summer 1989');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Virginia law forbids bathtubs in the house; tubs must be kept in the yard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','This product is meant for educational purposes only.  Any resemblance to real<BR>\npersons, living or dead is purely coincidental.  Void where prohibited.  Some<BR>\nassembly may be required.  Batteries not included.  Contents may settle during<BR>\nshipment.  Use only as directed.  May be too intense for some viewers.  If<BR>\ncondition persists, consult your physician.  No user-serviceable parts inside.<BR>\nBreaking seal constitutes acceptance of agreement.  Not responsible for direct,<BR>\nindirect, incidental or consequential damages resulting from any defect, error<BR>\nor failure to perform.  Slippery when wet.  For office use only.  Substantial<BR>\npenalty for early withdrawal.  Do not write below this line.  Your cancelled<BR>\ncheck is your receipt.  Avoid contact with skin.  Employees and their families<BR>\nare not eligible.  Beware of dog.  Driver does not carry cash.  Limited time<BR>\noffer, call now to insure prompt delivery.  Use only in well-ventilated area.<BR>\nKeep away from fire or flame.  Some equipment shown is optional.  Price does<BR>\nnot include taxes, dealer prep, or delivery.  Penalty for private use.  Call<BR>\ntoll free before digging.  Some of the trademarks mentioned in this product<BR>\nappear for identification purposes only.  All models over 18 years of age.  Do<BR>\nnot use while operating a motor vehicle or heavy equipment.  Postage will be<BR>\npaid by addressee.  Apply only to affected area.  One size fits all.  Many<BR>\nsuitcases look alike.  Edited for television.  No solicitors.  Reproduction<BR>\nstrictly prohibited.  Restaurant package, not for resale.  Objects in mirror<BR>\nare closer than they appear.  Decision of judges is final.  This supersedes<BR>\nall previous notices.  No other warranty expressed or implied.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','We should realize that a city is better off with bad laws, so long as they <BR>\nremain fixed, then with good laws that are constantly being altered, that<BR>\nthe lack of learning combined with sound common sense is more helpful than<BR>\nthe kind of cleverness that gets out of hand, and that as a general rule,<BR>\nstates are better governed by the man in the street than by intellectuals.<BR>\nThese are the sort of people who want to appear wiser than the laws, who<BR>\nwant to get their own way in every general discussion, because they feel that<BR>\nthey cannot show off their intelligence in matters of greater importance, and<BR>\nwho, as a result, very often bring ruin on their country.<BR>\n&nbsp;-- Cleon, Thucydides, III, 37 translation by Rex Warner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','There is no better way of exercising the imagination than the study of law.<BR>\nNo poet ever interpreted nature as freely as a lawyer interprets truth.<BR>\n&nbsp;-- Jean Giraudoux, \"Tiger at the Gates\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','\"There was an interesting development in the CBS-Westmoreland trial:<BR>\nboth sides agreed that after the trial, Andy Rooney would be allowed to<BR>\ntalk to the jury for three minutes about little things that annoyed him<BR>\nduring the trial.\"<BR>\n&nbsp;-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','There is a Massachusetts law requiring all dogs to have their hind legs<BR>\ntied during the month of April.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The Worst Jury<BR>\n&nbsp;A murder trial at Manitoba in February 1978 was well advanced, when<BR>\none juror revealed that he was completely deaf and did not have the<BR>\nremotest clue what was happening.<BR>\n&nbsp;The judge, Mr. Justice Solomon, asked him if he had heard any<BR>\nevidence at all and, when there was no reply, dismissed him.<BR>\n&nbsp;The excitement which this caused was only equalled when a second<BR>\njuror revealed that he spoke not a word of English.  A fluent French<BR>\nspeaker, he exhibited great surprised when told, after two days, that he<BR>\nwas hearing a murder trial.<BR>\n&nbsp;The trial was abandoned when a third juror said that he suffered<BR>\nfrom both conditions, being simultaneously unversed in the English language<BR>\nand nearly as deaf as the first juror.<BR>\n&nbsp;The judge ordered a retrial.<BR>\n&nbsp;-- Stephen Pile, \"The Book of Heroic Failures\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The state law of Pennsylvania prohibits singing in the bathtub.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The primary requisite for any new tax law is for it to exempt enough<BR>\nvoters to win the next election.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','The Least Successful Equal Pay Advertisement<BR>\n&nbsp;In 1976 the European Economic Community pointed out to the Irish<BR>\nGovernment that it had not yet implemented the agreed sex equality<BR>\nlegislation.  The Dublin Government immediately advertised for an equal pay<BR>\nenforcement officer.  The advertisement offered different salary scales for<BR>\nmen and women.<BR>\n&nbsp;-- Stephen Pile, \"The Book of Heroic Failures\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Humor in the Court:<BR>\nQ.  Doctor, did you say he was shot in the woods?<BR>\nA.  No, I said he was shot in the lumbar region.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','It shall be unlawful for any suspicious person to be within the municipality.<BR>\n&nbsp;-- Local ordinance, Euclid Ohio');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Welcome to Utah.<BR>\nIf you think our liquor laws are funny, you should see our underwear!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('law','Minors in Kansas City, Missouri, are not allowed to purchase cap pistols;<BR>\nthey may buy shotguns freely, however.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man from Fort Drum<BR>\nWhose son was incredibly dumb.<BR>\n&nbsp;When he urged him ahead,<BR>\n&nbsp;He went down instead,<BR>\nFor he thought to succeed meant succumb.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Two eager young men from Cawnpore<BR>\nOnce buggared and fucked the same whore.<BR>\n&nbsp;But her partition split<BR>\n&nbsp;And the blood and the shit<BR>\nRolled out in a mess on the floor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Under the spreading chestnut tree<BR>\nThe village smith he sat,<BR>\n&nbsp;Amusing himself<BR>\n&nbsp;By abusing himself<BR>\nAnd catching the load in his hat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Gloria<BR>\nWho was had by Sir Gerald Du Maurier,<BR>\n&nbsp;And then by six men,<BR>\n&nbsp;Sir Gerald again,<BR>\nAnd the band at the Waldorf-Astoria.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Banker,<BR>\nWho slept while the ship lay at anchor,<BR>\n&nbsp;She woke in dismay,<BR>\n&nbsp;When she heard the mate say,<BR>\n\"Now hoist up the topsheet and spanker.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Maine<BR>\nWhose prick was as strong as a crane;<BR>\n&nbsp;It was almost as long,<BR>\n&nbsp;So he strolled with his dong<BR>\nExtended in sunshine and rain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Australia<BR>\nWho went on a wild bacchanalia.<BR>\n&nbsp;He buggered a frog,<BR>\n&nbsp;Two mice and a dog,<BR>\nAnd a bishop in fullest regalia.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Madras<BR>\nWhose balls were constructed of brass.<BR>\n&nbsp;When jangled together<BR>\n&nbsp;They played \"Stormy Weather\",<BR>\nAnd lightning shot out of his ass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young person of Kent<BR>\nWho was famous wherever he went.<BR>\n&nbsp;All the way through a fuck,<BR>\n&nbsp;He would quack like a duck,<BR>\nAnd he crowed like a cock when he spent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Kutki<BR>\nWho could blink himself off with one eye.<BR>\n&nbsp;For a while though, he pined,<BR>\n&nbsp;When his organ declined<BR>\nTo function, because of a stye.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old gent from Kentuck<BR>\nWho boasted a filigreed schmuck,<BR>\n&nbsp;But he put it away<BR>\n&nbsp;For fear that one day<BR>\nHe might put it in and get stuck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man from Bengal<BR>\nWho liked to do tricks in the hall.<BR>\n&nbsp;His favorite trick<BR>\n&nbsp;Was to stand on his dick<BR>\nWhile he rolled around on one ball.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Spain<BR>\nWho got sick as she rode on a train;<BR>\n&nbsp;Not once, but again,<BR>\n&nbsp;And again, and again,<BR>\nAnd again, and again, and again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Flynn<BR>\nWho thought fornication a sin,<BR>\n&nbsp;But when she was tight<BR>\n&nbsp;It seemed quite all right,<BR>\nSo everyone filled her with gin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Gilda<BR>\nWho went on a date with a builder.<BR>\n&nbsp;He said that he would,<BR>\n&nbsp;And he could and he should,<BR>\nAnd he did and it damn well near killed her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Kent<BR>\nWhose tool was so long that it bent.<BR>\n&nbsp;To save himself trouble<BR>\n&nbsp;He put it in double<BR>\nAnd instead of coming, he went.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An uptight young lady named Breerley<BR>\nWho valued her morals too dearly<BR>\n&nbsp;Had sex, so I hear,<BR>\n&nbsp;Only once every year,<BR>\nAnd she strained her vagina severely.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Astor<BR>\nWho never let any get past her.<BR>\n&nbsp;She finally got plenty<BR>\n&nbsp;By stopping twenty,<BR>\nWhich certainly ought to last her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Flo<BR>\nWhose lover had pulled out too slow.<BR>\n&nbsp;So they tried it all night,<BR>\n&nbsp;Till he got it just right...<BR>\nWell, practice makes pregnant, you know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Bright<BR>\nWho could travel much faster than light.<BR>\n&nbsp;She took off one day,<BR>\n&nbsp;In a relative way,<BR>\nAnd returned on the previous night.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Brook<BR>\nWho never could learn how to cook.<BR>\n&nbsp;But on a divan<BR>\n&nbsp;She could please any man-<BR>\nShe knew every darn trick in the book!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Brent<BR>\nWith a cunt of enormous extent,<BR>\n&nbsp;And so deep and so wide,<BR>\n&nbsp;The acoustics inside<BR>\nWere so good you could hear when you spent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Blount<BR>\nWho had a rectangular cunt.<BR>\n&nbsp;She learned for diversion<BR>\n&nbsp;Posterior perversion,<BR>\nSince no one could fit here in front.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Bower<BR>\nWho dwelt in an Ivory Tower.<BR>\n&nbsp;But a poet from Perth<BR>\n&nbsp;Laid her flat on the earth,<BR>\nAnd proceeded with penis to plough her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Clair<BR>\nWho possessed a magnificent pair;<BR>\n&nbsp;At least so I thought<BR>\n&nbsp;Till I saw one get caught<BR>\nOn a thorn, and begin losing air.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Duff<BR>\nWith a lovely, luxuriant muff.<BR>\n&nbsp;In his haste to get in her<BR>\n&nbsp;One eager beginner<BR>\nLost both of his balls in the rough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Fleager<BR>\nWho was terribly, terribly eager<BR>\n&nbsp;To be all the rage<BR>\n&nbsp;On the tragedy stage,<BR>\nThough her talents were pitifully meagre.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a gaucho named Bruno,<BR>\nWho said, \"About sex, well, I do know,<BR>\n&nbsp;Sheep are just fine,<BR>\n&nbsp;Chickens, divine,<BR>\nBut iguanas are Numero Uno.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A charmer from old Amarillo,<BR>\nSick of finding strange heads on her pillow,<BR>\n&nbsp;Decided one day<BR>\n&nbsp;That to keep men away<BR>\nShe would stuff up her crevice with Brillo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A marine being sent to Hong Kong<BR>\nGot a doctor to alter his dong.<BR>\n&nbsp;He sailed off with a tool<BR>\n&nbsp;Flat and thin as a rule -<BR>\nWhen he got there he found he was wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Hong Kong<BR>\nWho said, \"You are utterly wrong<BR>\n&nbsp;To say my vagina<BR>\n&nbsp;Is the largest in China<BR>\nJust because of your mean little dong.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Peru,<BR>\nWho had nothing whatever to do.<BR>\n&nbsp;So she sat on the stairs,<BR>\n&nbsp;And counted cunt hairs,<BR>\nFour thousand, three hundred and two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A cautious young fellow named Lodge<BR>\nHad seatbelts installed in his Dodge.<BR>\n&nbsp;When his date was strapped in,<BR>\n&nbsp;He committed a sin,<BR>\nWithout even leaving his grodge.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A burleyque dancer, a pip<BR>\nNamed Virginia, could peel in a zip;<BR>\n&nbsp;But she read science fiction<BR>\n&nbsp;And died of constriction<BR>\nAttempting a Moebius strip.<BR>\n&nbsp;-- Cyril Kornbluth, \"The Unfortunate Topology\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Angina<BR>\nWho stretched catgut across her vagina.<BR>\n&nbsp;From the love-making frock<BR>\n&nbsp;(With the proper sized cock)<BR>\nCame Toccata and Fugue in D minor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Bude<BR>\nWho walked down the street in the nude.<BR>\n&nbsp;A bobby said, \"Whattum<BR>\n&nbsp;Magnificent bottom!\"<BR>\nAnd slapped it as hard as he could.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A beetling young woman named Pridgets<BR>\nHad a violent abhorrence of midgets;<BR>\n&nbsp;Off the end of a wharf<BR>\n&nbsp;She once pushed a dwarf<BR>\nWhose truncation reduced her to fidgets.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A bather whose clothing was strewed<BR>\nBy breezes that left her quite nude,<BR>\n&nbsp;Saw a man come along<BR>\n&nbsp;And, unless I am wrong,<BR>\nYou expected this line to be lewd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A cautious young fellow named Lodge,<BR>\nHad seatbelts installed in his Dodge.<BR>\n&nbsp;With his date all strapped in<BR>\n&nbsp;He committed a sin<BR>\nWithout even leaving the garage.<BR>\n&nbsp;-- \"A Boy and His Dog\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Spain<BR>\nWho was fucked by a monk in a drain.<BR>\n&nbsp;They did it again<BR>\n&nbsp;And again and again,<BR>\nAnd again and again and again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Spain<BR>\nWho took down her pants on a train.<BR>\n&nbsp;There was a young porter<BR>\n&nbsp;Saw more than he orter,<BR>\nAnd asked her to do it again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A maestro directing in Rome<BR>\nHad a quaint way of driving it home.<BR>\n&nbsp;Whoever he climbed<BR>\n&nbsp;Had to keep her tail timed<BR>\nTo the beat of his old metronome.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady whose cunt<BR>\nCould accomodate a small punt.<BR>\n&nbsp;Her mother said, \"Annie,<BR>\n&nbsp;It matches your fanny,<BR>\nWhich never was that of a runt.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Dundee<BR>\nWho buggered an ape in a tree.<BR>\n&nbsp;The results were quite horrid:<BR>\n&nbsp;All ass and no forehead,<BR>\nThree balls and a purple goatee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from East Lizes<BR>\nWhose balls were of two different sizes<BR>\n&nbsp;One was so small<BR>\n&nbsp;It was no ball at all<BR>\nThe other was large and won prizes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A do-it-yourselfer named Alice,<BR>\nUsed a dynamite stick for a phallus.<BR>\n&nbsp;She blew her vagina<BR>\n&nbsp;To South Carolina,<BR>\nAnd her tits landed somewhere in Dallas.<BR>\n&nbsp;A cute friend of hers, Fanny Hill,<BR>\nUsed two dynamite sticks for a dil.<BR>\n&nbsp;They found her vagina,<BR>\n&nbsp;In South Carolina,<BR>\nAnd part of her ass in Brazil.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A busy young lady named Gloria<BR>\nWas had by Sir Gerald du Maurier<BR>\n&nbsp;And then by six men,<BR>\n&nbsp;Sir Gerald again,<BR>\nAnd the band at the Waldorf-Astoria.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A fellow whose surname was Hunt<BR>\nTrained his cock to perform a slick stunt:<BR>\n&nbsp;This versatile spout<BR>\n&nbsp;Could be turned inside out,<BR>\nLike a glove, and be used as a cunt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A fair-haired young damsel named Grace<BR>\nThought it very, very foolish to place<BR>\n&nbsp;Her hand on your cock<BR>\n&nbsp;When it turned hard as rock,<BR>\nFor fear it would explode in your face.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady from Kalamazoo<BR>\nOnce found she had nothing to do,<BR>\n&nbsp;So she sat on the stairs<BR>\n&nbsp;And she counted her hairs:<BR>\n4,302.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lass at the foot of her class<BR>\nAsked a brainier chick how to pass.<BR>\n&nbsp;She replied, \"With no fuss<BR>\n&nbsp;You can get a B-plus,<BR>\nBy letting the prof pat your ass.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A joker who haunts Monticello<BR>\nIs really a terrible fellow.<BR>\n&nbsp;In the midst of caresses<BR>\n&nbsp;He fills ladies dresses<BR>\nWith garter snakes, ice cubes, and jello.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lovely young maid from St. Jude<BR>\nOnce rode through the streets in the nude.<BR>\n&nbsp;The police cried, \"Whatam--<BR>\n&nbsp;Agnificent bottom\"<BR>\nAnd slapped it as hard as they could.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A dreary young bank clerk named Fennis<BR>\nWished to foster an aura of menace.<BR>\n&nbsp;To make people afraid<BR>\n&nbsp;He wore gloves of grey suede<BR>\nAnd white footgear intended for tennis.<BR>\n&nbsp;-- Edward Gorey, \"Amphigorey\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A girl of uncertain nativity<BR>\nHad an ass of extreme sensitivity<BR>\n&nbsp;While she sat on the lap<BR>\n&nbsp;Of a German or Jap,<BR>\nShe could sense Fifth Column activity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lonely young lad of Eton<BR>\nUsed always to sleep with the heat on,<BR>\n&nbsp;Till he ran into a lass<BR>\n&nbsp;Who showed him her ass --<BR>\nNow they sleep with only a sheet on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A highway patrol buff named Claire,<BR>\nOnce screwed half a troop on a dare,<BR>\n&nbsp;And her parts grew so hot,<BR>\n&nbsp;There was steam on her twat,<BR>\nSo they nicknamed her Smokey the Bare!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A green-thumbed young farmer from Leeds<BR>\nOnce swallowed a package of seeds.<BR>\n&nbsp;In a month, his ass<BR>\n&nbsp;Was covered with grass<BR>\nAnd his balls were grown over with weeds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A despairing old landlord named Fyfe,<BR>\nWith a frigid and quarrelsome wife,<BR>\n&nbsp;Let his third-story front,<BR>\n&nbsp;To a willing young cunt,<BR>\nWho supplied him a new lease on life!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A dentist, young doctor Malone,<BR>\nGot a charming girl patient alone,<BR>\n&nbsp;And, in his depravity,<BR>\n&nbsp;Filled the wrong cavity.<BR>\nGod, how his practice has grown.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A deep-throated virgin named Netty<BR>\nWas sucking a cock on the jetty.<BR>\n&nbsp;She said, \"It tastes nice,<BR>\n&nbsp;Much better than rice,<BR>\nThough not quite as good as spaghetti.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A delighted, incredulous bride<BR>\nRemarked to her groom at her side :<BR>\n&nbsp;\"I never could quite<BR>\n&nbsp;Believe till tonight<BR>\nOur anatomies would coincide.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A pious old woman named Tweak<BR>\nHad taught her vagina to speak.<BR>\n&nbsp;It was frequently liable<BR>\n&nbsp;To quote from the Bible,<BR>\nBut when fucking -- not even a squeak!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A pretty young boy known as Kevin<BR>\nWas raped in a pasture by seven<BR>\n&nbsp;Lascivious beasts<BR>\n&nbsp;(Oh, those Anglican priests)<BR>\nAnd such is the Kingdom of Heaven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A physical fellow named Fisk<BR>\nCould screw at a rate very brisk.<BR>\n&nbsp;So fast was his action<BR>\n&nbsp;The Fitzgerald contraction<BR>\nWould shrink up his rod to a disk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A slick talking pirate named Bruce<BR>\nTo steal code, had a plan to seduce<BR>\n&nbsp;An Apple II+.<BR>\n&nbsp;Now Bruce wears a truss<BR>\nAnd was jailed for computer abuse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A newlywed couple from Goshen<BR>\nSpent their honeymoon sailing the ocean.<BR>\n&nbsp;In twenty-eight days<BR>\n&nbsp;They got laid eighty ways --<BR>\nImagine such fucking devotion!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A computer, to print out a fact,<BR>\nWill divide, multiply, and subtract.<BR>\n&nbsp;But this output can be<BR>\n&nbsp;No more than debris,<BR>\nIf the input was short of exact.<BR>\n&nbsp;-- Gigo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','According to experts, the oyster<BR>\nIn its shell - a crustacean cloister -<BR>\n&nbsp;May frequently be<BR>\n&nbsp;Either he or a she<BR>\nOr both, if it should be its choice ter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An amazon giantess named Dunne<BR>\nLet a midget screw her for fun.<BR>\n&nbsp;But the poor little runt<BR>\n&nbsp;Was engulfed in her cunt<BR>\nAnd re-born as the twin of his son.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a Duchess of Bruges<BR>\nWhose cunt was incredibly huge.<BR>\n&nbsp;Said the king to this dame<BR>\n&nbsp;As he thunderously came:<BR>\n\"Mon Dieu!  Apres moi, le deluge!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady removing her scanties,<BR>\nHeard them crackle electrical chanties.<BR>\n&nbsp;Said her beau, \"Have no fear,<BR>\n&nbsp;For the reason is clear:<BR>\nYou simply have amps in your panties.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A newly-wed man of Peru<BR>\nFound himself in a terrible stew:<BR>\n&nbsp;His wife was in bed<BR>\n&nbsp;Much deader than dead,<BR>\nAnd so he had no one to screw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady from Old Little Rock<BR>\nIn fidelity took little stock,<BR>\n&nbsp;And deserted her man<BR>\n&nbsp;In the streets of Japan<BR>\nFor a boy with a prehensile cock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A gift was delivered to Laura<BR>\nFrom a cousin who lived in Gomorrah;<BR>\n&nbsp;Wrapped in tissue and crepe,<BR>\n&nbsp;It was peeled, like a grape,<BR>\nAnd emitted a pale, greenish aura.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A gentleman, otherwise meek,<BR>\nDetested with passion the leek;<BR>\n&nbsp;When offered one out<BR>\n&nbsp;He dealt such a clout<BR>\nTo the maid, she was down for a week.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A habit obscene and unsavory,<BR>\nHolds a CS professor in slavery.<BR>\n&nbsp;With maniacal howls,<BR>\n&nbsp;He deflowers young owls,<BR>\nThat he keeps in an underground aviary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A graduate student named Zac<BR>\nWas said to be great in the sack.<BR>\n&nbsp;An inch of his boner <BR>\n&nbsp;Put girls in a coma<BR>\nAnd two gave them epileptic attacks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lad of the brainier kind<BR>\nHad erogenous zones in his mind.<BR>\n&nbsp;He got his sensations,<BR>\n&nbsp;By solving equations,<BR>\n(Of course, in the end, he went blind.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A german composer named Bruckner<BR>\nRemarked to a lady while fuckener :<BR>\n&nbsp;\"Less lento, my dear,<BR>\n&nbsp;With your cute little rear;<BR>\nI like a hot presto when muckener!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A habit depraved and unsavory<BR>\nHeld the bishop of Bingham in slavery<BR>\n&nbsp;Midst screeches and howls<BR>\n&nbsp;He deflowered young owls<BR>\nWhich he kept in an underground aviary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A handsome young rodent named Gratian<BR>\nAs a lifeguard became a sensation.<BR>\n&nbsp;All the lady mice waved<BR>\n&nbsp;And screamed to be saved<BR>\nBy his mouse-to-mouse resuscitation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A beautiful belle of Del Norte<BR>\nIs reckoned disdainful and haughrty<BR>\n&nbsp;Because during the day<BR>\n&nbsp;She says: \"Boys, keep away!\"<BR>\nBut she fucks in the gloaming like forty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A happy old hooker named Grace<BR>\nOnce sponsored a cunt-lapping race.<BR>\n&nbsp;It was hard for beginners<BR>\n&nbsp;To tell who were winners :<BR>\nThere were cunt hairs all over the place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A gay young prince from Morocco<BR>\nMade love in a manner rococco.<BR>\n&nbsp;He painted his penis<BR>\n&nbsp;To resemble a venus<BR>\nAnd flavored his semen with cocoa.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A frustrated lady named Alice<BR>\nUsed a dynamite stick for a phallus.<BR>\n&nbsp;They found her vagina<BR>\n&nbsp;In North Carolina<BR>\nAnd bits of her tits were in Dallas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A Frenchman who lived in Alsace<BR>\nHad sex with a virgin named Grace.<BR>\n&nbsp;When he popped her cherry,<BR>\n&nbsp;She made things hairy<BR>\nBy bleeding all over his face.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A girl of the Enterprise crew<BR>\nRefused every offer to screw.<BR>\n&nbsp;But a Vulcan named Spock<BR>\n&nbsp;Crawled under her smock,<BR>\nAnd now she is eating for two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A hearty young fellow named Yost<BR>\nOnce had an affair with a ghost.<BR>\n&nbsp;At the height of the spasm<BR>\n&nbsp;The poor ectoplasm<BR>\nCried, \"Goodie, I feel it... almost.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A habit obscene and bizarre,<BR>\nHas taken a-hold of papa.<BR>\n&nbsp;He brings home young camels<BR>\n&nbsp;And other odd mammals,<BR>\nAnd gives them a go at mama.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A highly aesthetic young Jew<BR>\nHad eyes of a heavenly blue;<BR>\n&nbsp;The end of his dillie<BR>\n&nbsp;Was shaped like a lilly,<BR>\nAnd his balls were too utterly two!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lacklustre lady of Brougham<BR>\nWeaveth all night at her loom.<BR>\n&nbsp;Anon she doth blench<BR>\n&nbsp;When her lord and his wench<BR>\nPull a chain in the neighbouring room.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A huge-organed female in Dallas,<BR>\nNamed Alice, who yearned for a phallus,<BR>\n&nbsp;Was virgo intacto,<BR>\n&nbsp;Because, ipso facto,<BR>\nNo phallus in Dallas fit Alice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A horny young fellow named Reg,<BR>\nWas jerking off under a hedge.<BR>\n&nbsp;The gardener drew near<BR>\n&nbsp;With a huge pruning shear,<BR>\nAnd trimmed off the edge of his wedge.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A playful young chemist named Byrd<BR>\nHad an urge that could not be deferred.<BR>\n&nbsp;So to irritate Knox<BR>\n&nbsp;He shit in his sox,<BR>\nAnd plastered the walls with his turd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A nurse motivated by spite<BR>\nTied her infantine charge to a kite;<BR>\n&nbsp;She launched it with ease<BR>\n&nbsp;On the afternoon breeze,<BR>\nAnd watched till it flew out of sight.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A remarkable race are the Persians;<BR>\nThey have such peculiar diversions.<BR>\n&nbsp;They screw the whole day<BR>\n&nbsp;In the regular way,<BR>\nAnd save up the nights for perversions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A certain young person of Ghent,<BR>\nUncertain if lady or gent,<BR>\n&nbsp;Shows his organs at large<BR>\n&nbsp;For a small handling charge<BR>\nTo assist him in paying the rent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A maiden who travelled in France<BR>\nOnce got on a train, just by chance.<BR>\n&nbsp;The engineer fucked her,<BR>\n&nbsp;The conductor sucked her,<BR>\nAnd the fireman came in his pants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A maiden who wrote of big cities<BR>\nSome songs full of love, fun and pities,<BR>\n&nbsp;Sold her stuff at the shop<BR>\n&nbsp;Of a musical wop<BR>\nWho played with her soft little titties.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lusty young maid from Seattle<BR>\nGot pleasure by sleeping with cattle;<BR>\n&nbsp;Till she found a bull<BR>\n&nbsp;Who filled her so full<BR>\nIt made both her ovaries rattle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lovely young diver named Nancy,<BR>\nWore a bikini bottom quite chancy,<BR>\n&nbsp;The fish of Bonaire,<BR>\n&nbsp;Watched her Derriere,<BR>\nAnd the sea fans all tickled her fancy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lusty young woodsman of Maine<BR>\nFor years with no woman had lain,<BR>\n&nbsp;But he found sublimation<BR>\n&nbsp;At a high elevation<BR>\nIn the crotch of a pine -- God, the pain!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A maiden who lived in Virginny<BR>\nHad a cunt that could bark, neigh and whinny.<BR>\n&nbsp;The horsey set rushed her,<BR>\n&nbsp;But success finally crushed her<BR>\nFor her tone soon became harsh and tinny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A linguist thought it a farce<BR>\nThat memory space was so sparse.<BR>\n&nbsp;One day they increased it.<BR>\n&nbsp;Said he as he seized it:<BR>\n\"At last! Enough core for the parse\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A hidebound young virgin named Carrie<BR>\nWould say, when the fellows got hairy :<BR>\n&nbsp;\"Keep your prick in your pants<BR>\n&nbsp;Till the end of this dance--\"<BR>\nWhich is why Carrie still has her cherry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady with features cherubic<BR>\nWas famed for her area pubic.<BR>\n&nbsp;When they asked her its size<BR>\n&nbsp;She replied in surprise,<BR>\n\"Are you speaking of square feet, or cubic?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady stockholder quite hetera<BR>\nDecided her fortune to bettera:<BR>\n&nbsp;On the floor, quite unclad,<BR>\n&nbsp;She successively had<BR>\nMerrill Lynch, Pierce, Fenner, et cetera...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A geneticist living in Delft<BR>\nScientifically played with himself,<BR>\n&nbsp;And when he was done<BR>\n&nbsp;He labled it: son,<BR>\nAnd filed him away on a shelf.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young man by a girl was desired<BR>\nTo give her the thrills she required,<BR>\n&nbsp;But he died of old age<BR>\n&nbsp;Ere his cock could assuage<BR>\nThe volcanic desire it inspired.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A responsive young girl from the East<BR>\nIn bed was an able artiste.<BR>\n&nbsp;She had learned two positions<BR>\n&nbsp;From family physicians,<BR>\nAnd ten more from the old parish priest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A dolly in Dallas named Alice,<BR>\nWhose overworked sex is all callous,<BR>\n&nbsp;Wore the foreskin away<BR>\n&nbsp;On uncircumcised Ray,<BR>\nThrough exuberance, tightness, and malice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A silly young man from Hong Kong<BR>\nHad hands that were skinny and long.<BR>\n&nbsp;He ate rice with his fingers--<BR>\n&nbsp;The taste of it lingers,<BR>\nBut now all his fingers are gone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A scream from the crypt of St. Giles<BR>\nResounded for miles upon miles.<BR>\n&nbsp;Said the friar, \"Good gracious,<BR>\n&nbsp;The brother Ignatious<BR>\nForgeteth the abbot hath piles.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A space shuttle pilot named Ventry,<BR>\nMade love to a lovely girl sentry.<BR>\n&nbsp;She started to pout,<BR>\n&nbsp;Because it fell out,<BR>\nBut the mission was saved by re-entry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A savvy young hooker named Gail<BR>\nGot busted and lodged in the jail.<BR>\n&nbsp;But the jailer got hot,<BR>\n&nbsp;To be lodged in her twat,<BR>\nAnd so Gail made the bail with her tail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young maiden from France was no prude,<BR>\nShe decided to dive in the nude,<BR>\n&nbsp;But her buddy, behind,<BR>\n&nbsp;Went out of his mind,<BR>\nWhen he noticed where she was tatooed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A madam who ran a bordello<BR>\nPut come in her pineapple jello,<BR>\n&nbsp;For the rich, sexy taste<BR>\n&nbsp;And not wanting to waste<BR>\nThat greasy kid stuff from a fellow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A rapturous young fellatrix<BR>\nOne day was at work on five pricks.<BR>\n&nbsp;With an unholy cry<BR>\n&nbsp;She whipped out her glass eye:<BR>\n\"Tell the boys I can now take on six.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A progressive professor named Winners<BR>\nHeld classes each evening for sinners.<BR>\n&nbsp;They were graded and spaced<BR>\n&nbsp;So the vile and debased<BR>\nWould not be held back by beginners.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A reckless young lady of France<BR>\nHad no qualms about taking a chance,<BR>\n&nbsp;But she thought it was crude<BR>\n&nbsp;To get screwed in the nude,<BR>\nSo she always went home with damp pants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A princess who lived near a bog<BR>\nMet a prince in the form of a frog.<BR>\n&nbsp;Now she and her prince<BR>\n&nbsp;Are the parents of quints,<BR>\nFour boys and one fine polliwog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A remarkable race are the Persians;<BR>\nThey have such peculiar diversions.<BR>\n&nbsp;They make love the whole day<BR>\n&nbsp;In the usual way<BR>\nAnd save up the nights for perversions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A pathetic old maid of Bordeaux<BR>\nFell in love with a dashing young beau.<BR>\n&nbsp;To arrest his regard<BR>\n&nbsp;She would squat in his yard<BR>\nAnd longingly pee in the sneaux.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A pansy who lived in Khartoum<BR>\nTook a lesbian up to his room.<BR>\n&nbsp;They argued all night<BR>\n&nbsp;Over who had the right<BR>\nTo do what, with which, and to whom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A passionate red-haired girl<BR>\nWhen you kissed her, her senses would whirl,<BR>\n&nbsp;And her twat would get wet,<BR>\n&nbsp;And would wiggle and fret,<BR>\nAnd her cunt-lips would curl and unfurl.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A milkmaid there was, with a stutter,<BR>\nWho was lonely and wanted a futter.<BR>\n&nbsp;She had nowhere to turn,<BR>\n&nbsp;So she diddled a churn,<BR>\nAnd managed to come with the butter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A wide-bottomed girl named Trasket<BR>\nHad a hole as big as a basket.<BR>\n&nbsp;A spot, as a bride,<BR>\n&nbsp;In it now, you could hide,<BR>\nAnd include with your luggage your mascot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A whimsical fellow named Bloch<BR>\nCould beat the base drum with his cock.<BR>\n&nbsp;With a special erection<BR>\n&nbsp;He could play a selection<BR>\nFrom Johann Sebastian Bach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young bride and groom of Australia<BR>\nRemarked as they joined genitalia :<BR>\n&nbsp;\"Though the system seems odd,<BR>\n&nbsp;We are thankful that God<BR>\nDeveloped the genus Mammalia.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A wicked stone cutter named Cary<BR>\nDrilled holes in divine statuary.<BR>\n&nbsp;With eyes full of malice<BR>\n&nbsp;He pulled out his phallus,<BR>\nAnd buggered a stone Virgin Mary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A worried young man from Stamboul<BR>\nFounds lots of red spots on his tool.<BR>\n&nbsp;Said the doctor, a cynic,<BR>\n&nbsp;\"Get out of my clinic;<BR>\nJust wipe off the lipstick, you fool!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A very odd pair are the Pitts:<BR>\nHis balls are as large as her tits,<BR>\n&nbsp;Her tits are as large<BR>\n&nbsp;As an invasion barge--<BR>\nNeither knows how the other cohabits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A tutor who tooted a flute<BR>\nTried to tutor two tutors to toot<BR>\n&nbsp;Said the two to the tutor:<BR>\n&nbsp;\"Is it harder to toot or<BR>\nTo tutor two tutors to toot\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A water pipe suited Miss Hunt;<BR>\nShe used it for many a bunt.<BR>\n&nbsp;But the unlucky wench<BR>\n&nbsp;Got it caught in her trench ---<BR>\nIt took twenty-two men and a big Stillson wrench,<BR>\nTo get the thing out of her cunt. ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A tidy young lady of Streator<BR>\nDearly loved to nibble a peter.<BR>\n&nbsp;She always would say,<BR>\n&nbsp;\"I prefer it this way.<BR>\nI think it is very much neater.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A tired young trollop of Nome<BR>\nWas worn out from her toes to her dome.<BR>\n&nbsp;Eight miners came screwing,<BR>\n&nbsp;But she said, \"Nothing doing;<BR>\nOne of you has to go home!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A weary old lecher named Blott<BR>\nTook a luscious young blond to his yacht.<BR>\n&nbsp;Too lazy to rape her,<BR>\n&nbsp;He made darts out of paper,<BR>\nWhich he leisurely tossed at her twat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A trapper named Francois Lefebrve<BR>\nOnce captured and buggered a beabrve.<BR>\n&nbsp;The result of this fuck<BR>\n&nbsp;Was a three titted duck,<BR>\nA canoe, and an Irish retriebrve.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A worried young man from Stamboul<BR>\nDiscovered red spots on his tool.<BR>\n&nbsp;Said the doctor, a cynic,<BR>\n&nbsp;\"Get out of my clinic<BR>\nJust wipe off the lipstick, you fool.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lady born under a curse<BR>\nUsed to drive forth each day in a hearse;<BR>\n&nbsp;From the back she would wail<BR>\n&nbsp;Through a thickness of veil:<BR>\n\"Things do not get better, but worse.\"<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A team playing baseball in Dallas<BR>\nCalled the umpire blind out of malice.<BR>\n&nbsp;While this worthy had fits<BR>\n&nbsp;The team made eight hits<BR>\nAnd a girl in the bleachers named Alice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A talented fuckstress, Miss Chisholm,<BR>\nWas renowned for her fine paroxysm.<BR>\n&nbsp;While the man detumesced<BR>\n&nbsp;She still spent on with zest,<BR>\nHer rapture sheer anachronism.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A talented girl from Detroit<BR>\nCould fuck you in ways quite adroit.<BR>\n&nbsp;She could squeeze her vagina<BR>\n&nbsp;To a pin-point or finer<BR>\nOr open it out like a quoit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A teenage protester named Lil<BR>\nCried, \"Those watergate spies make me ill<BR>\n&nbsp;First they bugged our martinis,<BR>\n&nbsp;Our bras and bikinis,<BR>\nAnd now they are bugging the pill.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A lecherous barkeep named Dale,<BR>\nAfter fucking his favorite female,<BR>\n&nbsp;Mixed Drambuie and scotch<BR>\n&nbsp;With the cream in her crotch<BR>\nFor a lustier, Rusty-er Nail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A starship commander named Kirk<BR>\nEmerged from his cabin berserk.<BR>\n&nbsp;He grabbed a girl yeoman<BR>\n&nbsp;Beneath the abdomen,<BR>\nAnd gave her a physical jerk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A studious professor named Nestor<BR>\nBet a whore all his books that he could best her.<BR>\n&nbsp;But she drained out his balls<BR>\n&nbsp;And skipped up the walls,<BR>\nBeseeching poor Nestor to rest her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A CS student named Lin<BR>\nHad a prick the size of a pin<BR>\n&nbsp;It was no good for girls<BR>\n&nbsp;But just great for squirrels<BR>\nWho squealed with delight with it in.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An ARPAnaut name of Corvette<BR>\nHad a fetish involving the net.<BR>\n&nbsp;As he fondled his IMP<BR>\n&nbsp;His cock went from limp<BR>\nTo as hard as concrete which has set.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An ambitious lady named Harriet<BR>\nOnce dreamed she was raped in a chariot<BR>\n&nbsp;By seventeen sailors<BR>\n&nbsp;A monk and three tailors,<BR>\nMohammed and Judas Iscariot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A potter who lived in Bombay<BR>\nOnce fashioned a cunt out of clay;<BR>\n&nbsp;But the heat of his prick<BR>\n&nbsp;Kilned the damn thing to brick<BR>\nAnd chafed all his foreskin away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young wife in the outskirts of Reims<BR>\nPreferred frigging to going to mass.<BR>\n&nbsp;Said her husband, \"Take Jacques,<BR>\n&nbsp;Or any young cock,<BR>\nFor I cannot live up to your ass.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young violinist from Rio<BR>\nWas seducing a woman named Cleo.<BR>\n&nbsp;As she took down her panties<BR>\n&nbsp;She said, \"No andantes;<BR>\nI want this allegro con brio!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','All the female apes ran from King Kong<BR>\nFor his dong was unspeakably long.<BR>\n&nbsp;But a friendly giraffe<BR>\n&nbsp;Quaffed his yard and a half,<BR>\nAnd ecstatically burst into song.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young man of Llanfairpwllgwyngyll<BR>\nWhile bent over plucking a dingle<BR>\n&nbsp;Had the whole of Eisteddfod<BR>\n&nbsp;Taking turns at his pod<BR>\nWhile they sang some impossible jingle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An artist who lived in Australia<BR>\nOnce painted his ass like a Dahlia.<BR>\n&nbsp;The drawing was fine,<BR>\n&nbsp;The colour - divine,<BR>\nThe scent - ah, that was a failia.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An orgasmic young sex star named Sue<BR>\nWas a hit as she writhed to a screw.<BR>\n&nbsp;Her climatic fame spread<BR>\n&nbsp;With an ad blitz that said:<BR>\nComing soon at a theater near you!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young polo-player of Berkeley<BR>\nMade love to his sweetheart beserkly.<BR>\n&nbsp;In the midst of each chukker<BR>\n&nbsp;He would break off and fuck her<BR>\nHorizontally, laterally and verkeley.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young man grew increasingly peaky<BR>\nIn a house where the hinges were squeaky,<BR>\n&nbsp;The ferns curled up brown,<BR>\n&nbsp;The ceilings flaked down,<BR>\nAnd all of the faucets were leaky.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An agreeable girl named Miss Doves<BR>\nLikes to jack off the young men she loves.<BR>\n&nbsp;She will use her bare fist<BR>\n&nbsp;If the fellows insist<BR>\nBut she really prefers to wear gloves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young lady sat by the sea,<BR>\nJust as proper as proper could be.<BR>\n&nbsp;A young fellow goosed her,<BR>\n&nbsp;And roughly seduced her,<BR>\nSo she thanked him and went home to tea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young lad named Lester McGraw<BR>\nCaught a stranger on top of his Maw.<BR>\n&nbsp;As he watched him stick her<BR>\n&nbsp;He said, with a snicker,<BR>\n\"You do it much faster than Paw.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young lady who lived by the Usk<BR>\nSubsisted each day on a rusk;<BR>\n&nbsp;She ate the first bite<BR>\n&nbsp;Before it was light,<BR>\nAnd the last crumb sometime after dusk.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A young fellow discovered through Freud<BR>\nThat although of penis devoid,<BR>\n&nbsp;He could practice coitus<BR>\n&nbsp;By eating a foetus,<BR>\nAnd his parents were quite overjoyed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An old couple just at Shrovetide<BR>\nWere having a piece -- when he died.<BR>\n&nbsp;The wife for a week<BR>\n&nbsp;Sat tight on his peak,<BR>\nAnd bounced up and down as she cried.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A big-bosomed Bunny named Gression<BR>\nSold cigars at a key-club concession.<BR>\n&nbsp;When she swiveled about<BR>\n&nbsp;Even strong men cried out,<BR>\nFor her costume did not keep her flesh in.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An impotent Scot named MacDougall<BR>\nHad to husband his sperm and be frugal.<BR>\n&nbsp;He was gathering semen<BR>\n&nbsp;To gender a he-man,<BR>\nBy screwing his wife through a bugle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A broken-down harlot named Tupps<BR>\nWas heard to confess in her cups:<BR>\n&nbsp;\"The height of my folly<BR>\n&nbsp;Was fucking a collie --<BR>\nBut I got a nice price for the pups.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An ingenious young man in South Bend<BR>\nMade a synthetic ass for a friend,<BR>\n&nbsp;But the friend shortly found<BR>\n&nbsp;Its construction unsound,<BR>\nIt was simply a bother -- no end.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An old maid who had a pet ape<BR>\nLived in fear of perpetual rape.<BR>\n&nbsp;His red, hairy phallus<BR>\n&nbsp;So filled her with malice<BR>\nThat she sealed up her snatch with Scotch tape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An innocent maiden named Herridge<BR>\nWas cruelly tricked ito marriage;<BR>\n&nbsp;When she later found out<BR>\n&nbsp;What her spouse was about,<BR>\nShe threw herself under a carriage.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A cabin boy on an old clipper<BR>\nGrew steadily flipper and flipper.<BR>\n&nbsp;He plugged up his ass<BR>\n&nbsp;With fragments of glass<BR>\nAnd thus circumcised his old skipper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An exotic young lady named Suki<BR>\nOnce danced in a troupe of kabuki<BR>\n&nbsp;When asked for a fuck<BR>\n&nbsp;She said, \"Solly, no luck--<BR>\nSee here: looky looky, no nuki \"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A clerical student named Pryne<BR>\nThrough pain sought to reach the divine:<BR>\n&nbsp;He wore a hair shirt,<BR>\n&nbsp;Quite often ate dirt,<BR>\nAnd bathed every Friday in brine.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An incautious young woman named Venn<BR>\nWas seen with the wrong sort of men;<BR>\n&nbsp;She vanished one day,<BR>\n&nbsp;But the following May<BR>\nHer legs were retrieved from a fen.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An eager young hacker named Gus<BR>\nOnce buggered a VAX Unibus.<BR>\n&nbsp;The hardware went bad,<BR>\n&nbsp;But not the young lad<BR>\n(Except for the toupee and truss).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A corpulent maiden named Kroll<BR>\nHad a notion exceedingly droll:<BR>\n&nbsp;At a masquerade ball,<BR>\n&nbsp;Dressed in nothing at all,<BR>\nShe backed in as a Parker House roll.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An anonymous woman we knew<BR>\nWas dozing one day in her pew;<BR>\n&nbsp;When the preacher yelled \"Sin!\"<BR>\n&nbsp;She said, \"Count me in<BR>\nAs soon as the service is through.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An old man at the Folies Bergere<BR>\nHad a jock, a most wondrous affair:<BR>\n&nbsp;It snipped off a twat-curl<BR>\n&nbsp;From each new chorus girl,<BR>\nAnd he had a wig made of the hair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Each Friday his engines abort,<BR>\nBut Scotty is never caught short.<BR>\n&nbsp;He fills his machines<BR>\n&nbsp;With space-navy beans,<BR>\nAnd farts the ship back into port.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','From the bathing machine came a din<BR>\nAs of jollification within;<BR>\n&nbsp;It was heard far and wide,<BR>\n&nbsp;And the incoming tide<BR>\nHad a definite flavour of gin.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','At the Villa Nemetia the sleepers<BR>\nAre disturbed by a phantom in weepers;<BR>\n&nbsp;It beats all night long<BR>\n&nbsp;A dirge on a gong<BR>\nAs it staggers about in the creepers.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Coblenz<BR>\nWhose ballocks were simply immense:<BR>\n&nbsp;It took forty-four draymen,<BR>\n&nbsp;A priest and three laymen<BR>\nTo carry them thither and thence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','As tourists inspected the apse<BR>\nAn ominous series of raps<BR>\n&nbsp;Came from under the altar,<BR>\n&nbsp;Which caused some to falter<BR>\nAnd others to shriek and collapse.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Asked a supplicant priest of the pontiff,<BR>\n\"Do I sin if I do what I want, if<BR>\n&nbsp;I screw a young nun<BR>\n&nbsp;In the eastertide sun?\"<BR>\nHis holiness murmured, \"Gut yontiff.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Wheeling<BR>\nWho professed to lack sexual feeling.<BR>\n&nbsp;But a cynic named Boris<BR>\n&nbsp;Just touched her clitoris,<BR>\nAnd she had to be scraped off the ceiling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','At a dance, a girl from Connecticut<BR>\nShowed an absolute absence of etiquette<BR>\n&nbsp;Letting all comers press<BR>\n&nbsp;Through the skirt of her dress<BR>\nAnd wiping the mess with her petticoat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Though most of the crewmen are whites,<BR>\nUhura has full equal rights.<BR>\n&nbsp;Her crewmates, you see,<BR>\n&nbsp;Love De-mo-cra-cy,<BR>\nAnd the way that she fills out her tights.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Saskatchewan,<BR>\nWhose penis was truly gargantuan.<BR>\n&nbsp;It was good for large whores,<BR>\n&nbsp;And for small dinosaurs,<BR>\nAnd was rough enough to scratch a match upon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a young man from Yuma<BR>\nWho attempted sex with a puma<BR>\n&nbsp;He gave up real quick<BR>\n&nbsp;Minus nose, toes, and prick<BR>\nIn obvious pain and ill huma.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fencer named Fisk,<BR>\nWhose speed was incredibly brisk.<BR>\n&nbsp;So fast was his action,<BR>\n&nbsp;The Fitzgerald contraction,<BR>\nForeshortended his foil to a disk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','As the breeches-buoy swing towards the rocks,<BR>\nIts occupant cried, \"Save my socks!<BR>\n&nbsp;I could not bear the loss,<BR>\n&nbsp;For with scarlet silk floss<BR>\nMy mama has embroidered their clocks.\"<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Racine,<BR>\nWho invented a screwing machine.<BR>\n&nbsp;Both concave and convex,<BR>\n&nbsp;It could please either sex,<BR>\nBut, oh, what a bastard to clean!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Dee<BR>\nWho went down to the river to pee.<BR>\n&nbsp;A man in a punt<BR>\n&nbsp;Put his hand on her cunt,<BR>\nAnd God! how I wish it were me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fag of Khartoom<BR>\nWho spent the night in a Lesbians room.<BR>\n&nbsp;They argued all night,<BR>\n&nbsp;Over who had the right,<BR>\nTo do what, and with which, and to whom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a couple named Kelley,<BR>\nWho lived their life belly to belly.<BR>\n&nbsp;Because in their haste<BR>\n&nbsp;They used library paste,<BR>\nInstead of petroleum jelly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An arrogant wench from Salt Lake<BR>\nLiked to tease all the boys on the make.<BR>\n&nbsp;She was finally the prize<BR>\n&nbsp;Of a man twice her size<BR>\nAnd all she recalls is the ache.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a chick named Longet,<BR>\nWho went out to Aspen to play.<BR>\n&nbsp;Along came a Spyder,<BR>\n&nbsp;Who sat down beside her<BR>\nAnd she blew the poor bastard away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a dentist named Stone<BR>\nWho saw all his patients alone.<BR>\n&nbsp;In a fit of depravity<BR>\n&nbsp;He filled the wrong cavity,<BR>\nAnd my, how his practice has grown!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fellow named Sweeney<BR>\nWho spilled gin all over his weenie.<BR>\n&nbsp;Not being uncouth,<BR>\n&nbsp;He added vermouth<BR>\nAnd slipped his amour a martini.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','The limerick is furtive and mean;<BR>\nYou must keep her in close quarantine,<BR>\n&nbsp;Or she sneaks to the slums<BR>\n&nbsp;And promptly becomes<BR>\nDisorderly, drunk, and obscene.<BR>\n&nbsp;-- Morris Bishop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','The limerick, a verse form iniquitous,<BR>\nHas nonetheless been ubiquitous.<BR>\n&nbsp;Once Congress in session,<BR>\n&nbsp;Declared its suppression,<BR>\nBut people got around that by writing the last line with no rhyme or meter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An octagenerian Jew<BR>\nTo his wife remained steadfastly true.<BR>\n&nbsp;This was not from compunction,<BR>\n&nbsp;But due to dysfunction<BR>\nOf his spermatic glands -- nuts to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There a young man from the Coast<BR>\nWho had an affair with a ghost.<BR>\n&nbsp;At the height of orgasm<BR>\n&nbsp;Said the pallid phantasm,<BR>\n\"I think I can feel it -- almost!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young physicist named Fisk<BR>\nWhose lovemaking was rather brisk.<BR>\n&nbsp;So quick was his action,<BR>\n&nbsp;The Lorentz Contraction<BR>\nShortened his rod to a disc !!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','\"Fucked by the finger of Fate!\"<BR>\nBewailed a young fellow named Tate.<BR>\n&nbsp;\"Since dating Miss Baugh,<BR>\n&nbsp;My whole tongue has been raw--<BR>\nIt must have been something I ate.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Kildare<BR>\nWho was fucking a girl on the stair.<BR>\n&nbsp;The bannister broke,<BR>\n&nbsp;But he doubled his stroke<BR>\nAnd finished her off in mid-air.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','The latest reports from Good Hope<BR>\nState that apes there have pricks thick as rope,<BR>\n&nbsp;And fuck high, wide, and free,<BR>\n&nbsp;From the top of one tree<BR>\nTo the top of the next -- what a scope!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Khartoum<BR>\nWho lured a poor girl to her doom.<BR>\n&nbsp;He not only fucked her,<BR>\n&nbsp;But buggered and sucked her--<BR>\nAnd left her to pay for the room.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','From deep in the crypt at St. Giles<BR>\nCame a bellow that echoed for miles.<BR>\n&nbsp;Said the rector, \"My gracious,<BR>\n&nbsp;Has Father Ignatius<BR>\nForgotten the Bishop has piles!?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A bad little girl in Madrid,<BR>\nA most reprehensible kid,<BR>\n&nbsp;Told her Tante Louise<BR>\n&nbsp;That her cunt smelled like cheese,<BR>\nAnd the worst of it was that it did!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a lady named Myrtle<BR>\nWho had an affair with a turtle.<BR>\n&nbsp;She had crabs, so they say,<BR>\n&nbsp;In a year and a day<BR>\nWhich proved that that turtle was fertile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a lifeguard named Lee<BR>\nWho rescued a girl from the sea<BR>\n&nbsp;She asked how to pay,<BR>\n&nbsp;And he said \"Try this way,<BR>\nGo down for the third time on me.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a lady from Exeter,<BR>\nSo pretty that men craned their necks at her.<BR>\n&nbsp;One was even so brave<BR>\n&nbsp;As to take out and wave<BR>\nThe distinguishing mark of his sex at her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a husky young Viking<BR>\nWhose sexual prowess was striking.<BR>\n&nbsp;Every time he got hot<BR>\n&nbsp;He would scour the twat<BR>\nOf some girl that might be to his liking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a handsome young seaman<BR>\nWho with ladies was really a demon.<BR>\n&nbsp;In peace or in war,<BR>\n&nbsp;At sea or on shore,<BR>\nHe could certainly dish out the semen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a horny old bitch<BR>\nWith a motorized self-frigger which<BR>\n&nbsp;She would use with delight<BR>\n&nbsp;All day long and all night -<BR>\nTwenty bucks: Abercrombie & Fitch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a horse named Lily<BR>\nWhose dingus was really a dilly.<BR>\n&nbsp;It was vaginoid duply,<BR>\n&nbsp;And labial quadruply --<BR>\nIn fact, he was really a filly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a maid from Mobile<BR>\nWhose cunt was made of blue steel.<BR>\n&nbsp;She only got thrills<BR>\n&nbsp;From pneumatic drills<BR>\nAnd an off-centered emery wheel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a girl so lovely,<BR>\nWho wanted to make love in the bubbly,<BR>\n&nbsp;She strapped on her tanks,<BR>\n&nbsp;And started her pranks,<BR>\nBut the lobsters all thought she was ugly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a golfer named Leer,<BR>\nWho got put in the clink for a year,<BR>\n&nbsp;For an action obscene,<BR>\n&nbsp;On the very first green.<BR>\nWhere the sign said \"Enter course here.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a girl named Priscilla<BR>\nWhose vagina was flavored vanilla.<BR>\n&nbsp;The taste was so fine<BR>\n&nbsp;Man and beast stood in line<BR>\n(Including a stud armadilla).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a girl named Louise<BR>\nWho cunt hair hung down to her knees<BR>\n&nbsp;The crabs in her twat<BR>\n&nbsp;Tied the hairs in a knot<BR>\nAnd constructed a flying trapeze');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a girl from Madras<BR>\nWho had such a beautiful ass -<BR>\n&nbsp;It was not round and pink<BR>\n&nbsp;(As you bastards think)<BR>\nBut had two ears, a tail, and ate grass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a girl from Cornell<BR>\nWhose teats were shaped like a bell.<BR>\n&nbsp;When you touched them they shrunk,<BR>\n&nbsp;Except when she was drunk,<BR>\nAnd then they got bigger than hell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Calcutta<BR>\nWho used to beat off in the gutta<BR>\n&nbsp;The heat of the sun<BR>\n&nbsp;Affected his gun<BR>\nAnd turned all his cream into butta!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a floozie named Annie<BR>\nWhose prices were cosy--but cannie:<BR>\n&nbsp;A buck for a fuck,<BR>\n&nbsp;Fifty cents for a suck,<BR>\nAnd a dime for a feel of her fanny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a gangster named Brown<BR>\n- the sneakiest bastard in town.<BR>\n&nbsp;He was caught by G-men<BR>\n&nbsp;Shooting his semen<BR>\nWhere the cops would slip and fall down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','While travelling in farthest Tibet,<BR>\nLord Irongate found cause to regret<BR>\n&nbsp;The buttered-up tea,<BR>\n&nbsp;A pain in his knee,<BR>\nAnd the frivolous tourists he met.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','While spending the winter at Pau<BR>\nLady Pamela forgot to say \"No.\"<BR>\n&nbsp;So the head-porter made her<BR>\n&nbsp;And the second-cook laid her;<BR>\nThe waiters were all hanging low.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','We dedicate this to the cunt,<BR>\nThe kind the broad-minded guys hunt :<BR>\n&nbsp;All hail to the twat,<BR>\n&nbsp;Willing, thrilling, and hot,<BR>\nThat wears peckers down, limp and blunt!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','While his duchess lay practically dead,<BR>\nThe Duke of Daguerrodargue said:<BR>\n&nbsp;\"Can it be this is all?<BR>\n&nbsp;How puny! How small!<BR>\nHave destroyed this disgrace to my bed.\"<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Visas erat: huic geminarum<BR>\nDispar modus testicularum:<BR>\n&nbsp;Minor haec nihili,<BR>\n&nbsp;Palma triplici,<BR>\nJam fecerat altera clarum.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a gay young Parisian<BR>\nWho screwed an appendix incision,<BR>\n&nbsp;And the girl of his choice<BR>\n&nbsp;Could hardly rejoice<BR>\nAt the horrible lack of precision.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a young man from France<BR>\nWho waited ten years for his chance;<BR>\nThen he muffed it...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fellow named Howard,<BR>\nWhose tool it was nuclear-powered,<BR>\n&nbsp;While grabbing some ass,<BR>\n&nbsp;He reached critical mass,<BR>\nBut think of the girl he deflowered!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fellow named Potts<BR>\nWho was prone to having the trots<BR>\n&nbsp;But his humble abode<BR>\n&nbsp;Was without a commode<BR>\nSo his carpet was covered with spots.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a fairy named Avers<BR>\nWho encircled his cock with lifesavers.<BR>\n&nbsp;Though buggers all claimed<BR>\n&nbsp;That their asses were maimed,<BR>\nSixy-niners all cheered the new flavors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a woman from Arden<BR>\nWho sucked off a man in a garden.<BR>\n&nbsp;He said, \"My dear Flo,<BR>\n&nbsp;Where does all that stuff go?\"<BR>\nAnd she said, \"[Swallow hard] I beg pardon?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a Usenetter named Mark,<BR>\nWhose gender was kept in the dark.<BR>\n&nbsp;He/she/it said with a nod,<BR>\n&nbsp;\"My ancestors were odd!\"<BR>\nDid Noah need two for the ark?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a whore from Regina<BR>\nWho had a stupendous vagina.<BR>\n&nbsp;To save herself time,<BR>\n&nbsp;She had six at a time,<BR>\nAnd another one working behind her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a young fellow named Blaine,<BR>\nAnd he screwed some disgusting old jane.<BR>\n&nbsp;She was ugly and smelly,<BR>\n&nbsp;With an awful pot-belly,<BR>\nBut... well, they were caught in the rain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a sailor named Gasted,<BR>\nA swell guy, as long as he lasted,<BR>\n&nbsp;He could jerk himself off<BR>\n&nbsp;In a basket, aloft,<BR>\nOr a breeches-buoy swung from the masthead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a son-of-a-bitch,<BR>\nNeither clever, nor handsome, nor rich,<BR>\n&nbsp;Yet the girls he would dazzle,<BR>\n&nbsp;And fuck to a frazzle,<BR>\nAnd then ditch them, the son-of-a-bitch!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a spaceman named Spock<BR>\nWho had a huge Vulcanized cock.<BR>\n&nbsp;A girl from Missouri<BR>\n&nbsp;Whose name was Uhura<BR>\nJust fainted away from the shock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a queen of Bulgaria<BR>\nWhose bush had grown hairier and hairier,<BR>\n&nbsp;Till a prince from Peru<BR>\n&nbsp;Who came up for a screw<BR>\nHad to hunt for her cunt with a terrier.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a member of Mensa<BR>\nWho was a most excellent fencer.<BR>\n&nbsp;The sword that he used<BR>\n&nbsp;Was his -- (line is refused,<BR>\nAnd has now been removed by the censor).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man named McGruder,<BR>\nWho canoed with a girl in Bermuder.<BR>\n&nbsp;But the girl thought it crude,<BR>\n&nbsp;To be wooed in the nude,<BR>\nSo McGru took an oar and subduder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man named Lodge,<BR>\nwho had seatbelts installed in his Dodge.<BR>\n&nbsp;When his date was strapped in,<BR>\n&nbsp;He committed a sin,<BR>\nwithout ever leaving the garage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man named McSweeny<BR>\nWho spilled some raw gin on his weeny.<BR>\n&nbsp;Just to be couth,<BR>\n&nbsp;He added vermouth,<BR>\nAnd slipped his girlfriend a martini.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Dunoon,<BR>\nWho always ate soup with a fork.<BR>\n&nbsp;He said \"When I eat<BR>\n&nbsp;Either fish, foul or flesh,<BR>\nI otherwise finish too quick.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Nantucket<BR>\nWhose dick was so long he could suck it.<BR>\n&nbsp;He said with a grin<BR>\n&nbsp;As he wiped off his chin,<BR>\n\"If my ear was a cunt, I could fuck it!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Madras,<BR>\nWhose balls were made out of brass.<BR>\n&nbsp;When they clanged together,<BR>\n&nbsp;They played \"Stormy Weather\",<BR>\nAnd lightning shot out of his ass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Sandem<BR>\nWho was making his girl on a tandem.<BR>\n&nbsp;At the peak of the make<BR>\n&nbsp;She jammed on the brake<BR>\nAnd scattered his semen at random.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a newspaper vendor,<BR>\nA person of dubious gender.<BR>\n&nbsp;He would charge one-and-two<BR>\n&nbsp;For permission to view<BR>\nHis remarkable double pudenda.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a man from Nantee<BR>\nWho buggered an ape in a tree.<BR>\n&nbsp;The results were most horrid<BR>\n&nbsp;All ass and no forehead<BR>\nThree balls and a purple goatee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a jolly old bloke<BR>\nWho picked up a girl for a poke.<BR>\n&nbsp;He took down her pants,<BR>\n&nbsp;Fucked her into a trance,<BR>\nAnd then shit into her shoe for a joke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a lawyer named Rex<BR>\nWith minuscule organs of sex.<BR>\n&nbsp;Arraigned for exposure,<BR>\n&nbsp;He maintained with composure,<BR>\n\"De minimis non curat lex.\"<BR>\n&nbsp;[Trans: the law does not concern itself with small things.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young belle of old Natchez<BR>\nWhose garments were always in patchez.<BR>\n&nbsp;When comment arose<BR>\n&nbsp;On the state of her clothes<BR>\nShe, drawled, \"When ah itchez, ah scratchez.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a gay parson of Tooting<BR>\nWhose roe he was frequently shooting,<BR>\n&nbsp;Till he married a lass<BR>\n&nbsp;With a face like my arse,<BR>\nAnd a cunt you could put a top-boot in.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a man from Mich.<BR>\nWho used to wish and wich.<BR>\n&nbsp;That spring would come<BR>\n&nbsp;So he could bum<BR>\nAround and go out fich.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a strong man of Drumrig<BR>\nWho one day did seven times frig.<BR>\n&nbsp;He buggered three sailors,<BR>\n&nbsp;Four dogs and two tailors,<BR>\nAnd ended by fucking a pig.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young curate whose brain<BR>\nWas deranged from the use of cocaine;<BR>\n&nbsp;He lured a small child<BR>\n&nbsp;To a copse dark and wild,<BR>\nWhere he beat it to death with his cane.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a bluestocking in Florence<BR>\nWrote anti-sex pamphlets in torrents,<BR>\n&nbsp;Till a Spanish grandee,<BR>\n&nbsp;Got her off with his knee,<BR>\nAnd she burned all her works with abhorrence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a miner named Dave,<BR>\nWho kept a dead whore in his cave.<BR>\n&nbsp;She was ugly as shit,<BR>\n&nbsp;And missing one tit,<BR>\nBut think of the money he saves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once were two brothers named Luntz<BR>\nWho buggered each other at once.<BR>\n&nbsp;When asked to account<BR>\n&nbsp;For this intricate mount,<BR>\nThey said, \"Ass-holes are tighter than cunts.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was an Arpanet freak,<BR>\nWho better response-time did seek.<BR>\n&nbsp;He searched coast to coast,<BR>\n&nbsp;For a reliable host,<BR>\nWhose logger took less than a week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Rhyll<BR>\nIn an omnibus was taken ill,<BR>\n&nbsp;So she called the conductor,<BR>\n&nbsp;Who got in and fucked her,<BR>\nWhich did more good than a pill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young damsel named Baker<BR>\nWho was poked in a pew by a Quaker.<BR>\n&nbsp;He yelled, \"My God!  what<BR>\n&nbsp;Do you call this -- a twat?<BR>\nWhy, the entrance is more than an acre!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a young man named Lancelot<BR>\nWhom the townsfolk would look at askance a lot<BR>\n&nbsp;For when he should pass<BR>\n&nbsp;A desirable lass<BR>\nThe front of his pants would advance a lot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a fat man from Rangoon<BR>\nWhose prick was much like a ballon.<BR>\n&nbsp;He tried hard to ride her<BR>\n&nbsp;And when finally inside her<BR>\nShe thought she was pregnant too soon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from East Lynn<BR>\nWhose mother ( to save her from sin )<BR>\n&nbsp;Had filled up her crack<BR>\n&nbsp;With hard-setting shellac,<BR>\nBut the boys picked it out with a pin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There once was a young man named Gene,<BR>\nWho invented a screwing machine.<BR>\n&nbsp;Concave and convex,<BR>\n&nbsp;It served either sex,<BR>\nAnd it played with itself inbetween.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Gene<BR>\nWho first picked his asshole quite clean.<BR>\n&nbsp;He next picked his toes,<BR>\n&nbsp;And lastly his nose,<BR>\nAnd he never did wash in between.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Case<BR>\nWho entered a cunt-lapping race.<BR>\n&nbsp;He licked his way clean<BR>\n&nbsp;Through Number thirteen,<BR>\nBut then slipped and got pissed in the face.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Fyfe<BR>\nWhose marriage was ruined for life,<BR>\n&nbsp;For he had an aversion<BR>\n&nbsp;To every perversion,<BR>\nAnd only liked fucking his wife.<BR>\n&nbsp;Well, one year the poor woman struck,<BR>\nAnd she wept, and she cursed at her luck,<BR>\n&nbsp;And said, \"Where have you gotten us<BR>\n&nbsp;With your goddamn monotonous<BR>\nFuck after fuck after fuck?<BR>\n&nbsp;\"I once knew a harlot named Lou --<BR>\nAnd a versatile girl she was, too.<BR>\n&nbsp;After ten years of whoredom<BR>\n&nbsp;She perished of boredom<BR>\nWhen she married a jackass like you!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Feeney<BR>\nWhose girl was a terrible meany.<BR>\n&nbsp;The hatch of her snatch<BR>\n&nbsp;Had a catch that would latch<BR>\n- She could only be screwed by Houdini.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Cribbs<BR>\nWhose cock was so big it had ribs.<BR>\n&nbsp;They were inches apart,<BR>\n&nbsp;And to suck it took art,<BR>\nWhile to fuck it took forty-two trips.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Brewer<BR>\nWhose girl made her home in a sewer.<BR>\n&nbsp;Thus he, the poor soul,<BR>\n&nbsp;Could get into her hole,<BR>\nAnd still not be able to screw her!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named dick<BR>\nWho had a magnificent prick.<BR>\n&nbsp;It was shaped like a prism<BR>\n&nbsp;And shot so much gism<BR>\nIt made every cocksucker sick.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Hall,<BR>\nWore a newspaper dress to a ball.<BR>\n&nbsp;The dress caught on fire<BR>\n&nbsp;And burned her entire<BR>\nFront page, sporting section, and all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Blaine,<BR>\nAnd he screwed some disgusting old jane.<BR>\n&nbsp;She was ugly and smelly<BR>\n&nbsp;With an awful pot-belly,<BR>\nBut... well, they were caught in the rain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Bill,<BR>\nWho took an atomic pill,<BR>\n&nbsp;His navel corroded,<BR>\n&nbsp;His asshole exploded,<BR>\nAnd they found his nuts in Brazil.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow from Leeds<BR>\nWho swallowed a package of seeds.<BR>\n&nbsp;Great tufts of grass<BR>\n&nbsp;Sprouted out of his ass<BR>\nAnd his balls were all covered with weeds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Babbitt<BR>\nWho could screw nine times like a rabbit,<BR>\n&nbsp;But a girl from Johore<BR>\n&nbsp;Could do it twice more,<BR>\nWhich was just enough extra to crab it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Ades<BR>\nWhose favorite fruit was young maids.<BR>\n&nbsp;But sheep, nigger boys, whores,<BR>\n&nbsp;And the knot holes in doors<BR>\nWere by no means exempt from his raids.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Bliss<BR>\nWhose sex life was strangely amiss,<BR>\n&nbsp;For even with Venus<BR>\n&nbsp;His recalcitrant penis<BR>\nWould never do better than t<BR>\n&nbsp;h<BR>\n&nbsp;i<BR>\n&nbsp;s<BR>\n&nbsp;.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow from Kent<BR>\nWhose cock was so long that it bent<BR>\n&nbsp;To save himself trouble<BR>\n&nbsp;He put it in double<BR>\nAnd instead of coming, he went.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow from Cal.,<BR>\nIn bed with a passionate gal.<BR>\n&nbsp;He leapt from the bed,<BR>\n&nbsp;To the toilet he sped;<BR>\nSaid the gal, \"What about me, old pal?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Ealing<BR>\nAnd her lover before her was kneeling.<BR>\n&nbsp;Said she, \"Dearest Jim,<BR>\n&nbsp;Take your hands off my quim;<BR>\nI much prefer fucking to feeling.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Cape Town<BR>\nWho usually fucked with a clown.<BR>\n&nbsp;He taught her the trick<BR>\n&nbsp;Of sucking his prick,<BR>\nAnd when it went up -- she went down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Rose<BR>\nWith erogenous zones in her toes.<BR>\n&nbsp;She remained onanistic<BR>\n&nbsp;Till a foot-fetishistic<BR>\nYoung man became one of her beaux.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a pianist named Liszt<BR>\nWho played with one hand while he pissed,<BR>\n&nbsp;But as he grew older<BR>\n&nbsp;His technique grew bolder,<BR>\nAnd in concert jacked off with his fist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Schneider<BR>\nWho often kept trysts with a spider.<BR>\n&nbsp;She found a strange bliss,<BR>\n&nbsp;In the hiss of her piss,<BR>\nAs it strained through the cobwebs inside her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a poor parson from Goring,<BR>\nWho made a small hole in his flooring,<BR>\n&nbsp;Fur-lined it all round,<BR>\n&nbsp;Then laid on the ground,<BR>\nAnd declared it was cheaper than whoring.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Sweeney,<BR>\nWhose girl was a terrible meanie,<BR>\n&nbsp;The hatch of her snatch,<BR>\n&nbsp;Had a catch that would latch,<BR>\nShe could only be screwed by Houdini.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Coxsaxie<BR>\nWhose skirt was more mini than maxi.<BR>\n&nbsp;She was fucked at the show<BR>\n&nbsp;In the twenty-third row,<BR>\nAnd once more going home in the taxi.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Darjeeling<BR>\nWho could dance with such exquisite feeling<BR>\n&nbsp;There was never a sound<BR>\n&nbsp;For miles around<BR>\nSave of fly-buttons hitting the ceiling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Skinner<BR>\nWho took a young lady to dinner<BR>\n&nbsp;At a quarter to nine,<BR>\n&nbsp;They sat down to dine,<BR>\nAt twenty to ten it was in her.<BR>\nThe dinner, not Skinner -- Skinner was in her before dinner.<BR>\n&nbsp;There was a young fellow named Tupper<BR>\nWho took a young lady to supper.<BR>\n&nbsp;At a quarter to nine,<BR>\n&nbsp;They sat down to dine,<BR>\nAnd at twenty to ten it was up her.<BR>\nNot the supper -- not Tupper -- It was some son-of-a-bitch named Skinner!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Ransom<BR>\nWho was rogered three times in a hansom.<BR>\n&nbsp;When she cried out for more<BR>\n&nbsp;A voice from the floor<BR>\nReplied, \"My name is Simpson, not Samson.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named May<BR>\nWho strolled in a park by the way,<BR>\n&nbsp;And she met a youg man<BR>\n&nbsp;Who fucked her and ran --<BR>\nNow she goes to the park every day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Newcastle<BR>\nWhose charms were declared universal.<BR>\n&nbsp;While one man in front<BR>\n&nbsp;Wired into her cunt,<BR>\nAnother was engaged at her arsehole.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Price<BR>\nWho dabbled in all sorts of vice.<BR>\n&nbsp;He had virgins and boys<BR>\n&nbsp;And mechanical toys,<BR>\nAnd on Mondays... he meddled with mice!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Dee<BR>\nWhose hymen was split into three.<BR>\n&nbsp;And when she was diddled<BR>\n&nbsp;The middle string fiddled :<BR>\n\"Nearer My God To Thee.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Kimble<BR>\nWhose prick was exceedingly nimble,<BR>\n&nbsp;But fragile and slender,<BR>\n&nbsp;And dainty and tender,<BR>\nSo he kept it encased in a thimble.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Meek<BR>\nWho invented a lingual technique.<BR>\n&nbsp;It drove women frantic,<BR>\n&nbsp;And made them romantic,<BR>\nAnd wore all the hair off his cheek.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a lewd fellow named Duff<BR>\nWho loved to dive deep in the muff.<BR>\n&nbsp;With his head in a whirl<BR>\n&nbsp;He said, \"Spread it, Pearl;<BR>\nI cunt get enough of the stuff!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Nelly<BR>\nWhose tits would jiggle like jelly.<BR>\n&nbsp;They could tickle her twat<BR>\n&nbsp;Or be tied in a knot,<BR>\nAnd could even swat flies on her belly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow named Morgan<BR>\nWho possessed an unusual organ:<BR>\n&nbsp;The end of his dong,<BR>\n&nbsp;Which was nine inches long,<BR>\nWas tipped with the head of a gorgon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Mandel<BR>\nWho caused quite a neighborhood scandal<BR>\n&nbsp;By coming out bare<BR>\n&nbsp;On the main village square<BR>\nAnd frigging herself with a candle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Twiss<BR>\nWho said she thought fucking a bliss,<BR>\n&nbsp;For it tickled her bum<BR>\n&nbsp;And caused her to come<BR>\n.siht ekil gniyl ylbatrofmoc elihW');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young laundress named Wrangle<BR>\nWhose tits tilted up at an angle.<BR>\n&nbsp;\"They may tickle my chin,\"<BR>\n&nbsp;She said with a grin,<BR>\n\"But at least they keep out of the mangle.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man named Laplace<BR>\nWhose balls were made out of spun glass.<BR>\n&nbsp;When they banged together<BR>\n&nbsp;They played \"Stormy Weather\"<BR>\nAnd lightning shot out of his ass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Kent,<BR>\nWho admitted she knew what it meant<BR>\n&nbsp;When men asked her to dine,<BR>\n&nbsp;And plied her with wine,<BR>\nShe knew, oh she knew -- but she went!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Lee<BR>\nWho scrambled up into a tree,<BR>\n&nbsp;When she got there<BR>\n&nbsp;Her arsehole was bare,<BR>\nAnd so was her C U N T.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young gaucho named Bruno<BR>\nWho said, \"There is one thing I do know,<BR>\n&nbsp;Women are fine<BR>\n&nbsp;And children devine,<BR>\nBut the llama is numero uno.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young gaucho named Bruno<BR>\nWho said, \"Screwing is one thing I do know.<BR>\n&nbsp;A woman is fine,<BR>\n&nbsp;And a sheep is divine,<BR>\nBut a llama is Numero Uno.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Gloucester<BR>\nWhose friends they thought they had lost her<BR>\n&nbsp;Till they found on the grass<BR>\n&nbsp;The marks of her arse,<BR>\nAnd the knees of the man who had crossed her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Gaza<BR>\nWho shaved her cunt bare with a razor.<BR>\n&nbsp;The crabs, in a lump,<BR>\n&nbsp;Made tracks to her rump--<BR>\nThis passing parade did amaze her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Fez<BR>\nWho was known to the public as \"Jez.\"<BR>\n&nbsp;Jezebel was her name,<BR>\n&nbsp;Sucking cocks was the game<BR>\nShe excelled at (so everyone says).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow whose dong<BR>\nWas prodigiously massive and long.<BR>\n&nbsp;On each side of his whang<BR>\n&nbsp;Two testes did hang<BR>\nThat attracted a curious throng.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Decatur<BR>\nWho was raped by an alligator.<BR>\n&nbsp;But no one quite knew<BR>\n&nbsp;How she relished that screw,<BR>\nFor after he screwed her, he ate her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow of Warwick<BR>\nWho had reason for feeling euphoric,<BR>\n&nbsp;For he could by election<BR>\n&nbsp;Have triune erection:<BR>\nIonic, Corinthian, and Doric.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Carmia<BR>\nWhose housekeeping ways would alarm ya.<BR>\n&nbsp;At every cold snap<BR>\n&nbsp;She would climb in your lab,<BR>\nSo her little base burner could warm ya.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Dover<BR>\nWhose passion was such that it drove her<BR>\n&nbsp;To cry, when you came,<BR>\n&nbsp;\"Oh dear!  What a shame!<BR>\nWell, now we shall have to start over.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow of Mayence<BR>\nWho fucked his own arse in defiance<BR>\n&nbsp;Not only of custom<BR>\n&nbsp;And morals, dad-bust him,<BR>\nBut of most of the known laws of science.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow of Kent<BR>\nWhose prick was so long that it bent,<BR>\n&nbsp;So to save himself trouble<BR>\n&nbsp;He put it in double,<BR>\nAnd instead of coming he went.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow of Perth<BR>\nWhose balls were the finest on earth.<BR>\n&nbsp;They grew to such size<BR>\n&nbsp;That one won a prize,<BR>\nAnd goodness knows what they were worth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady of Bicester<BR>\nWho was nicer by far than her sister:<BR>\n&nbsp;The sister would giggle<BR>\n&nbsp;And wiggle and jiggle,<BR>\nBut this one would come if you kissed her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Wylde<BR>\nWho kept herself quite undefiled<BR>\n&nbsp;By thinking of Jesus;<BR>\n&nbsp;Contagious diseases;<BR>\nAnd the bother of having a child.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young fellow of Strensall<BR>\nWhose prick was as sharp as a pencil.<BR>\n&nbsp;On the night of his wedding<BR>\n&nbsp;It went through the bedding,<BR>\nAnd shattered the chamber utensil.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady named Rose<BR>\nWho fainted whenever she chose;<BR>\n&nbsp;She did so one day<BR>\n&nbsp;While playing croquet,<BR>\nBut was quickly revived with a hose.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Dundee,<BR>\nFrom her fanny there grew a plum tree.<BR>\n&nbsp;No one ate the nice fruit,<BR>\n&nbsp;To tell you the truth,<BR>\nBecause they knew it came from her tooty-toot-toot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man named Knute<BR>\nWho had warts all over his root.<BR>\n&nbsp;He put acid on these<BR>\n&nbsp;And now when he pees,<BR>\nHe fingers the thing like a flute.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Bombay<BR>\nWho fashioned a cunt out of clay<BR>\n&nbsp;But the heat of his prick<BR>\n&nbsp;Turned it into a brick<BR>\nAnd rubbed all his foreskin away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Jodhpur<BR>\nWho found he could easily cure<BR>\n&nbsp;His dread diabetes<BR>\n&nbsp;By eating a foetus<BR>\nServed up in a sauce of manure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Biloxi<BR>\nWhose bowels responded to Moxie.<BR>\n&nbsp;Drinking glass after glass,<BR>\n&nbsp;He would tune up his ass,<BR>\nTill he played like the band at the Roxy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Bel-Aire<BR>\nWho was screwing his girl on the stair.<BR>\n&nbsp;But the banister broke<BR>\n&nbsp;So he doubled his stroke<BR>\nAnd finished her off in mid-air.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lass from Surat.<BR>\nThe cheeks of her ass were so fat<BR>\n&nbsp;That they had to be parted<BR>\n&nbsp;Whenever she farted,<BR>\nAnd also whenever she shat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from the coast<BR>\nWho, just when she needed it most,<BR>\n&nbsp;Lost her Kotex and bled<BR>\n&nbsp;All over the bed,<BR>\nAnd the head and the beard of her host.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl named Ann Heuser<BR>\nWho swore that no man could surprise her.<BR>\n&nbsp;But Pabst took a chance,<BR>\n&nbsp;Found a Schlitz in her pants,<BR>\nAnd now she is sadder Budweiser.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from St. Paul<BR>\nWho went to a newspaper ball.<BR>\n&nbsp;Her dress caught on fire<BR>\n&nbsp;And burnt her entire<BR>\nFront page and sport section and all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady in Reno,<BR>\nWho lost all her dough playing Keno.<BR>\n&nbsp;But she lay on her back,<BR>\n&nbsp;And opened her crack,<BR>\nSo now she owns the Casino!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from New York<BR>\nWho plugged up her cunt with a cork.<BR>\n&nbsp;A woodpecker or two<BR>\n&nbsp;Made the grade it is true,<BR>\nBut it totally baffled the stork.<BR>\n&nbsp;Till along came a man who presented<BR>\nA tool that was strangely indented.<BR>\n&nbsp;With a dizzying twirl<BR>\n&nbsp;He punctured that girl,<BR>\nAnd thus was the cork-screw invented.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Seattle,<BR>\nWhose hobby was sucking off cattle.<BR>\n&nbsp;But a bull from the South<BR>\n&nbsp;Shot a wad in her mouth<BR>\nThat made both her ovaries rattle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from New York<BR>\nWho plugged up her quim with a cork<BR>\n&nbsp;A woodpecker or two<BR>\n&nbsp;Made the grade, it is true,<BR>\nBut it totally baffled the stork.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Gibraltar<BR>\nWho was raped as she knelt at the altar.<BR>\n&nbsp;It really seems odd<BR>\n&nbsp;That a virtuous God<BR>\nShould answer her prayers and assault her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young Jew of Far Rockaway<BR>\nWhose screams could be heard for a block away.<BR>\n&nbsp;Perceiving his error,<BR>\n&nbsp;The Rabbi in terror<BR>\nCried, \"God! I have cut his whole cock away!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','To his bride said a numskull named Clarence :<BR>\n\"I trust you will show some forbearance.<BR>\n&nbsp;My sexual habits<BR>\n&nbsp;I picked up from rabbits,<BR>\nAnd occasionally watching my parents.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Medina<BR>\nWho could completely control her vagina.<BR>\n&nbsp;She could twist it around<BR>\n&nbsp;Like the cunts that are found<BR>\nIn Japan, Manchukuo and China.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl in Berlin<BR>\nWho was fucked by an elderly Finn.<BR>\n&nbsp;Though he diddled his best,<BR>\n&nbsp;And fucked her with zest,<BR>\nShe kept asking, \"Hey, Pop, is it in?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of LLewellyn<BR>\nWhose breasts were as big as a melon.<BR>\n&nbsp;They were big it is true,<BR>\n&nbsp;But her cunt was big too,<BR>\nLike a bifocal, full-color, aerial view<BR>\nOf Cape Horn and the Straits of Magellan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man named Zerubbabub<BR>\nWho belonged to the Block, Fuck & Bugger Club<BR>\n&nbsp;But the pride of his life<BR>\n&nbsp;Were the tits of his wife --<BR>\nOne real, and one India-rubber bub.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man, name of Fred,<BR>\nWho spent every Thursday in bed;<BR>\n&nbsp;He lay with his feet<BR>\n&nbsp;Outside of the sheet,<BR>\nAnd the pillows on top of his head.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man, name of Saul,<BR>\nWho was able to bounce either ball,<BR>\n&nbsp;He could stretch them and snap them,<BR>\n&nbsp;And juggle and clap them,<BR>\nWhich earned him the plaudits of all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man in Havana,<BR>\nBanged his girl on a player-piana.<BR>\n&nbsp;At the height of their fever<BR>\n&nbsp;Her ass hit the lever<BR>\nAnd: yes, he has no banana.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man in Norway,<BR>\nTried to jerk himself off in a sleigh,<BR>\n&nbsp;But the air was so frigid<BR>\n&nbsp;It froze his cock rigid,<BR>\nAnd all he could come was frappe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Nantucket<BR>\nWhose cock was so long he could suck it.<BR>\n&nbsp;But he looked in the glass,<BR>\n&nbsp;And saw his own ass,<BR>\nAnd broke his neck trying to fuck it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from New Haven<BR>\nWho had an affair with a raven.<BR>\n&nbsp;He said with a grin<BR>\n&nbsp;As he wiped off his chin,<BR>\n\"Nevermore!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Stamboul<BR>\nWho boasted so torrid a tool<BR>\n&nbsp;That each female crater<BR>\n&nbsp;Explored by this satyr<BR>\nSeemed almost unpleasantly cool.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man named Crockett<BR>\nWhose balls got caught in a socket.<BR>\n&nbsp;His wife was a bitch<BR>\n&nbsp;So she threw the switch,<BR>\nAnd Crockett went off like a rocket.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Batonger<BR>\nwho diddled herself with a conger,<BR>\n&nbsp;When asked how it feels<BR>\n&nbsp;To be pleasured by eels<BR>\nShe said, \"Just like a man, only longer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Aberystwyth<BR>\nWho screwed every man that she kissed with.<BR>\n&nbsp;She tickled the balls<BR>\n&nbsp;Of the men in the halls,<BR>\nAnd pulled on the prongs that they pissed with.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Tibet-<BR>\nAnd this is the strangest one yet-<BR>\n&nbsp;Whose tool was so long,<BR>\n&nbsp;So pointed and strong,<BR>\nHe could bugger six Greeks \"en brochette\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Racine<BR>\nWho invented a fucking machine.<BR>\n&nbsp;Concave or convex,<BR>\n&nbsp;It served either sex,<BR>\nBut oh what a bitch to keep clean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Siam<BR>\nWho said, \"I go in with a wham,<BR>\n&nbsp;But I soon lose my starch<BR>\n&nbsp;Like the mad month of March,<BR>\nAnd the lion comes out like a lamb.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl from Samoa<BR>\nWho pledged that no man would know her.<BR>\n&nbsp;One young fellow tried,<BR>\n&nbsp;But she wriggled aside,<BR>\nAnd he spilled all his spermatozoa.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl named Heather<BR>\nWhose twitcher was made out of leather.<BR>\n&nbsp;She made a queer noise,<BR>\n&nbsp;Which attracted the boys,<BR>\nBy flapping the edges together.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl named McCall<BR>\nWhose cunt was exceedingly small,<BR>\n&nbsp;But the size of her anus<BR>\n&nbsp;Was something quite heinous --<BR>\nIt could hold seven pricks and one ball.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Peru,<BR>\nWho took a long trip by canoe.<BR>\n&nbsp;While staring at Venus,<BR>\n&nbsp;And rubbing his penis,<BR>\nHe wound up with a handful of goo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man from Salinas<BR>\nWho had an extremely long penis:<BR>\n&nbsp;Believe it or not,<BR>\n&nbsp;When he lay on his cot<BR>\nIt reached from Marin to Martinez.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Detroit<BR>\nWho at fucking was very adroit:<BR>\n&nbsp;She could squeeze her vagina<BR>\n&nbsp;To a pin-point, or finer,<BR>\nOr open it out like a quoit.<BR>\n&nbsp;And she had a friend named Durand<BR>\nWhose cock could contract or expand.<BR>\n&nbsp;He could diddle a midge<BR>\n&nbsp;Or the arch of a bridge --<BR>\nTheir performance together was grand!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young harlot named Schwartz	<BR>\nWhose cock-pit was studded with warts,<BR>\n&nbsp;And they tickled so nice<BR>\n&nbsp;She drew a high price<BR>\nFrom the studs at the summer resorts.<BR>\n&nbsp;Her pimp, a young fellow named Biddle,<BR>\nWas seldom hard up for a diddle,<BR>\n&nbsp;For according to rumor<BR>\n&nbsp;His tool had a tumor<BR>\nAnd a fine row of warts down the middle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Tibet<BR>\n-- And this is the strangest one yet --<BR>\n&nbsp;His prick was so long,<BR>\n&nbsp;And so pointed and strong,<BR>\nHe could bugger six sheep en brochette.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young student from Yale<BR>\nWho was getting his first piece of tail.<BR>\n&nbsp;He shoved in his pole,<BR>\n&nbsp;But in the wrong hole,<BR>\nAnd a voice from beneath yelled: \"No sale!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Lake Placid<BR>\nWhose prick was lethargic and flaccid.<BR>\n&nbsp;When he wanted to sport<BR>\n&nbsp;He would have to resort<BR>\nTo injections of sulphuric acid.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Greenwich<BR>\nWhose balls were all covered with spinach.<BR>\n&nbsp;So long was his tool<BR>\n&nbsp;That it wound round a spool,<BR>\nAnd he let it out inach by inach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Des Moines<BR>\nWhose cunt could be fitted with coins,<BR>\n&nbsp;Till a guy from Hoboken<BR>\n&nbsp;Went and dropped in a token,<BR>\nAnd now she rides free on the ferry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Natal<BR>\nAnd Sue was the name of his gal.<BR>\n&nbsp;One day, north of Aden,<BR>\n&nbsp;He got his hard rod in,<BR>\nAnd came clear up Suez Canal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Devizes,<BR>\nWhose balls were of different sizes.<BR>\n&nbsp;One was so small,<BR>\n&nbsp;It was nothing at all;<BR>\nThe other took numerous prizes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Dumfries<BR>\nWho said to his girl, \"If you please,<BR>\n&nbsp;It would give me great bliss<BR>\n&nbsp;If, while playing with this,<BR>\nYou would pay some attention to these!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Devizes<BR>\nWhose balls were of different sizes.<BR>\n&nbsp;His tool when at ease,<BR>\n&nbsp;Hung down to his knees,<BR>\nOh, what must it be when it rises!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Calcutta,<BR>\nWho tried to write \"cunt\" on a shutter.<BR>\n&nbsp;When he got to c-u,<BR>\n&nbsp;A pious Hindoo<BR>\nKnocked him ass-over-head in the gutter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Moline<BR>\nWhose fucking was sweet and obscene.<BR>\n&nbsp;She would work on a prick<BR>\n&nbsp;With every known trick,<BR>\nAnd finish by winking it clean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Belgrade<BR>\nWho slept with a girl in the trade.<BR>\n&nbsp;She said to him, \"Jack,<BR>\n&nbsp;Try the hole in the back;<BR>\nThe front one is badly decayed.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Arras<BR>\nWho stretched himself out on the grass,<BR>\n&nbsp;And with no little trouble,<BR>\n&nbsp;He bent himself double,<BR>\nAnd stuck his prick well up his ass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man named Zerubbabel<BR>\nWho had only one real, and one rubber ball.<BR>\n&nbsp;When they asked if his pleasure<BR>\n&nbsp;Was only half measure,<BR>\nHe replied, \"That is highly improbable.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of East Lynne<BR>\nWhose mother, to save her from sin,<BR>\n&nbsp;Had filled up her crack,<BR>\n&nbsp;To the brim with shellac,<BR>\nBut the boys picked it out with a pin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Bengal<BR>\nWho swore he had only one ball,<BR>\n&nbsp;But two little bitches<BR>\n&nbsp;Unbuttoned his britches,<BR>\nAnd found he had no balls at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Mobile,<BR>\nWho hymen was made of chilled steel,<BR>\n&nbsp;To give her a thrill,<BR>\n&nbsp;Took a rotary drill,<BR>\nOr a number nine emery wheel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lad name of Ward<BR>\nWho strung himself up with a cord<BR>\n&nbsp;Said he, of his work<BR>\n&nbsp;(Ere the rope snapped with a jerk)<BR>\n\"I am leaving because I am bored.\"<BR>\n&nbsp;- E.A. Guest');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old fellow named Skinner<BR>\nWhose prick, his wife said, had grown thinner.<BR>\n&nbsp;But still, by and large,<BR>\n&nbsp;It would always discharge<BR>\nOnce he could just get it in her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young idler named Blood,<BR>\nMade a fortune performing at stud,<BR>\n&nbsp;With a fifteen-inch peter,<BR>\n&nbsp;A double-beat metre,<BR>\nAnd a load like the Biblical Flood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Drew<BR>\nWho ended her verse at line two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman of Cheadle,<BR>\nWho once gave the clap to a beadle.<BR>\n&nbsp;Said she, \"Does it itch?\"<BR>\n&nbsp;\"It does, you damned bitch,<BR>\nAnd it burns like hell-fire when I peedle.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young soldier from Munich<BR>\nWhose penis hung down past his tunic,<BR>\n&nbsp;And their chops girls would lick<BR>\n&nbsp;When they thought of his prick,<BR>\nBut alas! he was only a eunuch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young sportsman named Peel<BR>\nWho went for a trip on his wheel;<BR>\n&nbsp;He pedalled for days<BR>\n&nbsp;Through crepuscular haze,<BR>\nAnd returned feeling somewhat unreal.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young peasant named Gorse<BR>\nWho fell madly in love with his horse.<BR>\n&nbsp;Said his wife, \"You rapscallion,<BR>\n&nbsp;That horse is a stallion --<BR>\nThis constitutes grounds for divorce.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Toulouse<BR>\nWho had a deficient prepuce,<BR>\n&nbsp;But the foreskin he lacked<BR>\n&nbsp;He made up in his sac;<BR>\nThe result was, his balls were too loose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young squaw of Wohunt<BR>\nWho possessed a collapsible cunt.<BR>\n&nbsp;It had many odd uses,<BR>\n&nbsp;Produced no papooses,<BR>\nAnd fitted both giant and runt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young monk from Tibet<BR>\nAnd this is the damnedest one yet<BR>\n&nbsp;His cock was so long<BR>\n&nbsp;And incredibly strong<BR>\nThat he buggered six Greeks en brochette.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl who begat<BR>\nThree brats, by name Nat, Pat, and Tat.<BR>\n&nbsp;It was fun in the breeding,<BR>\n&nbsp;But hell in the feeding,<BR>\nWhen she found there was no tit for Tat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man with one foot<BR>\nWho had a very long root.<BR>\n&nbsp;If he used this peg<BR>\n&nbsp;As an extra leg<BR>\nIs a question exceedingly moot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young man of Missouri<BR>\nWho fucked with a terrible fury.<BR>\n&nbsp;Till hauled into court<BR>\n&nbsp;For his beastial sport,<BR>\nAnd condemned by a poorly-hung jury.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old fellow named Art<BR>\nWho awoke with a horrible start,<BR>\n&nbsp;For down by his rump<BR>\n&nbsp;Was a generous lump<BR>\nOf what should have been just a fart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady at sea<BR>\nWho complained that it hurt her to pee.<BR>\n&nbsp;Said the brawny old mate,<BR>\n&nbsp;\"That accounts for the state<BR>\nOf the cook and the captain and me.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old girl of Kilkenny<BR>\nWhose usual charge was a penny.<BR>\n&nbsp;For half of that sum<BR>\n&nbsp;You could finger her bum--<BR>\nA source of amusement to many.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Brussels<BR>\nWho was proud of her vaginal muscles.<BR>\n&nbsp;She could easily plex them<BR>\n&nbsp;And so interflex them<BR>\nAs to whistle love songs through her bustles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old Scot named McTavish<BR>\nWho attempted an anthropoid ravish.<BR>\n&nbsp;The object of rape<BR>\n&nbsp;Was the wrong sex of ape,<BR>\nAnd the anthropoid ravished McTavish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old count of Swoboda<BR>\nWho would not pay a whore what he owed her.<BR>\n&nbsp;So, with great savoir-faire,<BR>\n&nbsp;She stood on a chair<BR>\nAnd pissed in his whiskey-and-soda.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman whose stammer<BR>\nWas atrocious, and so was her grammar;<BR>\n&nbsp;But they were not improved<BR>\n&nbsp;When her husband was moved<BR>\nTo knock out her teeth with a hammer.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman, quite handsome,<BR>\nWho got stuck in a sleeping room transom.<BR>\n&nbsp;When she offered much gold<BR>\n&nbsp;For release, she was told<BR>\nThat the view was worth more than the ransom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman named Alice<BR>\nWho peed in a Catholic chalice.<BR>\n&nbsp;She said, \"I do this<BR>\n&nbsp;From a great need to piss,<BR>\nAnd not from sectarian malice.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An Edwardian father named Udgeon,<BR>\nWhose offspring provoked him to dudgeon,<BR>\n&nbsp;Used on Saturday nights<BR>\n&nbsp;To turn down the lights,<BR>\nAnd chase them around with a bludgeon.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A contortionist hailing from Lynch<BR>\nUsed to rent out his tool by the inch.<BR>\n&nbsp;A foot cost a quid --<BR>\n&nbsp;He could and he did<BR>\nStretch it to three in a pinch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An architect fellow named Yoric<BR>\nCould, when feeling euphoric,<BR>\n&nbsp;Display for selection<BR>\n&nbsp;Three kinds of erection-<BR>\nCorinthian, ionic, and doric.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An ardent young man named Magruder<BR>\nOnce wooed a girl nude in Bermuda.<BR>\n&nbsp;She thought it quite lewd<BR>\n&nbsp;To be wooed in the nude,<BR>\nBut magruder was shrewder, he screwed her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','A computer called Illiac4<BR>\nHad a rather tough bug in its core.<BR>\n&nbsp;It chewed up its cards<BR>\n&nbsp;And spewed yards and yards<BR>\nOf illegible tape on the floor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','An Argentine gaucho named Bruno<BR>\nWho said, \"Fucking is one thing I do know.<BR>\n&nbsp;Women are fine<BR>\n&nbsp;And sheep are divine<BR>\nBut llamas are numero uno.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman named Florence<BR>\nWho for fucking professed an abhorrence,<BR>\n&nbsp;But they found her in bed<BR>\n&nbsp;With her cunt flaming red,<BR>\nAnd her poodle-dog spending in torrents.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman named Plunnery<BR>\nWho rejoiced in the practice of gunnery.<BR>\n&nbsp;Till one day unobservant,<BR>\n&nbsp;She blew up a servant,<BR>\nAnd was forced to retire to a nunnery.<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young woman in Dee<BR>\nWho stayed with each man she did see.<BR>\n&nbsp;When it came to a test<BR>\n&nbsp;She wished to be best,<BR>\nAnd practice makes perfect, you see.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young trollop at Yale,<BR>\nWho had verses tattooed on her tail,<BR>\n&nbsp;And on her behind,<BR>\n&nbsp;For the sake of the blind,<BR>\nA duplicate version in Braille.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young whore from Kaloo<BR>\nWho filled her vagina with glue.<BR>\n&nbsp;She said with a grin,<BR>\n&nbsp;\"If they pay to get in,<BR>\nThey can pay to get out again too!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young girl of Penzance<BR>\nWho boarded a bus in a trance.<BR>\n&nbsp;The passengers fucked her,<BR>\n&nbsp;Likewise the conductor,<BR>\nWhile the driver shot off in his pants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Wheeling<BR>\nWho had a peculiar feeling.<BR>\n&nbsp;She laid on her back<BR>\n&nbsp;And tickled her crack<BR>\nAnd pissed all over the ceiling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lad named McFee<BR>\nWho was stung in the balls by a bee<BR>\n&nbsp;He made oodles of money<BR>\n&nbsp;By oozing pure honey<BR>\nEvery time he attempted to pee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man who said, \"Tush!<BR>\nMy balls always hang in the brush,<BR>\n&nbsp;And I fumble about,<BR>\n&nbsp;Half in and half out,<BR>\nWith a pecker as limber as mush.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man with a beard<BR>\nWho said, \"It is just what I feared!<BR>\n&nbsp;Two owls and a hen,<BR>\n&nbsp;Four larks and a wren<BR>\nHave all built their nests in my beard!\" ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Cajon<BR>\nWho never could get a good bone.<BR>\n&nbsp;With the aid of a gland<BR>\n&nbsp;It grew simply grand;<BR>\nNow his wife cannot leave it alone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Tagore<BR>\nWhose tool was a yard long or more,<BR>\n&nbsp;So he wore the damn thing<BR>\n&nbsp;In a surgical sling<BR>\nTo keep it from wiping the floor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Bright,<BR>\nWhose speed was much faster than light.<BR>\n&nbsp;She went out one day<BR>\n&nbsp;In a relative way<BR>\nAnd returned on the previous night.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old pirate named Bates<BR>\nWho was learning to rhumba on skates<BR>\n&nbsp;He fell on his cutlass<BR>\n&nbsp;Which rendered him nutless<BR>\nAnd practically useless on dates.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Hong Kong<BR>\nWho never did anything wrong.<BR>\n&nbsp;He would lie on his back<BR>\n&nbsp;With his head in a sack<BR>\nAnd secretly finger his dong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Duluth<BR>\nWhose cock was shot off in his youth.<BR>\n&nbsp;He fucked with his nose<BR>\n&nbsp;And with fingers and toes,<BR>\nAnd he came through a hole in his tooth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Duddee<BR>\nWho came home as drunk as could be.<BR>\n&nbsp;He wound up the clock<BR>\n&nbsp;With the end of his cock,<BR>\nAnd buggered his wife with the key.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady at sea<BR>\nWho said, \"God, how it hurts me to pee.\"<BR>\n&nbsp;\"I see,\" said the mate,<BR>\n&nbsp;\"That accounts for the state<BR>\nOf the captain, the purser, and me.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man from Duluth<BR>\nWhose cock was shot off in his youth.<BR>\n&nbsp;He fucked with his nose<BR>\n&nbsp;Or his fingers and toes<BR>\nAnd he came thru a hole in his tooth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old man of Alsace<BR>\nWho played the trombone with his ass.<BR>\n&nbsp;He put in a trap<BR>\n&nbsp;To take out the crap,<BR>\nBut the vapors corroded the brass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old lady of Glascow,<BR>\nWhose party proved quite a fiasco.<BR>\n&nbsp;At nine-thirty, about,<BR>\n&nbsp;The lights all went out,<BR>\nThrough a lapse on the part of the Gas Co.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old lady of Bingly<BR>\nWho wailed, \"I do hate to sleep singly.<BR>\n&nbsp;I thought I had got<BR>\n&nbsp;A bloke for my twat,<BR>\nBut he seems rather queenly than kingly.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady called Ciss<BR>\nWho went to the river to piss.<BR>\n&nbsp;A young man in a punt<BR>\n&nbsp;Put his hand on her cunt;<BR>\nNo wonder she thought it was bliss.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was an old feminine blighter<BR>\nWho trained a Chow dog to delight her.<BR>\n&nbsp;She would cream her own pool<BR>\n&nbsp;While she sucked off his tool --<BR>\nHow his cock in her cunt would excite her!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Wheeling<BR>\nWho claimed to lack sexual feeling.<BR>\n&nbsp;But a cynic named Boris<BR>\n&nbsp;Just touched her clitoris<BR>\nAnd she had to be scraped off the ceiling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Spain<BR>\nWho demurely undressed on a train.<BR>\n&nbsp;A helpful young porter<BR>\n&nbsp;Helped more than he orter,<BR>\nAnd she promptly cried \"Help me again\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Rio<BR>\nWho slept with the Fornier trio.<BR>\n&nbsp;As she dropped her panties<BR>\n&nbsp;She said, \"No andanties<BR>\nI want this allegro con brio.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Rheims<BR>\nWho amazingly pissed in four streams.<BR>\n&nbsp;A friend poked around<BR>\n&nbsp;And a fly-button found<BR>\nLodged tight in her hole so it seems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Spain<BR>\nWhose face was exceedingly plain,<BR>\n&nbsp;But her cunt had a pucker<BR>\n&nbsp;That made the men fuck her,<BR>\nAgain, and again, and again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','They had come in the fugue to the stretto<BR>\nWhen a dark, bearded man from a ghetto<BR>\n&nbsp;Slipped forward and grabbed<BR>\n&nbsp;Her tresses and stabbed<BR>\nHer to death with a rusty stiletto. <BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Munich<BR>\nWho had an affair with a eunuch.<BR>\n&nbsp;At the height of their passion<BR>\n&nbsp;He dealt her a ration<BR>\nFrom a squirt gun concealed in his tunic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','Though the invalid Saint of Brac<BR>\nLay all of his life on his back,<BR>\n&nbsp;His wife got her share,<BR>\n&nbsp;And the pilgrims now stare<BR>\nAt the scene, in his shrine, on a plaque.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Hyde<BR>\nWho ate a green apple and died.<BR>\n&nbsp;While her lover lamented<BR>\n&nbsp;The apple fermented<BR>\nAnd made cider inside her inside.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','To a weepy young woman in Thrums<BR>\nHer betrothed remarked, \"This is what comes<BR>\n&nbsp;Of allowing your tears<BR>\n&nbsp;To fall into my ears -<BR>\nI think they have rotted the drums.\"<BR>\n&nbsp;-- Edward Gorey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was a young lady from Exeter,<BR>\nSo pretty that men craned their necks at her.<BR>\n&nbsp;One was even so brave<BR>\n&nbsp;As to take out and wave<BR>\nThe distinguishing mark of his sex at her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('limerick','There was once a mechanic named Bench<BR>\nWhose best tool was a sturdy gut-wrench.<BR>\n&nbsp;With this vibrant device<BR>\n&nbsp;He could reach, in a trice,<BR>\nThe innermost parts of a wench.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<james> Are we going to make an emacs out of apt?<BR>\n&nbsp;APT - Debian in a program.  It even does your laundry<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> Linux is not user-friendly. <BR>\nIt _is_ user-friendly.  It is not ignorant-friendly and idiot-friendly.<BR>\n&nbsp;-- Seen somewhere on the net');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','I develop for Linux for a living, I used to develop for DOS.<BR>\nGoing from DOS to Linux is like trading a glider for an F117.<BR>\n&nbsp;-- Lawrence Foard, entropy@world.std.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','finlandia:~> apropos win<BR>\nwin: nothing appropriate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Q: How does a Unix guru have sex?<BR>\nA: unzip;strip;touch;finger;mount;fsck;more;yes;umount;sleep<BR>\n&nbsp;-- unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> Is there any hope for me? Am I just thick? Does anyone remember the<BR>\n> Rubiks Cube, it was easier!<BR>\nI found that the Rubiks cube and Linux are alike. Looks real confusing<BR>\nuntil you read the right book. :-)<BR>\n&nbsp;-- seen on c.o.l.misc, about the \"Linux Learning Curve\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Intel engineering seem to have misheard Intel marketing strategy.  The<BR>\nphrase was \"Divide and conquer\" not \"Divide and cock up\"<BR>\n&nbsp;-- Alan Cox, iialan@www.linux.org.uk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Avoid the Gates of Hell.  Use Linux<BR>\n&nbsp;-- unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Absolutely nothing should be concluded from these figures except that<BR>\nno conclusion can be drawn from them.<BR>\n&nbsp;-- Joseph L. Brothers, Linux/PowerPC Project)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux, the way to get rid of boot viruses<BR>\n&nbsp;-- MaDsen Wikholm, mwikholm@at8.abo.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','----==-- _                     / /  <BR>\n---==---(_)__  __ ____  __    / / / <BR>\n--==---/ / _ / // / / /   / /_/  <BR>\n-=====/_/_//_/_,_/ /_/_  /______  <BR>\nA proud member of TeamLinux _________/<BR>\n&nbsp;-- CHaley (HAC), haley@unm.edu, ch008cth@pi.lanl.gov)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','win-nt from the people who invented edlin.<BR>\n&nbsp;-- MaDsen Wikholm, mwikholm@at8.abo.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Windows without the X is like making love without a partner.<BR>\n&nbsp;-- MaDsen Wikholm, mwikholm@at8.abo.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Sex, Drugs & Linux Rules<BR>\n&nbsp;-- MaDsen Wikholm, mwikholm@at8.abo.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Apples  have  meant  trouble  since  eden.<BR>\n&nbsp;-- MaDsen Wikholm, mwikholm@at8.abo.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','In most countries selling harmful things like drugs is punishable.<BR>\nThen howcome people can sell Microsoft software and go unpunished?<BR>\n&nbsp;-- Hasse Skrifvars, hasku@rost.abo.fi, ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux!  Guerrilla UNIX Development     Venimus, Vidimus, Dolavimus.<BR>\n&nbsp;-- Mark A. Horton KA4YBR, mah@ka4ybr.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','C:> WIN<BR>\nBad command or filename<BR>\n&nbsp;C:> LOSE<BR>\nLoading Microsoft Windows ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Machine Always Crashes, If Not, The Operating System Hangs (MACINTOSH)<BR>\n&nbsp;-- Topic on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Microsoft is not the answer.<BR>\nMicrosoft is the question.<BR>\nNO (or Linux) is the answer.<BR>\n&nbsp;-- Taken from a .signature from someone from the UK, source unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','\"Who is General Failure and why is he reading my hard disk?\"<BR>\nMicrosoft spel chekar vor sail, worgs grate !!<BR>\n&nbsp;-- Felix von Leitner, leitner@inf.fu-berlin.de');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If the future navigation system [for interactive networked services on<BR>\nthe NII] looks like something from Microsoft, it will never work.<BR>\n&nbsp;-- Chairman of Walt Disney Television & Telecommunications');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','\"How do you pronounce SunOS?\"  \"Just like you hear it, with a big SOS\"<BR>\n&nbsp;-- dedicated to Roland Kaltefleiter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Less is more or less more<BR>\n&nbsp;-- Y_Plentyn on #LinuxGER');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','I once witnessed a long-winded, month-long flamewar over the use of<BR>\nmice vs. trackballs... It was very silly.<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','...Deep Hack Mode -- that mysterious and frightening state of<BR>\nconsciousness where Mortal Users fear to tread.<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','All the existing 2.0.x kernels are to buggy for 2.1.x to be the<BR>\nmain goal.<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If you want to travel around the world and be invited to speak at a lot<BR>\nof different places, just write a Unix operating system.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux poses a real challenge for those with a taste for late-night<BR>\nhacking (and/or conversations with God).<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','What you end up with, after running an operating system concept through<BR>\nthese many marketing coffee filters, is something not unlike plain hot<BR>\nwater.<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','...you might as well skip the Xmas celebration completely, and instead<BR>\nsit in front of your linux computer playing with the all-new-and-improved <BR>\nlinux kernel version.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','..you could spend *all day* customizing the title bar.  Believe me.  I<BR>\nspeak from experience.<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','LOAD \"LINUX\",8,1<BR>\n&nbsp;-- Topic on #LinuxGER');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Problem solving under Linux has never been the circus that it is under<BR>\nAIX.<BR>\n&nbsp;-- Pete Ehlke in comp.unix.aix');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Oh, and this is another kernel in that great and venerable \"BugFree(tm)\"<BR>\nseries of kernels.  So be not afraid of bugs, but go out in the streets<BR>\nand deliver this message of joy to the masses.<BR>\n&nbsp;-- Linus, in the announcement for 1.3.27');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Also another major deciding factor is availability of source code.<BR>\nIt just gives everybody a warm fuzzy feeling knowing that there is<BR>\nsource code available to the product you are using.  It allows everybody<BR>\nto improve on the product and fix bugs etc. sooner that the author(s)<BR>\nwould get the time/chance to.<BR>\n&nbsp;-- Atif Khan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','lp1 on fire<BR>\n&nbsp;-- One of the more obfuscated kernel messages');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Note that if I can get you to \"su and say\" something just by asking,<BR>\nyou have a very serious security problem on your system and you should<BR>\nlook into it.<BR>\n&nbsp;-- Paul Vixie, vixie-cron 3.0.1 installation notes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If Bill Gates is the Devil then Linus Torvalds must be the Messiah.<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Be warned that typing Bkillall InameP may not have the desired<BR>\neffect on non-Linux systems, especially when done by a privileged user.<BR>\n&nbsp;-- From the killall manual page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We come to bury DOS, not to praise it.<BR>\n&nbsp;-- Paul Vojta, vojta@math.berkeley.edu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We can use symlinks of course... syslogd would be a symlink to syslogp and <BR>\nftpd and ircd would be linked to ftpp and ircp... and of course the <BR>\npoint-to-point protocal paenguin.<BR>\n&nbsp;-- Kevin M. Bealer, commenting on the penguin Linux logo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We are MicroSoft.  You will be assimilated.  Resistance is futile.<BR>\n&nbsp;-- Attributed to B.G., Gill Bates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','A Linux machine!  Because a 486 is a terrible thing to waste!<BR>\n&nbsp;-- Joe Sloan, jjs@wintermute.ucr.edu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','When you say \"I wrote a program that crashed Windows\", people just stare at<BR>\nyou blankly and say \"Hey, I got those with the system, *for free*\".<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Who wants to remember that escape-x-alt-control-left shift-b puts you into<BR>\nsuper-edit-debug-compile mode?<BR>\n&nbsp;-- Discussion on the intuitiveness of commands, especially Emacs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Anyone who thinks UNIX is intuitive should be forced to write 5000 lines of <BR>\ncode using nothing but vi or emacs.  AAAAACK!<BR>\n&nbsp;-- Discussion on the intuitiveness of commands, especially Emacs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','How do I type \"for i in *.dvi do xdvi $i done\" in a GUI?<BR>\n&nbsp;-- Discussion in comp.os.linux.misc on the intuitiveness of interfaces');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','oh okay. my mistake.<BR>\n&nbsp;Yafcot:atj(*),<BR>\n&nbsp;mark<BR>\n&nbsp;* Yet another fool coming over this: according to joey<BR>\n&nbsp;-- mark@mail.novare.net');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The POP3 server service depends on the SMTP server service, which<BR>\nfailed to start because of the following error:<BR>\nThe operation completed successfully.<BR>\n&nbsp;-- Windows NT Server v3.51');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','After watching my newly-retired dad spend two weeks learning how to make a new<BR>\nfolder, it became obvious that \"intuitive\" mostly means \"what the writer or<BR>\nspeaker of intuitive likes\".<BR>\n&nbsp;-- Bruce Ediger, bediger@teal.csn.org, on X the intuitiveness of a Mac interface');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Now I know someone out there is going to claim, \"Well then, UNIX is intuitive,<BR>\nbecause you only need to learn 5000 commands, and then everything else follows<BR>\nfrom that! Har har har!\"<BR>\n&nbsp;-- Andy Bates on \"intuitive interfaces\", slightly defending Macs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Never make any mistaeks.<BR>\n&nbsp;-- Anonymous, in a mail discussion about to a kernel bug report');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We are using Linux daily to UP our productivity - so UP yours!<BR>\n&nbsp;-- Adapted from Pat Paulsen by Joe Sloan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','But what can you do with it?<BR>\n&nbsp;-- ubiquitous cry from Linux-user partner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux: the operating system with a CLUE... Command Line User Environment.<BR>\n&nbsp;-- seen in a posting in comp.software.testing');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Dijkstra probably hates me.<BR>\n&nbsp;-- Linus Torvalds, in kernel/sched.c');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','&nbsp;Why use Windows when you can have air conditioning?<BR>\n&nbsp;Why use Windows, when you can leave through the door?<BR>\n&nbsp;-- Konrad Blum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','I still maintain the point that designing a monolithic kernel in 1991 is a<BR>\nfundamental error.  Be thankful you are not my student.  You would not get a<BR>\nhigh grade for such a design :-)<BR>\n&nbsp;-- Andrew Tanenbaum to Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We all know Linux is great... it does infinite loops in 5 seconds.<BR>\n&nbsp;- Linus Torvalds about the superiority of Linux on the Amterdam Linux Symposium');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux is obsolete<BR>\n&nbsp;-- Andrew Tanenbaum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','...Unix, MS-DOS, and Windows NT (also known as the Good, the Bad, and<BR>\nthe Ugly).<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','...very few phenomena can pull someone out of Deep Hack Mode, with two<BR>\nnoted exceptions: being struck by lightning, or worse, your *computer*<BR>\nbeing struck by lightning.<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','One tree to rule them all,<BR>\nOne tree to find them,<BR>\nOne tree to bring them all,<BR>\nand to itself bind them.<BR>\n&nbsp;-- Gavin Koch <gavin@cygnus.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','How many chunks could checkchunk check if checkchunk could check chunks?<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Computers are useless.  They can only give you answers.<BR>\n&nbsp;-- Pablo Picasso');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Beeping is cute, if you are in the office ;)<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Check it out, send me comments, and dance joyously in the streets,<BR>\n&nbsp;-- Linus Torvalds announcing 2.0.27');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> Also another major deciding factor is availability of source code.<BR>\n> It just gives everybody a warm fuzzy feeling knowing that there is<BR>\n> source code available to the product you are using.  It allows everybody<BR>\n> to improve on the product and fix bugs etc. sooner that the author(s)<BR>\n> would get the time/chance to.<BR>\n&nbsp;I think this is one the really BIG reasons for the snowball/onslaught<BR>\nof Linux and the wealth of stuff available that gets enhanced faster<BR>\nthan the real vendors can keep up.<BR>\n&nbsp;-- Norman ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Not only Guinness - Linux is good for you, too.<BR>\n&nbsp;-- Banzai on IRC');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> NE-2000 clone.  Pentium optimizing gcc (pentium gcc pl8 I think).<BR>\n&nbsp;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^<BR>\n&nbsp;Build a kernel with the proper gcc. Reports with a non standard compiler<BR>\nare useless.<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','BTW: I have a better name for the software .... Microsoft Internet<BR>\nExploder.<BR>\n&nbsp;-- George Bonser <grep@cris.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','... of course, this probably only happens for tcsh which uses wait4(),<BR>\nwhich is why I never saw it.  Serves people who use that abomination<BR>\nright 8^)<BR>\n&nbsp;-- Linus Torvalds, about a patch that fixes getrusage for 1.3.26');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux: The OS people choose without $200,000,000 of persuasion.<BR>\n&nbsp;-- Mike Coleman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','+#if defined(__alpha__) && defined(CONFIG_PCI)<BR>\n+       /*<BR>\n+        * The meaning of life, the universe, and everything. Plus<BR>\n+        * this makes the year come out right.<BR>\n+        */<BR>\n+       year -= 42;<BR>\n+#endif<BR>\n&nbsp;-- From the patch for 1.3.2: (kernel/time.c), submitted by Marcus Meissner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If you really want pure ASCII, save it as text... or browse<BR>\nit with your favorite browser...<BR>\n&nbsp;-- Alexandre Maret <amaret@infomaniak.ch>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The memory management on the PowerPC can be used to frighten small children.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','People disagree with me.  I just ignore them.<BR>\n&nbsp;-- Linus Torvalds, regarding the use of C++ for the Linux kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The chat program is in public domain.  This is not the GNU public license.<BR>\nIf it breaks then you get to keep both pieces.<BR>\n&nbsp;-- Copyright notice for the chat program');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Actually, typing random strings in the Finder does the equivalent of<BR>\nfilename completion.<BR>\n&nbsp;-- Discussion on file completion vs. the Mac Finder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','A feature is nothing more than a bug with seniority.<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','(It is an old Debian tradition to leave at least twice a year ...)<BR>\n&nbsp;-- Sven Rudolph');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','People are going to scream bloody murder about that.<BR>\n&nbsp;-- Seen on linux-kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','i dont even know if it makes sense at all :) This is an experimental patch<BR>\nfor an experimental kernel :))<BR>\n&nbsp;-- Ingo Molnar on linux-kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If loving linux is wrong, I dont wanna be right.<BR>\n&nbsp;-- Topic for #LinuxGER');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The documentation is in Japanese.  Good luck.<BR>\n&nbsp;-- Rich $alz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<lilo> Fairlight: udp is the light margarine of tcp/ip transport protocols :)<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Computers are not intelligent.  They only think they are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Sex dumps core<BR>\n(Sex is a Simple editor for X11)<BR>\n&nbsp;-- Seen on debian bugtracking');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','-  long    f_ffree;    /* free file nodes in fs */<BR>\n+  long    f_ffree;    /* freie Dateiknoten im Dateisystem */<BR>\n&nbsp;-- Seen in a translation');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','- DDD no longer requires the librx library.  Consequently, librx<BR>\n&nbsp;errors can no more cause DDD to crash.<BR>\n&nbsp;-- DDD');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','&nbsp;*  This is complicated.  Has to do with interrupts.  Thus, I am<BR>\n&nbsp;*  scared witless.  Therefore I refuse to write this function. :-P<BR>\n&nbsp;-- From the maclinux patch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<sct> Anyone want the new supermount? :)<BR>\n<klogd> whats new aboutit<BR>\n<sct> klogd: It cleans whiter than white. :)<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* Jes wonders why so many people in here uses fooZZZZZ and foo_sleeping nicks<BR>\n<peter> Jes: Because they are sleeping?<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Whoa, first contact!<BR>\n&nbsp;[...]<BR>\n&nbsp;Welcome, from the people of Terra (Sol III). We extend our hands in<BR>\nfriendship, and sincerely hope you shall do the same with your<BR>\nhand-equivelents.<BR>\n&nbsp;-- Jason Burrell about a russian posting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Netscape is not a newsreader, and probably never shall be.<BR>\n&nbsp;-- Tom Christiansen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','If someone can point me to a good and _FREE_ backup software that keeps<BR>\ntrack of which files get stored on which tape, we can change to it.<BR>\n&nbsp;-- Mike Neuffer, admin of i-Connect Corp.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','martin@bdsi.com (no longer valid - where are you now, Martin?)<BR>\n&nbsp;-- from /usr/src/linux/drivers/cdrom/mcd.c');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Well, since MS cant be sure of the username of someone downloading<BR>\nthings, they are going to play it safe and have everything dowloaded<BR>\nand executed by Explorer as suid root. That way, it will run on ANY<BR>\nsystem anywhere. :)<BR>\n&nbsp;-- George Bonser <grep@cris.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','>       Yeah, Linus is in the US.<BR>\n><BR>\n>       His source trees are in Finland.<BR>\n&nbsp;OK, someone give him access -fast- ...... ;-)<BR>\n&nbsp;-- babydr@nwrain.net, because of problems with the kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','>  Where in the US is Linus?<BR>\n&nbsp;He was in the \"Promise Land\".<BR>\n&nbsp;-- David S. Miller <davem@caip.rutgers.edu>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Alan Cox wrote:<BR>\n>> On any procmail new enough not to be full of security holes you set<BR>\n>Brain on, Imeant majordomo of course 8)<BR>\nYou got me worried there for a brief (very brief) moment :-).<BR>\n&nbsp;-- Stephen R. van den Berg (AKA BuGless)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','#define FALSE   0               /* This is the naked Truth */<BR>\n#define TRUE    1               /* and this is the Light */<BR>\n&nbsp;-- mailto.c');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The bug system is not a release-specific entity.  Users of<BR>\nDebian 1.3.1 use the same bug tracking system as users of hamm.<BR>\n&nbsp;-- James Troup <troup@debian.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','On Netscape GPLing their browser: \`\`How can you trust a browser that<BR>\nANYONE can hack? For the secure choice, choose Microsoft.\'<BR>\n&nbsp;-- <oryx@pobox.com> in a comment on slashdot.org');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* SynrG notes that the number of configuration questions to answer in sendmail<BR>\n&nbsp;is NON-TRIVIAL<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','&nbsp;* In anticipation of 2.10.02 release, updated to patchlevel<BR>\n&nbsp;+ircu2.10.01+.config6-7.config7-8.lgline3.iwho.limit.glibc.motdcache2.trace.whois1-2.config8-9.statsw.sprintf2-3.msgtree2.memleak1-2+.msgtree2-3.gline8-9.gline9-10.invite2.rbr.stats.numclients.whisper.whisper1-2.stats1-2.nokick1-2.chroot.config9-11.snomask7-8.limi+t1-3.userip1-3.userip3-4.config11-12.config12-13.umode2-3.akillsbt.who4-5.kn.kn1-2.freebsdcore2.msgtree3-5.y2k.glibc1-2.rmfunc.msgf+lags2.who5-6.nickchange2.glibc2-3.modeless3<BR>\n&nbsp;-- From the annoucement of ircd 2.10.01-3 for Debian GNU/Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','... Linux und seine Programme sind damit so etwas wie ein real existierender<BR>\nSozialismus der besseren Art ...<BR>\n&nbsp;-- Christian Seel in der Berliner Morgenpost v. 9.3.1997');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','I am NOT a kludge!  I am a computer!<BR>\n&nbsp;-- tts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Steal my cash, car and TV - but leave the computer!<BR>\n&nbsp;-- Soenke Lange <soenke@escher.north.de>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','BREAKFAST.COM Halted... Cereal Port Not Responding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','RIP is irrelevant.  Spoofing is futile.  Your routes will be aggregated.<BR>\n&nbsp;-- Alex Yuriev');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Computers are like air conditioners.  Both stop working, if you open windows.<BR>\n&nbsp;-- Adam Heath');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The only really good reason I can think to not release specs is<BR>\nembarrassment on just how crappy some hardware out there is, or just how<BR>\nbuggy it is.<BR>\n&nbsp;-- Chris Wedgwood <cw@ix.net.nz>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<Myxie> I know. Unless htere is a cookie monster somewhere between us tat muches the amil.<BR>\n<Myxie> amil/mail<BR>\n<Myxie> muches/munches tat/that htere/there<BR>\n<HippieGuy> heheh<BR>\n<HippieGuy> problems? :)<BR>\n* Myxie needs an ircii addon that pipes teh command line through ispell :)<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','#Debian makes me feel all warm and fuzzy inside. :)<BR>\n&nbsp;-- HippieGuy on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Netscape is not a newsreader, and probably never shall be.<BR>\n&nbsp;-- Tom Christiansen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Sorry.  I just realized this sentance makes no sense :)<BR>\n&nbsp;-- Ian Main');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Make it idiot-proof, and someone will breed a better idiot.<BR>\n&nbsp;-- Oliver Elphick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> Alan Cox wrote:<BR>\n[..]<BR>\n&nbsp;No I didnt.  Someone else wrote that.  Please keep attributions<BR>\nstraight.<BR>\n&nbsp;-- From linux-kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','>   1. is qmail as secure as they say?<BR>\n&nbsp;Depends on what they were saying, but most likely yes.<BR>\n&nbsp;-- Seen on debian-devel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Debian is like Suse with yast turned off, just better. :)<BR>\n&nbsp;-- Goswin Brederlow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','*** Rince is wagner@schizo.DAINet.de (We have Joey, we have Fun, we have Linux on a Sun)<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','... Linux und seine Programme sind damit<BR>\nso etwas wie ein real existierender Sozialismus der besseren Art...<BR>\n&nbsp;-- Christian Seel in der Berliner Morgenpost v. 9.3.1997');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The problem here (as someon else stated) is that when multiple dists<BR>\nuse the same package format it only gives a \"false sense of compatibility\".<BR>\n&nbsp;-- Stephen Carpenter <sjc@delphi.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The most effective has probably been Linux/8086 - that was a joke<BR>\nthat got out of hand.  So far out of hand in fact its almost approaching<BR>\nusability because other folks thought it worth doing - Alistair Riddoch<BR>\nespecially.<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Just go ahead and write your own multitasking multiuser os!<BR>\nWorked for me all the times.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','baz bat bamus batis bant.<BR>\n&nbsp;-- James Troup');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','#ifdef __SMP__<BR>\n#error \"Me no hablo Alpha SMP\"<BR>\n#else<BR>\n#define irq_enter(cpu, irq)     (++local_irq_count[cpu])<BR>\n#define irq_exit(cpu, irq)      (--local_irq_count[cpu])<BR>\n#endif<BR>\n&nbsp;-- from kernel 2.1.90, arch/alpha/kernel/irc.c');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linus Torvalds:<BR>\n> This is the special easter release of linux, more mundanely called 1.3.84<BR>\nWinfried Truemper:<BR>\n> Umh, oh. What do you mean by \"special easter release\"?. Will it quit<BR>\n> working today and rise on easter?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','These download files are in Microsoft Word 6.0 format. After<BR>\nunzipping, these files can be viewed in any text editor, including<BR>\nall versions of Microsoft Word, WordPad, and Microsoft Word Viewer<BR>\n&nbsp;-- From Micro$oft');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* Linux Viruscan.....<BR>\n&nbsp;Windows 95 found.  Remove it? (Y/y)<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<sel> need help: my first packet to my provider gets lost :-(<BR>\n<netgod> sel:  dont send the first one, start with #2<BR>\n* netgod is kidding');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Fehlermeldung von StarOffice:<BR>\n&nbsp;Das Dokument wurde fuer den Drucker Generic PostScript Printer formatiert.<BR>\nDer Drucker ist nicht vorhanden.  Soll der Standarddrucker Generic<BR>\nPostScript Printer verwendet werden?<BR>\n&nbsp;Ob Programme schizophren werden koennen?<BR>\n&nbsp;-- Oliver Bedford <O.Bedford@uni-koeln.de>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','/*<BR>\n&nbsp;*     Please skip to the bottom of this file if you ate lunch recently<BR>\n&nbsp;*                             -- Alan<BR>\n&nbsp;*/<BR>\n&nbsp;-- from Linux kernel pre-2.1.91-1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','#if _FP_W_TYPE_SIZE < 64<BR>\n#error \"Only stud muffins allowed, schmuck.\"<BR>\n#endif<BR>\n&nbsp;-- linux/arch/sparc64/quad.c');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','When you have 200 programmers trying to write code for one<BR>\nproduct, like Win95 or NT, what you get is a multipule personality<BR>\nprogram.  By definition, the real problem is that these programs are<BR>\npsychotic by nature and make people crazy when they use them.<BR>\n&nbsp;-- Joan Brewer on alt.destroy.microsoft');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<grin> seen jhm<BR>\n<dpkg> jhm is Sarek, and jhm is on the channel right now!<BR>\n* JHM wonders why dpkg remembers that particular nick.<BR>\n<grin> dpkg: Sarek? ermm, sure, and I am Khan<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<igor> Hah! we have 2 Johnie Ingrams in the channel :)<BR>\n<igor> Hey all btw :)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Remember: While root can do most everything, there are certain<BR>\nprivileges that only a partner can grant.<BR>\n&nbsp;-- Telsa Gwynne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<netgod> And once Diziet/CQ make the formal announcment that LSA<BR>\n&nbsp;sucks, we can even reduce the Crisis Level rating and move<BR>\n&nbsp;on to linuxfoundation.org.<BR>\n&nbsp;-- #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* liw prefers not to have Linus run Debian, because then /me would<BR>\n&nbsp;have to run Red Hat, just to keep the power balance :)<BR>\n&nbsp;-- #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','When a float occurs on the same page as the start of a supertabular<BR>\nyou can expect unexpected results.<BR>\n&nbsp;-- Documentation of supertabular.sty');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','From: Ean Schuessler <ean@novare.net><BR>\nThe unrecognized minister of propaganda,<BR>\nE<BR>\n&nbsp;-- Debian, joking');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','And Bruce is effectively building BruceIX<BR>\n&nbsp;-- Alan Cox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<Culus-> I will be known as Ian Black, Ean can be Ian Red, Netgod Ian Blue,<BR>\n&nbsp;Che gets Ian Yellow, CQ is Ian Purple and Joey is Ian Indigo<BR>\n&nbsp;-- Some #Debian channel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> Tut mir Leid, Jost, aber Du bist ein unertraeglicher Troll.<BR>\nWas soll das? Du *beleidigst* die Trolle!<BR>\n&nbsp;-- de.comp.os.unix.linux.misc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Perhaps the RBLing (Realtime Black Hole) of msn.com recently, which<BR>\nprevented a large amount of mail going out for about 4 days, has had a<BR>\npositive influence in Redmond.  They did agree to work on their anti-relay<BR>\ncapabilities at their POPs to get the RBL lifted.<BR>\n&nbsp;-- Bill Campbell on Smail3-users');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Day X+4 months: Microsoft ships NT 5.0 for Intel.with a big media<BR>\n&nbsp;event on TV. IBM begins to ship Debian 4.6 as the<BR>\n&nbsp;standard OS on all machines from mainframe to PC<BR>\n&nbsp;and announces the move on Slashdot.<BR>\n&nbsp;-- Christoph Lameter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Microsoft DNS service terminates abnormally when it recieves a response<BR>\nto a DNS query that was never made.  Fix Information: Run your DNS<BR>\nservice on a different platform.<BR>\n&nbsp;-- bugtraq');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<rm_-rf_> The real value of KDE is that they inspired and push the<BR>\n&nbsp;development of GNOME :-)<BR>\n&nbsp;-- #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Despite the best efforts of a quantum bigfoot drive (yes I know everyone<BR>\ntold me they suck, now I know they were right) 2.1.109ac1 is now available<BR>\n&nbsp;-- Alan Cox announcing Linux 2.1.109ac1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Alex Buell:<BR>\nOr how about a Penguin logo painted in really really trippy<BR>\ncolours, and emblazoned with the word LSD. :o)<BR>\n&nbsp;Geert Uytterhoeven:<BR>\nWe already had that one, but unfortunately Russell King fixed that nasty<BR>\npalette bug in drivers/video/fbcon.c :-)<BR>\n&nbsp;-- linux-kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<alaint> joey--very clever !!!<BR>\n<alaint> joey--no wonder that Debian is a good distrib with coder like you<BR>\n&nbsp;-- Seen on #Debian (referring to my RAID article for the LJ)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Being overloaded is the sign of a true Debian maintainer.<BR>\n&nbsp;-- JHM on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Go not unto the Usenet for advice, for you will be told both yea and nay (and<BR>\nquite a few things that just have nothing at all to do with the question).<BR>\n&nbsp;-- seen in a .sig somewhere');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Whip me.  Beat me.  Make me maintain AIX.<BR>\n&nbsp;-- Stephan Zielinski');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','panic(\"Foooooooood fight!\");<BR>\n&nbsp;-- In the kernel source aha1542.c, after detecting a bad segment list');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Convention organizer to Linus Torvalds: \"You might like to come with us <BR>\nto some licensed[1] place, and have some pizza.\"<BR>\n&nbsp;Linus: \"Oh, I did not know that you needed a license to eat pizza\".<BR>\n&nbsp;[1] Licenced - refers in Australia to a restaurant which has government <BR>\nlicence to sell liquor.<BR>\n&nbsp;-- Linus at a talk at the Melbourne University');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','And 1.1.81 is officially BugFree(tm), so if you receive any bug-reports<BR>\non it, you know they are just evil lies.<BR>\n&nbsp;-- Linus Torvalds');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<miguel> any new sendmail hole I have to fix before going on vacations?<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Are Linux users lemmings collectively jumping off of the cliff of<BR>\nreliable, well-engineered commercial software?<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Seriously, the way I did this was by using a special /sbin/loader binary<BR>\nwith debugging hooks that I made (\"dd\" is your friend: binary editors<BR>\nare for wimps).<BR>\n&nbsp;-- Linus Torvalds, in an article on a dnserver');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','NEVER RESPOND TO CRITICAL PRESS.  IT IS A GAME YOU CAN ONLY LOSE, AND IT<BR>\nMAKES US LOOK BAD.<BR>\n&nbsp;-- Bruce Perens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','All language designers are arrogant. Goes with the territory...<BR>\n&nbsp;-- Larry Wall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','AUTHOR<BR>\nFvwmAuto just appeared one day, nobody knows how.<BR>\n&nbsp;-- FvwmAuto(1x)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux - Das System fuer schlaue Maedchen ;)<BR>\n&nbsp;-- banshee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','>>> FreeOS is an english-centric name<BR>\n&nbsp;Have you all been stuck in email, or have any of you tried<BR>\n*pronouncing* that? free-oh-ess? free-ows? fritos? :-)<BR>\n&nbsp;-- Mark Eichin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','You will not censor me through bug terrorism.<BR>\n&nbsp;-- James Troup');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Someone on IRC was very sad about the uptime of his machine wrapping<BR>\nfrom 497 days to 0.<BR>\n&nbsp;-- linux-kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<doogie> Thinking is dangerous.  It leads to ideas.<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<doogie> netgod:  8:42pm is not late.<BR>\n<netgod> doogie: its 2:42am in Joeyland<BR>\n&nbsp;-- #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We knew from experience that the essence of communal computing, as<BR>\nsupplied by remote-access, time-shared machines, is not just to type<BR>\nprograms into a terminal instead of a keypunch, but to encourage close<BR>\ncommunication.<BR>\n&nbsp;-- Dennis Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<dark> Turns out that grep returns error code 1 when there are no matches.<BR>\n&nbsp;I KNEW that.  Why did it take me half an hour?<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','As to house maintenance, does it involve problem solfing?  If so,<BR>\nyour hacker can safely be left to deall with the panning (for the <BR>\nmusement value, if nothering ese).<BR>\n&nbsp;-- Telsa Gwynne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<stu> Stupid nick highlighting<BR>\n<stu> Whenever someone starts with \"stupid\" it highlights the nick.  Hmm.<BR>\n&nbsp;-- #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linus?  Whose that?<BR>\n&nbsp;-- clueless newbie on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','.. I used to get in more fights with SCO than I did my girlfriend, but <BR>\nnow, thanks to Linux, she has more than happily accepted her place back at <BR>\nnumber one antagonist in my life.. <BR>\n&nbsp;-- Jason Stiefel, krypto@s30.nmex.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','We should start referring to processes which run in the background by their <BR>\ncorrect technical name... paenguins.<BR>\n&nbsp;-- Kevin M. Bealer, commenting on the penguin Linux logo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','C is quirky, flawed, and an enormous success<BR>\n&nbsp;-- Dennis M. Ritchie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','To kick or not to kick...<BR>\n&nbsp;-- Somewhere on IRC, inspired by Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Vini, vidi, Linux!<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','When a trainstation is were a train stops what is a workstation?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Das ganze Saarland ist von M$ besetzt - das ganze? Nein eine kleine<BR>\nGruppe im Sudwesten trotzt dem ubergrosen Herrscher dank ihres<BR>\nZaubertrankes Linux<BR>\n&nbsp;-- Tooster on #LinuxGER');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','REST:<BR>\nP:      Linus Torvalds<BR>\nS:      Buried alive in email<BR>\n&nbsp;-- from /usr/src/linux/MAINTAINERS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<Stealth> How do I bind a computer to an NIS server?<BR>\n<Joey> Use a rope?<BR>\n&nbsp;-- Seen on #Debian');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Turn right here. No! NO! The OTHER right!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','| |-sshd---tcsh-+-dpkg-buildpacka---rules---sh---make---make---sh---make---sh---make---sh---make---sh---make---sh---make<BR>\n&nbsp;-- While packaging XFree86 for Debian GNU/Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* Phaedrus wishes he could get a machine that consists of Sparc IO,<BR>\n&nbsp;Alpha Processors and sleek design of an SGI<BR>\n<pp> And intel prices<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','\"You, sir, are nothing but a pathetically lame salesdroid!<BR>\nI fart in your general direction!\"<BR>\n&nbsp;-- Randseed on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Various documentation updates and bugfixes (the best way to know that a<BR>\nstable kernel is approaching is to notice that somebody starts to<BR>\nspellcheck the kernel - it has so far never failed)<BR>\n&nbsp;-- Linus Torvalds in the annoucement for pre-2.1.99-3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','This is a scsi driver, scraes the shit out of me, therefore I tapdanced<BR>\nand wrote a unix clone around it (C) by linus<BR>\n&nbsp;-- Somewhere in the kernel tree');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Try to remove the color-problem by restarting your computer several times.<BR>\n&nbsp;-- Microsoft-Internet Explorer README.TXT');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','<Tazman> damn my office is cold.<BR>\n<Tazman> need a hot secretary to warm it up.<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Even more amazing was the realization that God has Internet access.  I<BR>\nwonder if He has a full newsfeed?<BR>\n&nbsp;-- Matt Welsh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','\"... being a Linux user is sort of like living in a house inhabited<BR>\nby a large family of carpenters and architects. Every morning when<BR>\nyou wake up, the house is a little different. Maybe there is a new<BR>\nturret, or some walls have moved. Or perhaps someone has temporarily<BR>\nremoved the floor under your bed.\" - Unix for Dummies, 2nd Edition<BR>\n&nbsp;-- found in the .sig of Rob Riggs, rriggs@tesser.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Checking host system type...<BR>\ni586-unknown-linux<BR>\nconfigure: error: sorry, this is the gnu os, not linux<BR>\n&nbsp;-- Topic on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Only wimps use tape backup: _real_ men just upload their important stuff <BR>\non ftp, and let the rest of the world mirror it ;)<BR>\n&nbsp;-- Linus Torvalds, about his failing hard drive on linux.cs.helsinki.fi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> I get the following error messages at bootup, could anyone tell me <BR>\n> what they mean?<BR>\n> fcntl_setlk() called by process 51 (lpd) with broken flock() emulation<BR>\nThey mean that you have not read the documentation when upgrading the<BR>\nkernel.<BR>\n&nbsp;-- seen on c.o.l.misc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','I mean, well, if it were not for Linux I might be roaming the streets looking<BR>\nfor drugs or prostitutes or something.  Hannu and Linus have my highest<BR>\nadmiration (apple polishing mode off).<BR>\n&nbsp;-- Phil Lewis, plewis@nyx.nyx.net');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Shoot me again.<BR>\nJust proving that the quickest way to solve the problem is to post a<BR>\nwhine to the newsgroups: within moments the solution presents itself to<BR>\nme, and meanwhile my ass is hanging out on the Net... *sigh*... <BR>\n&nbsp;-- Dave Phillips, dlphilp@bright.net, about problem solving via news');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','> You know you are \"there\" when you are known by your first name, and<BR>\n> are recognized.<BR>\n> Lemmie see, there is Madonna, and Linus, and ..... help me out here!<BR>\nBill ? ;-)<BR>\n&nbsp;-- From some postings on comp.os.linux.misc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','N: Phil Lewis<BR>\nE: beans@bucket.ualr.edu<BR>\nD: Promised to send money if I would put his name in the source tree.<BR>\nS: PO Box 371<BR>\nS: North Little Rock, Arkansas 72115<BR>\nS: US<BR>\n&nbsp;-- /usr/src/linux/CREDITS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The easiest way to get the root password is to become system admin.<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The good thing about standards is that there are so many to choose from.<BR>\n&nbsp;-- Andrew S. Tanenbaum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','How do you power off this machine?<BR>\n&nbsp;-- Linus, when upgrading linux.cs.helsinki.fi, and after using the machine for several months');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Excusing bad programming is a shooting offence, no matter _what_ the<BR>\ncircumstances.<BR>\n&nbsp;-- Linus Torvalds, to the linux-kernel list');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Linux - Where do you want to fly today?<BR>\n&nbsp;-- Unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The primary difference [...] is that the Java programm will reliably and<BR>\nobviously crash, whereas the C Program will do something obscure<BR>\n&nbsp;-- Java Language Tutorial');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Old MacLinus had a stack/l-i-n-u-x/and on this stack he had a trace/l-i-n-u-x<BR>\nwith an Oops-Oops here and an Oops-Oops there<BR>\nhere an Oops, there an Oops, everywhere an Oops-Oops.<BR>\n&nbsp;-- tjimenez@site.gmu.edu, linux.dev.kernel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The state of some commercial Un*x is more unsecure than any Linux box<BR>\nwithout a root password...<BR>\n&nbsp;-- Bernd Eckenfels');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The most important design issue... is the fact that Linux is supposed to <BR>\nbe fun...<BR>\n&nbsp;-- Linus Torvalds at the First Dutch International Symposium on Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','The linuX Files -- The Source is Out There.<BR>\n&nbsp;-- Sent in by Craig S. Bell, goat@aracnet.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','ECRC hat keine lynx komp. seiten, sowas MUSS ja pleite gehen ;-)=<BR>\n&nbsp;-- Getty on #LinuxGER');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','* gb notes that fdisk thinks his cdrom can store one terabyte<BR>\n&nbsp;-- Seen on #Linux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','Win95 is not a virus; a virus does something.<BR>\n&nbsp;-- unknown source');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linux','snafu = Situation Normal All F%$*ed up');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','I develop for Linux for a living, I used to develop for DOS.<BR>\nGoing from DOS to Linux is like trading a glider for an F117.<BR>\n(By entropy@world.std.com, Lawrence Foard)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','How do I type \"for i in *.dvi do xdvi i done\" in a GUI?<BR>\n(Discussion in comp.os.linux.misc on the intuitiveness of interfaces.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','We come to bury DOS, not to praise it.<BR>\n(Paul Vojta, vojta@math.berkeley.edu, paraphrasing a quote of Shakespeare)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','----==-- _                     / /  <BR>\n---==---(_)__  __ ____  __    / / / <BR>\n--==---/ / _ / // / / /   / /_/  <BR>\n-=====/_/_//_/_,_/ /_/_  /______  <BR>\nA proud member of TeamLinux _________/<BR>\n(By CHaley (HAC), haley@unm.edu, ch008cth@pi.lanl.gov)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Fatal Error: Found [MS-Windows] System -> Repartitioning Disk for Linux...<BR>\n(By cbbrown@io.org, Christopher Browne)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"I once witnessed a long-winded, month-long flamewar over the use of<BR>\nmice vs. trackballs...It was very silly.\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Dijkstra probably hates me<BR>\n(Linus Torvalds, in kernel/sched.c)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Avoid the Gates of Hell.  Use Linux<BR>\n(Unknown source)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"...Deep Hack Mode--that mysterious and frightening state of<BR>\nconsciousness where Mortal Users fear to tread.\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Linux: the operating system with a CLUE...<BR>\nCommand Line User Environment\".<BR>\n(seen in a posting in comp.software.testing)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','I still maintain the point that designing a monolithic kernel in 1991 is a<BR>\nfundamental error.  Be thankful you are not my student.  You would not get a<BR>\nhigh grade for such a design :-)<BR>\n(Andrew Tanenbaum to Linus Torvalds)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Running Windows on a Pentium is like having a brand new Porsche but only<BR>\nbe able to drive backwards with the handbrake on.<BR>\n(Unknown source)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','And 1.1.81 is officially BugFree(tm), so if you receive any bug-reports<BR>\non it, you know they are just evil lies.\"<BR>\n(By Linus Torvalds, Linus.Torvalds@cs.helsinki.fi)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"All language designers are arrogant.  Goes with the territory...\"<BR>\n(By Larry Wall)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','After watching my newly-retired dad spend two weeks learning how to make a new<BR>\nfolder, it became obvious that \"intuitive\" mostly means \"what the writer or<BR>\nspeaker of intuitive likes\".<BR>\n(Bruce Ediger, bediger@teal.csn.org, in comp.os.linux.misc, on X the<BR>\nintuitiveness of a Mac interface.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Actually, typing random strings in the Finder does the equivalent of<BR>\nfilename completion.<BR>\n(Discussion in comp.os.linux.misc on the intuitiveness of commands: file<BR>\ncompletion vs. the Mac Finder.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','A Linux machine! because a 486 is a terrible thing to waste!<BR>\n(By jjs@wintermute.ucr.edu, Joe Sloan)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Absolutely nothing should be concluded from these figures except that<BR>\nno conclusion can be drawn from them.\"<BR>\n(By Joseph L. Brothers, Linux/PowerPC Project)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Are [Linux users] lemmings collectively jumping off of the cliff of<BR>\nreliable, well-engineered commercial software?\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Be warned that typing Bkillall InameP may not have the desired<BR>\neffect on non-Linux systems, especially when done by a privileged user.<BR>\n(From the killall manual page)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','But what can you do with it?  -- ubiquitous cry from Linux-user partner.<BR>\n(Submitted by Andy Pearce, ajp@hpopd.pwd.hp.com)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Note that if I can get you to \\"su and say\\" something just by asking,<BR>\nyou have a very serious security problem on your system and you should<BR>\nlook into it.\"<BR>\n(By Paul Vixie, vixie-cron 3.0.1 installation notes)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Linux: Because a PC is a terrible thing to waste.<BR>\n(By komarimf@craft.camp.clarkson.edu, Mark Komarinski)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Never make any mistaeks.\"<BR>\n(Anonymous, in a mail discussion about to a kernel bug report.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','lp1 on fire<BR>\n(One of the more obfuscated kernel messages)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Microsoft is not the answer.<BR>\nMicrosoft is the question.<BR>\nNO (or Linux) is the answer.<BR>\n(Taken from a .signature from someone from the UK, source unknown)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Intel engineering seem to have misheard Intel marketing strategy. The phrase<BR>\nwas \"Divide and conquer\" not \"Divide and cock up\"<BR>\n(By iialan@www.linux.org.uk, Alan Cox)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','In most countries selling harmful things like drugs is punishable.<BR>\nThen howcome people can sell Microsoft software and go unpunished?<BR>\n(By hasku@rost.abo.fi, Hasse Skrifvars)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"If you want to travel around the world and be invited to speak at a lot<BR>\nof different places, just write a Unix operating system.\"<BR>\n(By Linus Torvalds)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"If the future navigation system [for interactive networked services on<BR>\nthe NII] looks like something from Microsoft, it will never work.\"<BR>\n(Chairman of Walt Disney Television & Telecommunications)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Anyone who thinks UNIX is intuitive should be forced to write 5000 lines of <BR>\ncode using nothing but vi or emacs. AAAAACK!<BR>\n(Discussion in comp.os.linux.misc on the intuitiveness of commands, especially<BR>\nEmacs.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"A word to the wise: a credentials dicksize war is usually a bad idea on the<BR>\nnet.\"<BR>\n(David Parsons in c.o.l.development.system, about coding in C.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Even more amazing was the realization that God has Internet access.  I<BR>\nwonder if He has a full newsfeed?\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','+#if defined(__alpha__) && defined(CONFIG_PCI)<BR>\n+       /*<BR>\n+        * The meaning of life, the universe, and everything. Plus<BR>\n+        * this makes the year come out right.<BR>\n+        */<BR>\n+       year -= 42;<BR>\n+#endif<BR>\n(From the patch for 1.3.2: (kernel/time.c), submitted by Marcus Meissner)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','We are using Linux daily to UP our productivity - so UP yours!<BR>\n(Adapted from Pat Paulsen by Joe Sloan)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"What you end up with, after running an operating system concept through<BR>\nthese many marketing coffee filters, is something not unlike plain hot<BR>\nwater.\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','This  message was brought to  you by Linux, the free  unix.<BR>\nWindows without the X is like making love without a partner.<BR>\nSex, Drugs & Linux Rules<BR>\nwin-nt from the people who invented edlin<BR>\napples  have  meant  trouble  since  eden<BR>\nLinux, the way to get rid of boot viruses<BR>\n(By mwikholm@at8.abo.fi, MaDsen Wikholm)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"...Unix, MS-DOS, and Windows NT (also known as the Good, the Bad, and<BR>\nthe Ugly).\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','The chat program is in public domain. This is not the GNU public license. If<BR>\nit breaks then you get to keep both pieces.<BR>\n(Copyright notice for the chat program)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Linux is obsolete<BR>\n(Andrew Tanenbaum)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Problem solving under linux has never been the circus that it is under<BR>\nAIX.\"<BR>\n(By Pete Ehlke in comp.unix.aix)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Linux!  Guerrilla UNIX Development     Venimus, Vidimus, Dolavimus.<BR>\n(By mah@ka4ybr.com, Mark A. Horton KA4YBR)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Linux poses a real challenge for those with a taste for late-night<BR>\nhacking (and/or conversations with God).\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Now I know someone out there is going to claim, \"Well then, UNIX is intuitive,<BR>\nbecause you only need to learn 5000 commands, and then everything else follows<BR>\nfrom that! Har har har!\"<BR>\n(Andy Bates in comp.os.linux.misc, on \"intuitive interfaces\", slightly<BR>\ndefending Macs.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','We are MicroSoft.  You will be assimilated.  Resistance is futile.<BR>\n(Attributed to B.G., Gill Bates)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"We all know Linux is great...it does infinite loops in 5 seconds.\"<BR>\n(Linus Torvalds about the superiority of Linux on the Amsterdam<BR>\nLinux Symposium)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"...very few phenomena can pull someone out of Deep Hack Mode, with two<BR>\nnoted exceptions: being struck by lightning, or worse, your *computer*<BR>\nbeing struck by lightning.\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','..you could spend *all day* customizing the title bar.  Believe me.  I<BR>\nspeak from experience.\"<BR>\n(By Matt Welsh)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Why use Windows, since there is a door?<BR>\n(By fachat@galileo.rhein-neckar.de, Andre Fachat)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"...you might as well skip the Xmas celebration completely, and instead<BR>\nsit in front of your linux computer playing with the<BR>\nall-new-and-improved linux kernel version.\"<BR>\n(By Linus Torvalds)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Who is General Failure and why is he reading my hard disk ?\"<BR>\nMicrosoft spel chekar vor sail, worgs grate !!<BR>\n(By leitner@inf.fu-berlin.de, Felix von Leitner)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"Whip me.  Beat me.  Make me maintain AIX.\"<BR>\n(By Stephan Zielinski)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','Who wants to remember that escape-x-alt-control-left shift-b puts you into<BR>\nsuper-edit-debug-compile mode?<BR>\n(Discussion in comp.os.linux.misc on the intuitiveness of commands, especially<BR>\nEmacs.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('linuxcookie','\"World domination.  Fast\"<BR>\n(By Linus Torvalds)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Having nothing, nothing can he lose.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','If one cannot enjoy reading a book over and over again, there is no use<BR>\nin reading it at all.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He is now rising from affluence to poverty.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','It is by the fortune of God that, in this country, we have three benefits:<BR>\nfreedom of speech, freedom of thought, and the wisdom never to use either.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','If you laid all of our laws end to end, there would be no end.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Grief can take care of itself; but to get the full value of a joy you must<BR>\nhave somebody to divide it with.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Man is the only animal that blushes -- or needs to.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In Marseilles they make half the toilet soap we consume in America, but<BR>\nthe Marseillaise only have a vague theoretical idea of its use, which they<BR>\nhave obtained from books of travel.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In a museum in Havana, there are two skulls of Christopher Columbus,<BR>\n\"one when he was a boy and one when he was a man.\"<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In the first place, God made idiots; this was for practice; then he made<BR>\nschool boards.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Harp not on that string.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','It is a wise father that knows his own child.<BR>\n&nbsp;-- William Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Have a place for everything and keep the thing somewhere else; this is not<BR>\nadvice, it is merely custom.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','It has long been an axiom of mine that the little things are infinitely<BR>\nthe most important.<BR>\n&nbsp;-- Sir Arthur Conan Doyle, \"A Case of Identity\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In the space of one hundred and seventy-six years the Mississippi has<BR>\nshortened itself two hundred and forty-two miles.  Therefore ... in the Old<BR>\nSilurian Period the Mississippi River was upward of one million three hundred<BR>\nthousand miles long ... seven hundred and forty-two years from now the<BR>\nMississippi will be only a mile and three-quarters long.  ... There is<BR>\nsomething fascinating about science.  One gets such wholesome returns of<BR>\nconjecture out of such a trifling investment of fact.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In the Spring, I have counted 136 different kinds of weather inside of<BR>\n24 hours.<BR>\n&nbsp;-- Mark Twain, on New England weather');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He jests at scars who never felt a wound.<BR>\n&nbsp;-- Shakespeare, \"Romeo and Juliet, II. 2\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Its name is Public Opinion.  It is held in reverence.  It settles everything.<BR>\nSome think it is the voice of God.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In the plot, people came to the land; the land loved them; they worked and<BR>\nstruggled and had lots of children.  There was a Frenchman who talked funny<BR>\nand a greenhorn from England who was a fancy-pants but when it came to the<BR>\ncrunch he was all courage.  Those novels would make you retch.<BR>\n&nbsp;-- Canadian novelist Robertson Davies, on the generic Canadian<BR>\n&nbsp;novel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','AWAKE! FEAR! FIRE! FOES! AWAKE!<BR>\n&nbsp;FEAR! FIRE! FOES!<BR>\n&nbsp;AWAKE! AWAKE!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Always do right.  This will gratify some people and astonish the rest.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I do desire we may be better strangers.<BR>\n&nbsp;-- William Shakespeare, \"As You Like It\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','All things that are, are with more spirit chased than enjoyed.<BR>\n&nbsp;-- Shakespeare, \"Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','As flies to wanton boys are we to the gods; they kill us for their sport.<BR>\n&nbsp;-- Shakespeare, \"King Lear\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','All I know is what the words know, and dead things, and that<BR>\nmakes a handsome little sum, with a beginning and a middle and <BR>\nan end, as in the well-built phrase and the long sonata of the dead.<BR>\n&nbsp;-- Samuel Beckett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','All generalizations are false, including this one.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','At once it struck me what quality went to form a man of achievement,<BR>\nespecially in literature, and which Shakespeare possessed so enormously<BR>\n-- I mean negative capability, that is, when a man is capable of being<BR>\nin uncertainties, mysteries, doubts, without any irritable reaching<BR>\nafter fact and reason.<BR>\n&nbsp;-- John Keats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','How apt the poor are to be proud.<BR>\n&nbsp;-- William Shakespeare, \"Twelfth-Night\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','After all, all he did was string together a lot of old, well-known quotations.<BR>\n&nbsp;-- H.L. Mencken, on Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A Tale of Two Cities LITE(tm)<BR>\n&nbsp;-- by Charles Dickens<BR>\n&nbsp;A man in love with a girl who loves another man who looks just<BR>\n&nbsp;like him has his head chopped off in France because of a mean<BR>\n&nbsp;lady who knits.<BR>\n&nbsp;Crime and Punishment LITE(tm)<BR>\n&nbsp;-- by Fyodor Dostoevski<BR>\n&nbsp;A man sends a nasty letter to a pawnbroker, but later<BR>\n&nbsp;feels guilty and apologizes.<BR>\n&nbsp;The Odyssey LITE(tm)<BR>\n&nbsp;-- by Homer<BR>\n&nbsp;After working late, a valiant warrior gets lost on his way home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A classic is something that everyone wants to have read<BR>\nand nobody wants to read.<BR>\n&nbsp;-- Mark Twain, \"The Disappearance of Literature\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A horse!  A horse!  My kingdom for a horse!<BR>\n&nbsp;-- Wm. Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A light wife doth make a heavy husband.<BR>\n&nbsp;-- Wm. Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A kind of Batman of contemporary letters.<BR>\n&nbsp;-- Philip Larkin on Anthony Burgess');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','&nbsp;A man was reading The Canterbury Tales one Saturday morning, when his<BR>\nwife asked \"What have you got there?\"  Replied he, \"Just my cup and Chaucer.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','... A solemn, unsmiling, sanctimonious old iceberg who looked like he<BR>\nwas waiting for a vacancy in the Trinity.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A is for Apple.<BR>\n&nbsp;-- Hester Pryne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','A banker is a fellow who lends you his umbrella when the sun is shining<BR>\nand wants it back the minute it begins to rain.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','\"Elves and Dragons!\" I says to him.  \"Cabbages and potatoes are better<BR>\nfor you and me.\"<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Every why hath a wherefore.<BR>\n&nbsp;-- William Shakespeare, \"A Comedy of Errors\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Extreme fear can neither fight nor fly.<BR>\n&nbsp;-- William Shakespeare, \"The Rape of Lucrece\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Fame is a vapor; popularity an accident; the only earthly certainty is<BR>\noblivion.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Every cloud engenders not a storm.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Familiarity breeds contempt -- and children.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','F.S. Fitzgerald to Hemingway:<BR>\n&nbsp;\"Ernest, the rich are different from us.\"<BR>\nHemingway:<BR>\n&nbsp;\"Yes.  They have more money.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','For courage mounteth with occasion.<BR>\n&nbsp;-- William Shakespeare, \"King John\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','For the fashion of Minas Tirith was such that it was built on seven levels,<BR>\neach delved into a hill, and about each was set a wall, and in each wall<BR>\nwas a gate.<BR>\n&nbsp;-- J.R.R. Tolkien, \"The Return of the King\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to system overview.]<BR>\n&nbsp;');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','For there are moments when one can neither think nor feel.  And if one can<BR>\nneither think nor feel, she thought, where is one?<BR>\n&nbsp;-- Virginia Woolf, \"To the Lighthouse\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to powerfail recovery.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I will honour Christmas in my heart, and try to keep it all the year.  I<BR>\nwill live in the Past, the Present, and the Future.  The Spirits of all<BR>\nThree shall strive within me.  I will not shut out the lessons that they<BR>\nteach.  Oh, tell me that I may sponge away the writing on this stone!<BR>\n&nbsp;-- Charles Dickens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Delores breezed along the surface of her life like a flat stone forever<BR>\nskipping along smooth water, rippling reality sporadically but oblivious<BR>\nto it consistently, until she finally lost momentum, sank, and due to an<BR>\noverdose of flouride as a child which caused her to suffer from chronic<BR>\napathy, doomed herself to lie forever on the floor of her life as useless<BR>\nas an appendix and as lonely as a five-hundred pound barbell in a<BR>\nsteroid-free fitness center.<BR>\n&nbsp;-- Winning sentence, 1990 Bulwer-Lytton bad fiction contest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Delay not, Caesar.  Read it instantly.<BR>\n&nbsp;-- Shakespeare, \"Julius Caesar\" 3,1<BR>\n&nbsp;Here is a letter, read it at your leisure.<BR>\n&nbsp;-- Shakespeare, \"Merchant of Venice\" 5,1<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to I/O system services.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Alas, how love can trifle with itself!<BR>\n&nbsp;-- William Shakespeare, \"The Two Gentlemen of Verona\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','\"... all the modern inconveniences ...\"<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Be careful of reading health books, you might die of a misprint.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Always the dullness of the fool is the whetstone of the wits.<BR>\n&nbsp;-- William Shakespeare, \"As You Like It\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','An honest tale speeds best being plainly told.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Condense soup, not books!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Conscience doth make cowards of us all.<BR>\n&nbsp;-- Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Clothes make the man.  Naked people have little or no influence on society.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','If more of us valued food and cheer and song above hoarded gold, it would<BR>\nbe a merrier world.<BR>\n&nbsp;-- J.R.R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','And do you think (fop that I am) that I could be the Scarlet Pumpernickel?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Big book, big bore.<BR>\n&nbsp;-- Callimachus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','But, for my own part, it was Greek to me.<BR>\n&nbsp;-- William Shakespeare, \"Julius Caesar\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','When in doubt, tell the truth.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Talkers are no good doers.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Go not to the elves for counsel, for they will say both yes and no.<BR>\n&nbsp;-- J.R.R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He hath eaten me out of house and home.<BR>\n&nbsp;-- William Shakespeare, \"Henry IV\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Civilization is the limitless multiplication of unnecessary necessities.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I have never let my schooling interfere with my education.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','\"... an experienced, industrious, ambitious, and often quite often<BR>\npicturesque liar.\"<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I must have a prodigious quantity of mind; it takes me as much as a<BR>\nweek sometimes to make it up.<BR>\n&nbsp;-- Mark Twain, \"The Innocents Abroad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I dote on his very absence.<BR>\n&nbsp;-- William Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','I fell asleep reading a dull book, and I dreamt that I was reading on,<BR>\nso I woke up from sheer boredom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The fashion wears out more apparel than the man.<BR>\n&nbsp;-- William Shakespeare, \"Much Ado About Nothing\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The devil can cite Scripture for his purpose.<BR>\n&nbsp;-- William Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The Bulwer-Lytton fiction contest is held ever year at San Jose State<BR>\nUniv.  by Professor Scott Rice.  It is held in memory of Edward George<BR>\nEarle Bulwer-Lytton (1803-1873), a rather prolific and popular (in his<BR>\ntime) novelist.  He is best known today for having written \"The Last<BR>\nDays of Pompeii.\"<BR>\n&nbsp;Whenever Snoopy starts typing his novel from the top of his doghouse,<BR>\nbeginning \"It was a dark and stormy night...\" he is borrowing from Lord<BR>\nBulwer-Lytton.  This was the line that opened his novel, \"Paul Clifford,\"<BR>\nwritten in 1830.  The full line reveals why it is so bad:<BR>\n&nbsp;It was a dark and stormy night; the rain fell in torrents -- except<BR>\n&nbsp;at occasional intervals, when it was checked by a violent gust of<BR>\n&nbsp;wind which swept up the streets (for it is in London that our scene<BR>\n&nbsp;lies), rattling along the housetops, and fiercely agitating the scanty<BR>\n&nbsp;flame of the lamps that struggled against the darkness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The surest protection against temptation is cowardice.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The difference between a Miracle and a Fact is exactly the difference<BR>\nbetween a mermaid and a seal.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The camel died quite suddenly on the second day, and Selena fretted<BR>\nsullenly and, buffing her already impeccable nails -- not for the first<BR>\ntime since the journey begain -- pondered snidely if this would dissolve<BR>\ninto a vignette of minor inconveniences like all the other holidays spent<BR>\nwith Basil.<BR>\n&nbsp;-- Winning sentence, 1983 Bulwer-Lytton bad fiction contest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The difference between the right word and the almost right word is the<BR>\ndifference between lightning and the lightning bug.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The smallest worm will turn being trodden on.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Tempt not a desperate man.<BR>\n&nbsp;-- William Shakespeare, \"Romeo and Juliet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Let him choose out of my files, his projects to accomplish.<BR>\n&nbsp;-- Shakespeare, \"Coriolanus\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He was part of my dream, of course -- but then I was part of his dream too.<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','In India, \"cold weather\" is merely a conventional phrase and has come into<BR>\nuse through the necessity of having some way to distinguish between weather<BR>\nwhich will melt a brass door-knob and weather which will only make it mushy.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Repartee is something we think of twenty-four hours too late.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','To be or not to be.<BR>\n&nbsp;-- Shakespeare<BR>\nTo do is to be.<BR>\n&nbsp;-- Nietzsche<BR>\nTo be is to do.<BR>\n&nbsp;-- Sartre<BR>\nDo be do be do.<BR>\n&nbsp;-- Sinatra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Never laugh at live dragons.<BR>\n&nbsp;-- Bilbo Baggins [J.R.R. Tolkien, \"The Hobbit\"]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The only people for me are the mad ones -- the ones who are mad to live,<BR>\nmad to talk, mad to be saved, desirous of everything at the same time,<BR>\nthe ones who never yawn or say a commonplace thing, but burn, burn, burn<BR>\nlike fabulous yellow Roman candles.<BR>\n&nbsp;-- Jack Kerouac, \"On the Road\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The man who sets out to carry a cat by its tail learns something that<BR>\nwill always be useful and which never will grow dim or doubtful.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Steady movement is more important than speed, much of the time.  So long<BR>\nas there is a regular progression of stimuli to get your mental hooks<BR>\ninto, there is room for lateral movement.  Once this begins, its rate is<BR>\na matter of discretion.<BR>\n&nbsp;-- Corwin, Prince of Amber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The better part of valor is discretion.<BR>\n&nbsp;-- William Shakespeare, \"Henry IV\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The last thing one knows in constructing a work is what to put first.<BR>\n&nbsp;-- Blaise Pascal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The human race is a race of cowards; and I am not only marching in that<BR>\nprocession but carrying a banner.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The human race has one really effective weapon, and that is laughter.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The abuse of greatness is when it disjoins remorse from power.<BR>\n&nbsp;-- William Shakespeare, \"Julius Caesar\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Too much is just enough.<BR>\n&nbsp;-- Mark Twain, on whiskey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','question = ( to ) ? be : ! be;<BR>\n&nbsp;-- Wm. Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Noise proves nothing.  Often a hen who has merely laid an egg cackles<BR>\nas if she laid an asteroid.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Things past redress and now with me past care.<BR>\n&nbsp;-- William Shakespeare, \"Richard II\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','They spell it \"da Vinci\" and pronounce it \"da Vinchy\".  Foreigners<BR>\nalways spell better than they pronounce.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There is no hunting like the hunting of man, and those who have hunted<BR>\narmed men long enough and liked it, never care for anything else thereafter.<BR>\n&nbsp;-- Ernest Hemingway');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','So she went into the garden to cut a cabbage leaf to make an apple pie;<BR>\nand at the same time a great she-bear, coming up the street pops its head<BR>\ninto the shop. \"What! no soap?\" So he died, and she very imprudently<BR>\nmarried the barber; and there were present the Picninnies, and the Grand<BR>\nPanjandrum himself, with the little round button at top, and they all<BR>\nfell to playing the game of catch as catch can, till the gunpowder ran<BR>\nout at the heels of their boots.<BR>\n&nbsp;-- Samuel Foote');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There is no distinctly native American criminal class except Congress.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There is an old time toast which is golden for its beauty.<BR>\n\"When you ascend the hill of prosperity may you not meet a friend.\"<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Small things make base men proud.<BR>\n&nbsp;-- William Shakespeare, \"Henry VI\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There is always one thing to remember: writers are always selling somebody out.<BR>\n&nbsp;-- Joan Didion, \"Slouching Towards Bethlehem\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','This night methinks is but the daylight sick.<BR>\n&nbsp;-- William Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There is a great discovery still to be made in Literature: that of<BR>\npaying literary men by the quantity they do NOT write.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Suspicion always haunts the guilty mind.<BR>\n&nbsp;-- Wm. Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','My only love sprung from my only hate!<BR>\nToo early seen unknown, and known too late!<BR>\n&nbsp;-- William Shakespeare, \"Romeo and Juliet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','So so is good, very good, very excellent good:<BR>\nand yet it is not; it is but so so.<BR>\n&nbsp;-- William Shakespeare, \"As You Like It\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The secret source of humor is not joy but sorrow; there is no humor in Heaven.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','If two people love each other, there can be no happy end to it.<BR>\n&nbsp;-- Ernest Hemingway');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The very ink with which all history is written is merely fluid prejudice.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The Public is merely a multiplied \"me.\"<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Soap and education are not as sudden as a massacre, but they are more<BR>\ndeadly in the long run.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','There are more things in heaven and earth,<BR>\nHoratio, than are dreamt of in your philosophy.<BR>\n&nbsp;-- Wm. Shakespeare, \"Hamlet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','The ripest fruit falls first.<BR>\n&nbsp;-- William Shakespeare, \"Richard II\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','This was the most unkindest cut of all.<BR>\n&nbsp;-- William Shakespeare, \"Julius Caesar\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','What good is an obscenity trial except to popularize literature?<BR>\n&nbsp;-- Nero Wolfe, \"The League of Frightened Men\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','No violence, gentlemen -- no violence, I beg of you!  Consider the furniture!<BR>\n&nbsp;-- Sherlock Holmes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','What I tell you three times is true.<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','When I was younger, I could remember anything, whether it had happened<BR>\nor not; but my faculties are decaying now and soon I shall be so I<BR>\ncannot remember any but the things that never happened.  It is sad to<BR>\ngo to pieces like this but we all have to do it.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Perilous to all of us are the devices of an art deeper than we ourselves<BR>\npossess.<BR>\n&nbsp;-- Gandalf the Grey [J.R.R. Tolkien, \"Lord of the Rings\"]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Oh what a tangled web we weave, when first we practice to deceive.<BR>\n&nbsp;-- Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Rebellion lay in his way, and he found it.<BR>\n&nbsp;-- William Shakespeare, \"Henry IV\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','We should be careful to get out of an experience only the wisdom that is<BR>\nin it - and stay there, lest we be like the cat that sits down on a hot<BR>\nstove-lid.  She will never sit down on a hot stove-lid again - and that<BR>\nis well; but also she will never sit down on a cold one any more.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Persons attempting to find a motive in this narrative will be prosecuted;<BR>\npersons attempting to find a moral in it will be banished; persons attempting<BR>\nto find a plot in it will be shot.  By Order of the Author<BR>\n&nbsp;-- Mark Twain, \"Tom Sawyer\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Patch griefs with proverbs.<BR>\n&nbsp;-- William Shakespeare, \"Much Ado About Nothing\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Reader, suppose you were an idiot.  And suppose you were a member of<BR>\nCongress.  But I repeat myself.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Water, taken in moderation cannot hurt anybody.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Truth is the most valuable thing we have -- so let us economize it.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Unless hours were cups of sack, and minutes capons, and clocks the tongues<BR>\nof bawds, and dials the signs of leaping houses, and the blessed sun himself<BR>\na fair, hot wench in flame-colored taffeta, I see no reason why thou shouldst<BR>\nbe so superfluous to demand the time of the day.  I wasted time and now doth<BR>\ntime waste me.<BR>\n&nbsp;-- William Shakespeare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Your manuscript is both good and original, but the part that is good is not<BR>\noriginal and the part that is original is not good.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','You never have to change anything you got up in the middle of the night<BR>\nto write.<BR>\n&nbsp;-- Saul Bellow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','You may my glories and my state dispose,<BR>\nBut not my griefs; still am I king of those.<BR>\n&nbsp;-- William Shakespeare, \"Richard II\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','You mentioned your name as if I should recognize it, but beyond the<BR>\nobvious facts that you are a bachelor, a solicitor, a freemason, and<BR>\nan asthmatic, I know nothing whatever about you.<BR>\n&nbsp;-- Sherlock Holmes, \"The Norwood Builder\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','\"You have been in Afghanistan, I perceive.\"<BR>\n&nbsp;-- Sir Arthur Conan Doyle, \"A Study in Scarlet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Many pages make a thick book, except for pocket Bibles which are on very<BR>\nvery thin paper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Writing is easy; all you do is sit staring at the blank sheet of paper until<BR>\ndrops of blood form on your forehead.<BR>\n&nbsp;-- Gene Fowler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','&nbsp;My dear People.<BR>\n&nbsp;My dear Bagginses and Boffins, and my dear Tooks and Brandybucks,<BR>\nand Grubbs, and Chubbs, and Burrowses, and Hornblowers, and Bolgers,<BR>\nBracegirdles, Goodbodies, Brockhouses and Proudfoots.  Also my good<BR>\nSackville Bagginses that I welcome back at last to Bag End.  Today is my<BR>\none hundred and eleventh birthday: I am eleventy-one today!\"<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','No group of professionals meets except to conspire against the public at large.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Work consists of whatever a body is obliged to do.<BR>\nPlay consists of whatever a body is not obliged to do.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Must I hold a candle to my shames?<BR>\n&nbsp;-- William Shakespeare, \"The Merchant of Venice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Many pages make a thick book.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Whenever you find that you are on the side of the majority, it is time<BR>\nto reform.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','When you are about to die, a wombat is better than no company at all.<BR>\n&nbsp;-- Roger Zelazny, \"Doorways in the Sand\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Wrinkles should merely indicate where smiles have been.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','It is right that he too should have his little chronicle, his memories,<BR>\nhis reason, and be able to recognize the good in the bad, the bad in the<BR>\nworst, and so grow gently old all down the unchanging days and die one<BR>\nday like any other day, only shorter.<BR>\n&nbsp;-- Samuel Beckett, \"Malone Dies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Kindness is a language which the deaf can hear and the blind can read.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He that breaks a thing to find out what it is has left the path of wisdom.<BR>\n&nbsp;-- J.R.R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','It usually takes more than three weeks to prepare a good impromptu speech.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','His followers called him Mahasamatman and said he was a god.  He preferred<BR>\nto drop the Maha- and the -atman, however, and called himself Sam.  He never<BR>\nclaimed to be a god.  But then, he never claimed not to be a god.  Circum-<BR>\nstances being what they were, neither admission could be of any benefit.<BR>\nSilence, though, could.  It was in the days of the rains that their prayers<BR>\nwent up, not from the fingering of knotted prayer cords or the spinning of<BR>\nprayer wheels, but from the great pray-machine in the monastery of Ratri,<BR>\ngoddess of the Night.  The high-frequency prayers were directed upward through<BR>\nthe atmosphere and out beyond it, passing into that golden cloud called the<BR>\nBridge of the Gods, which circles the entire world, is seen as a bronze<BR>\nrainbow at night and is the place where the red sun becomes orange at midday.<BR>\nSome of the monks doubted the orthodoxy of this prayer technique...<BR>\n&nbsp;-- Roger Zelazny, \"Lord of Light\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','&nbsp;You will remember, Watson, how the dreadful business of the<BR>\nAbernetty family was first brought to my notice by the depth which the<BR>\nparsley had sunk into the butter upon a hot day.<BR>\n&nbsp;-- Sherlock Holmes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','You tread upon my patience.<BR>\n&nbsp;-- William Shakespeare, \"Henry IV\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','She is not refined.  She is not unrefined.  She keeps a parrot.<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','He that is giddy thinks the world turns round.<BR>\n&nbsp;-- William Shakespeare, \"The Taming of the Shrew\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Hell is empty and all the devils are here.<BR>\n&nbsp;-- Wm. Shakespeare, \"The Tempest\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','No live organism can continue for long to exist sanely under conditions of<BR>\nabsolute reality; even larks and katydids are supposed, by some, to dream.<BR>\nHill House, not sane, stood by itself against its hills, holding darkness<BR>\nwithin; it had stood so for eighty years and might stand for eighty more.<BR>\nWithin, walls continued upright, bricks met neatly, floors were firm, and<BR>\ndoors were sensibly shut; silence lay steadily against the wood and stone<BR>\nof Hill House, and whatever walked there, walked alone.<BR>\n&nbsp;-- Shirley Jackson, \"The Haunting of Hill House\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('literature','Seeing that death, a necessary end,<BR>\nWill come when it will come.<BR>\n&nbsp;-- William Shakespeare, \"Julius Caesar\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','\"Maybe we should think of this as one perfect week... where we found each<BR>\nother, and loved each other... and then let each other go before anyone<BR>\nhad to seek professional help.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','In a great romance, each person basically plays a part that the<BR>\nother really likes.<BR>\n&nbsp;-- Elizabeth Ashley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The perfect lover is one who turns into a pizza at 4:00 A.M.<BR>\n&nbsp;-- Charles Pierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I think a relationship is like a shark.  It has to constantly move forward<BR>\nor it dies.  Well, what we have on our hands here is a dead shark.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I never loved another person the way I loved myself.<BR>\n&nbsp;-- Mae West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','If only you knew she loved you, you could face the uncertainty of<BR>\nwhether you love her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','A kiss is a course of procedure, cunningly devised, for the mutual<BR>\nstoppage of speech at a moment when words are superfluous.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Give me chastity and continence, but not just now.<BR>\n&nbsp;-- St. Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','His heart was yours from the first moment that you met.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Absence is to love what wind is to fire.  It extinguishes the small,<BR>\nit enkindles the great.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Falling in love is a lot like dying.  You never get to do it enough to<BR>\nbecome good at it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Finish the sentence below in 25 words or less:<BR>\n&nbsp;\"Love is what you feel just before you give someone a good ...\"<BR>\n&nbsp;Mail your answer along with the top half of your supervisor to:<BR>\n&nbsp;P.O. Box 35<BR>\n&nbsp;Baffled Greek, Michigan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I am two fools, I know, for loving, and for saying so.<BR>\n&nbsp;-- John Donne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','All the passions make us commit faults; love makes us commit the most<BR>\nridiculous ones.<BR>\n&nbsp;-- La Rochefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Distrust all those who love you extremely upon a very slight acquaintance<BR>\nand without any visible reason.<BR>\n&nbsp;-- Lord Chesterfield');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Bondage maybe, discipline never!<BR>\n&nbsp;-- T.K.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','A woman was in love with fourteen soldiers.  It was clearly platoonic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Absence diminishes mediocre passions and increases great ones,<BR>\nas the wind blows out candles and fans fires.<BR>\n&nbsp;-- La Rochefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Always there remain portions of our heart into which no one is able to enter,<BR>\ninvite them as we may.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Absence in love is like water upon fire; a little quickens, but much<BR>\nextinguishes it.<BR>\n&nbsp;-- Hannah More');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I can mend the break of day, heal a broken heart, and provide temporary<BR>\nrelief to nymphomaniacs.<BR>\n&nbsp;-- Larry Lee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Let us live!!!<BR>\nLet us love!!!<BR>\nLet us share the deepest secrets of our souls!!!<BR>\n&nbsp;You first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','If love is the answer, could you rephrase the question?<BR>\n&nbsp;-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Just how difficult it is to write biography can be reckoned by anybody<BR>\nwho sits down and considers just how many people know the real truth<BR>\nabout his or her love affairs.<BR>\n&nbsp;-- Rebecca West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','It is far better to be deceived than to be undeceived by those we love.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I used to be Snow White, but I drifted.<BR>\n&nbsp;-- Mae West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','One expresses well the love he does not feel.<BR>\n&nbsp;-- J.A. Karr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','\"He did decide, though, that with more time and a great deal of mental<BR>\neffort, he could probably turn the activity into an acceptable perversion.\"<BR>\n&nbsp;-- Mick Farren, \"When Gravity Fails\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','God is love, but get it in writing.<BR>\n&nbsp;-- Gypsy Rose Lee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','People think love is an emotion.  Love is good sense.<BR>\n&nbsp;-- Ken Kesey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The onset and the waning of love make themselves felt in the uneasiness<BR>\nexperienced at being alone together.<BR>\n&nbsp;-- Jean de la Bruyere');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Sorry never means having your say to love.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Oh, love is real enough, you will find it some day, but it has one<BR>\narch-enemy -- and that is life.<BR>\n&nbsp;-- Jean Anouilh, \"Ardele\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','May your SO always know when you need a hug.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is the triumph of imagination over intelligence.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Nature abhors a virgin -- a frozen asset.<BR>\n&nbsp;-- Clare Booth Luce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is in the offing.<BR>\n&nbsp;-- The Homicidal Maniac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is like the measles; we all have to go through it.<BR>\n&nbsp;-- Jerome K. Jerome');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is never asking why?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love and scandal are the best sweeteners of tea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love at first sight is one of the greatest labor-saving devices the<BR>\nworld has ever seen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love cannot be much younger than the lust for murder.<BR>\n&nbsp;-- Sigmund Freud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love tells us many things that are not so.<BR>\n&nbsp;-- Krainian Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The person you rejected yesterday could make you happy, if you say yes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Without love intelligence is dangerous;<BR>\nwithout intelligence love is not enough.<BR>\n&nbsp;-- Ashley Montagu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The seven year itch comes from fooling around during the fourth, fifth,<BR>\nand sixth years.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The sweeter the apple, the blacker the core --<BR>\nScratch a lover and find a foe!<BR>\n&nbsp;-- Dorothy Parker, \"Ballad of a Great Weariness\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The story of the butterfly:<BR>\n&nbsp;\"I was in Bogota and waiting for a lady friend.  I was in love,<BR>\na long time ago.  I waited three days.  I was hungry but could not go<BR>\nout for food, lest she come and I not be there to greet her.  Then, on<BR>\nthe third day, I heard a knock.\"<BR>\n&nbsp;\"I hurried along the old passage and there, in the sunlight,<BR>\nthere was nothing.\"<BR>\n&nbsp;\"Just,\" Vance Joy said, \"a butterfly, flying away.\"<BR>\n&nbsp;-- Peter Carey, BLISS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','When your life is a leaf that the seasons tear off and condemn<BR>\nThey will bind you with love that is graceful and green as a stem.<BR>\n&nbsp;-- Leonard Cohen, \"Sisters of Mercy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','To be loved is very demoralizing.<BR>\n&nbsp;-- Katharine Hepburn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','To fear love is to fear life, and those who fear life are already three<BR>\nparts dead.<BR>\n&nbsp;-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','True happiness will be found only in true love.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','There is no fear in love; but perfect love casteth out fear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','There is only one way to be happy by means of the heart -- to have none.<BR>\n&nbsp;-- Paul Bourget');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Timing must be perfect now.  Two-timing must be better than perfect.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The way to love anything is to realize that it might be lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','What is irritating about love is that it is a crime that requires an accomplice.<BR>\n&nbsp;-- Charles Baudelaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Support wildlife -- vote for an orgy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The little pieces of my life I give to you, with love, to make a quilt<BR>\nto keep away the cold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','That is the true season of love, when we believe that we alone can love,<BR>\nthat no one could have loved so before us, and that no one will love<BR>\nin the same way as us.<BR>\n&nbsp;-- Johann Wolfgang von Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The magic of our first love is our ignorance that it can ever end.<BR>\n&nbsp;-- Benjamin Disraeli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love -- the last of the serious diseases of childhood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Lonely is a man without love.<BR>\n&nbsp;-- Englebert Humperdinck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love conquers all things; let us too surrender to love.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is being stupid together.<BR>\n&nbsp;-- Paul Valery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is a snowmobile racing across the tundra, which suddenly flips<BR>\nover, pinning you underneath.  At night the ice weasels come.<BR>\n&nbsp;-- Matt Groening, \"Love is Hell\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is sentimental measles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is not enough, but it sure helps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is staying up all night with a sick child, or a healthy adult.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is a grave mental disease.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is the process of my leading you gently back to yourself.<BR>\n&nbsp;-- Saint Exupery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is the only game that is not called on account of darkness.<BR>\n&nbsp;-- M. Hirschfield');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Once the realization is accepted that even between the closest human beings<BR>\ninfinite distances continue to exist, a wonderful living side by side can<BR>\ngrow up, if they succeed in loving the distance between them which makes it<BR>\npossible for each to see each other whole against the sky.<BR>\n&nbsp;-- Rainer Rilke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Of all forms of caution, caution in love is the most fatal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The giraffe you thought you offended last week is willing to be nuzzled today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The heart is wiser than the intellect.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','The heart has its reasons which reason knows nothing of.<BR>\n&nbsp;-- Blaise Pascal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Love is like a friendship caught on fire.  In the beginning a flame, very<BR>\npretty, often hot and fierce, but still only light and flickering.  As love<BR>\ngrows older, our hearts mature and our love becomes as coals, deep-burning<BR>\nand unquenchable.<BR>\n&nbsp;-- Bruce Lee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I love you, not only for what you are, but for what I am when I am with you.<BR>\n&nbsp;-- Roy Croft');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','I loved her with a love thirsty and desperate. I felt that we two might commit<BR>\nsome act so atrocious that the world, seeing us, would find it irresistible.<BR>\n&nbsp;-- Gene Wolfe, \"The Shadow of the Torturer\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','Hearts will never be practical until they can be made unbreakable.<BR>\n&nbsp;-- The Wizard of Oz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('love','In love, she who gives her portrait promises the original.<BR>\n&nbsp;-- Bruton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','\"Do not meddle in the affairs of wizards, for you are crunchy and good<BR>\nwith ketchup.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','An ancient proverb summed it up: when a wizard is tired of looking for<BR>\nbroken glass in his dinner, it ran, he is tired of life.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Do not meddle in the affairs of wizards, for they become soggy and hard to<BR>\nlight.<BR>\n&nbsp;Do not throw cigarette butts in the urinal, for they are subtle and<BR>\nquick to anger.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','A Thaum is the basic unit of magical strength.  It has been universally<BR>\nestablished as the amount of magic needed to create one small white pigeon<BR>\nor three normal sized billiard balls.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','\"A wizard cannot do everything; a fact most magicians are reticent to admit,<BR>\nlet alone discuss with prospective clients.  Still, the fact remains that <BR>\nthere are certain objects, and people, that are, for one reason or another, <BR>\ncompletely immune to any direct magical spell.  It is for this group of<BR>\nbeings that the magician learns the subtleties of using indirect spells.<BR>\nIt also does no harm, in dealing with these matters, to carry a large club<BR>\nnear your person at all times.\"<BR>\n&nbsp;-- The Teachings of Ebenezum, Volume VIII');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','&nbsp;\"Verily and forsooth,\" replied Goodgulf darkly.  \"In the past year<BR>\nstrange and fearful wonders I have seen.  Fields sown with barley reap<BR>\ncrabgrass and fungus, and even small gardens reject their artichoke hearts.<BR>\nThere has been a hot day in December and a blue moon.  Calendars are made with<BR>\na month of Sundays and a blue-ribbon Holstein bore alive two insurance<BR>\nsalesmen.  The earth splits and the entrails of a goat were found tied in<BR>\nsquare knots.  The face of the sun blackens and the skies have rained down<BR>\nsoggy potato chips.\"<BR>\n&nbsp;\"But what do all these things mean?\" gasped Frito.<BR>\n&nbsp;\"Beats me,\" said Goodgulf with a shrug, \"but I thought it made good<BR>\ncopy.\"<BR>\n&nbsp;-- Harvard Lampoon, \"Bored of the Rings\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Watch Rincewind.<BR>\n&nbsp;Look at him.  Scrawny, like most wizards, and clad in a dark red robe on<BR>\nwhich a few mystic sigils were embroidered in tarnished sequins. Some might<BR>\nhave taken him for a mere apprentice enchanter who had run away from his<BR>\nmaster out of defiance, boredom, fear and a lingering taste for<BR>\nheterosexuality.  Yet around his neck was a chain bearing the bronze octagon<BR>\nthat marked him as an alumnus of Unseen University, the high school of magic<BR>\nwhose time-and-space transcendent campus is never precisely Here or There.<BR>\nGraduates were usually destined for mageship at least, but Rincewind--after<BR>\nan unfortunate event--had left knowing only one spell and made a living of<BR>\nsorts around the town by capitalizing on an innate gift for languages.  He<BR>\navoided work as a rule, but had a quickness of wit that put his<BR>\nacquaintances in mind of a bright rodent.<BR>\n&nbsp;-- Terry Pratchett, \"The Colour of Magic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Using words to describe magic is like using a screwdriver to cut roast beef.<BR>\n&nbsp;-- Tom Robbins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','What is a magician but a practising theorist?<BR>\n&nbsp;-- Obi-Wan Kenobi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Somewhere, just out of sight, the unicorns are gathering.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','There are those who claim that magic is like the tide; that it swells and<BR>\nfades over the surface of the earth, collecting in concentrated pools here<BR>\nand there, almost disappearing from other spots, leaving them parched for<BR>\nwonder.  There are also those who believe that if you stick your fingers up<BR>\nyour nose and blow, it will increase your intelligence.<BR>\n&nbsp;-- The Teachings of Ebenezum, Volume VII');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','No matter how subtle the wizard, a knife in the shoulder blades will seriously<BR>\ncramp his style.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Knowledge is power -- knowledge shared is power lost.<BR>\n&nbsp;-- Aleister Crowley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Magic is always the best solution -- especially reliable magic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Unseen University had never admitted women, muttering something about<BR>\nproblems with the plumbing, but the real reason was an unspoken dread that<BR>\nif women were allowed to mess around with magic they would probably be<BR>\nembarrassingly good at it ...<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','\"How do you know she is a unicorn?\" Molly demanded.  \"And why were you afraid<BR>\nto let her touch you?  I saw you.  You were afraid of her.\"<BR>\n&nbsp;\"I doubt that I will feel like talking for very long,\" the cat<BR>\nreplied without rancor.  \"I would not waste time in foolishness if I were <BR>\nyou.  As to your first question, no cat out of its first fur can ever be<BR>\ndeceived by appearances.  Unlike human beings, who enjoy them.  As for your<BR>\nsecond question --\"  Here he faltered, and suddenly became very interested<BR>\nin washing; nor would he speak until he had licked himself fluffy and then<BR>\nlicked himself smooth again.  Even then he would not look at Molly, but <BR>\nexamined his claws.<BR>\n&nbsp;\"If she had touched me,\" he said very softly, \"I would have been<BR>\nhers and not my own, not ever again.\"<BR>\n&nbsp;-- Peter S. Beagle, \"The Last Unicorn\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Chaos is King and Magic is loose in the world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','It is well known that *things* from undesirable universes are always seeking<BR>\nan entrance into this one, which is the psychic equivalent of handy for the<BR>\nbuses and closer to the shops.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','Do what thou wilt shall be the whole of the Law.<BR>\n&nbsp;-- Aleister Crowley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('magic','When I say the magic word to all these people, they will vanish forever.<BR>\nI will then say the magic words to you, and you, too, will vanish -- never<BR>\nto be seen again.<BR>\n&nbsp;-- Kurt Vonnegut Jr., \"Between Time and Timbuktu\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','A CODE OF ETHICAL BEHAVIOR FOR PATIENTS:<BR>\n&nbsp;4. DO NOT COMPLAIN IF THE TREATMENT FAILS TO BRING RELIEF.<BR>\n&nbsp;You must believe that your doctor has achieved a deep insight into<BR>\n&nbsp;the true nature of your illness, which transcends any mere permanent<BR>\n&nbsp;disability you may have experienced.<BR>\n&nbsp;5. NEVER ASK YOUR DOCTOR TO EXPLAIN WHAT HE IS DOING OR WHY HE IS DOING IT.<BR>\n&nbsp;It is presumptuous to assume that such profound matters could be<BR>\n&nbsp;explained in terms that you would understand.<BR>\n&nbsp;6. SUBMIT TO NOVEL EXPERIMANTAL TREATMENT READILY.<BR>\n&nbsp;Though the surgery may not benefit you directly, the resulting<BR>\n&nbsp;research paper will surely be of widespread interest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Neurotics build castles in the sky,<BR>\nPsychotics live in them,<BR>\nAnd psychiatrists collect the rent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','The trouble with heart disease is that the first symptom is often hard to<BR>\ndeal with: death.<BR>\n&nbsp;-- Michael Phelps');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Human cardiac catheterization was introduced by Werner Forssman in 1929.<BR>\nIgnoring his department chief, and tying his assistant to an operating<BR>\ntable to prevent her interference, he placed a ureteral catheter into<BR>\na vein in his arm, advanced it to the right atrium [of his heart], and<BR>\nwalked upstairs to the x-ray department where he took the confirmatory<BR>\nx-ray film.  In 1956, Dr. Forssman was awarded the Nobel Prize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','I get my exercise acting as pallbearer to my friends who exercise.<BR>\n&nbsp;-- Chauncey Depew');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Paralysis through analysis.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Proper treatment will cure a cold in seven days, but left to itself,<BR>\na cold will hang on for a week.<BR>\n&nbsp;-- Darrell Huff');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','The secret of healthy hitchhiking is to eat junk food.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Some people need a good imaginary cure for their painful imaginary ailment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Pushing 40 is exercise enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Psychiatry is the care of the id by the odd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','The New England Journal of Medicine reports that 9 out of 10 doctors agree<BR>\nthat 1 out of 10 doctors is an idiot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Cure the disease and kill the patient.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Death has been proven to be 99% fatal in laboratory rats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Never go to a doctor whose office plants have died.<BR>\n&nbsp;-- Erma Bombeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Ever notice that the word \"therapist\" breaks down into \"the rapist\"?<BR>\nSimple coincidence?<BR>\nMaybe...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Anyone who goes to a psychiatrist ought to have his head examined.<BR>\n&nbsp;-- Samuel Goldwyn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','After twelve years of therapy my psychiatrist said something that<BR>\nbrought tears to my eyes.  He said, \"No hablo ingles.\"<BR>\n&nbsp;-- Ronnie Shakes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','A woman physician has made the statement that smoking is neither<BR>\nphysically defective nor morally degrading, and that nicotine, even<BR>\nwhen indulged to in excess, is less harmful than excessive petting.\"<BR>\n&nbsp;-- Purdue Exponent, Jan 16, 1925');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Stress has been pinpointed as a major cause of illness.  To avoid overload<BR>\nand burnout, keep stress out of your life.  Give it to others instead.  Learn<BR>\nthe \"Gaslight\" treatment, the \"Are you talking to me?\" technique, and the<BR>\n\"Do you feel okay?  You look pale.\" approach.  Start with negotiation and<BR>\nimplication.  Advance to manipulation and humiliation.  Above all, relax<BR>\nand have a nice day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Sometimes the best medicine is to stop taking something.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','The Vet Who Surprised A Cow<BR>\n&nbsp;In the course of his duties in August 1977, a Dutch veterinary<BR>\nsurgeon was required to treat an ailing cow.  To investigate its internal<BR>\ngases he inserted a tube into that end of the animal not capable of facial<BR>\nexpression and struck a match.  The jet of flame set fire first to some<BR>\nbales of hay and then to the whole farm causing damage estimate at L45,000. <BR>\nThe vet was later fined L140 for starting a fire in a manner surprising to<BR>\nthe magistrates.  The cow escaped with shock.<BR>\n&nbsp;-- Stephen Pile, \"The Book of Heroic Failures\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Pushing 30 is exercise enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Show me a sane man and I will cure him for you.<BR>\n&nbsp;-- C.G. Jung');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Psychoanalysis is that mental illness for which it regards itself a therapy.<BR>\n&nbsp;-- Karl Kraus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Straw?  No, too stupid a fad.  I put soot on warts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','The real reason psychology is hard is that psychologists are trying to<BR>\ndo the impossible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Laetrile is the pits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','&nbsp;\"I keep seeing spots in front of my eyes.\"<BR>\n&nbsp;\"Did you ever see a doctor?\"<BR>\n&nbsp;\"No, just spots.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','&nbsp;page 46<BR>\n...a report citing a study by Dr. Thomas C. Chalmers, of the Mount Sinai<BR>\nMedical Center in New York, which compared two groups that were being used<BR>\nto test the theory that ascorbic acid is a cold preventative.  \"The group<BR>\non placebo who thought they were on ascorbic acid,\" says Dr. Chalmers,<BR>\n\"had fewer colds than the group on ascorbic acid who thought they were<BR>\non placebo.\"<BR>\n&nbsp;page 56<BR>\nThe placebo is proof that there is no real separation between mind and body.<BR>\nIllness is always an interaction between both.  It can begin in the mind and<BR>\naffect the body, or it can begin in the body and affect the mind, both of<BR>\nwhich are served by the same bloodstream.  Attempts to treat most mental<BR>\ndiseases as though they were completely free of physical causes and attempts<BR>\nto treat most bodily diseases as though the mind were in no way involved must<BR>\nbe considered archaic in the light of new evidence about the way the human<BR>\nbody functions.<BR>\n&nbsp;-- Norman Cousins,<BR>\n&nbsp;\"Anatomy of an Illness as Perceived by the Patient\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','His ideas of first-aid stopped short of squirting soda water.<BR>\n&nbsp;-- P.G. Wodehouse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','\"Good health\" is merely the slowest rate at which one can die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','I got the bill for my surgery.  Now I know what those doctors were<BR>\nwearing masks for.<BR>\n&nbsp;-- James Boren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Health nuts are going to feel stupid someday, lying in hospitals dying<BR>\nof nothing.<BR>\n&nbsp;-- Redd Foxx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Happiness is good health and a bad memory.<BR>\n&nbsp;-- Ingrid Bergman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','If a person (a) is poorly, (b) receives treatment intended to make him better,<BR>\nand (c) gets better, then no power of reasoning known to medical science can<BR>\nconvince him that it may not have been the treatment that restored his health.<BR>\n&nbsp;-- Sir Peter Medawar, \"The Art of the Soluble\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Health is merely the slowest possible rate at which one can die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','New England Life, of course.  Why do you ask?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Be a better psychiatrist and the world will beat a psychopath to your door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','[From an announcement of a congress of the International Ontopsychology<BR>\nAssociation, in Rome]:<BR>\n&nbsp;The Ontopsychological school, availing itself of new research criteria and<BR>\nof a new telematic epistemology, maintains that social modes do not spring<BR>\nfrom dialectics of territory or of class, or of consumer goods, or of means<BR>\nof power, but rather from dynamic latencies capillarized in millions of<BR>\nindividuals in system functions which, once they have reached the event<BR>\nmaturation, burst forth in catastrophic phenomenology engaging a suitable<BR>\nstereotype protagonist or duty marionette (general, president, political<BR>\nparty, etc.) to consummate the act of social schizophrenia in mass genocide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Better to use medicines at the outset than at the last moment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','Dental health is next to mental health.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('medicine','\"... the Mayo Clinic, named after its founder, Dr. Ted Clinic ...\"<BR>\n&nbsp;-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','His designs were strictly honourable, as the phrase is: that is, to rob<BR>\na lady of her fortune by way of marriage.<BR>\n&nbsp;-- Henry Fielding, \"Tom Jones\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','How much for your women?  I want to buy your daughter... how much for<BR>\nthe little girl?<BR>\n&nbsp;-- Jake Blues, \"The Blues Brothers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','For a young man, not yet: for an old man, never at all.<BR>\n&nbsp;-- Diogenes, asked when a man should marry<BR>\n&nbsp;When should a man marry?  A young man, not yet; an elder man, not at all.<BR>\n&nbsp;-- Sir Francis Bacon, \"Of Marriage and Single Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','For a young man, not yet: for an old man, never at all.<BR>\n&nbsp;-- Diogenes, asked when a man should marry<BR>\n&nbsp;When should a man marry?  A young man, not yet; an elder man, not at all.<BR>\n&nbsp;-- Sir Francis Bacon, \"Of Marriage and Single Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','For thirty years a certain man went to spend every evening with Mme. ___.<BR>\nWhen his wife died his friends believed he would marry her, and urged<BR>\nhim to do so.  \"No, no,\" he said: \"if I did, where should I have to<BR>\nspend my evenings?\"<BR>\n&nbsp;-- Chamfort');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Flirting is the gentle art of making a man feel pleased with himself.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;Equality is not when a female Einstein gets promoted to assistant<BR>\nprofessor; equality is when a female schlemiel moves ahead as fast as a<BR>\nmale schlemiel.<BR>\n&nbsp;-- Ewald Nyquist');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','For I swore I would stay a year away from her; out and alas!<BR>\nbut with break of day I went to make supplication.<BR>\n&nbsp;-- Paulus Silentarius, c. 540 A.D.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Every man who is high up likes to think that he has done it all himself,<BR>\nand the wife smiles and lets it go at that.<BR>\n&nbsp;-- Barrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Dull women have immaculate homes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Economists are still trying to figure out why the girls with the least<BR>\nprinciple draw the most interest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;During a visit to America, Winston Churchill was invited to a buffet<BR>\nluncheon at which cold fried chicken was served.  Returning for a second<BR>\nhelping, he asked politely, \"May I have some breast?\"<BR>\n&nbsp;\"Mr. Churchill,\" replied the hostess, \"in this country we ask for<BR>\nwhite meat or dark meat.\"  Churchill apologized profusely.<BR>\n&nbsp;The following morning, the lady received a magnificent orchid from<BR>\nher guest of honor.  The accompanying card read: \"I would be most obliged if<BR>\nyou would pin this on your white meat.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Do you think your mother and I should have lived comfortably so long<BR>\ntogether if ever we had been married?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Do not permit a woman to ask forgiveness, for that is only the first<BR>\nstep.  The second is justification of herself by accusation of you.<BR>\n&nbsp;-- DeGourmont');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Eighty percent of married men cheat in America.  The rest cheat in Europe.<BR>\n&nbsp;-- Jackie Mason');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Be circumspect in your liaisons with women.  It is better to be seen at<BR>\nthe opera with a man than at mass with a woman.<BR>\n&nbsp;-- De Maintenon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I want to marry a girl just like the girl that married dear old dad.<BR>\n&nbsp;-- Freud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If it were not for the presents, an elopement would be preferable.<BR>\n&nbsp;-- George Ade, \"Forty Modern Fables\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men say of women what pleases them; women do with men what pleases them.<BR>\n&nbsp;-- DeSegur');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Money is a powerful aphrodisiac.  But flowers work almost as well.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men never make passes at girls wearing glasses.<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men have as exaggerated an idea of their rights as women have of their wrongs.<BR>\n&nbsp;-- E.W. Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men seldom show dimples to girls who have pimples.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men have a much better time of it than women; for one thing they marry later;<BR>\nfor another thing they die earlier.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men still remember the first kiss after women have forgotten the last.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marry in haste and everyone starts counting the months.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men who cherish for women the highest respect are seldom popular with them.<BR>\n&nbsp;-- Joseph Addison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men are always ready to respect anything that bores them.<BR>\n&nbsp;-- Marilyn Monroe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Never sleep with a woman whose troubles are worse than your own.<BR>\n&nbsp;-- Nelson Algren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is learning about women the hard way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is based on the theory that when a man discovers a brand of beer<BR>\nexactly to his taste he should at once throw up his job and go to work<BR>\nin the brewery.<BR>\n&nbsp;-- George Jean Nathan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is like twirling a baton, turning handsprings, or eating with<BR>\nchopsticks.  It looks easy until you try it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is a three ring circus: engagement ring, wedding ring, and suffering.<BR>\n&nbsp;-- Roger Price');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is a romance in which the hero dies in the first chapter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is an institution in which two undertake to become one, and one<BR>\nundertakes to become nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is low down, but you spend the rest of your life paying for it.<BR>\n&nbsp;-- Baskins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is a ghastly public confession of a strictly private intention.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage causes dating problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Many husbands go broke on the money their wives save on sales.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is not merely sharing the fettucine, but sharing the<BR>\nburden of finding the fettucine restaurant in the first place.<BR>\n&nbsp;-- Calvin Trillin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Love makes fools, marriage cuckolds, and patriotism malevolent imbeciles.<BR>\n&nbsp;-- Paul Leautaud, \"Passe-temps\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Love is an obsessive delusion that is cured by marriage.<BR>\n&nbsp;-- Dr. Karl Bowman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Macho does not prove mucho.<BR>\n&nbsp;-- Zsa Zsa Gabor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Lots of girls can be had for a song.  Unfortunately, it often turns out to<BR>\nbe the wedding march.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Love is an ideal thing, marriage a real thing; a confusion of the real<BR>\nwith the ideal never goes unpunished.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Many a man in love with a dimple makes the mistake of marrying the<BR>\nwhole girl.<BR>\n&nbsp;-- Stephen Leacock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Little girls, like butterflies, need no excuse.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is the process of finding out what kind of man your wife would<BR>\nhave preferred.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Life in this society being, at best, an utter bore and no aspect of society<BR>\nbeing at all relevant to women, there remains to civic-minded responsible<BR>\nthrill-seeking females only to overthrow the government, eliminate the money<BR>\nsystem, institute complete automation and destroy the male sex.<BR>\n&nbsp;-- Valerie Solanas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Like all young men, you greatly exaggerate the difference between one<BR>\nyoung woman and another.<BR>\n&nbsp;-- George Bernard Shaw, \"Major Barbara\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Life begins at the centerfold and expands outward.<BR>\n&nbsp;-- Miss November, 1966');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Matrimony is the root of all evil.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;Once upon a time there were three brothers who were knights<BR>\nin a certain kingdom.  And, there was a Princess in a neighboring kingdom<BR>\nwho was of marriageable age.  Well, one day, in full armour, their horses,<BR>\nand their page, the three brothers set off to see if one of them could<BR>\nwin her hand.  The road was long and there were many obstacles along the<BR>\nway, robbers to be overcome, hard terrain to cross.  As they coped with<BR>\neach obstacle they became more and more disgusted with their page.  He was<BR>\nnot only inept, he was a coward, he could not handle the horses, he was,<BR>\nin short, a complete flop.  When they arrived at the court of the kingdom,<BR>\nthey found that they were expected to present the Princess with some<BR>\ntreasure.  The two older brothers were discouraged, since they had not<BR>\nthought of this and were unprepared.  The youngest, however, had the<BR>\nanswer:  Promise her anything, but give her our page.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Man and wife make one fool.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men live for three things, fast cars, fast women and fast food.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men are those creatures with two legs and eight hands.<BR>\n&nbsp;-- Jayne Mansfield');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Love is the delusion that one woman differs from another.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Of all the animals, the boy is the most unmanageable.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Not every problem someone has with his girlfriend is necessarily due to<BR>\nthe capitalist mode of production.<BR>\n&nbsp;-- Herbert Marcuse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Of course a platonic relationship is possible -- but only between<BR>\nhusband and wife.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No woman can endure a gambling husband, unless he is a steady winner.<BR>\n&nbsp;-- Lord Thomas Dewar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No woman can call herself free until she can choose consciously whether<BR>\nshe will or will not be a mother.<BR>\n&nbsp;-- Margaret H. Sanger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No woman ever falls in love with a man unless she has a better opinion of<BR>\nhim than he deserves.<BR>\n&nbsp;-- Edgar Watson Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Once a woman has given you her heart you can never get rid of the rest of her.<BR>\n&nbsp;-- Vanbrugh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No modern woman with a grain of sense ever sends little notes to an<BR>\nunmarried man -- not until she is married, anyway.<BR>\n&nbsp;-- Arthur Binstead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No friendship is so cordial or so delicious as that of girl for girl;<BR>\nno hatred so intense or immovable as that of woman for woman.<BR>\n&nbsp;-- Landor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','No one knows like a woman how to say things that are at once gentle and deep.<BR>\n&nbsp;-- Hugo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Lonely men seek companionship.  Lonely women sit at home and wait.<BR>\nThey never meet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','My notion of a husband at forty is that a woman should be able to change him,<BR>\nlike a bank note, for two twenties.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Men of quality are not afraid of women for equality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Never accept an invitation from a stranger unless he gives you candy.<BR>\n&nbsp;-- Linda Festa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Monogamy is the Western custom of one wife and hardly any mistresses.<BR>\n&nbsp;-- H.H. Munro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Money and women are the most sought after and the least known of any two<BR>\nthings we have.<BR>\n&nbsp;-- The Best of Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Miguel Cervantes wrote Donkey Hote.  Milton wrote Paradise Lost, then his<BR>\nwife died and he wrote Paradise Regained.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The anger of a woman is the greatest evil with which you can threaten your<BR>\nenemies.<BR>\n&nbsp;-- Bonnard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Take my word for it, the silliest woman can manage a clever man, but it<BR>\nneeds a very clever woman to manage a fool.<BR>\n&nbsp;-- Kipling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Some of us are becoming the men we wanted to marry.<BR>\n&nbsp;-- Gloria Steinem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Tehee quod she, and clapte the wyndow to.<BR>\n&nbsp;-- Geoffrey Chaucer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The average woman must inevitably view her actual husband with a certain<BR>\ndisdain; he is anything but her ideal.  In consequence, she cannot help<BR>\nfeeling that her children are cruelly handicapped by the fact that he is<BR>\ntheir father.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The first marriage is the triumph of imagination over intelligence,<BR>\nand the second the triumph of hope over experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Some men feel that the only thing they owe the woman who marries them<BR>\nis a grudge.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The girl who stoops to conquer usually wears a low-cut dress.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','So many beautiful women and so little time.<BR>\n&nbsp;-- John Barrymore');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','She been married so many times she got rice marks all over her face.<BR>\n&nbsp;-- Tom Waits');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','She missed an invaluable opportunity to give him a look that you could<BR>\nhave poured on a waffle ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','So many women; so little time!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Rich bachelors should be heavily taxed.  It is not fair that some men<BR>\nshould be happier than others.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Physically there is nothing to distinguish human society from the<BR>\nfarm-yard except that children are more troublesome and costly than<BR>\nchickens and women are not so completely enslaved as farm stock.<BR>\n&nbsp;-- George Bernard Shaw, \"Getting Married\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','She is descended from a long line that her mother listened to.<BR>\n&nbsp;-- Gypsy Rose Lee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The gentlemen looked one another over with microscopic carelessness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','One should always be in love.  That is the reason one should never marry.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Only two groups of people fall for flattery -- men and women.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','One girl can be pretty -- but a dozen are only a chorus.<BR>\n&nbsp;-- F. Scott Fitzgerald, \"The Last Tycoon\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','One is not born a woman, one becomes one.<BR>\n&nbsp;-- Simone de Beauvoir');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage always demands the greatest understanding of the art of<BR>\ninsincerity possible between two human beings.<BR>\n&nbsp;-- Vicki Baum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is the only adventure open to the cowardly.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Many a man has fallen in love with a girl in a light so dim he would<BR>\nnot have chosen a suit by it.<BR>\n&nbsp;-- Maurice Chevalier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage is the waste-paper basket of the emotions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A bachelor is a selfish, undeserving guy who has cheated some woman out<BR>\nof a divorce.<BR>\n&nbsp;-- Don Quinn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A beautiful woman is a picture which drives all beholders nobly mad.<BR>\n&nbsp;-- Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A bachelor is an unaltared male.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A boy gets to be a man when a man is needed.<BR>\n&nbsp;-- John Steinbeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A bachelor is a man who never made the same mistake once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','94% of the women in America are beautiful and the rest hang out around here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A hammer sometimes misses its mark - a bouquet never.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A good man always knows his limitations.<BR>\n&nbsp;-- Harry Callahan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A good marriage would be between a blind wife and deaf husband.<BR>\n&nbsp;-- Michel de Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A husband is what is left of the lover after the nerve has been extracted.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The most happy marriage I can imagine to myself would be the union<BR>\nof a deaf man to a blind woman.<BR>\n&nbsp;-- Samuel Taylor Coleridge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A lady is one who never shows her underwear unintentionally.<BR>\n&nbsp;-- Lillian Day');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The perfect man is the true partner.  Not a bed partner nor a fun partner,<BR>\nbut a man who will shoulder burdens equally with [you] and possess that<BR>\nquality of joy.<BR>\n&nbsp;-- Erica Jong');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The most popular labor-saving device today is still a husband with money.<BR>\n&nbsp;-- Joey Adams, \"Cindy and I\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The mother of the year should be a sterilized woman with two adopted children.<BR>\n&nbsp;-- Paul Ehrlich');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The mature bohemian is one whose woman works full time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The most difficult years of marriage are those following the wedding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The most important thing in a relationship between a man and a woman<BR>\nis that one of them be good at taking orders.<BR>\n&nbsp;-- Linda Festa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The most dangerous food is wedding cake.<BR>\n&nbsp;-- American proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The one charm of marriage is that it makes a life of deception a neccessity.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The heaviest object in the world is the body of the woman you have ceased<BR>\nto love.<BR>\n&nbsp;-- Marquis de Lac de Clapiers Vauvenargues');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The man who understands one woman is qualified to understand pretty well<BR>\neverything.<BR>\n&nbsp;-- Yeats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The honeymoon is not actually over until we cease to stifle our sighs<BR>\nand begin to stifle our yawns.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The only real argument for marriage is that it remains the best method<BR>\nfor getting acquainted.<BR>\n&nbsp;-- Heywood Broun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The gods gave man fire and he invented fire engines.  They gave him<BR>\nlove and he invented marriage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The prettiest women are almost always the most boring, and that is why<BR>\nsome people feel there is no God.<BR>\n&nbsp;-- Woody Allen, \"Without Feathers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The only really masterful noise a man makes in a house is the noise<BR>\nof his key, when he is still on the landing, fumbling for the lock.<BR>\n&nbsp;-- Colette');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The person who marries for money usually earns every penny of it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The difference between legal separation and divorce is that legal<BR>\nseparation gives the man time to hide his money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The days just prior to marriage are like a snappy introduction to a <BR>\ntedious book.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;The defense attorney was hammering away at the plaintiff:<BR>\n\"You claim,\" he jeered, \"that my client came at you with a broken bottle<BR>\nin his hand.  But is it not true, that you had something in YOUR hand?\"<BR>\n&nbsp;\"Yes,\" the man admitted, \"his wife. Very charming, of course,<BR>\nbut not much good in a fight.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The big question is why in the course of evolution the males permitted<BR>\nthemselves to be so totally eclipsed by the females.  Why do they tolerate<BR>\nthis total subservience, this wretched existence as outcasts who are<BR>\nhungry all the time?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The best thing about being bald is, that, when unexpected company arrives,<BR>\nall you have to do is straighten your tie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The surest sign that a man is in love is when he divorces his wife.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The chains of marriage are so heavy that it takes two to carry them, and<BR>\nsometimes three.<BR>\n&nbsp;-- Alexandre Dumas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The eternal feminine draws us upward.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man always remembers his first love with special tenderness, but after<BR>\nthat begins to bunch them.<BR>\n&nbsp;-- Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man may sometimes be forgiven the kiss to which he is not entitled,<BR>\nbut never the kiss he has not the initiative to claim.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A diplomatic husband said to his wife, \"How do you expect me to remember<BR>\nyour birthday when you never look any older?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A figure with curves always offers a lot of interesting angles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A gentleman never strikes a lady with his hat on.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman can never be too rich or too thin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Too much of a good thing is WONDERFUL.<BR>\n&nbsp;-- Mae West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','To many, total abstinence is easier than perfect moderation.<BR>\n&nbsp;-- St. Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','To err is human -- but it feels divine.<BR>\n&nbsp;-- Mae West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There is only one way to console a widow.  But remember the risk.<BR>\n&nbsp;-- Robert Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There is no such thing as an ugly woman -- there are only the ones who do<BR>\nnot know how to make themselves attractive.<BR>\n&nbsp;-- Christian Dior');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There are three things men can do with women: love them, suffer for them,<BR>\nor turn them into literature.<BR>\n&nbsp;-- Stephen Stills');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The six great gifts of an Irish girl are beauty, soft voice, sweet speech,<BR>\nwisdom, needlework, and chastity.<BR>\n&nbsp;-- Theodore Roosevelt, 1907');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The best man for the job is often a woman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Stanford women are responsible for the success of many Stanford men:<BR>\nthey give them \"just one more reason\" to stay in and study every night.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Sometimes a cigar is just a cigar.<BR>\n&nbsp;-- Sigmund Freud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Some men are all right in their place -- if they only the knew the right places!<BR>\n&nbsp;-- Mae West');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Some husbands are living proof that a woman can take a joke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','So many women; so little nerve.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','So many men; so little time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','She liked him; he was a man of many qualities, even if most of them were bad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Scientists still know less about what attracts men than they do about<BR>\nwhat attracts mosquitoes.<BR>\n&nbsp;-- Dr. Joyce Brothers,<BR>\n&nbsp;\"What Every Woman Should Know About Men\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A boy can learn a lot from a dog: obedience, loyalty, and the importance<BR>\nof turning around three times before lying down.<BR>\n&nbsp;-- Robert Benchley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A beautiful man is paradise for the eyes, hell for the soul, and<BR>\npurgatory for the purse. ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A beautiful woman is a blessing from Heaven, but a good cigar is a smoke.<BR>\n&nbsp;-- Kipling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A bachelor never quite gets over the idea that he is a thing of beauty<BR>\nand a boy for ever.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A modest woman, dressed out in all her finery, is the most tremendous object<BR>\nin the whole creation.<BR>\n&nbsp;-- Goldsmith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A fox is a wolf who sends flowers.<BR>\n&nbsp;-- Ruth Weston');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man wrapped up in himself makes a very small package.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A Roman divorced from his wife, being highly blamed by his friends, who<BR>\ndemanded, \"Was she not chaste?  Was she not fair?  Was she not fruitful?\"<BR>\nholding out his shoe, asked them whether it was not new and well made.<BR>\nYet, added he, none of you can tell where it pinches me.<BR>\n&nbsp;-- Plutarch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A real gentleman never takes bases unless he really has to.<BR>\n&nbsp;-- Overheard in an algebra lecture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A psychiatrist is a fellow who asks you a lot of expensive questions<BR>\nyour wife asks you for nothing.<BR>\n&nbsp;-- Joey Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A mother takes twenty years to make a man of her boy, and another woman<BR>\nmakes a fool of him in twenty minutes.<BR>\n&nbsp;-- Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A pedestal is as much a prison as any small, confined space.<BR>\n&nbsp;-- Gloria Steinem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A wife lasts only for the length of the marriage, but an ex-wife is there<BR>\n*for the rest of your life*.<BR>\n&nbsp;-- Jim Samuels');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man is like a rusty wheel on a rusty cart,<BR>\nHe sings his song as he rattles along and then he falls apart.<BR>\n&nbsp;-- Richard Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man is already halfway in love with any woman who listens to him.<BR>\n&nbsp;-- Brendan Francis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man in love is incomplete until he is married.  Then he is finished.<BR>\n&nbsp;-- Zsa Zsa Gabor, \"Newsweek\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;\"Anything else, sir?\" asked the attentive bellhop, trying his best<BR>\nto make the lady and gentleman comfortable in their penthouse suite in the<BR>\nposh hotel.<BR>\n&nbsp;\"No.  No, thank you,\" replied the gentleman.<BR>\n&nbsp;\"Anything for your wife, sir?\" the bellhop asked.<BR>\n&nbsp;\"Why, yes, young man,\" said the gentleman.  \"Would you bring me a<BR>\npostcard?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman, especially if she have the misfortune of knowing anything,<BR>\nshould conceal it as well as she can.<BR>\n&nbsp;-- Jane Austen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman without a man is like a fish without a bicycle.<BR>\n&nbsp;-- Gloria Steinem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman is like your shadow; follow her, she flies; fly from her, she follows.<BR>\n&nbsp;-- Chamfort');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman of generous character will sacrifice her life a thousand times<BR>\nover for her lover, but will break with him for ever over a question of<BR>\npride -- for the opening or the shutting of a door.<BR>\n&nbsp;-- Stendhal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman may very well form a friendship with a man, but for this to endure,<BR>\nit must be assisted by a little physical antipathy.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There are three things I have always loved and never understood --<BR>\nart, music, and women.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','\"And what do you two think you are doing?!\" roared the husband, as he came<BR>\nupon his wife in bed with another man.  The wife turned and smiled at her<BR>\ncompanion.<BR>\n&nbsp;\"See?\" she said.  \"I told you he was stupid!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman without a man is like a fish without a bicycle.<BR>\nTherefore, a man without a woman is like a bicycle without a fish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Beauty, brains, availability, personality; pick any two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A girl with a future avoids the man with a past.<BR>\n&nbsp;-- Evan Esar, \"The Humor of Humor\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A girl and a boy bump into each other -- surely an accident.<BR>\nA girl and a boy bump and her handkerchief drops -- surely another accident.<BR>\nBut when a girl gives a boy a dead squid -- *____that ___had __to ____mean _________something*.<BR>\n&nbsp;-- S. Morganstern, \"The Silent Gondoliers\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man without a woman is like a statue without pigeons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Any girl can be glamorous; all you have to do is stand still and look stupid.<BR>\n&nbsp;-- Hedy Lamarr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Any woman is a volume if one knows how to read her.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Anyone who says he can see through women is missing a lot.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','And yet I should have dearly liked, I own, to have touched her lips; to<BR>\nhave questioned her, that she might have opened them; to have looked upon<BR>\nthe lashes of her downcast eyes, and never raised a blush; to have let<BR>\nloose waves of hair, an inch of which would be a keepsake beyond price:<BR>\nin short, I should have liked, I do confess, to have had the lightest<BR>\nlicense of a child, and yet been man enough to know its value.<BR>\n&nbsp;-- Charles Dickens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Alimony is a system by which, when two people make a mistake, one of them<BR>\ncontinues to pay for it.<BR>\n&nbsp;-- Peggy Joyce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Alimony is like buying oats for a dead horse.<BR>\n&nbsp;-- Arthur Baer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There are a few things that never go out of style, and a feminine woman<BR>\nis one of them.<BR>\n&nbsp;-- Ralston');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','AAAAAAAAAAAaaaaaaaaaaaaaaaccccccccckkkkkk!!!!!!!!!<BR>\nYou brute!  Knock before entering a ladies room!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','All husbands are alike, but they have different faces so you can tell<BR>\nthem apart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','All heiresses are beautiful.<BR>\n&nbsp;-- John Dryden');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','All most men really want in life is a wife, a house, two kids and a car,<BR>\na cat, no maybe a dog.  Ummm, scratch one of the kids and add a dog.<BR>\nDefinitely a dog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','All the men on my staff can type.<BR>\n&nbsp;-- Bella Abzug');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Alimony is the curse of the writing classes.<BR>\n&nbsp;-- Norman Mailer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','All work and no pay makes a housewife.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A fool and his honey are soon parted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman did what a woman had to, the best way she knew how.<BR>\nTo do more was impossible, to do less, unthinkable.<BR>\n&nbsp;-- Dirisha, \"The Man Who Never Missed\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman has got to love a bad man once or twice in her life to be<BR>\nthankful for a good one.<BR>\n&nbsp;-- Marjorie Kinnan Rawlings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','An optimist is a man who looks forward to marriage.<BR>\nA pessimist is a married optimist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman forgives the audacity of which her beauty has prompted us to be guilty.<BR>\n&nbsp;-- LeSage');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A woman can look both moral and exciting -- if she also looks as if it<BR>\nwere quite a struggle.<BR>\n&nbsp;-- Edna Ferber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man usually falls in love with a woman who asks the kinds of questions<BR>\nhe is able to answer.<BR>\n&nbsp;-- Ronald Colman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A pretty woman can do anything; an ugly woman must do everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man does not look behind the door unless he has stood there himself.<BR>\n&nbsp;-- Du Bois');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','A man may be so much of everything that he is nothing of anything.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Two sure ways to tell a REALLY sexy man; the first is, he has a bad memory.<BR>\nI forget the second.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Very few modern women either like or desire marriage, especially after the<BR>\nceremony has been performed.  Primarily women wish attention and affection.<BR>\nMatrimony is something they accept when there is no alternative.  Really,<BR>\nit is a waste of time, and hazardous, to marry them.  It leaves one open<BR>\nto a rival.  Husbands, good or bad, always have rivals.  Lovers, never.<BR>\n&nbsp;-- Helen Lawrenson, \"Esquire\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Trust your husband, adore your husband, and get as much as you can in your<BR>\nown name.<BR>\n&nbsp;-- Joan Rivers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Birds and bees have as much to do with the facts of life as black<BR>\nnightgowns do with keeping warm.<BR>\n&nbsp;-- Hester Mundis, \"Powermom\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','To our sweethearts and wives.  May they never meet.<BR>\n&nbsp;-- 19th century toast');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','We were happily married for eight months.  Unfortunately, we were married<BR>\nfor four and a half years.<BR>\n&nbsp;-- Nick Faldo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Today when a man gets married he gets a home, a housekeeper, a cook, a cheering<BR>\nsquad and another paycheck.  When a woman marries, she gets a boarder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There is not much to choose between a woman who deceives us for another,<BR>\nand a woman who deceives another for ourselves.<BR>\n&nbsp;-- Augier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','To be successful, a woman has to be much better at her job than a man.<BR>\n&nbsp;-- Golda Meir');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Brigands will demand your money or your life, but a woman will demand both.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There goes the good time that was had by all.<BR>\n&nbsp;-- Bette Davis, remarking on a passing starlet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There is no realizable power that man cannot, in time, fashion the tools<BR>\nto attain, nor any power so secure that the naked ape will not abuse it.<BR>\nSo it is written in the genetic cards -- only physics and war hold him in<BR>\ncheck.  And also the wife who wants him home by five, of course.<BR>\n&nbsp;-- Encyclopadia Apocryphia, 1990 ed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','There is a vast difference between the savage and civilized man, but it<BR>\nis never apparent to their wives until after breakfast.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The truth about a woman often lasts longer than the woman is true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The two things that can get you into trouble quicker than anything else<BR>\nare fast women and slow horses.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The way to fight a woman is with your hat.  Grab it and run.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The trouble with some women is that they get all excited about nothing<BR>\n-- and then marry him.<BR>\n&nbsp;-- Cher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','FORTUNE DISCUSSES THE DIFFERENCES BETWEEN MEN AND WOMEN:	#9<BR>\n&nbsp;Laundry:<BR>\n&nbsp;Women do laundry every couple of days.  A man will wear every article<BR>\nof clothing he owns, including his surgical pants that were hip about eight<BR>\nyears ago, before he will do his laundry.  When he is finally out of clothes,<BR>\nhe will wear a dirty sweatshirt inside out, rent a U-Haul and take his mountain<BR>\nof clothes to the laundromat.  Men always expect to meet beautiful women at<BR>\nthe laundromat.  This is a myth.<BR>\n&nbsp;Nicknames:<BR>\n&nbsp;If Gloria, Suzanne, Deborah and Michelle get together for lunch,<BR>\nthey will call each other Gloria, Suzanne, Deborah and Michelle.  But if<BR>\nMike, Dave, Rob and Jack go out for a brewsky, they will affectionately<BR>\nrefer to each other as Bullet-Head, Godzilla, Peanut Brain and Useless.<BR>\n&nbsp;Socks:<BR>\n&nbsp;Men wear sensible socks.  They wear standard white sweatsocks.<BR>\nWomen wear strange socks.  They are cut way below the ankles, have pictures<BR>\nof clouds on them, and have a big fuzzy ball on the back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Feminists just want the human race to be a tie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Farmers in the Iowa State survey rated machinery breakdowns more<BR>\nstressful than divorce.<BR>\n&nbsp;-- Wall Street Journal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Fortunate is he for whom the belle toils.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','He who is intoxicated with wine will be sober again in the course of the<BR>\nnight, but he who is intoxicated by the cupbearer will not recover his<BR>\nsenses until the day of judgement.<BR>\n&nbsp;-- Saadi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It was a fine, sweet night, the nicest since my divorce, maybe the nicest<BR>\nsince the middle of my marriage.  There was energy, softness, grace and<BR>\nlaughter.  I even took my socks off.  In my circle, that means class.<BR>\n&nbsp;-- Andrew Bergman \"The Big Kiss-off of 1944\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Girls who throw themselves at men, are actually taking very careful aim.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Girls really do know just what they want -- you to figure it out for yourself!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Girls marry for love.  Boys marry because of a chronic irritation that<BR>\ncauses them to gravitate in the direction of objects with certain curvilinear<BR>\nproperties.<BR>\n&nbsp;-- Ashley Montagu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Girls are better looking in snowstorms.<BR>\n&nbsp;-- Archie Goodwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Good girls go to heaven, bad girls go everywhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;Fred noticed his roommate had a black eye upon returning from a dance.<BR>\n\"What happened?\"<BR>\n&nbsp;\"I was struck by the beauty of the place.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;Friends were surprised, indeed, when Frank and Jennifer broke their <BR>\nengagement, but Frank had a ready explanation: \"Would you marry someone who <BR>\nwas habitually unfaithful, who lied at every turn, who was selfish and lazy <BR>\nand sarcastic?\"<BR>\n&nbsp;\"Of course not,\" said a sympathetic friend.<BR>\n&nbsp;\"Well,\" retorted Frank, \"neither would Jennifer.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','God created a few perfect heads.  The rest he covered with hair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','... eighty years later he could still recall with the young pang of his<BR>\noriginal joy his falling in love with Ada.<BR>\n&nbsp;-- Nabokov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Keep women you cannot.  Marry them and they come to hate the way you walk<BR>\nacross the room; remain their lover, and they jilt you at the end of six<BR>\nmonths.<BR>\n&nbsp;-- Moore');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It takes a smart husband to have the last word and not use it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I was in a beauty contest one.  I not only came in last, I was hit in<BR>\nthe mouth by Miss Congeniality.<BR>\n&nbsp;-- Phyllis Diller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I think the world is ready for the story of an ugly duckling, who grew up to<BR>\nremain an ugly duckling, and lived happily ever after.<BR>\n&nbsp;-- Chick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I respect the institution of marriage.  I have always thought that every<BR>\nwoman should marry -- and no man.<BR>\n&nbsp;-- Benjamin Disraeli, \"Lothair\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I will not say that women have no character; rather, they have a new<BR>\none every day.<BR>\n&nbsp;-- Heine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I never expected to see the day when girls would get sunburned in the<BR>\nplaces they do today.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I married beneath me.  All women do.<BR>\n&nbsp;-- Lady Nancy Astor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I refuse to consign the whole male sex to the nursery.  I insist on<BR>\nbelieving that some men are my equals.<BR>\n&nbsp;-- Brigid Brophy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I have found it impossible to carry the heavy burden of responsibility and<BR>\nto discharge my duties as king as I would wish to do without the help and<BR>\nsupport of the woman I love.<BR>\n&nbsp;-- Edward, Duke of Windsor, 1936, announcing his abdication<BR>\n&nbsp;of the British throne in order to marry the American<BR>\n&nbsp;divorcee Wallis Warfield Simpson.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I like young girls.  Their stories are shorter.<BR>\n&nbsp;-- Tom McGuane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I have a hard time being attracted to anyone who can beat me up.<BR>\n&nbsp;-- John McGrath, Atlanta sportswriter, on women weightlifters.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I have now come to the conclusion never again to think of marrying,<BR>\nand for this reason: I can never be satisfied with anyone who would<BR>\nbe blockhead enough to have me.<BR>\n&nbsp;-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I come from a small town whose population never changed.  Each time a woman<BR>\ngot pregnant, someone left town.<BR>\n&nbsp;-- Michael Prichard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I believe a little incompatibility is the spice of life, particularly if he<BR>\nhas income and she is pattable.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I do enjoy a good long walk -- especially when my wife takes one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I can feel for her because, although I have never been an Alaskan prostitute<BR>\ndancing on the bar in a spangled dress, I still get very bored with washing<BR>\nand ironing and dishwashing and cooking day after relentless day.<BR>\n&nbsp;-- Betty MacDonald');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','\"Home, Sweet Home\" must surely have been written by a bachelor.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','High heels are a device invented by a woman who was tired of being kissed<BR>\non the forehead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I am very fond of the company of ladies.  I like their beauty,<BR>\nI like their delicacy, I like their vivacity, and I like their silence.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Let thy maid servant be faithful, strong, and homely.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Large increases in cost with questionable increases in performance can<BR>\nbe tolerated only in race horses and women.<BR>\n&nbsp;-- Lord Kalvin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Like the ski resort of girls looking for husbands and husbands looking<BR>\nfor girls, the situation is not as symmetrical as it might seem.<BR>\n&nbsp;-- Alan McKay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriage, in life, is like a duel in the midst of a battle.<BR>\n&nbsp;-- Edmond About');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It [marriage] happens as with cages: the birds without despair<BR>\nto get in, and those within despair of getting out.<BR>\n&nbsp;-- Michel Eyquem de Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Is not marriage an open question, when it is alleged, from the<BR>\nbeginning of the world, that such as are in the institution wish to get<BR>\nout, and such as are out wish to get in?<BR>\n&nbsp;-- Ralph Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If you want to be ruined, marry a rich woman.<BR>\n&nbsp;-- Michelet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','In Christianity, a man may have only one wife.  This is called Monotony.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Insanity is considered a ground for divorce, though by the very same<BR>\ntoken it is the shortest detour to marriage.<BR>\n&nbsp;-- Wilson Mizner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','In olden times sacrifices were made at the altar -- a practice which is<BR>\nstill continued.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It is now quite lawful for a Catholic woman to avoid pregnancy by a resort to<BR>\nmathematics, though she is still forbidden to resort to physics and chemistry.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Is a wedding successful if it comes off without a hitch?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It has been justly observed by sages of all lands that although a man may be<BR>\nmost happily married and continue in that state with the utmost contentment,<BR>\nit does not necessarily follow that he has therefore been struck stone-blind.<BR>\n&nbsp;-- H. Warner Munn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If you want your spouse to listen and pay strict attention to every<BR>\nword you say, talk in your sleep.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If you wish women to love you, be original; I know a man who wore fur<BR>\nboots summer and winter, and women fell in love with him.<BR>\n&nbsp;-- Anton Chekhov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','In buying horses and taking a wife shut your eyes tight and commend<BR>\nyourself to God.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If you want me to be a good little bunny just dangle some carats in front<BR>\nof my nose.<BR>\n&nbsp;-- Lauren Bacall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If you are looking for a kindly, well-to-do older gentleman who is no<BR>\nlonger interested in sex, take out an ad in The Wall Street Journal.<BR>\n&nbsp;-- Abigail Van Buren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If we men married the women we deserved, we should have a very bad time of it.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','In marriage, as in war, it is permitted to take every advantage of the enemy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If men acted after marriage as they do during courtship, there would<BR>\nbe fewer divorces -- and more bankruptcies.<BR>\n&nbsp;-- Frances Rodman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If someone were to ask me for a short cut to sensuality, I would<BR>\nsuggest he go shopping for a used 427 Shelby-Cobra.  But it is only<BR>\nfair to warn you that of the 300 guys who switched to them in 1966,<BR>\nonly two went back to women.<BR>\n&nbsp;-- Mort Sahl');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','If I told you you had a beautiful body, would you hold it against me?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Keep your eyes wide open before marriage, half shut afterwards.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Just as I cannot remember any time when I could not read and write, I cannot<BR>\nremember any time when I did not exercise my imagination in daydreams about<BR>\nwomen.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Kissing your hand may make you feel very good, but a diamond and<BR>\nsapphire bracelet lasts for ever.<BR>\n&nbsp;-- Anita Loos, \"Gentlemen Prefer Blondes\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','I sat down beside her, said hello, offered to buy her a drink... and then<BR>\nnatural selection reared its ugly head.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It is possible that blondes also prefer gentlemen.<BR>\n&nbsp;-- Maimie Van Doren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Marriages are made in heaven and consummated on earth.<BR>\n&nbsp;-- John Lyly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The girl who swears no one has ever made love to her has a right to swear.<BR>\n&nbsp;-- Sophia Loren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','It is idle to attempt to talk a young woman out of her passion:<BR>\nlove does not lie in the ear.<BR>\n&nbsp;-- Walpole');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','The woman you buy -- and she is the least expensive -- takes a great<BR>\ndeal of money.  The woman who gives herself takes all your time.<BR>\n&nbsp;-- Balzac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','He gave her a look that you could have poured on a waffle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','As fathers commonly go, it is seldom a misfortune to be fatherless; and<BR>\nconsidering the general run of sons, as seldom a misfortune to be childless.<BR>\n&nbsp;The only solid and lasting peace between a man and his wife is, doubtless,<BR>\na separation.<BR>\n&nbsp;-- Lord Chesterfield, letter to his son, 1763');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Courtship to marriage, as a very witty prologue to a very dull play.<BR>\n&nbsp;-- William Congreve');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women are just like men, only different.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When there is an old maid in the house, a watch dog is unnecessary.<BR>\n&nbsp;-- Balzac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When the candles are out all women are fair.<BR>\n&nbsp;-- Plutarch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When one knows women one pities men, but when one studies men,<BR>\none excuses women.<BR>\n&nbsp;-- Horne Tooke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When two people are under the influence of the most violent, most insane,<BR>\nmost delusive, and most transient of passions, they are required to swear<BR>\nthat they will remain in that excited, abnormal, and exhausting condition<BR>\ncontinuously until death do them part.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women, deceived by men, want to marry them; it is a kind of revenge<BR>\nas good as any other.<BR>\n&nbsp;-- Philippe De Remi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Boys will be boys, and so will a lot of middle-aged men.<BR>\n&nbsp;-- Kin Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When a girl marries she exchanges the attentions of many men for the<BR>\ninattentions of one.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When Marriage is Outlawed, Only Outlaws will have Inlaws.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Twenty years of romance make a woman look like a ruin; but twenty years of<BR>\nmarriage make her something like a public building.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When I was a young man, I vowed never to marry until I found the ideal<BR>\nwoman.  Well, I found her -- but alas, she was waiting for the ideal man.<BR>\n&nbsp;-- Robert Schuman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When a woman gives me a present I have always two surprises:<BR>\nfirst is the present, and afterward, having to pay for it.<BR>\n&nbsp;-- Donnay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When God created two sexes, he may have been overdoing it.<BR>\n&nbsp;-- Charles Merrill Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Whatever women do they must do twice as well as men to be thought half<BR>\nas good.  Luckily this is not difficult.<BR>\n&nbsp;-- Charlotte Whitton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When a girl can read the handwriting on the wall, she may be in the wrong<BR>\nrest room.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When a man steals your wife, there is no better revenge than to let him<BR>\nkeep her.<BR>\n&nbsp;-- Sacha Guitry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;\"What do you give a man who has everything?\" the pretty teenager<BR>\nasked her mother.<BR>\n&nbsp;\"Encouragement, dear,\" she replied.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When a woman marries again it is because she detested her first husband.<BR>\nWhen a man marries again, it is because he adored his first wife.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Beauty seldom recommends one woman to another.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women wish to be loved without a why or a wherefore; not because they are<BR>\npretty, or good, or well-bred, or graceful, or intelligent, but because<BR>\nthey are themselves.<BR>\n&nbsp;-- Amiel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','What a misfortune to be a woman!  And yet, the worst misfortune is not to<BR>\nunderstand what a misfortune it is.<BR>\n&nbsp;-- Kierkegaard, 1813-1855.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Bigamy is having one spouse too many.  Monogamy is the same.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','What do you give a man who has everything?  Penicillin.<BR>\n&nbsp;-- Jerry Lester');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Wedding is destiny, and hanging likewise.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','You can never trust a woman; she may be true to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','You know, of course, that the Tasmanians, who never committed adultery,<BR>\nare now extinct.<BR>\n&nbsp;-- M. Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women who want to be equal to men lack imagination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','You have only to mumble a few words in church to get married and few words<BR>\nin your sleep to get divorced.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women give themselves to God when the Devil wants nothing more to do with them.<BR>\n&nbsp;-- Arnould');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women reason with the heart and are much less often wrong than men who<BR>\nreason with the head.<BR>\n&nbsp;-- DeLescure');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women treat us just as humanity treats its gods.  They worship us and are<BR>\nalways bothering us to do something for them.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women give to men the very gold of their lives.  Possibly; but they<BR>\ninvariably want it back in such very small change.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women in love consist of a little sighing, a little crying, a little dying<BR>\n-- and a good deal of lying.<BR>\n&nbsp;-- Ansey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women sometimes forgive a man who forces the opportunity, but never a man<BR>\nwho misses one.<BR>\n&nbsp;-- Charles De Talleyrand-Perigord');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;\"You are *so* lovely.\"<BR>\n&nbsp;\"Yes.\"<BR>\n&nbsp;\"Yes!  And you take a compliment, too!  I like that in a goddess.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women are wiser than men because they know less and understand more.<BR>\n&nbsp;-- Stephens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women complain about sex more than men.  Their gripes fall into two<BR>\ncategories: (1) Not enough and (2) Too much.<BR>\n&nbsp;-- Ann Landers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women are not much, but they are the best other sex we have.<BR>\n&nbsp;-- Herold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','You are not permitted to kill a woman who has wronged you, but nothing<BR>\nforbids you to reflect that she is growing older every minute.  You are<BR>\navenged fourteen hundred and forty times a day.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Changing husbands/wives is only changing troubles.<BR>\n&nbsp;-- Kathleen Norris');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Choose in marriage only a woman whom you would choose as a friend if she<BR>\nwere a man.<BR>\n&nbsp;-- Joubert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women can keep a secret just as well as men, but it takes more of them<BR>\nto do it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Woman was taken out of man -- not out of his head, to rule over him; nor<BR>\nout of his feet, to be trampled under by him; but out of his side, to be<BR>\nequal to him -- under his arm, that he might protect her, and near his heart<BR>\nthat he might love her.<BR>\n&nbsp;-- Henry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Woman inspires us to great things, and prevents us from achieving them.<BR>\n&nbsp;-- Dumas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Young men want to be faithful and are not; old men want to be faithless and<BR>\ncannot.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','When women kiss it always reminds one of prize fighters shaking hands.<BR>\n&nbsp;-- H.L. Mencken, \"Sententiae\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Youth had been a habit of hers so long that she could not part with it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','&nbsp;Young men and young women may work systematically six days in the<BR>\nweek and rise fresh in the morning, but let them attend modern dances for<BR>\nonly a few hours each evening and see what happens.  The Waltz, Polka,<BR>\nGallop and other dances of the same kind will be disastrous in their effects<BR>\nto both sexes.  Health and vigor will vanish like the dew before the sun.<BR>\n&nbsp;It is not the extraordinary exercise which harms the dancer, but<BR>\nrather the coming into close contact with the opposite sex.  It is the<BR>\nfury of lust craving incessantly for more pleasure that undermines the<BR>\nsoul, the body, the sinews and nerves.  Experience and statistics show<BR>\nbeyond doubt that passionate excessive dancing girls can hardly reach<BR>\ntwenty-five years of age and men thirty-one.  Even if they reached that<BR>\nage they will in most instances be broken in health physically and morally.<BR>\nThis is the claim of prominent physicians in this country.<BR>\n&nbsp;-- Quote from a 1910 periodical');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Women are always anxious to urge bachelors to matrimony; is it from charity,<BR>\nor revenge?<BR>\n&nbsp;-- Gustave Vapereau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Whenever I date a guy, I think, is this the man I want my children<BR>\nto spend their weekends with?<BR>\n&nbsp;-- Rita Rudner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Why a man would want a wife is a big mystery to some people.  Why a man<BR>\nwould want *___two* wives is a bigamystery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Some marriages are made in heaven -- but so are thunder and lightning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('men-women','Darling: the popular form of address used in speaking to a member of the<BR>\nopposite sex whose name you cannot at the moment remember.<BR>\n&nbsp;-- Oliver Herford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Agree with them now, it will save so much time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Amnesia used to be my favorite word, but then I forgot it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Bare feet magnetize sharp metal objects so they point upward from the<BR>\nfloor -- especially in the dark.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Blessed are they who Go Around in Circles, for they Shall be Known as Wheels.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There is nothing new except what has been forgotten.<BR>\n&nbsp;-- Marie Antoinette');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Boy, that crayon sure did hurt!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Kilroe hic erat!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The most important things, each person must do for himself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The one good thing about repeating your mistakes is that you know when to<BR>\ncringe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The last person who said that (God rest his soul) lived to regret it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The luck that is ordained for you will be coveted by others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The important thing to remember about walking on eggs is not to hop.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The fact that it works is immaterial.<BR>\n&nbsp;-- L. Ogborn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The future not being born, my friend, we will abstain from baptizing it.<BR>\n&nbsp;-- George Meredith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The groundhog is like most other prophets; it delivers its message and then<BR>\ndisappears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The eagle may soar, but the weasel never gets sucked into a jet engine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The adjective is the banana peel of the parts of speech.<BR>\n&nbsp;-- Clifton Fadiman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The cart has no place where a fifth wheel could be used.<BR>\n&nbsp;-- Herbert von Fritzlar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The hearing ear is always found close to the speaking tongue, a custom<BR>\nwhereof the memory of man runneth not howsomever to the contrary, nohow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Stability itself is nothing else than a more sluggish motion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Standing on head makes smile of frown, but rest of face also upside down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sooner or later you must pay for your sins.<BR>\n(Those who have already paid may disregard this cookie).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Somehow I reached excess without ever noticing when I was passing through<BR>\nsatisfaction.<BR>\n&nbsp;-- Ashleigh Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Somehow, the world always affects you more than you affect it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Somewhere, something incredible is waiting to be known.<BR>\n&nbsp;-- Carl Sagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Kissing a fish is like smoking a bicycle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There seems no plan because it is all plan.<BR>\n&nbsp;-- C.S. Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The rose of yore is but a name, mere names are left to us.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The sheep that fly over your head are soon to land.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Thank you for observing all safety precautions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The reader this message encounters not failing to understand is cursed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Drop the vase and it will become a Ming of the past.<BR>\n&nbsp;-- The Adventurer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do not underestimate the power of the Force.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do students of Zen Buddhism do Om-work?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dungeons and Dragons is just a lot of Saxon Violence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;Chapter VIII<BR>\n&nbsp;Due to the convergence of forces beyond his comprehension, Salvatore<BR>\nQuanucci was suddenly squirted out of the universe like a watermelon<BR>\nseed, and never heard from again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','CF&C stole it, fair and square.<BR>\n&nbsp;-- Tim Hahn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Culture is the habit of being pleased with the best and knowing why.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There is always something new out of Africa.<BR>\n&nbsp;-- Gaius Plinius Secundus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','For a holy stint, a moth of the cloth gave up his woolens for lint.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Did you know ...<BR>\n&nbsp;That no-one ever reads these things?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I hate trolls.  Maybe I could metamorph it into something else -- like a<BR>\nravenous, two-headed, fire-breathing dragon.<BR>\n&nbsp;-- Willow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Ahhhhhh... the smell of cuprinol and mahogany.  It excites me to...<BR>\nacts of passion... acts of... ineptitude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','All the really good ideas I ever had came to me while I was milking a cow.<BR>\n&nbsp;-- Grant Wood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','AMAZING BUT TRUE ...<BR>\n&nbsp;There is so much sand in Northern Africa that if it were spread out it<BR>\n&nbsp;would completely cover the Sahara Desert.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If the English language made any sense, lackadaisical would have something<BR>\nto do with a shortage of flowers.<BR>\n&nbsp;-- Doug Larson<BR>\n&nbsp;[Not to mention, butterfly would be flutterby. Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If you are going to walk on thin ice, you may as well dance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There is a natural hootchy-kootchy to a goldfish.<BR>\n&nbsp;-- Walt Disney');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If it pours before seven, it has rained by eleven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If you do not think about the future, you cannot have one.<BR>\n&nbsp;-- John Galsworthy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Indifference will certainly be the downfall of mankind, but who cares?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If God is dead, who will save the Queen?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Identify your visitor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There is always someone worse off than yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I will make you shorter by the head.<BR>\n&nbsp;-- Elizabeth I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I will never lie to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I want to reach your mind -- where is it currently located?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I refuse to have a battle of wits with an unarmed person.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I smell a wumpus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I love treason but hate a traitor.<BR>\n&nbsp;-- Gaius Julius Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I live the way I type; fast, with a lot of mistakes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;[I plan] to see, hear, touch, and destroy everything in my path,<BR>\nincluding beets, rutabagas, and most random vegetables, but excluding yams,<BR>\nas I am absolutely terrified of yams...<BR>\n&nbsp;Actually, I think my fear of yams began in my early youth, when many<BR>\nof my young comrades pelted me with same for singing songs of far-off lands<BR>\nand deep blue seas in a language closely resembling that of the common sow.<BR>\nMy psychosis was further impressed into my soul as I reached adolescence,<BR>\nwhen, while skipping through a field of yams, light-heartedly tossing flowers<BR>\ninto the stratosphere, a great yam-picking machine tore through the fields,<BR>\npursuing me to the edge of the great plantation, where I escaped by diving<BR>\ninto a great ditch filled with a mixture of water and pig manure, which may<BR>\nexplain my tendency to scream, \"Here come the Martians!  Hide the eggs!\" every<BR>\ntime I have pork.  But I digress.  The fact remains that I cannot rationally<BR>\ndeal with yams, and pigs are terrible conversationalists.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I have more hit points that you can possible imagine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"I only touch base with reality on an as-needed basis!\"<BR>\n&nbsp;-- Royal Floyd Mengot (Klaus)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I never did it that way before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I will not forget you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I am the mother of all things, and all things should wear a sweater.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I can read your mind, and you should be ashamed of yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I feel sorry for your brain... all alone in that great big head...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I can resist anything but temptation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','How come only your friends step on your new white sneakers?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','How come we never talk anymore?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I always wake up at the crack of ice.<BR>\n&nbsp;-- Joe E. Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Laughing at you is like drop kicking a wounded humming bird.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Language is a virus from another planet.<BR>\n&nbsp;-- William Burroughs');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Let others praise ancient times; I am glad I was born in these.<BR>\n&nbsp;-- Ovid (43 B.C. - A.D. 18)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Some parts of the past must be preserved, and some of the future prevented<BR>\nat all costs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Know what I hate most?  Rhetorical questions.<BR>\n&nbsp;-- Henry N. Camp');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','They finally got King Midas, I hear.  Gild by association.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Lake Erie died for your sins.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Look!  Before our very eyes, the future is becoming the past.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mother is far too clever to understand anything she does not like.<BR>\n&nbsp;-- Arnold Bennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','This is NOT a repeat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','This is the tomorrow you worried about yesterday.  And now you know why.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Rainy days and Mondays always get me down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It was one of those perfect summer days -- the sun was shining, a breeze<BR>\nwas blowing, the birds were singing, and the lawn mower was broken ...<BR>\n&nbsp;--- James Dent');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The world wants to be deceived.<BR>\n&nbsp;-- Sebastian Brant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The sky is blue so we know where to stop mowing.<BR>\n&nbsp;-- Judge Harold T. Stone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The whole world is a scab.  The point is to pick it constructively.<BR>\n&nbsp;-- Peter Beard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"It was a virgin forest, a place where the Hand of Man had never set foot.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There are two kinds of pedestrians... the quick and the dead.<BR>\n&nbsp;-- Lord Thomas Rober Dewar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is better to kiss an avocado than to get in a fight with an aardvark.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is easier to resist at the beginning than at the end.<BR>\n&nbsp;-- Leonardo da Vinci');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is the business of the future to be dangerous.<BR>\n&nbsp;-- Hawkwind');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is better to be bow-legged than no-legged.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is a lesson which all history teaches wise men, to put trust in ideas,<BR>\nand not in circumstances.<BR>\n&nbsp;-- Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is better never to have been born.  But who among us has such luck?<BR>\nOne in a million, perhaps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There has been an alarming increase in the number of things you know<BR>\nnothing about.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','In case of fire, stand in the hall and shout \"Fire!\"<BR>\n&nbsp;-- The Kidner Report');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Imagination is the one weapon in the war against reality.<BR>\n&nbsp;-- Jules de Gaultier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If you knew what to say next, would you say it?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Include me out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','By perseverance the snail reached the Ark.<BR>\n&nbsp;-- Charles Spurgeon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Bushydo -- the way of the shrub.  Bonsai!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Phone call for chucky-pooh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Boy!  Eucalyptus!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Blue paint today.<BR>\n&nbsp;[Funny to Jack Slingwine, Guy Harris and Hal Pierson.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Bizarreness is the essence of the exotic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Biggest security gap -- an open mouth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nothing is so firmly believed as that which we least know.<BR>\n&nbsp;-- Michel de Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Being frustrated is disagreeable, but the real disasters in life begin<BR>\nwhen you get what you want.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Before I knew the best part of my life had come, it had gone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nothing is so often irretrievably missed as a daily opportunity.<BR>\n&nbsp;-- Ebner-Eschenbach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','BE ALOOF!  (There has been a recent population explosion of lerts.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','BE ALERT!!!! (The world needs more lerts...)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Batteries not included.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','BAD CRAZINESS, MAN!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Avec!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','As Zeus said to Narcissus, \"Watch yourself.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Are we not men?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Any time things appear to be going better, you have overlooked something.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nothing lasts forever.<BR>\nWhere do I find nothing?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Any stone in your boot always migrates against the pressure gradient to<BR>\nexactly the point of most pressure.<BR>\n&nbsp;-- Milt Barber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','And I alone am returned to wag the tail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','An atom-blaster is a good weapon, but it can point both ways.<BR>\n&nbsp;-- Isaac Asimov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','AMAZING BUT TRUE ...<BR>\n&nbsp;If all the salmon caught in Somewhere in one year were laid end to end<BR>\n&nbsp;across the Sahara Desert, the smell would be absolutely awful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Am I ranting?  I hope so.  My ranting gets raves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','All phone calls are obscene.<BR>\n&nbsp;-- Karen Elizabeth Gordon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;A reverend wanted to telephone another reverend.  He told the operator,<BR>\n\"This is a parson to parson call.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Never use \"etc.\" -- it makes people think there is more where there is not<BR>\nor that there is not space to list it all, etc.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"To vacillate or not to vacillate, that is the question ... or is it?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','NOTICE:<BR>\n&nbsp;-- THE ELEVATORS WILL BE OUT OF ORDER TODAY --<BR>\n&nbsp;(The nearest working elevator is in the building across the street.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','New members are urgently needed in the Society for Prevention of<BR>\nCruelty to Yourself.  Apply within.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','May your camel be as swift as the wind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','May a hundred thousand midgets invade your home singing cheesy lounge-lizard<BR>\nversions of songs from The Wizard of Oz.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Memory should be the starting point of the present.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Man who falls in blast furnace is certain to feel overwrought.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Man who falls in vat of molten optical glass makes spectacle of self.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mirrors should reflect a little before throwing back images.<BR>\n&nbsp;-- Jean Cocteau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Marigold:		Jealousy<BR>\nMint:			Virute<BR>\nOrange blossom:		Your purity equals your loveliness<BR>\nOrchid:			Beauty, magnificence<BR>\nPansy:			Thoughts<BR>\nPeach blossom:		I am your captive<BR>\nPetunia:		Your presence soothes me<BR>\nPoppy:			Sleep<BR>\nRose, any color:	Love<BR>\nRose, deep red:		Bashful shame<BR>\nRose, single, pink:	Simplicity<BR>\nRose, thornless, any:	Early attachment<BR>\nRose, white:		I am worthy of you<BR>\nRose, yellow:		Decrease of love, rise of jealousy<BR>\nRosebud, white:		Girlhood, and a heart ignorant of love<BR>\nRosemary:		Remembrance<BR>\nSunflower:		Haughtiness<BR>\nTulip, red:		Declaration of love<BR>\nTulip, yellow:		Hopeless love<BR>\nViolet, blue:		Faithfulness<BR>\nViolet, white:		Modesty<BR>\nZinnia:			Thoughts of absent friends<BR>\n&nbsp;* An upside-down blossom reverses the meaning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Imagine what we can imagine!<BR>\n&nbsp;-- Arthur Rubinstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Man who sleep in beer keg wake up sticky.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Most general statements are false, including this one.<BR>\n&nbsp;-- Alexander Dumas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is fraught with opportunities to keep your mouth shut.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life -- Love It or Leave It.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is like a simile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Let me put it this way: today is going to be a learning experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything takes longer, costs more, and is less useful.<BR>\n&nbsp;-- Erwin Tomash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything should be built top-down, except this time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','To see you is to sympathize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything should be built top-down, except the first time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything might be different in the present if only one thing had<BR>\nbeen different in the past.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Trouble always comes at the wrong time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything bows to success, even grammar.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sailors in ships, sail on!  Even while we died, others rode out the storm.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dyslexics have more fnu.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Remember the... the... uhh.....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When eating an elephant take one bite at a time.<BR>\n&nbsp;-- Gen. C. Abrams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Ducks?  What ducks??');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Duckies are fun!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Time is but the stream I go a-fishing in.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Drawing on my fine command of language, I said nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Plastic...  Aluminum...  These are the inheritors of the Universe!<BR>\nFlesh and Blood have had their day... and that day is past!<BR>\n&nbsp;-- Green Lantern Comics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dr. Livingston?<BR>\nDr. Livingston I. Presume?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dr. Jekyll had something to Hyde.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Double!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Wasting time is an important part of living.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Fats Loves Madelyn.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','This sentence no verb.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Facts, apart from their relationships, are like labels on empty bottles.<BR>\n&nbsp;-- Sven Italla');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','True to our past we work with an inherited, observed, and accepted vision of<BR>\npersonal futility, and of the beauty of the world.<BR>\n&nbsp;-- David Mamet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','We must die because we have known them.<BR>\n&nbsp;-- Ptah-hotep, 2000 B.C.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If everything seems to be going well, you have obviously overlooked something.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Who dat who say \"who dat\" when I say \"who dat\"?<BR>\n&nbsp;-- Hattie McDaniel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If all men were brothers, would you let one marry your sister?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Idleness is the holiday of fools.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Who messed with my anti-paranoia shot?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Why does a ship carry cargo and a truck carry shipments?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I will always love the false image I had of you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I thought YOU silenced the guard!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I saw what you did and I know who you are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I predict that today will be remembered until tomorrow!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Why would anyone want to be called \"Later\"?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I hear the sound that the machines make, and feel my heart break, just<BR>\nfor a moment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I have seen the Great Pretender and he is not what he seems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I have become me without my consent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Zeus gave Leda the bird.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I have a terrible headache,  I was putting on toilet water and the lid fell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I fear explanations explanatory of things explained.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','You can get there from here, but why on earth would you want to?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I exist, therefore I am paid.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I enjoy the time that we spend together.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','You auto buy now.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','[ ] Safeguard this message - it is an important historical document.<BR>\n[ ] Delete after reading -- Subversive Literature.<BR>\n[ ] Ignore and go back to what you were doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I despise the pleasure of pleasing people whom I despise.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Would you care to drift aimlessly in my direction?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I can relate to that.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Would that my hand were as swift as my tongue.<BR>\n&nbsp;-- Alfieri');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','WRONG!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Huh?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','How untasteful can you get?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','How come wrong numbers are never busy?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Without adventure, civilization is in full decay.<BR>\n&nbsp;-- Alfred North Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Honk if you love peace and quiet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Honk if you hate bumper stickers that say \"Honk if ...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"His eyes were cold.  As cold as the bitter winter snow that was falling<BR>\noutside.  Yes, cold and therefore difficult to chew...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Who are you?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Why are you so hard to ignore?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Here there be tygers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','HELP!  MY TYPEWRITER IS BROKEN!<BR>\n&nbsp;-- E. E. CUMMINGS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Whereof one cannot speak, thereof one must be silent.<BR>\n&nbsp;-- Wittgenstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Help stamp out and abolish redundancy and repetition.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Help a swallow land at Capistrano.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','My interest is in the future because I am going to spend the rest of my<BR>\nlife there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mount St. Helens should have used earth control.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What soon grows old?  Gratitude.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mother Earth is not flat!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Most burning issues generate far more heat than light.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Monday is an awful way to spend one seventh of your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','HELP!  Man trapped in a human body!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Housework can kill you if done right.<BR>\n&nbsp;-- Erma Bombeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','How much of their influence on you is a result of your influence on them?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"I found out why my car was humming.  It had forgotten the words.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Happiness makes up in height what it lacks in length.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;\"Have you lived here all your life?\"<BR>\n&nbsp;\"Oh, twice that long.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Hedonist for hire... no job too easy!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Fly me away to the bright side of the moon ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Furious activity is no substitute for understanding.<BR>\n&nbsp;-- H.H. Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Forest fires cause Smokey Bears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','For thee the wonder-working earth puts forth sweet flowers.<BR>\n&nbsp;-- Titus Lucretius Carus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Just give Alice some pencils and she will stay busy for hours.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','I hate quotations.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','General notions are generally wrong.<BR>\n&nbsp;-- Lady M.W. Montagu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Every word is like an unnecessary stain on silence and nothingness.<BR>\n&nbsp;-- Beckett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Every time you manage to close the door on Reality, it comes in through the<BR>\nwindow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Every absurdity has a champion who will defend it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything can be filed under \"miscellaneous\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Everything you know is wrong!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Events are not affected, they develop.<BR>\n&nbsp;-- Sri Aurobindo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Editing is a rewording activity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Eggheads unite!  You have nothing to lose but your yolks.<BR>\n&nbsp;-- Adlai Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"Earth is a great, big funhouse without the fun.\"<BR>\n&nbsp;-- Jeff Berner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','DYSLEXICS OF THE WORLD, UNTIE!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Facts do not cease to exist because they are ignored.<BR>\n&nbsp;-- Aldous Huxley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Drop that pickle!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Does a one-legged duck swim in a circle?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;\"Do you believe in intuition?\"<BR>\n&nbsp;\"No, but I have a strange feeling that someday I will.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Moebius always does it on the same side.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mobius strippers never show you their back side.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Microbiology Lab:  Staph Only!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Metermaids eat their young.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Mene, mene, tekel, upharsen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Meester, do you vant to buy a duck?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','May your Tongue stick to the Roof of your Mouth with the Force of a<BR>\nThousand Caramels.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','May the fleas of a thousand camels infest your armpits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','May a Misguided Platypus lay its Eggs in your Jockey Shorts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Madness takes its toll.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Love the sea?  I dote upon it -- from the beach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Lookie, lookie, here comes cookie...<BR>\n&nbsp;-- Stephen Sondheim');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Look out!  Behind you!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Littering is dumb.<BR>\n&nbsp;-- Ronald Macdonald');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Like winter snow on summer lawn, time past is time gone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life would be tolerable but for its amusements.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is not for everyone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is like an analogy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is both difficult and time consuming.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life being what it is, one dreams of revenge.<BR>\n&nbsp;-- Paul Gauguin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Let he who takes the plunge remember to return it by Tuesday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','La-dee-dee, la-dee-dah.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Join the march to save individuality!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It would save me a lot of time if you just gave up and went mad now.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It occurred to me lately that nothing has occurred to me lately.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It looks like blind screaming hedonism won out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is very difficult to prophesy, especially when it pertains to the future.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','It is easier to run down a hill than up one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Is death legally binding?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Indecision is the true basis for flexibility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','In my end is my beginning.<BR>\n&nbsp;-- Mary Stuart, Queen of Scots');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Immanuel Kant but Kubla Khan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If time heals all wounds, how come the belly button stays the same?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If there is no God, who pops up the next Kleenex?<BR>\n&nbsp;-- Art Hoppe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If the odds are a million to one against something occurring, chances<BR>\nare 50-50 it will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If the meanings of \"true\" and \"false\" were switched, then this sentence<BR>\nwould not be false.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If the grass is greener on other side of fence, consider what may be<BR>\nfertilizing it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If life is merely a joke, the question still remains: for whose amusement?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When does later become never?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If life gives you lemons, make lemonade.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When the English language gets in my way, I walk over it.<BR>\n&nbsp;-- Billy Sunday');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Whatever became of eternal truth?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If I love you, what business is it of yours?<BR>\n&nbsp;-- Johann van Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Whip it, whip it good!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sleep is for the weak and sickly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Slang is language that takes off its coat, spits on its hands, and goes to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Silence is the only virtue you have left.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Silence is the element in which great things fashion themselves.<BR>\n&nbsp;-- Thomas Carlyle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sight is a faculty; seeing is an art.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Save the whales.  Collect the whole set.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Save the Whales -- Harpoon a Honda.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Save the bales!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Satire does not look pretty upon a tombstone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Santa Claus is watching!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sank heaven for leetle curls.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Safety Third.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Rubber bands have snappy endings!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Ring around the collar.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Remember, drive defensively! And of course, the best defense is a good offense!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Remember that there is an outside world to see and enjoy.<BR>\n&nbsp;-- Hans Liepmann');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','This sentence does in fact not have the property it claims not to have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Reality -- what a concept!<BR>\n&nbsp;-- Robin Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Rainy days and automatic weapons always get me down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Two cars in every pot and a chicken in every garage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Think sideways!<BR>\n&nbsp;-- Ed De Bono');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Quick!!  Act as if nothing has happened!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Quack!<BR>\n&nbsp;Quack!! Quack!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','QED.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Wanna buy a duck?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Preserve the old, but know the new.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','We have lingered long enough on the shores of the Cosmic Ocean.<BR>\n&nbsp;-- Carl Sagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Prediction is very difficult, especially of the future.<BR>\n&nbsp;-- Niels Bohr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Predestination was doomed from the start.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Welcome to the Zoo!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Piece of cake!<BR>\n&nbsp;-- G.S. Koblas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Peace be to this house, and all that dwell in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What color is a chameleon on a mirror?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Paul Revere was a tattle-tale.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Our problems are so serious that the best way to talk about them is<BR>\nlightheartedly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What does \"it\" mean in the sentence \"What time is it?\"?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What causes the mysterious death of everyone?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Our houseplants have a good sense of humous.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Onward through the fog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Oh, wow!  Look at the moon!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Oh, well, I guess this is just going to be one of those lifetimes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Oh yeah?  Well, I remember when sex was dirty and the air was clean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Odets, where is thy sting?<BR>\n&nbsp;-- George S. Kaufman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','O.K., fine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','O imitators, you slavish herd!<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','We have ears, earther...FOUR OF THEM!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nudists are people who wear one-button suits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nothing can be done in one trip.<BR>\n&nbsp;-- Snider');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Not to laugh, not to lament, not to curse, but to understand.<BR>\n&nbsp;-- Spinoza');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nostalgia is living life in the past lane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Non-sequiturs make me eat lampshades.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nobody ever died from oven crude poisoning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','No yak too dirty; no dumpster too hollow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','No small art is it to sleep: it is necessary for that purpose to keep<BR>\nawake all day.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','No matter how much you do you never do enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','No guts, no glory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','No bird soars too high if he soars with his own wings.<BR>\n&nbsp;-- William Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Nietzsche is pietzsche, but Schiller is killer, and Goethe is moethe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Never volunteer for anything.<BR>\n&nbsp;-- Lackland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Never be afraid to tell the world who you are.<BR>\n&nbsp;-- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What we cannot speak about we must pass over in silence.<BR>\n&nbsp;-- Wittgenstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Solipsists of the World... you are already united.<BR>\n&nbsp;-- Kayvan Sylvan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','1 bulls, 3 cows.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','A prediction is worth twenty explanations.<BR>\n&nbsp;-- K. Brecher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;A crow perched himself on a telephone wire.  He was going to make a<BR>\nlong-distance caw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','A furore Normanorum libera nos, O Domine!<BR>\n&nbsp;[From the fury of the norsemen deliver us, O Lord!]<BR>\n&nbsp;-- Medieval prayer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','A log may float in a river, but that does not make it a crocodile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','$3,000,000.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','A vacuum is a hell of a lot better than some of the stuff that nature<BR>\nreplaces it with.<BR>\n&nbsp;-- Tennessee Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Adults die young.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Age is a tyrant who forbids, at the penalty of life, all the pleasures of youth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The shortest distance between any two puns is a straight line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The Killer Ducks are coming!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','There is no such thing as a problem without a gift for you in its hands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Think big.  Pollute the Mississippi.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','They just buzzed and buzzed...buzzed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The worst part of valor is indiscretion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The tree in which the sap is stagnant remains fruitless.<BR>\n&nbsp;-- Hosea Ballou');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The sheep died in the wool.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The mosquito exists to keep the mighty humble.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The grass is always greener on the other side of your sunglasses.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The future lies ahead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','... the flaw that makes perfection perfect.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The executioner is, I hear, very expert, and my neck is very slender.<BR>\n&nbsp;-- Anne Boleyn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The difference between this place and yogurt is that yogurt has a live culture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The day after tomorrow is the third day of the rest of your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The day advanced as if to light some work of mine; it was morning, <BR>\nand lo! now it is evening, and nothing memorable is accomplished.  <BR>\n&nbsp;-- H.D. Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The best prophet of the future is the past.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','The beauty of a pun is in the \"Oy!\" of the beholder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Tempt me with a spoon!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Take what you can use and let the rest go by.<BR>\n&nbsp;-- Ken Kesey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Progress was all right.  Only it went on too long.<BR>\n&nbsp;-- James Thurber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Quod erat demonstrandum.<BR>\n&nbsp;[Thus it is proven.  For those who wondered WTF QED means.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Please help keep the world clean: others may wish to use it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','This must be morning.  I never could get the hang of mornings.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do YOU have redeeming social value?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do you have lysdexia?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do people know you have freckles everywhere?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Do not use that foreign word \"ideals\".  We have that excellent native<BR>\nword \"lies\".<BR>\n&nbsp;-- Henrik Ibsen, \"The Wild Duck\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Pyros of the world... IGNITE !!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','To generalize is to be an idiot.<BR>\n&nbsp;-- William Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dime is money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Dignity is like a flag.  It flaps in a storm.<BR>\n&nbsp;-- Roy Mengot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Paranoid Club meeting this Friday.  Now ... just try to find out where!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Did you hear about the model who sat on a broken bottle and cut a nice figure?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Did it ever occur to you that fat chance and slim chance mean the same thing?<BR>\n&nbsp;Or that we drive on parkways and park on driveways?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Did I say 2?  I lied.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Depart in pieces, i.e., split.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Operator, please trace this call and tell me where I am.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Death to all fanatics!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Pardon me while I laugh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Custer committed Siouxicide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Congratulations are in order for Tom Reid.<BR>\n&nbsp;He says he just found out he is the winner of the 2021 Psychic of the<BR>\nYear award.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Where will it all end?  Probably somewhere near where it all began.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Which is worse: ignorance or apathy?  Who knows?  Who cares?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Why is it called a funny bone when it hurts so much?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','He who spends a storm beneath a tree, takes life with a grain of TNT.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','\"He flung himself on his horse and rode madly off in all directions.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Have you noticed that all you need to grow healthy, vigorous grass is a<BR>\ncrack in your sidewalk?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Have you locked your file cabinet?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When you dial a wrong number you never get a busy signal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Have the courage to take your own thoughts seriously, for they will shape you.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Have at you!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When pleasure remains, does it remain a pleasure?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Hard reality has a way of cramping your style.<BR>\n&nbsp;-- Daniel Dennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Happy feast of the pig!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When things go well, expect something to explode, erode, collapse or<BR>\njust disappear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Where am I?  Who am I?  Am I?  I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Why is it taking so long for her to bring out all the good in you?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Would you care to view the ruins of my good intentions?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','God, I ask for patience -- and I want it right now!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','God was satisfied with his own work, and that is fatal.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','God made the world in six days, and was arrested on the seventh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What!?  Me worry?<BR>\n&nbsp;-- Alfred E. Newman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','God is Dead.<BR>\n&nbsp;-- Nietzsche<BR>\nNietzsche is Dead.<BR>\n&nbsp;-- God<BR>\nNietzsche is God.<BR>\n&nbsp;-- Dead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Go climb a gravity well!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When a cow laughs, does milk come out of its nose?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What excuses stand in your way?  How can you eliminate them?<BR>\n&nbsp;-- Roger von Oech');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Gloffing is a state of mine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','&nbsp;\"What did you do when the ship sank?\"<BR>\n&nbsp;\"I grabbed a cake of soap and washed myself ashore.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What happens when you cut back the jungle?  It recedes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','GIVE UP!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Well, the handwriting is on the floor.<BR>\n&nbsp;-- Joe E. Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','From a certain point onward there is no longer any turning back. <BR>\nThat is the point that must be reached.<BR>\n&nbsp;-- F. Kafka');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','What is the sound of one hand clapping?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When a fly lands on the ceiling, does it do a half roll or a half loop?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','FORCE YOURSELF TO RELAX!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Flame on!<BR>\n&nbsp;-- Johnny Storm');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Wait for that wisest of all counselors, Time.<BR>\n&nbsp;-- Pericles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Five bicycles make a volkswagen, seven make a truck.<BR>\n&nbsp;-- Adolfo Guzman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Finding out what goes on in the C.I.A. is like performing acupuncture<BR>\non a rock.<BR>\n&nbsp;-- New York Times, Jan. 20, 1981');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Use a pun, go to jail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Stop me, before I kill again!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Stealing a rhinoceros should not be attempted lightly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Stamp out philately.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sorry.  Nice try.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sorry.  I forget what I was going to say.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Life is just a bowl of cherries, but why do I always get the pits?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Confucius say too much.<BR>\n&nbsp;-- Recent Chinese Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','If God is One, what is bad?<BR>\n&nbsp;-- Charles Manson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Sometimes, too long is too long.<BR>\n&nbsp;-- Joe Crowe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','To love is good, love being difficult.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Colorless green ideas sleep furiously.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','When your memory goes, forget it!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('miscellaneous','Smear the road with a runner!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The hidden flaw never remains hidden.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more boring and out-of-date the magazines in the<BR>\nwaiting room, the longer you will have to wait for<BR>\nyour scheduled appointment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The organization of any program reflects the organization<BR>\nof the people who developed it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The feasibility of an operation is not the best<BR>\nindiciation for its performance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nature always sides with the hidden flaw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nature will tell you a direct lie if she can.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When a writer prepares a manuscript on a subject he does<BR>\nnot understand, his work will be understood only by<BR>\nreaders who know more about that subject than he does.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A mediocre player will sink to the level of his or<BR>\nher opposition.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All American cars are basically Chevrolets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When in doubt, predict that the trend will continue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Capitalism can exist in one of only two states:<BR>\nwelfare or warfare.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I finally got it all together...<BR>\nbut I forgot where I put it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A coup that is known in advance is a coup that does not<BR>\ntake place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more general the title of a course, the less<BR>\nyou will learn from it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any bureaucracy, paperwork increases as you spend<BR>\nmore and more time reporting on the less and less you<BR>\nare doing.  Stability is achieved when you spend all of<BR>\nyour time reporting on the nothing you are doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People will believe anything if you whisper it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A fool and his money are invited places.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Laziness is the mother of nine inventions out of ten.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more directives you issue to solve a problem,<BR>\nthe worse it gets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','At any level of traffic, any delay is intolerable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','As soon as the flight attendant serves the coffee, the<BR>\nairliner encounters turbulence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a series of events can go wrong, it will do so in<BR>\nin the worst possible sequence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','He who hesitates is not only lost, but several miles from<BR>\nthe next freeway exit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When the product is destined to fail, the delivery system<BR>\nwill perform perfectly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The chief cause of problems is solutions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Information travels more surely to those with a<BR>\nlesser need to know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Success can be insured only by devising a defense against<BR>\nfailure of the contingency plan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is impossible to build a fool proof system;<BR>\nbecause fools are so ingenious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A stagnant science is at a standstill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Them what gets--has.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The lagging activity in a project will invariably be found<BR>\nin the area where the highest overtime rates lie waiting.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When things are going well, someone will inevitably<BR>\nexperiment detrimentally.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Work may be the crabgrass of life, but money is still the<BR>\nwater that keeps it green.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If not controlled, work will flow to the competent<BR>\nman until he submerges.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Hockey is a game played by six good players and the<BR>\nhome team.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything put together sooner or later falls apart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All general statements are false.  (Think about it.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Talent in staff work or sales will continually be<BR>\ninterpreted as managerial ability.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If it happens, it must be possible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When your opponent is down, kick him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have to ask, you are not entitled to know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If anything can go wrong, it will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An original idea can never emerge from committee<BR>\nin its original form.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The road to hell is paved with good intentions<BR>\nand littered with sloppy analyses!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never be first to do anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No experiment is ever a complete failure.<BR>\nIt can always be used as a bad example.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A bird in the hand is dead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a three-story buiding served by one elevator, nine<BR>\ntimes out of ten the elevator care will be on a floor<BR>\nwhere you are not.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Calm down .... it is only ones and zeros.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Democracy is that form of government where<BR>\neverybody gets what the majority deserves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No system is ever completely debugged:  Attempts to debug<BR>\na system will inevitably introduce new bugs that are even<BR>\nharder to find.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Cop-out number 1.<BR>\nYou should have seen it when I got it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Speak softly and own a big, mean doberman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When a student asks for a second time if you have read<BR>\nhis book report, he did not read the book.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	Everything is a system.<BR>\n(2)	Everything is part of a larger system.<BR>\n(3)	The universe is infinitely systematized both upward<BR>\n&nbsp;(larger systems) and downward (smaller systems).<BR>\n(4)	All systems are infinitely complex.  (The illuison<BR>\n&nbsp;of simplicity comes from focussing attention on<BR>\n&nbsp;one or a few variables).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The least experienced fisherman always catches the<BR>\nbiggest fish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All trails have more uphill sections that they have<BR>\nlevel or downhill sections.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The speed of an oncoming vehicle is directly proportional<BR>\nto the length of the passing zone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Pity the poor egg;<BR>\nIt only gets laid once in its life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any tool dropped while repairing a car will roll underneath<BR>\nto the exact center.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No man is lonely while eating spaghetti.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything that can go wrong, will go wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If there are only two shows worth watching, they will<BR>\nbe on together.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The idea is to die young as late as possible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The stomach expands to accommodate the amount of<BR>\njunk food available.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The probablility of a cat eating its dinner has<BR>\nabsolutely nothing to do with the price of the food<BR>\nplaced before it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Most people deserve each other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A shy, introverted child will choose a crowded public<BR>\narea to loudly demonstrate new acquired vocabulary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The system itself does not do what it says it is doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you allow someone to get in front of you either:<BR>\n(1)	The car in front will be the last one over a<BR>\n&nbsp;railroad crossing, and you will be stuck waiting<BR>\n&nbsp;for a long, slow-moving train; or<BR>\n(2)	you both will have the same destination and the<BR>\n&nbsp;other car will get the last parking space.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I no longer get lost in the shuffle,<BR>\nI shuffle along with the lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The usefulness of any meeting<BR>\nis in inverse proportion to the attendance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any household, junk accumulates to the the space<BR>\navailable for its storage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one thing that money can not buy is poverty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more expensive the gadget, the less often you<BR>\nwill use it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The only new TV show worth watching will be cancelled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','During the time an item is on back-order, it will be<BR>\navailable cheaper and quicker from many other sources.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Once a dish is fouled up, anything added to save it<BR>\nonly makes it worse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any cooking utensil placed in the dishwasher will be<BR>\nneeded immediately thereafter for something else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A RACF protected dataset is inaccessible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The spot you are scrubbing on glassware is always on<BR>\nthe other side.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A carelessly planned project will take three times<BR>\nlonger than expected; a carefully planned project will<BR>\ntake only twice as long.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you do something right once, someone will ask<BR>\nyou to do it again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Virtue is its own punishment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The scratch on the record is always through the song<BR>\nyou like most.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If several things that could have gone wrong have not<BR>\ngone wrong, it would have been ultimately beneficial<BR>\nfor them to have gone wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Ignorance should be painful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','To err is human, to forgive is divine --<BR>\nbut to forget it altogether is humane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is trying to figure out how the family next<BR>\ndoor is doing it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The man who has no more problems is out of the game.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Remain silent about your intentions until you are sure');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When a distinguised scientist states something is possible,<BR>\nhe is almost certainly right.  When he states that<BR>\nsomething is impossible, he is very probably wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You win some, lose some, and some get rained out; but you<BR>\ngotta suit up for them all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','After all is said and done, a hell of a lot more is said<BR>\nthan done');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The six steps of program management are:<BR>\n(1)	Wild enthusiasm<BR>\n(2)	Disenchantment<BR>\n(3)	Total confusion<BR>\n(4)	Search for guilty<BR>\n(5)	Punishment for the innocent<BR>\n(6)	Promotion of the non-participants');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The higher the level of prestige accorded the people<BR>\nbehind the plan, the least less chance there is of<BR>\nabandoning it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first place to look for anything is the last place<BR>\nyou would expect to find it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any organization there will always be one person<BR>\nwho knows what is going on.<BR>\nThis person must be fired.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you try to please everybody, nobody will like it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You can pray hard enough to make water run uphill<BR>\nhow hard?<BR>\nHard enough to make water run uphill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers do not read books like<BR>\n\"effective listening\" and \"communication skills\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You are never given enough time or money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first page the author turns to upon receiving an<BR>\nadvance copy will be the page containing the worst<BR>\nerror.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Make it possible for programmers to write programs<BR>\nin english and you will find that programmers cannot<BR>\nwrite in english.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a program is useful, it will be changed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nothing is ever accomplished by a reasonable man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A lot of what appears to be progress is just so much<BR>\ntechnological roccoco.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is ok to be ignorant in some areas,<BR>\nbut some people abuse the privilege.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Clearly stated instructions will consistently produce<BR>\nmultiple interpretations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When necessary, metric and inch tools can be used<BR>\ninterchangeably.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything tastes more or less like chicken.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never wrestle with a pig; you both get dirty, and the pig<BR>\nlikes it!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is saving quarters in a mason jar for<BR>\nChristmas and spending them by Easter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is wondering why you should balance yours<BR>\nif the government can not balance theirs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A theory is better than its explanation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A diplomat is someone who can tell you to go to hell<BR>\nin such a way that you look forward to the trip.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter how minor the task, you will inevitably end<BR>\nup covered with grease and motor oil.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If daily class attendance is mandatory, a schedules<BR>\nexam will product increased absenteeism.  If attendance<BR>\nis optional, a schedules exam will produce persons you<BR>\nhave never seen before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The pills to be taken with meals will be the least<BR>\nappetizing ones.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one who least wants to play is the one who will win.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever can go to New York, will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The worse your line is tangled, the better is the<BR>\nfishing around you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Office machines which function perfectly during normal<BR>\nbusiness hours will break down when you return to the<BR>\noffice at night to use them for personal business.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The repairman will never have seen a model quite like<BR>\nyours before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Progress does not consist in replacing a theory that is<BR>\nwrong with one that is right.  It consists in replacing<BR>\na theory that is wrong with one that is more sublty wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A complex system that works is invariably found to have<BR>\nevolved from a simple system that works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','How did they measure hail before the golf ball was invented.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The quality of correlation is inversely proportional<BR>\nto the density of control.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If reproducibility may be a problem conduct the<BR>\ntest only once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything is revealed to he who turns over enough stones.<BR>\n(Including the snakes that he did not want to find.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The crucial memorandum will be snared in the out-basket by<BR>\nthe paper clip of the overlying memo and go to file.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When in doubt, mumble.<BR>\nWhen in trouble, delegate.<BR>\nWhen in charge, ponder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When the need arises, any tool or object closest to you<BR>\nbecomes a hammer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Live within your income,<BR>\neven if you have to borrow to do so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everyone gets away with something.<BR>\nNo one gets away with everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Make three correct guesses consectively and you will<BR>\nestablish yourself as an expert.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The distance to the gate is inversely proportional<BR>\nto the time available to catch you flight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There are three ways to get things done:<BR>\n&nbsp;(1)  Do it yourself,<BR>\n&nbsp;(2)  Hire someone to do it, or<BR>\n&nbsp;(3)  Forbid your kids to do it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one course you must take to graduate will not be<BR>\noffered during your last semester.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything east of the San Andreas fault will evenutally<BR>\nplunge into the Atlantic ocean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any given program will expand to fill all available memory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Definition of an elephant:<BR>\nA mouse built to goverment specifications.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Complex systems tend to oppose their own proper function.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is better to be part of the idle rich class<BR>\nthan be part of the idle poor class.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An Irishman is not drunk as long as<BR>\nhe can hang onto a single blade of grass<BR>\nand not fall off the face of the earth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Pills to be taken in twos always come<BR>\nout of the bottle in threes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','After winning an argument with his wife,<BR>\nthe wisest thing a man can do is apologize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any surviving best shots are ruined when someone<BR>\ninadvertently open the darkroom door and all of the<BR>\ndark leaks out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It takes longer to glue a vase together than to<BR>\nbreak one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No news is ... impossible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Program complexity grows until it exceeds the capability<BR>\nof the programmer who must maintain it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers do not utter profanities at an elevated<BR>\ndecible level.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more elaborate and costly the equipment, the greater<BR>\nthe chance of having to stop at the fish market<BR>\non the way home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything you try to fix will take longer and cost more than<BR>\nyou thought.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Flynn is dead<BR>\nTron is dead<BR>\nlong live the MCP.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever carrousel you stand by, your baggage will<BR>\ncome in on another one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A penny saved is ... not much.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If it would be cheaper to repair the old one, the<BR>\ncompany will insist on the latest model.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When more and more people are thrown out of work,<BR>\nunemployment results.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I have not lost my mind, it is backed up on tape somewhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You never have the right number of pills left on the<BR>\nlast day of a prescription.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any sufficiently advanced technology is<BR>\nindistinguishable from magic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','For every action, there is an equal and opposite<BR>\ncriticism.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Assumption is the mother of all foul-ups.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Of two possible events,<BR>\nonly the undesired one will occur.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','1) Things will get worse before they get better.<BR>\n2) Who said things would get better?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Justice always prevails...<BR>\nthree times out of seven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Blessed is he who has reached the point of no return and<BR>\nknows it for he shall enjoy living.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never get excited about a blind date because of how<BR>\nit sounds over the phone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Friends come and go, but enemies accumulate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers argue with the systems analyst as a<BR>\nmatter of principle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Avoid reality at all costs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A Smith and Wesson beats four aces.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any measuring utensil used for liquid ingredients will<BR>\nbe needed immediately thereafter for dry ingredients.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have watched a TV series only once, and you watch<BR>\nit again, it will be a rerun of the same episode.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When they want it bad (in a rush), they get it bad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The light at the end of the tunnel is the headlamp of<BR>\nan oncoming train.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The yoo-hoo you yoo-hoo into the forest is the yoo-hoo you<BR>\nget back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Indecision is the basis for flexibility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When in doubt, mumble.  When in trouble, delegate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever it is, somebody will have had it for lunch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When travelling overseas, the exchange rate improves<BR>\nmarkedly the day after one has purchased foreign<BR>\ncurrency.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Fact is solidified opinion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more ridiculous a belief system,<BR>\nthe higher probability of its success.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never needlessly disturb a thing at rest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything happens at the same time with nothing in between.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Old age is always fifteen years older than I am.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nature always sides with the hidden flaw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whenever you cut your fingernails you will find a<BR>\nneed for them an hour later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Where you stand on an issue depends on where you sit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everbody wants a pain shot at the same time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Progress is made on alternate Fridays.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','To know yourself is the ultimate form of aggression.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The primary function of the design engineer is to make<BR>\nthings difficult for the fabricator and impossible<BR>\nfor the serviceman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any time you wish to demonstrate something, the number of<BR>\nfaults is proportional to the number of viewers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Some of it plus the rest of it is all of it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The item you had your eye on the minute you walked in<BR>\nwill be taken by the person in front of you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one who snores will fall asleep first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Time spent consuming a meal is in inverse proportion<BR>\nto time spent preparing it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You will remember that you forgot to take out the trash<BR>\nwhen the garbage truck is two doors away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never play leapfrog with a unicorn.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything takes longer than you expect.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You can observe a lot just by watching.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It does not matter if you fall down as long as you pick<BR>\nup something from the floor while you get up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A bird in hand is safer than one overhead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is far better to do nothing that to do<BR>\nsomething efficiently.<BR>\n&nbsp;-- Siezbo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everyone has a scheme for getting rich that will not work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Left to themselves, all things go from bad to worse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The time available to go fishing shrinks as the fishing<BR>\nseason draws nearer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you see that there are four possible ways in which a<BR>\nprocedure can go wrong, and circumvent these, then a<BR>\nfifth way, unprepared for, will promptly develop.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','To err is human -- to blame it on someone else is<BR>\neven more human.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If an experiment works, you must be using the wrong<BR>\nequipment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A fool and his money soon go partying.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You sure have to borrow a lot of money these days to<BR>\nbe an average consumer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The slowest checker is always at the quick-check-out<BR>\nlane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The night before the english history mid-term, your<BR>\nbiology instructor will assign 200 pages on planaria.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A free agent is anything but.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','For every human problem, there is a neat, plain solution --<BR>\nand it is always wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In a hierarchical system, the rate of pay varies<BR>\ninversely with the unpleasantness and difficulty<BR>\nof the task.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything may be divided into as many parts as you please.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is better to solve a problem with a crude<BR>\napproximation and know the truth, than to demand an<BR>\nexact solution and not know the truth at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','King Arthur ran the first knight club.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you change lines, the one you just left will start<BR>\nto move faster than the one you are now in.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A president of a democracy is a man who is always ready,<BR>\nwilling, and able to lay down your life for his country.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A car and a truck approaching each other on an otherwise<BR>\ndeserted road will meet at the narrow bridge.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have to park six blocks away, you will find two<BR>\nnew parking spaces right in front of the building<BR>\nentrance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Build a system that even a fool can use,<BR>\nand only a fool will use it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I finally got it all together ...<BR>\nbut I forgot where I put it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is no such thing as a straight line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more time and energy you put into preparing a meal<BR>\nthe greater the chance you guests will spend the entire<BR>\nmeal discussing other meals they have had.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nothing is ever as simple as it seems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An optimist is a person who looks forward to marriage.<BR>\nA pessimist is a married optimist!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything good in life is either illegal, immoral or<BR>\nfattening.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything good in life is either illegal, immoral<BR>\nor fattening.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever happens to you, it will previously have<BR>\nhappened to everyone you know only more so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any hierarchy, each individual rises to his own level<BR>\nof incompetence, and then remains there.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one ingredient you made a special trip to the store<BR>\nto get will be the one thing your guest is allergic to.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The quickest way to experiment with acupuncture is to<BR>\ntry on a new shirt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Beauty is only skin deep, ugly goes clear to the bone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The severity of an itch is inversely proportional<BR>\nto the reach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Writings prepared without understanding must fail in the<BR>\nfirst ojbective of communication -- informing<BR>\nthe uninformed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All things being equal, all things are never equal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Misery no longer loves company<BR>\nnowdays it insists on it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When working toward the solution of a problem,<BR>\nit always helps if you know the answer.<BR>\nProvided of course you know there is a problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never eat prunes when you are famished.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An easily-understood, workable falsehood is more useful<BR>\nthan a complex, incompreshensible truth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nothing is ever done for the right reasons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any child who chatters non-stop at home will adamantly<BR>\nrefuse to utter a word when requested to demonstrate<BR>\nfor an audience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When all else fails, read the instructions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers punch up their own programs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nothing improves an innovation like lack of controls.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a straight line fit is required, obtain only two<BR>\ndata points.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Hot glass looks exactly the same as cold glass.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','That component of any circuit which has the shortest<BR>\nservice life will be placed in the least<BR>\naccessible location.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If it would be cheaper to buy a new unit, the company<BR>\nwill insist upon repairing the old one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Most projects require three hands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Celibacy is not hereditary.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any task worth doing was worth doing yesterday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Blessed are those who go around in circles,<BR>\nfor they shall be known as wheels.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Possessions increase to fill the space available for<BR>\ntheir storage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The ratio of time involved in work to time available for<BR>\nwork is usually about 0.6');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The cream rises to the top.<BR>\nSo does the scum.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An expert is anyone from out of town.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The sun goes down just when you need it the most.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I know you believe you understand<BR>\n&nbsp;what you think I said,<BR>\n&nbsp;however, I am not sure you realize,<BR>\n&nbsp;that what I think you heard<BR>\n&nbsp;is not what I meant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Pure drivel tends to drive ordinary<BR>\ndrivel off the tv screen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In the fight between you and the world, back the world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Fuzzy project objectives are used to avoid the<BR>\nembarrassment of estimating the corresponding costs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A lack of planning on your part<BR>\ndoes not constitute an emergency on my part.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','ACF2 is a four letter word.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first myth of management is that it exists<BR>\nthe second myth of management is that success equals skill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Information deteriorates upward through the bureaucracies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first time is for love.<BR>\nThe next time is $200.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers know what saad means.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Authorization for a project will be granted only when<BR>\nnone of the authorizers can be blamed if the project<BR>\nfails but when all of the authorizers can claim credit<BR>\nif it succeeds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is trying to make $25.00 go as far today as<BR>\nit did when you were first married.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any dealings with a collective body of people, the<BR>\npeople will always be more tacky than originally expected.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There are some things which are impossible to know -<BR>\nbut it is impossible to know these things.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A disagreeable task is its own reward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	The telephone will ring when you are outside the<BR>\n&nbsp;door, fumbling for your keys.<BR>\n&nbsp;(2)	You will reach it just in time to hear the click<BR>\n&nbsp;of the caller hanging up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything may be divided into as many parts as you please.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Far-way talent always seems better than home-developed<BR>\ntalent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Mass man must be serviced by mass means.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People to whom you are attracted invariably thing you<BR>\nremind them of someone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The love letter you finally got the courage to send<BR>\nwill be delayed in the mail long enough for you to<BR>\nmake a fool of yourself in person.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one wrench or drill bit you need will be the one<BR>\nmissing from the tool chest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Machines that have broken down will work perfectly<BR>\nwhen the repairman arrives.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Important letters which contain no errors will develop<BR>\nerrors in the mail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Only errors exist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In any series of calculations, errors tend to occur<BR>\nat the opposite end to the end at which you begin<BR>\nchecking for errors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a scientist uncovers a publishable fact, it will<BR>\nbecome central to his theory.<BR>\n&nbsp;His theory, in turn, will become central to all<BR>\nscientific truth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An expert is one who knows more and more about less<BR>\nand less until he knows absolutely everything<BR>\nabout nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never go to a doctor whose office plants have died.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any improbable event which would create maximum confusion<BR>\nif it did occur, will occur.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When life hands you a lemon, make lemonade.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You may be recognized soon.<BR>\nHide!<BR>\nIf they find you, lie.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The phone will not ring until you leave your desk and walk<BR>\nto the other end of the building.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never make a decision you can get someone else to make.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Upon returning home, the exchange rate drops again as<BR>\nsoon as one has converted all unused foreign currency.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter what happens, there is always somebody<BR>\nwho knew that it would.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Unless the results are known in advance, funding<BR>\nagencies will reject the proposal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any circuit design must contain at least one part which<BR>\nis obsolete, two parts which are unobtainable and three<BR>\nparts which at still under development.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Sanity and insanity overlap a fine gray line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Work is accomplished by those employees who have not yet<BR>\nreached their level of incompetence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Almost anything is easier to get into than out of.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Program design philosophy:<BR>\n&nbsp;Start at the beginning and continue until the end,<BR>\n&nbsp;then stop.<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','How do they know no two snowflakes are alike.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','\"Close\" only counts in horseshoes, handgrenades and<BR>\nthermonuclear devices.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The label \"all new,\" \"completely new\" or \"great news\"<BR>\nmeans the price went way way up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Cost of repair can be determined by multiplying the<BR>\ncost of your new coat by 1.75, or by multiplying the<BR>\ncost of a new washer by .75.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Keep emotionally active,<BR>\ncater to your favorite neurosis.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The probability that a household pet will raise a fuss<BR>\nto go in or out is directly proportional to the number<BR>\nand importance of your dinner guests.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Washing machines only break down during the wash cycle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It works better if you plug it in.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you smile when everything goes wrong, you are<BR>\neither a nitwit or a repariman.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first insurance agent was David -<BR>\nhe gave Goliath a piece of the rock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is nothing more frightening than ignorance in action.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything hit with a big enough hammer will fall apart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never eat at a place called moms, never play cards with a<BR>\nman named doc, and never lie down with a woman who has<BR>\ngot more troubles than you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A memorandum is written not to inform the reader<BR>\nbut to protect the writer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The last person who quit or was fired will be held<BR>\nresponsible for everything that goes wrong -- until<BR>\nthe next person quits or is fired.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Leftover nuts never match leftover bolts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The deficiency will never show itself during the test runs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Multiple-function gadgets will not perform any<BR>\nfunction adequately.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','For every credibility gap there is a gullibility gap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The chances of anybody doing anything are inversely<BR>\nproportional to the number of other people who are in<BR>\na position to do it instead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Performance is directly affected by the perversity of<BR>\ninanimate objects.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Go where the money is.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The final test is when it goes production ...<BR>\nw h e n  i t  g o e s   p r o d u c t i o n  ...<BR>\nw h e n     i  t     g  o  e  s     p  r  o  d  u  c  t<BR>\nw h  e   n       i   t       g   o   e   s       p   r   o');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more complicated and grandiose the plan, the<BR>\ngreater the chance of failure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Eat a live toad the first thing in the morning and nothing<BR>\nworse will happen to you the rest of the day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The only winner in the war of 1812 was Tchaikovsky.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No good deed goes unpunished.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If project content is allowed to change freely, the rate of<BR>\nchange will exceed the rate of progress.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','This space for rent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','After things have gone from bad to worse, the cycle<BR>\nwill repeat itself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A little ignorance can go a long way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is no safety in numbers, or in anything else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any line, however short, is still too long.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Access holes will be 1/2\" too small.<BR>\nHoles that are the right size will be in the wrong place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Teamwork is essential.  It allows you to blame someone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You are not drunk if you can lay on the floor without<BR>\nholding on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	Everything depends.<BR>\n(2)	Nothing is always.<BR>\n(3)	Everything is sometimes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers always have a better idea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The further away the disaster or accident occurs, the<BR>\ngreater the number of dead and injured required for it<BR>\nto become a story.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a situation requires undivided attention, it will<BR>\noccur simultaneously with a compelling distraction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more studying you did for the exam, the less sure<BR>\nyou are as to which answer they want.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The longer you wait in line, the greater the<BR>\nlikelihood that you are standing in the wrong line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The amount of wind will vary inversely with the number<BR>\nand experience of the people you have on board.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Persons disagreeing with your facts are always emotional<BR>\nand employ faulty reasoning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter what goes wrong, there is always somebody<BR>\nwho knew it would.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If builders built buildings the way programmers wrote<BR>\nprograms, then the first woddpecker that came along would<BR>\ndestroy civilization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first 90 percent of the task takes 90 percent of the<BR>\ntime, the last 10 percent takes the other 90 percent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any theory can be made to fit any facts by means of<BR>\napproximate, additional assumptions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Even paranoids have enemies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anyone who follows a crowd will<BR>\nnever be followed by a crowd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When you are right be logical,<BR>\nwhen you are wrong be-fuddle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If it can be borrowed and it can be broken,<BR>\nyou will borrow it and<BR>\nyou will break it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Just about the time when you think you can make ends meet<BR>\nsomebody moves the ends!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Some come to the fountain of knowledge to drink,<BR>\nsome prefer to just gargle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Old programmers never die - they just abend.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If it jams --- force it.  If it breaks,<BR>\nit needed replacing anyway.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever creates the greatest inconvenience for the largest<BR>\nnumber must happen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter how long or hard you shop for an item, after<BR>\nyou have bought it, it will be on sale somewhere cheaper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The man who can smile when things go wrong has thought of<BR>\nsomeone he can blame it on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Inside every large program<BR>\nis a small program struggling to get out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first rule of intelligent tinkering is to<BR>\nsave all of the parts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Learn to be sincere.  Even if you have to fake it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Life is like an ice-cream cone:  You have to learn to<BR>\nlick it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The most valuable quotation will be the one for which<BR>\nyou cannot determine the source.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Complicated systems produce unexpected outcomes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A little humility is arrogance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Magellan was the first strait man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	Anyone can make a decision given enough facts.<BR>\n(2)	A good manager can make a decision without enough<BR>\n&nbsp;facts.<BR>\n(3)	A perfect manager can operate in perfect ignorance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Lead, follow, or get the hell out of the way!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People are promoted not by what they can do, but what<BR>\npeople think they can do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never insult an alligator<BR>\nuntil after you have crossed the river.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The best shots happen immediately after the last<BR>\nframe is exposed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers understand Pascal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never argue with an idiot:  People watching may not be able<BR>\nto tell the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A conclusion is the place where you got tired of thinking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is always one more bug.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have something to do, and you put it off long enough<BR>\nchances are someone else will do it for you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The value of a program is proportional<BR>\nto the weight of its output.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People in systems do not do what the systems says<BR>\nthey are doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	Never draw what you can copy.<BR>\n(2)	Never copy what you can trace.<BR>\n(3)	Never trace what you can cut out and paste down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a program is useless, it will be documented.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A complex system designed from scratch never works and<BR>\ncannot be patched up to make it work.  You have to start<BR>\nover, beginning with a working simple system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','At the end of the semester you will recall having<BR>\nenrolled in a course at the beginning of the semester<BR>\n-- and never attending.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nothing is indestructible, with the possible exception<BR>\nof discount-priced fruitcakes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When reviewing your notes before an exam, the most<BR>\nimportant ones will be illegible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nobody notices when things go right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Roses are red violets are blue<BR>\nI am schizophrenic and so am I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Complex problems have simple, easy-to-understand<BR>\nwrong answers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Systems should not be unnecessarily multiplied.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There are no winners in life:  Only survivors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An optimist believes we live in the best of all<BR>\npossible worlds.<BR>\nA pessimist fears this is true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','For every credibility gap there is a gullibility fill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A large system, produced by expanding the dimensions of<BR>\na smaller system, does not behave like the smaller system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If opportunity came disguised as temptation,<BR>\none knock would be enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The best shots are generally attempted through the<BR>\nlens cap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Blessed is he who expects no gratitude,<BR>\nfor he shall not be disappointed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is better for civilization to be going down the drain,<BR>\nthan to be coming up it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I have yet to see any problem, however complicated, which,<BR>\nwhen you looked at it in the right way, did not become<BR>\nstill more complicated.<BR>\n&nbsp;-- Poul Anderson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The meek shall inherit the earth,<BR>\nbut not its mineral rights.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers do not apply DP terminology to non-DP<BR>\nsituations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If facts do not conform to the theory,<BR>\nthey must be disposed of.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A fail-safe circuit will destroy others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People will accept your idea much more readily if you tell<BR>\nthem Benjamin Franklin said it first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The meek will inherit the earth<BR>\nafter the rest of us go to the stars.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never put all your eggs in your pocket.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Unless you intend to kill him immediately; never kick a man<BR>\nin the balls, not even symbolically or perhaps especially<BR>\nnot symbolically.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is a plan that falls apart when the plumber<BR>\nhas to make an emergency visit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Only a mediocre person is always at their best.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I no longer get lost in the shuffle....<BR>\nI shuffle along with the lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Even water tastes bad when taken on doctors orders.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An alcoholic is a person who drinks more than his<BR>\nown physician.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Exciting plays occur only while you are watching the<BR>\nscoreboard or out buying a hot dog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The mountain gets steeper as you get closer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Win or lose, you lose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you can get the faulty part off, the parts house<BR>\nwill have it back-ordered.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one you want is never the one on sale.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Indifference is the only sure defense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter how strong the breeze when you leave the dock<BR>\nonce you have reached the furthest point from port<BR>\nthe wind will die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When outrageous expenditures are divided finely enough<BR>\nthe public will not have enough stake in any one<BR>\nexpenditure to squelch it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If your next pot of chili tastes better, it probably is<BR>\nbecause of something left out, rather than added.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Law expands in proportion to the resources available<BR>\nfor its enforcement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The longer the title the less important the job.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','RACF is a four letter word.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anybody can win - unless there happens to be a second entry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The source for an unattributed quotation will appear<BR>\nin the most hostile review of your work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The life expectancy of a house plant varies inversely<BR>\nwith its price and directly with its ugliness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never argue with a fool,<BR>\npeople might not know the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers drink too much coffee so that they will<BR>\nalways seem tense and overworked.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers do not practice four-syllable words before<BR>\nwalkthroughs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Serving coffee on aircraft causes turbulence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever hits the fan will not be evenly distributed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All things being equal, you lose.<BR>\n&nbsp;All things being in your favor, you still lose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Those whose approval you seek the most give you the least.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When properly administered, vacations do not diminish<BR>\nproductivity.  For every week you are away and get nothing<BR>\ndone, there is another week when your boss is away and you<BR>\nget twice as much done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A closed mouth gathers no foot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never say \"oops\" after you have submitted a job.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A pessimist is an optimist with experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When we try to pick out anything by itself we find<BR>\nit hitched to everything else in the universe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The greater the cost of putting a plan into operation,<BR>\nthe less chance there is of abandoning the plan - even<BR>\nif it subsequently becomes irrevelant.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Do not believe in miracles -- rely on them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The bigger they are, the harder they hit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter how large the work space, if two projects<BR>\nmust be done at the same time they will require the<BR>\nsame part of the work space.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The most interesting specimen will not be labeled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The mountain looks closer than it is.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A man should be greater than some of his parts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Things get worse under pressure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The other line moves faster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A meeting is an event at which the minutes are kept<BR>\nand the hours are lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Automotive engine reparing law:<BR>\nIf you drop something, it will never reach the ground.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Every great idea has a disadvantage equal to or<BR>\nexceeding the greatness of the idea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It always takes longer to get there than to get back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Only adults have difficulty with child-proof bottles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Forgive and remember.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Usefulness is inversely proportional to its reputation<BR>\nfor being useful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you want to make an enemy, do someone a favor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People will buy anything that is one to a customer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is easier to get forgiveness than permission.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When the going gets tough, everyone leaves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you see a man approaching you with the obvious intent<BR>\nof doing you good, you should run for your life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All warranties expire upon payment of invoice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','He who dies with the most toys wins.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Create problems for which only you have the answer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People can be divided into three groups:<BR>\nThose who make things happen,<BR>\nThose who watch things happen and<BR>\nThose who wonder what happened.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The light at the end of the tunnel really is a train.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any technical problem can be overcome given enough<BR>\ntime and money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you are given an open-book exam, you will forget<BR>\nyour book.<BR>\nIf you are given a take-home  exam, you will forget<BR>\nwhere you live.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In case of doubt, make it sound convincing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An ounce of application is worth a ton of abstraction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Why worry about tomorrow?  We may not make it through today!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Laugh and the world laughs with you. cry and ...<BR>\nyou have to blow your nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','I think ... therefore I am confused.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Opportunity always knocks at the least opportune<BR>\nmoment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','On a clear disk, you can seek forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The client who pays the least complains the most');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A little ambiguity never hurt anyone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A $300.00 picture tube will protect a 10 fuse by blowing<BR>\nfirst.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','First rule of intelligent tinkering:<BR>\n&nbsp;Save all the parts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Bad news drives good news out of the media.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','On successive charts of the same organization, the number of<BR>\nboxes will never decrease.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never create a problem for which you do not have<BR>\nthe answer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A 60-day warranty guarantees that the product will<BR>\nself-destruct on the 61st day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you plan to leave your mark in the sands of time,<BR>\nyou better wear work shoes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Among economists, the real world is often a special case.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In a family recipe you just discovered in an old book,<BR>\nthe most vital measurement will be illegible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Entropy has us outnumbered.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is impossible for an optimist to be pleasantly<BR>\nsuprised.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Fools rush in -- and get the best seats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Cleanliness is next to impossible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers do not eat breakfast from the<BR>\nvending machines.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When putting it into memory, remember where you put it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','\"Watching a birdie\" in hand is safer that watching<BR>\none overhead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If one views his problem closely enough he will<BR>\nrecoginize himself as part of the problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A day without sunshine ....<BR>\nis like ... night!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The closer you are to the facts of a situation, the<BR>\nmore obvious are the errors in all news coverage of<BR>\nthe situation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A fool and your money are soon partners.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When an exaggerated emphasis is placed upon delegation,<BR>\nresponsibility, like sediment, sinks to the bottom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A hug is the perfect gift - one size fits all, and<BR>\nnobody minds if you exchange it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything good in life either causes cancer in<BR>\nlaboratory mice or is taxed beyond reality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When you dial a wrong number, you never get a busy signal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Assumption is the mother of all screw-ups.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The rotten egg will be the one you break into the<BR>\ncake batter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers print only clean compiles,<BR>\nfixing all errors through the terminal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All good things must come to an end.<BR>\nI want to know when they start!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Absolutely nothing in the world is friendlier than<BR>\na wet dog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A prerequisite for a desired course will be offered<BR>\nonly during the semester following the desired course.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any given program, when running, is obsolete.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','90% of everything is crud.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Common sense is not so common.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The big guys always win.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Those with the best advice offer no advice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Any given program cost more and take longer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Bare feet magnetize sharp metal objects so they always<BR>\npoint upward from the floor -- especially in the dark.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Nature is a mother.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When eating an elephant take one bite at a time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The one time in the day that you lean back and relax<BR>\nis the one time the boss walks through the office.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The best way to inspire fresh thoughts is to seal<BR>\nthe letter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The further you are from the facts of a situation,<BR>\nthe more you tend to believe news coverage of the<BR>\nsituation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The easiest way to find something lost around the house<BR>\nis to buy a replacement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is buying a dress two sizes too small because<BR>\nit was marked down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Hindsight is an exact science.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Personnel recruiting is a triumph of hope over<BR>\nexperience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you want to get along, go along.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When somebody drops something, everybody will kick it<BR>\naround instead of picking it up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have always done it that way, it is probably wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A man of quality does not fear a woman seeking equality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You will always find something in the last place you look.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In a hierarchical organization, the higher the level,<BR>\nthe greater the confusion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A drug is that substance which, when injected into a<BR>\nrat, will produce a scientific report.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','As the economy gets better, everything else gets worse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Leakproof seals --- will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The best way to lie is to tell the truth.....<BR>\ncarefully edited truth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is a solution to every problem;<BR>\nthe only difficulty is finding it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When you are able to schedule two classes in a row,<BR>\nthey will be held in classrooms at opposite end of<BR>\nthe campus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If there was any justice in this world, people would<BR>\noccasionally be permitted to fly over pigeons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','He who marries for money ... better be nice to his wife.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The chance of a piece of bread falling with the buttered<BR>\nside down is directly proportional to the cost of the<BR>\ncarpet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Class schedules are designed so that every student will<BR>\nwaste the maximum time between classes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Remember the golden rule:<BR>\nThose that have the gold make the rules.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whatever hits the fan will not be evenly distributed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The time it talkes to rectify a situation  is<BR>\ninversely proportional to the time it took<BR>\nto do the damage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The total behavior of large systems cannot be predicted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Most people want to be delivered from temptation but<BR>\nwould like it to keep in touch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The probability of anything happening is in<BR>\ninverse ratio to its desirability.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A budget is spending $15.00 on gas to drive to a<BR>\nshopping mall to save $4.30 on a 20 pound turkey.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A short cut is the longest distance between two points.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers are secure enough to write readable code,<BR>\nwhich they then self-righteously refuse to explain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers are kind to rookies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Adding manpower to a late software product makes it later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more specific the title of a course, the less you<BR>\nwill be able to apply it later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When you do not know what you are going, do it neatly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An auditor enters the battlefield after the war is over,<BR>\nand attacks the wounded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','(1)	If the weather is extremely bad, church<BR>\n&nbsp;attendance will be down.<BR>\n(2)	If the weather is extremely good, church<BR>\n&nbsp;attendance will be down.<BR>\n(3)	If the bulletin covers are in short supply<BR>\n&nbsp;church attendance will exceed all expectations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If only one price can be obtained for any quotation,<BR>\nthe price will be unreasonable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The success of any venture will be helped by prayer,<BR>\neven in the wrong denomination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Systems tend to grow and as they grow they encroach.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Real programmers can do octal, hexadecimal and<BR>\nbinary math in their heads.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is no such thng as a \"dirty capitalist\",<BR>\nonly a capitalist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The length of a marriage is inversely proportional<BR>\nto the amount spent on the wedding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The early worm deserves the bird.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If on an actuarial basis there is a 50 50 chance that<BR>\nsomething will go wrong,<BR>\nIt will actually go wrong nine times out of ten.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','At any event, the people whose seats are furthest from<BR>\nthe aisle arrive last.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Whenever a superstar is traded to your favorite team,<BR>\nhe fades.  Whenever your team trades away a usless<BR>\nno-name, he immediately rises to stardom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never play leapfrog with a photo enlarger.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The only way to make up for being lost is to make<BR>\nrecord time while you are lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','There is always more dirty laundry then clean laundry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Some errors will always go unnoticed until the book<BR>\nis in print.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never argue with an artist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','An unbreakable toy is useful for breaking other toys.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A pat on the back is only a few inches from a kick<BR>\nin the pants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never offend people with style<BR>\nwhen you can offend them with substance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','All things come to him whose name is on a mailing list.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Hollerith got us into this hole mess!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','History proves nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If a thing is done wrong ofter enough<BR>\nit becomes right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you have a difficult task give it to a lazy man, he<BR>\nwill find an easier way to do it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Never attribute to malice that which is adequately<BR>\nexplained by stupidity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The inside contact that you have developed at great<BR>\nexpense is the first person to be let go in any<BR>\nreorganization.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','To err is human, but to really foul things up requires<BR>\na computer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A consultant is an ordinary person a long way from home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Things equal to nothing else are equal to each other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','In order for something to become clean, something<BR>\nelse must become dirty.<BR>\n... but you can get everything dirty without getting<BR>\nanything clean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Liquidity tends to run out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anyone who make a significant contribution to any field<BR>\nof endeavor and stays in that field long enough,<BR>\nbecomes an obstruction to its progress -- in direct<BR>\nproportion to the importance of his original contribution.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','New systems generate new problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The more carefully you plan a project, the more<BR>\nconfusion there is when something goes wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Truth is elastic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When a broken appliance is demonstrated for the repairman,<BR>\nit will work perfectly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The other line always moves faster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everybody is ignorant, only on different subjects.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you fool around with a thing for very long you will<BR>\nscrew it up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','To spot the expert, pick the one who perdicts the job<BR>\nwill take the longest and cost the most.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','People who love sausage and respect the law should<BR>\nnever watch either one being made.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everything is contagious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A child will not spill on a dirty floor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The simpler the instruction, e.g. \"press here\", the<BR>\nmore difficult it will be to open the package.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is morally wrong to allow suckers to keep their money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The first bug to hit a clean windshield lands directly<BR>\nin front of your eyes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Bad law is more likely to be supplemented than repealed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Incompetence knows no barriers of time or place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Each problem solved introduces a new unsolved problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Simple jobs always get put off because there will be<BR>\ntime to do them later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Everyone breaks more than the seven-year-bad-luck allotment<BR>\nto cover rotten luck throughout an entire lifetime.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','You can never do just one thing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','It is a simple task to make things complex, but a complex<BR>\ntask to make them simple.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','For every vision, there is an equal and opposite revision.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No major project is ever installed on time, within budgets,<BR>\nwith the same staff that started it.  Yours will not be the<BR>\nfirst.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Anything is possible, but nothing is easy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','When in trouble, obfuscate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If you just try long enough and hard enough, you can always<BR>\nmanage to boot yourself in the posterior.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','A work project expands to fill the space available.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Beware of the physician who is great at getting<BR>\nout of trouble.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The boss who attempts to impress employees with his<BR>\nknowledge of intricate details has lost sight of his<BR>\nfinal objective.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Consultants are mystical people who ask a company for<BR>\na number and then give it back to them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The most important item in an order will no longer<BR>\nbe available.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','If more than one person is responsible for a<BR>\nmiscalculation, no one will be at fault.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Facts may weaken under extreme heat and pressure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','Superiority is recessive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The label \"new\" and/or \"improved\" means the price went up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','The faster the plane,<BR>\nthe narrower the seats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('murphy','No matter where you go, there you are!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','A help wanted add for a photo journalist asked the rhetorical question:<BR>\n&nbsp;If you found yourself in a situation where you could either save<BR>\na drowning man, or you could take a Pulitzer prize winning<BR>\nphotograph of him drowning, what shutter speed and setting would you use?<BR>\n&nbsp;-- Paul Harvey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','A Hen Brooding Kittens<BR>\n&nbsp;A friend informs us that he saw at the Novato ranch, Marin county,<BR>\na few days since, a hen actually brooding and otherwise caring for three<BR>\nkittens!  The gentleman upon whose premises this strange event is transpiring<BR>\nsays the hen adopted the kittens when they were but a few days old, and that<BR>\nshe has devoted them her undivided care for several weeks past.  The young<BR>\nfelines are now of respectable size, but they nevertheless follow the hen at<BR>\nher cluckings, and are regularly brooded at night beneath her wings.<BR>\n&nbsp;-- Sacramento Daily Union, July 2, 1861');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Journalism is literature in a hurry.<BR>\n&nbsp;-- Matthew Arnold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','In a medium in which a News Piece takes a minute and an \"In-Depth\"<BR>\nPiece takes two minutes, the Simple will drive out the Complex.<BR>\n&nbsp;-- Frank Mankiewicz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','FLASH!<BR>\nIntelligence of mankind decreasing.<BR>\nDetails at ... uh, when the little hand is on the ....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Of what you see in books, believe 75%.  Of newspapers, believe 50%.  And of<BR>\nTV news, believe 25% -- make that 5% if the anchorman wears a blazer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Its failings notwithstanding, there is much to be said in favor of journalism<BR>\nin that by giving us the opinion of the uneducated, it keeps us in touch with<BR>\nthe ignorance of the community.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Everything you read in newspapers is absolutely true, except for that<BR>\nrare story of which you happen to have first-hand knowledge.<BR>\n&nbsp;-- Erwin Knoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','... Had this been an actual emergency, we would have fled in terror,<BR>\nand you would not have been informed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Every journalist has a novel in him, which is an excellent place for it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','An editor is one who separates the wheat from the chaff and prints the chaff.<BR>\n&nbsp;-- Adlai Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','I only know what I read in the papers.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','All newspaper editorial writers ever do is come down from the hills after<BR>\nthe battle is over and shoot the wounded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','\"A raccoon tangled with a 23,000 volt line today.  The results blacked<BR>\nout 1400 homes and, of course, one raccoon.\"<BR>\n&nbsp;-- Steel City News');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','I read the newspaper avidly.  It is my one form of continuous fiction.<BR>\n&nbsp;-- Aneurin Bevan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','A newspaper is a circulating library with high blood pressure.<BR>\n&nbsp;-- Arthure \"Bugs\" Baer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Advertisements contain the only truths to be relied on in a newspaper.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','&nbsp;Once Again From the Top<BR>\n&nbsp;Correction notice in the Miami Herald: \"Last Sunday, The Herald erroneously<BR>\nreported that original Dolphin Johnny Holmes had been an insurance salesman<BR>\nin Raleigh, North Carolina, that he had won the New York lottery in 1982 and<BR>\nlost the money in a land swindle, that he had been charged with vehicular<BR>\nhomicide, but acquitted because his mother said she drove the car, and that<BR>\nhe stated that the funniest thing he ever saw was Flipper spouting water on<BR>\nGeorge Wilson.  Each of these items was erroneous material published<BR>\ninadvertently.  He was not an insurance salesman in Raleigh, did not win the<BR>\nlottery, neither he nor his mother was charged or involved in any way with<BR>\nvehicular homicide, and he made no comment about Flipper or George Wilson.<BR>\nThe Herald regrets the errors.\"<BR>\n&nbsp;-- \"The Progressive\", March, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','A New Way of Taking Pills<BR>\n&nbsp;A physician one night in Wisconsin being disturbed by a burglar, and<BR>\nhaving no ball or shot for his pistol, noiselessly loaded the weapon with<BR>\nsmall, hard pills, and gave the intruder a \"prescription\" which he thinks<BR>\nwill go far towards curing the rascal of a very bad ailment.<BR>\n&nbsp;-- Nevada Morning Transcript, January 30, 1861');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','&nbsp;A journalist, thrilled over his dinner, asked the chef for the recipe.<BR>\nRetorted the chef, \"Sorry, we have the same policy as you journalists, we<BR>\nnever reveal our sauce.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','I really look with commiseration over the great body of my fellow citizens<BR>\nwho, reading newspapers, live and die in the belief that they have known<BR>\nsomething of what has been passing in their time.<BR>\n&nbsp;-- H. Truman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','You know the great thing about TV?  If something important happens<BR>\nanywhere at all in the world, no matter what time of the day or night,<BR>\nyou can always change the channel.<BR>\n&nbsp;-- Jim Ignatowski');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','This is a test of the emergency broadcast system.  Had there been an<BR>\nactual emergency, then you would no longer be here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','\"The New York Times is read by the people who run the country.  The<BR>\nWashington Post is read by the people who think they run the country. The<BR>\nNational Enquirer is read by the people who think Elvis is alive and running<BR>\nthe country ...\"<BR>\n&nbsp;-- Robert J Woodhead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','The most important service rendered by the press is that of educating<BR>\npeople to approach printed matter with distrust. ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','This life is a test.  It is only a test.  Had this been an actual life, you<BR>\nwould have received further instructions as to what to do and where to go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','The advertisement is the most truthful part of a newspaper.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Photographing a volcano is just about the most miserable thing you can do.<BR>\n&nbsp;-- Robert B. Goodman<BR>\n&nbsp;[Who has clearly never tried to use a PDP-10.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','People who are funny and smart and return phone calls get much better<BR>\npress than people who are just funny and smart.<BR>\n&nbsp;-- Howard Simons, \"The Washington Post\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','The American Dental Association announced today that most plaque tends<BR>\nto form on teeth around 4:00 PM in the afternoon.<BR>\n&nbsp;Film at 11:00.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Never offend people with style when you can offend them with substance.<BR>\n&nbsp;-- Sam Brown, \"The Washington Post\", January 26, 1977');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','			*** NEWSFLASH ***<BR>\n&nbsp;Russian tanks steamrolling through New Jersey!!!!  Details at eleven!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','My father was a God-fearing man, but he never missed a copy of the<BR>\nNew York Times, either.<BR>\n&nbsp;-- E.B. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','Earth Destroyed by Solar Flare -- film clips at eleven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('news','\"No self-respecting fish would want to be wrapped in that kind of paper.\"<BR>\n&nbsp;-- Mike Royko on the Chicago Sun-Times after it was<BR>\n&nbsp;taken over by Rupert Murdoch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Speak softly and own a big, mean Doberman.<BR>\n&nbsp;-- Dave Millman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Speak softly and carry a +6 two-handed sword.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Start every day off with a smile and get it over with.<BR>\n&nbsp;-- W.C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Suicide is the sincerest form of self-criticism.<BR>\n&nbsp;-- Donald Kaul');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The probability of someone watching you is proportional to the<BR>\nstupidity of your action.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Put your trust in those who are worthy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Revenge is a form of nostalgia.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','... relaxed in the manner of a man who has no need to put up a front of<BR>\nany kind.<BR>\n&nbsp;-- John Ball, \"Mark One: the Dummy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Put your brain in gear before starting your mouth in motion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The propriety of some persons seems to consist in having improper<BR>\nthoughts about their neighbours.<BR>\n&nbsp;-- F.H. Bradley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sometimes I worry about being a success in a mediocre world.<BR>\n&nbsp;-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Beware of the man who knows the answer before he understands the question.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Questions are never indiscreet, answers sometimes are.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Practically perfect people never permit sentiment to muddle their thinking.<BR>\n&nbsp;-- Mary Poppins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Someone will try to honk your nose today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some rise by sin and some by virtue fall.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some people cause happiness wherever they go; others, whenever they go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Something unpleasant is coming when men are anxious to tell the truth.<BR>\n&nbsp;-- Benjamin Disraeli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some people have a way about them that seems to say: \"If I have<BR>\nonly one life to live, let me live it as a jerk.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some men are discovered; others are found out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some men love truth so much that they seem to be in continual fear<BR>\nlest she should catch a cold on overexposure.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some people have parts that are so private they themselves have no<BR>\nknowledge of them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Show your affection, which will probably meet with pleasant response.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','So far as we are human, what we do must be either evil or good: so far<BR>\nas we do evil or good, we are human: and it is better, in a paradoxical<BR>\nway, to do evil than to do nothing: at least we exist.<BR>\n&nbsp;-- T.S. Eliot, essay on Baudelaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','She often gave herself very good advice (though she very seldom followed it).<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Serenity through viciousness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Shall we make a new rule of life from tonight: always to try to be a<BR>\nlittle kinder than is necessary?<BR>\n&nbsp;-- J.M. Barrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sinners can repent, but stupid is forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Shame is an improper emotion invented by pietists to oppress the human race.<BR>\n&nbsp;-- Robert Preston, Toddy, \"Victor/Victoria\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sometimes I get the feeling that I went to a party on Perry Lane in 1962, and<BR>\nthe party spilled out of the house, and came down the street, and covered the<BR>\nworld.<BR>\n&nbsp;-- Robert Stone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People will accept your ideas much more readily if you tell them that Benjamin<BR>\nFranklin said it first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sanity and insanity overlap a fine grey line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sanity is the trademark of a weak mind.<BR>\n&nbsp;-- Mark Harrold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Rincewind looked down at him and grinned slowly.  It was a wide, manic, and<BR>\nutterly humourless rictus.  It was the sort of grin that is normally<BR>\naccompanied by small riverside birds wandering in and out, picking scraps<BR>\nout of the teeth.<BR>\n&nbsp;-- Terry Pratchett, \"The Lure of the Wyrm\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Progress is impossible without change, and those who cannot change their<BR>\nminds cannot change anything.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Schizophrenia beats being alone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Rarely do people communicate; they just take turns talking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Revenge is a meal best served cold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The great secret in life ... [is] not to open your letters for a fortnight.<BR>\nAt the expiration of that period you will find that nearly all of them have<BR>\nanswered themselves.<BR>\n&nbsp;-- Arthur Binstead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The greatest of faults is to be conscious of none.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The major advances in civilization are processes that all but wreck the<BR>\nsocieties in which they occur.<BR>\n&nbsp;-- A.N. Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The end of the human race will be that it will eventually die of civilization.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The distinction between true and false appears to become increasingly<BR>\nblurred by... the pollution of the language.<BR>\n&nbsp;-- Arne Tiselius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The full potentialities of human fury cannot be reached until a friend<BR>\nof both parties tactfully interferes.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The help people need most urgently is help in admitting that they need help.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The great merit of society is to make one appreciate solitude.<BR>\n&nbsp;-- Charles Chincholles, \"Reflections on the Art of Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','... the privileged being which we call human is distinguished from<BR>\nother animals only by certain double-edged manifestations which in<BR>\ncharity we can only call \"inhuman.\"<BR>\n&nbsp;-- R. A. Lafferty');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The difference between a good haircut and a bad one is seven days.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The best way to get rid of worries is to let them die of neglect.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The bigger they are, the harder they hit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The bland leadeth the bland and they both shall fall into the kitsch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The best thing about growing older is that it takes such a long time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The biggest problem with communication is the illusion that it has occurred.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The best laid plans of mice and men are usually about equal.<BR>\n&nbsp;-- Blair');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The angry man always thinks he can do more than he can.<BR>\n&nbsp;-- SomeStateno of Brescia');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The average nutritional value of promises is roughly zero.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The best that we can do is to be kindly and helpful toward our friends and<BR>\nfellow passengers who are clinging to the same speck of dirt while we are<BR>\ndrifting side by side to our common doom.<BR>\n&nbsp;-- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The adjuration to be \"normal\" seems shockingly repellent to me; I see neither<BR>\nhope nor comfort in sinking to that low level.  I think it is ignorance that<BR>\nmakes people think of abnormality only with horror and allows them to remain<BR>\nundismayed at the proximity of \"normal\" to average and mediocre.  For surely<BR>\nanyone who achieves anything is, essentially, abnormal.<BR>\n&nbsp;-- Dr. Karl Menninger, \"The Human Mind\", 1930');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The aim of a joke is not to degrade the human being but to remind him that<BR>\nhe is already degraded.<BR>\n&nbsp;-- George Orwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The average, healthy, well-adjusted adult gets up at seven-thirty in<BR>\nthe morning feeling just terrible.<BR>\n&nbsp;-- Jean Kerr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The difference between sentiment and being sentimental is the following:<BR>\nSentiment is when a driver swerves out of the way to avoid hitting a<BR>\nrabbit on the road.  Being sentimental is when the same driver, when<BR>\nswerving away from the rabbit hits a pedestrian.<BR>\n&nbsp;-- Frank Herbert, \"The White Plague\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Talk sense to a fool and he calls you foolish.<BR>\n&nbsp;-- Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Talking much about oneself can also be a means to conceal oneself.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Talk is cheap because supply always exceeds demand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Tart words make no friends; a spoonful of honey will catch more flies than<BR>\na gallon of vinegar.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Tact in audacity is knowing how far you can go without going too far.<BR>\n&nbsp;-- Jean Cocteau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Tact is the ability to tell a man he has an open mind when he has a<BR>\nhole in his head.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Surly to bed, surly to rise, makes you about average.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Take a lesson from the whale; the only time he gets speared is when he<BR>\nraises to spout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','That which is not good for the swarm, neither is it good for the bee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The difference between genius and stupidity is that genius has its limits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Success is in the minds of Fools.<BR>\n&nbsp;-- William Wrenshaw, 1578');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Subtlety is the art of saying what you think and getting out of the way<BR>\nbefore it is understood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Success is relative: It is what we can make of the mess we have made of things.<BR>\n&nbsp;-- T.S. Eliot, \"The Family Reunion\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Stupidity is its own reward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Such a fine first dream!<BR>\nBut they laughed at me; they said<BR>\nI had made it up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To be great is to be misunderstood.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Those who are mentally and emotionally healthy are those who have<BR>\nlearned when to say yes, when to say no and when to say whoopee.<BR>\n&nbsp;-- W.S. Krabill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Those who cannot remember the past are condemned to repeat it.<BR>\n&nbsp;-- George Santayana');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The shifts of Fortune test the reliability of friends.<BR>\n&nbsp;-- Marcus Tullius Cicero');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The strong give up and move away, while the weak give up and stay.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Start the day with a smile.  After that you can be your nasty old self again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The second best policy is dishonesty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The sudden sight of me causes panic in the streets. They have yet to learn<BR>\n-- only the savage fears what he does not understand.<BR>\n&nbsp;-- The Silver Surfer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The surest way to corrupt a youth is to instruct him to hold in higher<BR>\nesteem those who think alike than those who think differently.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The reasonable man adapts himself to the world; the unreasonable one<BR>\npersists in trying to adapt the world to himself.  Therefore all progress<BR>\ndepends on the unreasonable man.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The worst thing about some men is that when they are not drunk they are sober.<BR>\n&nbsp;-- William Butler Yeats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The people sensible enough to give good advice are usually sensible<BR>\nenough to give none.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The perfect friend sees the best in you -- sees it constantly -- not just<BR>\nwhen you occasionally are that way, but also when you waver, when you<BR>\nforget yourself, act like less than you are. In time, you become more<BR>\nlike his vision of you -- which is the person you have always wanted to be.<BR>\n&nbsp;-- Nancy Friday');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only way to get rid of a temptation is to yield to it.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only thing to do with good advice is pass it on.  It is never any<BR>\nuse to oneself.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only two things that motivate me and that matter to me are revenge<BR>\nand guilt.<BR>\n&nbsp;-- Elvis Costello');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only way to amuse some people is to slip and fall on an icy pavement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The part of the world that people find most puzzling is the part called \"Me\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The most hopelessly stupid man is he who is not aware that he is wise.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The odds are a million to one against your being one in a million.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The older a man gets, the farther he had to walk to school as a boy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The more we disagree, the more chance there is that at least one of us is right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The mirror sees the man as beautiful, the mirror loves the man; another<BR>\nmirror sees the man as frightful and hates him; and it is always the same<BR>\nbeing who produces the impressions.<BR>\n&nbsp;-- Marquis D.A.F. de Sade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The meeting of two personalities is like the contact of two<BR>\nchemical substances: if there is any reaction, both are transformed.<BR>\n&nbsp;-- Carl Jung');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The more I know men the more I like my horse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The more I see of men the more I admire dogs.<BR>\n&nbsp;-- Mme De Sevigne, 1626-1696');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only difference between the saint and the sinner is that every saint<BR>\nhas a past and every sinner has a future.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The point is, you see, that there is no point in driving yourself mad<BR>\ntrying to stop yourself going mad.  You might just as well give in and<BR>\nsave your sanity for later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The Least Successful Defrosting Device<BR>\n&nbsp;The all-time record here is held by Mr. Peter Rowlands of Lancaster<BR>\nwhose lips became frozen to his lock in 1979 while blowing warm air on it.<BR>\n&nbsp;\"I got down on my knees to breathe into the lock.  Somehow my lips<BR>\ngot stuck fast.\"<BR>\n&nbsp;While he was in the posture, an old lady passed an inquired if he<BR>\nwas all right.  \"Alra?  Igmmlptk\", he replied at which point she ran away.<BR>\n&nbsp;\"I tried to tell her what had happened, but it came out sort of...<BR>\nmuffled,\" explained Mr. Rowlands, a pottery designer.<BR>\n&nbsp;He was trapped for twenty minutes (\"I felt a bit foolish\") until<BR>\nconstant hot breathing brought freedom.  He was subsequently nicknamed \"Hot<BR>\nLips\".<BR>\n&nbsp;-- Stephen Pile, \"The Book of Heroic Failures\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The kind of danger people most enjoy is the kind they can watch from<BR>\na safe place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The idle mind knows not what it is it wants.<BR>\n&nbsp;-- Quintus Ennius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The human race never solves any of its problems.  It merely outlives them.<BR>\n&nbsp;-- David Gerrold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The important thing is not to stop questioning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The Lord prefers common-looking people.  That is the reason that He makes<BR>\nso many of them.<BR>\n&nbsp;-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The knowledge that makes us cherish innocence makes innocence unattainable.<BR>\n&nbsp;-- Irving Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The hardest thing is to disguise your feelings when you put a lot of<BR>\nrelatives on the train for home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The hatred of relatives is the most violent.<BR>\n&nbsp;-- Tacitus (c.55 - c.117)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The heroic hours of life do not announce their presence by drum and trumpet,<BR>\nchallenging us to be true to ourselves by appeals to the martial spirit that<BR>\nkeeps the blood at heat.  Some little, unassuming, unobtrusive choice presents<BR>\nitself before us slyly and craftily, glib and insinuating, in the modest garb<BR>\nof innocence.  To yield to its blandishments is so easy.  The wrong, it seems,<BR>\nis venial...  Then it is that you will be summoned to show the courage of<BR>\nadventurous youth.<BR>\n&nbsp;-- Benjamin Cardozo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The Golden Rule is of no use to you whatever unless you realize it<BR>\nis your move.<BR>\n&nbsp;-- Frank Crane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Thinking you know something is a sure way to blind yourself.<BR>\n&nbsp;-- Frank Herbert, \"Chapterhouse: Dune\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To believe your own thought, to believe that what is true for<BR>\nyou in your private heart is true for all men -- that is genius.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"They told me I was gullible ... and I believed them!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','They are ill discoverers that think there is no land, when they can see<BR>\nnothing but sea.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Therefore it is necessary to learn how not to be good, and to use<BR>\nthis knowledge and not use it, according to the necessity of the cause.<BR>\n&nbsp;-- Machiavelli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','They also serve who only stand and wait.<BR>\n&nbsp;-- John Milton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Walk softly and carry a megawatt laser.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is no statute of limitations on stupidity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is nothing more silly than a silly laugh.<BR>\n&nbsp;-- Gaius Valerius Catullus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is nothing stranger in a strange land than the stranger who comes<BR>\nto visit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is no such thing as inner peace.  There is only nervousness or death.<BR>\nAny attempt to prove otherwise constitutes unacceptable behaviour.<BR>\n&nbsp;-- Fran Lebowitz, \"Metropolitan Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is only one word for aid that is genuinely without strings,<BR>\nand that word is blackmail.<BR>\n&nbsp;-- Colm Brogan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are two types of people in this world, good and bad.  The good<BR>\nsleep better, but the bad seem to enjoy the waking hours much more.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There comes a time to stop being angry.<BR>\n&nbsp;-- A Small Circle of Friends');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is no substitute for good manners, except, perhaps, fast reflexes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are more dead people than living, and their numbers are increasing.<BR>\n&nbsp;-- Eugene Ionesco');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are no great men, only great challenges that ordinary men are forced<BR>\nby circumstances to meet.<BR>\n&nbsp;-- Admiral William Halsey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are few people more often in the wrong than those who cannot endure<BR>\nto be thought so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The worst thing one can do is not to try, to be aware of what one wants and<BR>\nnot give in to it, to spend years in silent hurt wondering if something could<BR>\nhave materialized -- and never knowing.<BR>\n&nbsp;-- David Viscott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The worst part of having success is trying to find someone who is happy for you.<BR>\n&nbsp;-- Bette Midler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are only two kinds of men -- the dead and the deadly.<BR>\n&nbsp;-- Helen Rowland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The worst cliques are those which consist of one man.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There may be said to be two classes of people in the world; those who constantly<BR>\ndivide the people of the world into two classes and those who do not.<BR>\n&nbsp;-- Robert Benchley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','With clothes the new are best, with friends the old are best.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The world needs more people like us and fewer like them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The worst is not so long as we can say \"This is the worst.\"<BR>\n&nbsp;-- King Lear');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The way of the world is to praise dead saints and prosecute live ones.<BR>\n&nbsp;-- Nathaniel Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The trouble with telling a good story is that it invariably reminds<BR>\nthe other fellow of a dull one.<BR>\n&nbsp;-- Sid Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The truth about a man lies first and foremost in what he hides.<BR>\n&nbsp;-- Andre Malraux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The very remembrance of my former misfortune proves a new one to me.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The things that interest people most are usually none of their business.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The strong individual loves the earth so much he lusts for recurrence.  He<BR>\ncan smile in the face of the most terrible thought: meaningless, aimless<BR>\nexistence recurring eternally.  The second characteristic of such a man is<BR>\nthat he has the strength to recognise -- and to live with the recognition --<BR>\nthat the world is valueless in itself and that all values are human ones.<BR>\nHe creates himself by fashoning his own values; he has the pride to live<BR>\nby the values he wills.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are each only one drop in a great ocean -- but some of the drops sparkle!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What on earth would a man do with himself if something did not stand in his way?<BR>\n&nbsp;-- H.G. Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We prefer to speak evil of ourselves rather than not speak of ourselves at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We promise according to our hopes, and perform according to our fears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We only acknowledge small faults in order to make it appear that we are<BR>\nfree from great ones.<BR>\n&nbsp;-- La Rouchefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We lie loudest when we lie to ourselves.<BR>\n&nbsp;-- Eric Hoffer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We may not return the affection of those who like us, but we always respect<BR>\ntheir good judgement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We prefer to believe that the absence of inverted commas guarantees the<BR>\noriginality of a thought, whereas it may be merely that the utterer has<BR>\nforgotten its source.<BR>\n&nbsp;-- Clifton Fadiman, \"Any Number Can Play\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We give advice, but we cannot give the wisdom to profit by it.<BR>\n&nbsp;-- La Rochefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We seldom repent talking too little, but very often talking too much.<BR>\n&nbsp;-- Jean de la Bruyere');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We ARE as gods and might as well get good at it.<BR>\n&nbsp;-- Whole Earth Catalog');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are not loved by our friends for what we are; rather, we are loved in<BR>\nspite of what we are.<BR>\n&nbsp;-- Victor Hugo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are all so much together and yet we are all dying of loneliness.<BR>\n&nbsp;-- A. Schweitzer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are anthill men upon an anthill world.<BR>\n&nbsp;-- Ray Bradbury');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are stronger than our skin of flesh and metal, for we carry and share a<BR>\nspectrum of suns and lands that lends us legends as we craft our immortality<BR>\nand interweave our destinies of water and air, leaving shadows that gather<BR>\ncolor of their own, until they outshine the substance that cast them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What upsets me is not that you lied to me, but that from now on I can no<BR>\nlonger believe you.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','With a gentleman I try to be a gentleman and a half, and with a fraud I<BR>\ntry to be a fraud and a half.<BR>\n&nbsp;-- Otto von Bismark');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are so fond of each other because our ailments are the same.<BR>\n&nbsp;-- Jonathon Swift');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are all born mad.  Some remain so.<BR>\n&nbsp;-- Samuel Beckett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Virtue is its own punishment.<BR>\n&nbsp;-- Denniston<BR>\n&nbsp;Righteous people terrify me ... virtue is its own punishment.<BR>\n&nbsp;-- Aneurin Bevan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Virtue is not left to stand alone.  He who practices it will have neighbors.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Virtue would go far if vanity did not keep it company.<BR>\n&nbsp;-- La Rochefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Unless you love someone, nothing else makes any sense.<BR>\n&nbsp;-- e.e. cummings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Try to divide your time evenly to keep others happy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Vila: \"I think I have just made the biggest mistake of my life.\"<BR>\n&nbsp;Orac: \"It is unlikely.  I would predict there are far greater mistakes<BR>\n&nbsp;waiting to be made by someone with your obvious talent for it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Trying to define yourself is like trying to bite your own teeth.<BR>\n&nbsp;-- Alan Watts');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Visits always give pleasure: if not on arrival, then on the departure.<BR>\n&nbsp;-- Edouard Le Berquier, \"Pensees des Autres\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Troglodytism does not necessarily imply a low cultural level.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Truly great madness can not be achieved without significant intelligence.<BR>\n&nbsp;-- Henrik Tikkanen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Try to be the best of whatever you are, even if what you are is no good.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To stay young requires unceasing cultivation of the ability to unlearn<BR>\nold falsehoods.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough For Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To keep your friends treat them kindly; to kill them, treat them often.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To find a friend one must close one eye; to keep him -- two.<BR>\n&nbsp;-- Norman Douglas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To make an enemy, do someone a favor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To understand the heart and mind of a person, look not at what<BR>\nhe has already achieved, but at what he aspires to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Walk softly and carry a big stick.<BR>\n&nbsp;-- Theodore Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To be is to be related.<BR>\n&nbsp;-- C.J. Keyser.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To be trusted is a greater compliment than to be loved.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To be who one is, is not to be someone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Will your long-winded speeches never end?<BR>\nWhat ails you that you keep on arguing?<BR>\n&nbsp;-- Job 16:3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Home is the place where, when you have to go there, they have to take you in.<BR>\n&nbsp;-- Robert Frost, \"The Death of the Hired Man\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','His life was formal; his actions seemed ruled with a ruler.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never speak ill of yourself, your friends will always say enough on<BR>\nthat subject.<BR>\n&nbsp;-- Charles-Maurice De Talleyrand');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never tell a lie unless it is absolutely convenient.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Animals can be driven crazy by putting too many in too small a pen.<BR>\nHomo sapiens is the only animal that voluntarily does this to himself.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hindsight is always 20:20.<BR>\n&nbsp;-- Billy Wilder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who wonders discovers that this in itself is wonder.<BR>\n&nbsp;-- M.C. Escher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No man is an island, but some of us are long peninsulas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who is known as an early riser need not get up until noon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Any coward can sit in his home and criticize a pilot for flying into a<BR>\nmountain in a fog.  But I would rather, by far, die on a mountainside<BR>\nthan in bed.  What kind of man would live where there is no daring?<BR>\nAnd is life so dear that we should blame men for dying in adventure?<BR>\nIs there a better way to die?<BR>\n&nbsp;-- Charles Lindbergh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who hoots with owls by night cannot soar with eagles by day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who always plows a straight furrow is in a rut.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He walks as if balancing the family tree on his nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"No one gets too old to learn a new way of being stupid.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He missed an invaluable opportunity to hold his tongue.<BR>\n&nbsp;-- Andrew Lang');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An expert is a person who avoids the small errors as he sweeps on to the<BR>\ngrand fallacy.<BR>\n&nbsp;-- Benjamin Stolberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nothing astonishes men so much as common sense and plain dealing.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old age and treachery will overcome youth and skill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only a mediocre person is always at his best.<BR>\n&nbsp;-- Laurence Peter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He is considered a most graceful speaker who can say nothing in the most words.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anger kills as surely as the other vices.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Having no talent is no longer enough.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hate the sin and love the sinner.<BR>\n&nbsp;-- Mahatma Gandhi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Any fool can tell the truth, but it requires a man of sense to know<BR>\nhow to lie well.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Greatness is a transitory experience. It is never consistent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Gratitude, like love, is never a dependable international emotion.<BR>\n&nbsp;-- Joseph Alsop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Good advice is something a man gives when he is too old to set a bad<BR>\nexample.<BR>\n&nbsp;-- La Rouchefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Good advice is one of those insults that ought to be forgiven.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An optimist is a guy that has never had much experience.<BR>\n&nbsp;-- Don Marquis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','And I will do all these good works, and I will do them for free!<BR>\nMy only reward will be a tombstone that says \"Here lies Gomez Addams --<BR>\nhe was good for nothing.\"<BR>\n&nbsp;-- Jack Sharkey, The Addams Family');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','God gives us relatives; thank goodness we can chose our friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Give me a sleeping pill and tell me your troubles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An infallible method of conciliating a tiger is to allow oneself to be<BR>\ndevoured.<BR>\n&nbsp;-- Konrad Adenauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Get forgiveness now -- tomorrow you may no longer feel guilty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Genius is the talent of a person who is dead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who have no faults are terrible; there is no way of taking<BR>\nadvantage of them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who make no mistakes do not usually make anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An intellectual is someone whose mind watches itself.<BR>\n&nbsp;-- Albert Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who push both buttons should get their wish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anger is momentary madness.<BR>\n&nbsp;-- Horace');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you continually give you will continually have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anybody can win, unless there happens to be a second entry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Love thy neighbor as thyself, but choose your neighborhood.<BR>\n&nbsp;-- Louise Beal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If there was any justice in the world, \"trust\" would be a four-letter word.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Modesty is a vastly overrated virtue.<BR>\n&nbsp;-- J.K. Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people are too busy to have time for anything important.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people feel that everyone is entitled to their opinion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people need some of their problems to help take their mind off<BR>\nsome of the others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','My brain is my second favorite organ.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I will follow the good side right to the fire, but not into it if I can<BR>\nhelp it.<BR>\n&nbsp;-- Michel Eyquem de Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anyone stupid enough to be caught by the police is probably guilty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I sometimes think that God, in creating man, somewhat overestimated his ability.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anybody with money to burn will easily find someone to tend the fire.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I can write better than anybody who can write faster, and I can write<BR>\nfaster than anybody who can write better.<BR>\n&nbsp;-- A.J. Liebling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Anyone can become angry -- that is easy; but to be angry with the right<BR>\nperson, to the right degree, at the right time, for the right purpose<BR>\nand in the right way -- that is not easy.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I am firm.  You are obstinate.  He is a pig-headed fool.<BR>\n&nbsp;-- Katharine Whitehorn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I allow the world to live as it chooses, and I allow myself to live as I<BR>\nchoose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Needs are a function of what other people have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never ask the barber if you need a haircut.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people prefer certainty to truth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Beauty may be skin deep, but ugly goes clear to the bone.<BR>\n&nbsp;-- Redd Foxx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most of the fear that spoils our life comes from attacking difficulties<BR>\nbefore we get to them.<BR>\n&nbsp;-- Dr. Frank Crane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','More people are flattered into virtue than bullied out of vice.<BR>\n&nbsp;-- R.S. Surtees');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','After living in New York, you trust nobody, but you believe everything.<BR>\nJust in case.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Men use thought only to justify their wrong doings, and speech only to<BR>\nconceal their thoughts.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If there is a wrong way to do something, then someone will do it.<BR>\n&nbsp;-- Edward A. Murphy Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If only one could get that wonderful feeling of accomplishment without<BR>\nhaving to accomplish anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If only I could be respected without having to be respectable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All I ask of life is a constant and exaggerated sense of my own importance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man has never reconciled himself to the ten commandments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Lying is an indispensable part of making life tolerable.<BR>\n&nbsp;-- Bergan Evans');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','After all, it is only the mediocre who are always at their best.<BR>\n&nbsp;-- Jean Giraudoux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Jealousy is all the fun you think they have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All his life he has looked away... to the horizon, to the sky,<BR>\nto the future.  Never his mind on where he was, on what he was doing.<BR>\n&nbsp;-- Yoda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It takes two to tell the truth: one to speak and one to hear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Albert Camus wrote that the only serious question is whether to kill yourself<BR>\nor not.  Tom Robbins wrote that the only serious question is whether time has<BR>\na beginning and an end.  Camus clearly got up on the wrong side of bed, and<BR>\nRobbins must have forgotten to set the alarm.<BR>\n&nbsp;-- Tom Robbins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It matters not whether you win or lose; what matters is whether II win or lose.<BR>\n&nbsp;-- Darrin Weinberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is only the great men who are truly obscene.  If they had not dared<BR>\nto be obscene, they could never have dared to be great.<BR>\n&nbsp;-- Havelock Ellis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is not enough to have great qualities, we should also have the<BR>\nmanagement of them.<BR>\n&nbsp;-- La Rochefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is impossible for an optimist to be pleasantly surprised.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is better for civilization to be going down the drain than to be <BR>\ncoming up it.<BR>\n&nbsp;-- Henry Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All I want is a warm bed and a kind word and unlimited power.<BR>\n&nbsp;-- Ashleigh Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In the misfortune of our friends we find something that is not displeasing<BR>\nto us.<BR>\n&nbsp;-- La Rochefoucauld, \"Maxims\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you try to please everyone, somebody is not going to like it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you think before you speak the other guy gets his joke in first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Before borrowing money from a friend, decide which you need more.<BR>\n&nbsp;-- Addison H. Hallock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you go out of your mind, do it quietly, so as not to disturb those<BR>\naround you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is impossible to make anything foolproof because fools are so ingenious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Any clod can have the facts, but having opinions is an art.<BR>\n&nbsp;-- Charles McCabe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you explain so clearly that nobody can misunderstand, somebody will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It seems to make an auto driver mad if he misses you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;Rate yourself on the nerd-o-matic scale. (1 point for each YES answer)<BR>\n0-2  -- You are really hip, a real cool cat, a hoopy frood.<BR>\n3-5  -- There is hope for you yet.<BR>\n6-7  -- Uh-oh, trouble in River City.<BR>\n8-10 -- Your immortal soul is in peril.<BR>\n11+  -- Does suicide seem attractive?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed is the man who, having nothing to say, abstains from giving<BR>\nwordy evidence of the fact.<BR>\n&nbsp;-- George Eliot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed is he who has reached the point of no return and knows it,<BR>\nfor he shall enjoy living.<BR>\n&nbsp;-- W.C. Bennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Personifiers of the world, unite!  You have nothing to lose but Mr. Dignity!<BR>\n&nbsp;-- Bernadette Bosky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Bounders get bound when they are caught bounding.<BR>\n&nbsp;-- Ralph Lewin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Say no, then negotiate.<BR>\n&nbsp;-- Helga');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed is he who expects nothing, for he shall never be disappointed.<BR>\n&nbsp;-- Alexander Pope');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many a family tree needs trimming.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If God had wanted you to go around nude, He would have given you bigger hands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','BEWARE!  People acting under the influence of human nature.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Birthdays are like busses, never the number you want.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed are the forgetful:  for they get the better even of their blunders.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed is he who expects no gratitude, for he shall not be disappointed.<BR>\n&nbsp;-- W.C. Bennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People respond to people who respond.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Go slowly to the entertainments of thy friends, but quickly to their<BR>\nmisfortunes.<BR>\n&nbsp;-- Chilo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People are unconditionally guaranteed to be full of defects.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Others can stop you temporarily, only you can do it permanently.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conscience is the inner voice that warns us somebody may be looking.<BR>\n&nbsp;-- H.L. Mencken, \"A Mencken Chrestomathy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Original thought is like original sin: both happened before you were born<BR>\nto people you could not have possibly met.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Optimism is the content of small men in high places.<BR>\n&nbsp;-- F. Scott Fitzgerald, \"The Crack Up\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Buck-passing usually turns out to be a boomerang.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only two of my personalities are schizophrenic, but one of them is<BR>\nparanoid and the other one is out to get him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only kings, presidents, editors, and people with tapeworms have the right<BR>\nto use the editorial \"we\".<BR>\n&nbsp;-- Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be independent.  Insult a rich relative today.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No one regards what is before his feet; we all gaze at the stars.<BR>\n&nbsp;-- Quintus Ennius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No one can make you feel inferior without your consent.<BR>\n&nbsp;-- Eleanor Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No one becomes depraved in a moment.<BR>\n&nbsp;-- Decimus Junius Juvenalis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No man is useless who has a friend, and if we are loved we are indispensable.<BR>\n&nbsp;-- Robert Louis Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be not anxious about what you have, but about what you are.<BR>\n&nbsp;-- Pope St. Gregory I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No character, however upright, is a match for constantly reiterated attacks,<BR>\nhowever false.<BR>\n&nbsp;-- Alexander Hamilton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never underestimate the power of human stupidity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never leave anything to chance; make sure all your crimes are premeditated.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Bad men live that they may eat and drink, whereas good men eat and drink<BR>\nthat they may live.<BR>\n&nbsp;-- Socrates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be self-reliant and your success is assured.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Associate with well-mannered persons and your manners will improve.  Run<BR>\nwith decent folk and your own decent instincts will be strengthened.  Keep<BR>\nthe company of bums and you will become a bum.  Hang around with rich people<BR>\nand you will end by picking up the check and dying broke.<BR>\n&nbsp;-- Stanley Walker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never argue with a man who buys ink by the barrel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','At no time is freedom of speech more precious than when a man hits his<BR>\nthumb with a hammer.<BR>\n&nbsp;-- Marshall Lumsden');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Back when I was a boy, it was 40 miles to everywhere, uphill both ways<BR>\nand it was always snowing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','My opinions may have changed, but not the fact that I am right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','My method is to take the utmost trouble to find the right thing to say.<BR>\nAnd then say it with the utmost levity.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Ask yourself whether you are happy and you cease to be so.<BR>\n&nbsp;-- John Stuart Mill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I either want less decadence or more chance to participate in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Creativity is no substitute for knowing what you are doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Dare to be naive.<BR>\n&nbsp;-- R. Buckminster Fuller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do not do unto others as you would they should do unto you.  Their tastes<BR>\nmay not be the same.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Courage is grace under pressure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Dear Lord: Please make my words sweet and tender, for tomorrow I may<BR>\nhave to eat them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is no sadder sight than a young pessimist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Delay is preferable to error.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is brutality and there is honesty.  There is no such thing as brutal<BR>\nhonesty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is an innocence in admiration; it is found in those to whom it<BR>\nhas not yet occurred that they, too, might be admired some day.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Courage is fear that has said its prayers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confession is good for the soul only in the sense that a tweed coat is<BR>\ngood for dandruff.<BR>\n&nbsp;-- Peter de Vries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The world is full of people who have never, since childhood, met an<BR>\nopen doorway with an open mind.<BR>\n&nbsp;-- E.B. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conceit causes more conversation than wit.<BR>\n&nbsp;-- LaRouchefoucauld');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confessions may be good for the soul, but they are bad for the reputation.<BR>\n&nbsp;-- Lord Thomas Dewar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The wise man seeks everything in himself; the ignorant man tries to get<BR>\neverything from somebody else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Common sense is the most evenly distributed quantity in the world.<BR>\nEveryone thinks he has enough.<BR>\n&nbsp;-- Descartes, 1637');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confidence is the feeling you have before you understand the situation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The right half of the brain controls the left half of the body.  This<BR>\nmeans that only left handed people are in their right mind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Common sense and a sense of humor are the same thing, moving at<BR>\ndifferent speeds.  A sense of humor is just common sense, dancing.<BR>\n&nbsp;-- Clive James');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The most disagreeable thing that your worst enemy says to your face does<BR>\nnot approach what your best friends say behind your back.<BR>\n&nbsp;-- Alfred De Musset');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Coming together is a beginning;<BR>\n&nbsp;keeping together is progress;<BR>\n&nbsp;working together is success.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Common sense is the collection of prejudices acquired by age eighteen.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The man who raises a fist has run out of ideas.<BR>\n&nbsp;-- H.G. Wells, \"Time After Time\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The human mind treats a new idea the way the body treats a strange<BR>\nprotein -- it rejects it.<BR>\n&nbsp;-- P. Medawar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Character is what you are in the dark!<BR>\n&nbsp;-- Lord John Whorfin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Calling you stupid is an insult to stupid people!<BR>\n&nbsp;-- Wanda, \"A Fish Called Wanda\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The best way to keep your friends is not to give them away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Charlie Brown:	Why was I put on this earth?<BR>\nLinus:		To make others happy.<BR>\nCharlie Brown:	Why were others put on this earth?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"But officer, I was only trying to gain enough speed so I could coast<BR>\nto the nearest gas station.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','But since I knew now that I could hope for nothing of greater value than <BR>\nfrivolous pleasures, what point was there in denying myself of them?  <BR>\n&nbsp;-- M. Proust');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conformity is the refuge of the unimaginative.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','By nature, men are nearly alike; by practice, they get to be wide apart.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Success is getting what you want; happiness is wanting what you get.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Success is a journey, not a destination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Blessed are they that have nothing to say, and who cannot be persuaded<BR>\nto say it.<BR>\n&nbsp;-- James Russell Lowell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Charm is a way of getting the answer \"Yes\" -- without having asked any<BR>\nclear question.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Still looking for the glorious results of my misspent youth.  Say, do you<BR>\nhave a map to the next joint?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sometimes when you look into his eyes you get the feeling that someone<BR>\nelse is driving.<BR>\n&nbsp;-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Brisk talkers are usually slow thinkers.  There is, indeed, no wild beast<BR>\nmore to be dreaded than a communicative man having nothing to communicate.<BR>\nIf you are civil to the voluble, they will abuse your patience; if<BR>\nbrusque, your character.<BR>\n&nbsp;-- Jonathan Swift');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','God must love the common man; He made so many of them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Good judgement comes from experience.  Experience comes from bad judgement.<BR>\n&nbsp;-- Jim Horning');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hate is like acid.  It can damage the vessel in which it is stored as well<BR>\nas destroy the object on which it is poured.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He thinks by infection, catching an opinion like a cold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Every man is apt to form his notions of things difficult to be apprehended,<BR>\nor less familiar, from their analogy to things which are more familiar.<BR>\nThus, if a man bred to the seafaring life, and accustomed to think and talk<BR>\nonly of matters relating to navigation, enters into discourse upon any other<BR>\nsubject; it is well known, that the language and the notions proper to his<BR>\nown profession are infused into every subject, and all things are measured<BR>\nby the rules of navigation: and if he should take it into his head to<BR>\nphilosophize concerning the faculties of the mind, it cannot be doubted,<BR>\nbut he would draw his notions from the fabric of the ship, and would find<BR>\nin the mind, sails, masts, rudder, and compass.<BR>\n&nbsp;-- Thomas Reid, \"An Inquiry into the Human Mind\", 1764');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For men use, if they have an evil turn, to write it in marble:<BR>\nand whoso doth us a good turn we write it in dust.<BR>\n&nbsp;-- Sir Thomas More');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Doubt is not a pleasant condition, but certainty is absurd.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Drive defensively.  Buy a tank.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone is entitled to my opinion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For most men life is a search for the proper manila envelope in which to<BR>\nget themselves filed.<BR>\n&nbsp;-- Clifton Fadiman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do you mean that you not only want a wrong answer, but a certain wrong answer?<BR>\n&nbsp;-- Tobaben');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do clones have navels?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Defeat is worse than death because you have to live with defeat.<BR>\n&nbsp;-- Bill Musselman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do not think by infection, catching an opinion like a cold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do more than anyone expects, and pretty soon everyone will expect more.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Dishonor will not trouble me, once I am dead.<BR>\n&nbsp;-- Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When it comes to helping you, some people stop at nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do you know, I think that Dr. Swift was silly to laugh about Laputa.  I<BR>\nbelieve it is a mistake to make a mock of people, just because they think.<BR>\nThere are ninety thousand people in this world who do not think, for every<BR>\none who does, and these people hate the thinkers like poison.  Even if some<BR>\nthinkers are fanciful, it is wrong to make fun of them for it.  Better to<BR>\nthink about cucumbers even, than not to think at all.<BR>\n&nbsp;-- T.H. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"For three days after death hair and fingernails continue to grow but<BR>\nphone calls taper off.\"<BR>\n&nbsp;-- Johnny Carson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Fortune finishes the great quotations, #21<BR>\n&nbsp;Shall I compare thee to a Summer day?<BR>\n&nbsp;No, I guess not.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Four fifths of the perjury in the world is expended on tombstones, women<BR>\nand competitors.<BR>\n&nbsp;-- Lord Thomas Dewar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For I do not do the good I want, but the evil I do not want is what I do.<BR>\n&nbsp;-- Paul of Tarsus, (Saint Paul)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Friends may come and go, but enemies accumulate.<BR>\n&nbsp;-- Thomas Jones');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For those who like this sort of thing, this is the sort of thing they like.<BR>\n&nbsp;-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Flattery is like cologne -- to be smelled, but not swallowed.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For an idea to be fashionable is ominous, since it must afterwards be<BR>\nalways old-fashioned.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For every action, there is an equal and opposite criticism.<BR>\n&nbsp;-- Harrison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Experience teaches you that the man who looks you straight in the eye,<BR>\nparticularly if he adds a firm handshake, is hiding something.<BR>\n&nbsp;-- Clifton Fadiman, \"Enter Conversing\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Friendships last when each friend thinks he has a slight superiority<BR>\nover the other.<BR>\n&nbsp;-- Honore DeBalzac');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Experience is what you get when you were expecting something else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Go out and tell a lie that will make the whole family proud of you.<BR>\n&nbsp;-- Cadmus, to Pentheus, in \"The Bacchae\" by Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Experience is that marvelous thing that enables you recognize a mistake<BR>\nwhen you make it again.<BR>\n&nbsp;-- Franklin P. Jones');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Fame may be fleeting but obscurity is forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Experience is not what happens to you; it is what you do with what happens<BR>\nto you.<BR>\n&nbsp;-- Aldous Huxley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Excess on occasion is exhilarating.  It prevents moderation from<BR>\nacquiring the deadening effect of a habit.<BR>\n&nbsp;-- W. Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Exhilaration is that feeling you get just after a great idea hits you,<BR>\nand just before you realize what is wrong with it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone talks about apathy, but no one ____does anything about it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Fashion is a form of ugliness so intolerable that we have to alter it<BR>\nevery six months.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Evil is that which one believes of others.  It is a sin to believe evil<BR>\nof others, but it is seldom a mistake.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Example is not the main thing in influencing others.  It is the only thing.<BR>\n&nbsp;-- Albert Schweitzer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone was born right-handed.  Only the greatest overcome it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone is more or less mad on one point.<BR>\n&nbsp;-- Rudyard Kipling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Fashions have done more harm than revolutions.<BR>\n&nbsp;-- Victor Hugo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone wants results, but no one is willing to do what it takes to get them.<BR>\n&nbsp;-- Dirty Harry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Genius may have its limitations, but stupidity is not thus handicapped.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Every man takes the limits of his own field of vision for the limits<BR>\nof the world.<BR>\n&nbsp;-- Schopenhauer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Every man is as God made him, ay, and often worse.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Every improvement in communication makes the bore more terrible.<BR>\n&nbsp;-- Frank Moore Colby');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Even a hawk is an eagle among crows.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Enjoy your life; be pleasant and gay, like the birds in May.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Even God lends a hand to honest boldness.<BR>\n&nbsp;-- Menander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For people who like that kind of book, that is the kind of book they will like.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I disagree with what you say, but will defend to the death your right to<BR>\ntell such LIES!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I am an optimist.  It does not seem too much use being anything else.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Appearances often are deceiving.<BR>\n&nbsp;-- Aesop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I am looking for a honest man.<BR>\n&nbsp;-- Diogenes the Cynic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I always choose my friends for their good looks and my enemies for their<BR>\ngood intellects.  Man cannot be too careful in his choice of enemies.<BR>\n&nbsp;-- Oscar Wilde, \"The Picture of Dorian Gray\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I always pass on good advice.  It is the only thing to do with it.<BR>\nIt is never any good to oneself.<BR>\n&nbsp;-- Oscar Wilde, \"An Ideal Husband\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Humility is the first of the virtues -- for other people.<BR>\n&nbsp;-- Oliver Wendell Holmes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"I am ready to meet my Maker.  Whether my Maker is prepared for the<BR>\ngreat ordeal of meeting me is another matter.\"<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','However, never daunted, I will cope with adversity in my traditional<BR>\nmanner ... sulking and nausea.<BR>\n&nbsp;-- Tom K. Ryan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Human kind cannot bear very much reality.<BR>\n&nbsp;-- T.S. Eliot, \"Four Quartets: Burnt Norton\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','How many \"coming men\" has one known!  Where on earth do they all go to?<BR>\n&nbsp;-- Sir Arthur Wing Pinero');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Home life as we understand it is no more natural to us than a cage is<BR>\nto a cockatoo.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hope is a waking dream.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Humanity has advanced, when it has advanced, not because it has been sober, <BR>\nresponsible, and cautious, but because it has been playful, rebellious, and <BR>\nimmature.<BR>\n&nbsp;-- Tom Robbins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I believe in getting into hot water; it keeps you clean.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','How comes it to pass, then, that we appear such cowards in reasoning,<BR>\nand are so afraid to stand the test of ridicule?<BR>\n&nbsp;-- A. Cooper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hindsight is an exact science.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','His mind is like a steel trap: full of mice.<BR>\n&nbsp;-- Foghorn Leghorn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Her days were spent in a kind of slow bustle; always busy without getting<BR>\non, always behind hand and lamenting it, without altering her ways;<BR>\nwishing to be an economist, without contrivance or regularity; dissatisfied<BR>\nwith her servants, without skill to make them better, and whether helping, or<BR>\nreprimanding, or indulging them, without any power of engaging their respect.<BR>\n&nbsp;-- J. Austen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','History repeats itself -- the first time as a tragi-comedy, the second<BR>\ntime as bedroom farce.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who minds his own business is never unemployed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who walks on burning coals is sure to get burned.<BR>\n&nbsp;-- Sinbad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who is good for making excuses is seldom good for anything else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He was so narrow-minded he could see through a keyhole with both eyes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You give me space to belong to myself yet without separating me <BR>\nfrom your own life.  May it all turn out to your happiness.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You cannot propel yourself forward by patting yourself on the back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You cannot use your friends and have them too.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You cannot shake hands with a clenched fist.<BR>\n&nbsp;-- Indira Gandhi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Young men, hear an old man to whom old men hearkened when he was young.<BR>\n&nbsp;-- Augustus Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Beware of self-styled experts: an ex is a has-been, and a spurt is a<BR>\ndrip under pressure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You can destroy your now by worrying about tomorrow.<BR>\n&nbsp;-- Janis Joplin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You are a wish to be here wishing yourself.<BR>\n&nbsp;-- Philip Whalen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Yes, but every time I try to see things your way, I get a headache.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You are absolute plate-glass. I see to the very back of your mind.<BR>\n&nbsp;-- Sherlock Holmes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Yield to Temptation ... it may not pass your way again.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Why be difficult when, with a bit of effort, you could be impossible?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Why was I born with such contemporaries?<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','While we are sleeping, two-thirds of the world is plotting to do us in.<BR>\n&nbsp;-- Dean Rusk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','... whether it is better to spend a life not knowing what you want or to<BR>\nspend a life knowing exactly what you want and that you will never have it.<BR>\n&nbsp;-- Richard Shelton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whoever fights monsters should see to it that in the process he does not<BR>\nbecome a monster.  And when you look into an abyss, the abyss also looks<BR>\ninto you.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A truly great man will neither trample on a worm nor sneak to an emperor.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Ah, sweet Springtime, when a young man lightly turns his fancy over!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A real person has two reasons for doing anything ... a good reason and<BR>\nthe real reason.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You should make a point of trying every experience once -- except<BR>\nincest and folk-dancing.<BR>\n&nbsp;-- A. Bax, \"Farewell My Youth\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You want to know why I kept getting promoted?  Because my mouth knows more<BR>\nthan my brain.<BR>\n&nbsp;-- W.G.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You never gain something but that you lose something.<BR>\n&nbsp;-- Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You never go anywhere without your soul.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You are not a fool just because you have done something foolish --<BR>\nonly if the folly of it escapes you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you bring forth what is within you, what you bring forth will save<BR>\nyou.  If you do not bring forth what is within you, what you do not<BR>\nbring forth will destroy you.<BR>\n&nbsp;-- Jesus, \"Gnostic Gospels\" (Elaine Pagel)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You must know that a man can have only one invulnerable loyalty, loyalty<BR>\nto his own concept of the obligations of manhood.  All other loyalties<BR>\nare merely deputies of that one.<BR>\n&nbsp;-- Nero Wolfe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You may easily play a joke on a man who likes to argue -- agree with him.<BR>\n&nbsp;-- Ed Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You never get a second chance to make a first impression.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You men out there probably think you already know how to dress for success.<BR>\nYou know, for example, that you should not wear leisure suits or white<BR>\nplastic belts and shoes, unless you are going to a costume party disguised<BR>\nas a pig farmer vacationing at Disney World.<BR>\n&nbsp;-- Dave Barry, \"How to Dress for Real Success\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You may be sure that when a man begins to call himself a \"realist,\" he<BR>\nis preparing to do something he is secretly ashamed of doing.<BR>\n&nbsp;-- Sydney Harris');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You never know what is enough until you know what is more than enough.<BR>\n&nbsp;-- William Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You cannot achieve the impossible without attempting the absurd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You never learn anything by doing it right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You cannot kill time without injuring eternity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All men have the right to wait in line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A narcissist is someone better looking than you are.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A pat on the back is only a few centimeters from a kick in the pants.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A man with 3 wings and a dictionary is cousin to the turkey.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A man who turns green has eschewed protein.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A person forgives only when they are in the wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A man would still do something out of sheer perversity - he would create<BR>\ndestruction and chaos - just to gain his point... and if all this could in<BR>\nturn be analyzed and prevented by predicting that it would occur, then man<BR>\nwould deliberately go mad to prove his point.<BR>\n&nbsp;-- Feodor Dostoevsky, \"Notes From the Underground\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A man of genius makes no mistakes.<BR>\nHis errors are volitional and are the portals of discovery.<BR>\n&nbsp;-- James Joyce, \"Ulysses\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A person is just about as big as the things that make them angry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A gossip is one who talks to you about others, a bore is one who talks to<BR>\nyou about himself; and a brilliant conversationalist is one who talks to<BR>\nyou about yourself.<BR>\n&nbsp;-- Lisa Kirk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A friend is a present you give yourself.<BR>\n&nbsp;-- Robert Louis Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A cynic is a person searching for an honest man, with a stolen lantern.<BR>\n&nbsp;-- Edgar A. Shoaff');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A fair exterior is a silent recommendation.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A person who has nothing looks at all there is and wants something.<BR>\nA person who has something looks at all there is and wants all the rest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A \"practical joker\" deserves applause for his wit according to its quality.<BR>\nBastinado is about right.  For exceptional wit one might grant keelhauling.<BR>\nBut staking him out on an anthill should be reserved for the very wittiest.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A bore is someone who persists in holding his own views after we have<BR>\nenlightened him with ours.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A city is a large community where people are lonesome together<BR>\n&nbsp;-- Herbert Prochnow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A pessimist is a man who has been compelled to live with an optimist.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Advice is a dangerous gift; be cautious about giving and receiving it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A compliment is something like a kiss through a veil.<BR>\n&nbsp;-- Victor Hugo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Better by far you should forget and smile than that you should remember<BR>\nand be sad.<BR>\n&nbsp;-- Christina Rossetti');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You can always tell luck from ability by its duration.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You shall judge of a man by his foes as well as by his friends.<BR>\n&nbsp;-- Joseph Conrad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Young men are fitter to invent than to judge; fitter for execution than for<BR>\ncounsel; and fitter for new projects than for settled business.  For the<BR>\nexperience of age, in things that fall within the compass of it, directeth<BR>\nthem; but in new things, abuseth them.  The errors of young men are the ruin<BR>\nof business; but the errors of aged men amount but to this, that more might<BR>\nhave been done, or sooner.  Young men, in the conduct and management of<BR>\nactions, embrace more than they can hold; stir more than they can quiet; fly<BR>\nto the end, without consideration of the means and degrees; pursue some few<BR>\nprinciples which they have chanced upon absurdly; care not how they innovate,<BR>\nwhich draws unknown inconveniences; and, that which doubleth all errors, will<BR>\nnot acknowledge or retract them; like an unready horse, that will neither stop<BR>\nnor turn.  Men of age object too much, consult too long, adventure too little,<BR>\nrepent too soon, and seldom drive business home to the full period, but<BR>\ncontent themselves with a mediocrity of success.  Certainly, it is good to<BR>\ncompound employments of both ... because the virtues of either age may correct<BR>\nthe defects of both.<BR>\n&nbsp;-- Francis Bacon, \"Essay on Youth and Age\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be open to other people -- they may enrich your dream.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are no emotional victims, only volunteers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be careful what you set your heart on -- for it will surely be yours.<BR>\n&nbsp;-- James Baldwin, \"Nobody Knows My Name\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There are no great men, buster.  There are only men.<BR>\n&nbsp;-- Elaine Stewart, \"The Bad and the Beautiful\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','There is a certain frame of mind to which a cemetery is, if not an antidote,<BR>\nat least an alleviation.  If you are in a fit of the blues, go nowhere else.<BR>\n&nbsp;--Robert Louis Stevenson: Immortelles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All possibility of understanding is rooted in the ability to say no.<BR>\n&nbsp;-- Susan Sontag');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','As you grow older, you will still do foolish things, but you will do them<BR>\nwith much more enthusiasm.<BR>\n&nbsp;-- The Cowboy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;After Snow White used a couple rolls of film taking pictures of the<BR>\nseven dwarfs, she mailed the roll to be developed.  Later she was heard to<BR>\nsing, \"Some day my prints will come.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Accept people for what they are -- completely unacceptable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Those of you who think you know everything are annoying those of us who do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Against stupidity the very gods Themselves contend in vain.<BR>\n&nbsp;-- Friedrich von Schiller, \"The Maid of Orleans\", III, 6');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Those who in quarrels interpose, must often wipe a bloody nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To any truly impartial person, it would be obvious that I am always right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To criticize the incompetent is easy; it is more difficult to criticize<BR>\nthe competent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A man who keeps stealing mopeds is an obvious cycle-path.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;\"A penny for your thoughts?\"<BR>\n&nbsp;\"A dollar for your death.\"<BR>\n&nbsp;-- The Odd Couple');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A well-known friend is a treasure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A well adjusted person is one who makes the same mistake twice without<BR>\ngetting nervous.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','According to the obituary notices, a mean and unimportant person never dies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To laugh at men of sense is the privilege of fools.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;\"...A strange enigma is man!\"<BR>\n&nbsp;\"Someone calls him a soul concealed in an animal,\" I suggested.<BR>\n&nbsp;\"Winwood Reade is good upon the subject,\" said Holmes.  \"He remarked<BR>\nthat, while the individual man is an insoluble puzzle, in the aggregate he<BR>\nbecomes a mathematical certainty.  You can, for example, never foretell what<BR>\nany one man will do, but you can say with precision what an average number<BR>\nwill be up to.  Individuals vary, but percentages remain constant.  So says<BR>\nthe statistician.\"<BR>\n&nbsp;-- Sherlock Holmes, \"The Sign of Four\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','To refuse praise is to seek praise twice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When all other means of communication fail, try words.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When among apes, one must play the ape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A prig is a fellow who is always making you a present of his opinions.<BR>\n&nbsp;-- George Eliot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A sadist is a masochist who follows the Golden Rule.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A rock pile ceases to be a rock pile the moment a single <BR>\nman contemplates it, bearing within him the image of a cathedral.<BR>\n&nbsp;-- Antoine de Saint-Exupery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is the theory which decides what can be observed.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A sense of humor keen enough to show a man his own absurdities will keep<BR>\nhim from the commission of all sins, or nearly all, save those that are<BR>\nworth committing.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A private sin is not so prejudicial in the world as a public indecency.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','A pretty foot is one of the greatest gifts of nature... please send me your<BR>\nlast pair of shoes, already worn out in dancing... so I can have something<BR>\nof yours to press against my heart.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Criticism comes easier than craftsmanship.<BR>\n&nbsp;-- Zeuxis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Creativity is not always bred in an environment of tranquility;<BR>\nsometimes you have to squeeze a little to get the paste out of the tube.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Correction does much, but encouragement does more.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All we know is the phenomenon: we spend our time sending messages to each<BR>\nother, talking and trying to listen at the same time, exchanging information.<BR>\nThis seems to be our most urgent biological function; it is what we do with<BR>\nour lives.\"<BR>\n&nbsp;-- Lewis Thomas, \"The Lives of a Cell\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Ambition is a poor excuse for not having sense enough to be lazy.<BR>\n&nbsp;-- Charlie McCarthy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conversation enriches the understanding, but solitude is the school of genius.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conscience is what hurts when everything else feels so good.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Conscience is a mother-in-law whose visit never ends.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confidence is simply that quiet, assured feeling you have before you<BR>\nfall flat on your face.<BR>\n&nbsp;-- Dr. L. Binder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Succumb to natural tendencies.  Be hateful and boring.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confession is good for the soul, but bad for the career.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Suicide is simply a case of mistaken identity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Support your local Search and Rescue unit -- get lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Tact is the art of making a point without making an enemy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Tell me what to think!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Confess your sins to the Lord and you will be forgiven;<BR>\nconfess them to man and you will be laughed at.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The discerning person is always at a disadvantage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The forest is safe because a lion lives therein and the lion is safe because<BR>\nit lives in a forest.  Likewise the friendship of persons rests on mutual help.<BR>\n&nbsp;-- Laukikanyay.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The greatest remedy for anger is delay.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Common sense is instinct, and enough of it is genius.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Cloning is the sincerest form of flattery.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"All my life I wanted to be someone; I guess I should have been more specific.\"<BR>\n&nbsp;-- Jane Wagner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Clones are people two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The louder he talked of his honour, the faster we counted our spoons.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','By failing to prepare, you are preparing to fail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An evil mind is a great comfort.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','By doing just a little every day, you can gradually let the task<BR>\ncompletely overwhelm you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The older I grow, the more I distrust the familiar doctrine that age<BR>\nbrings wisdom.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','But Officer, I stopped for the last one, and it was green!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The only rose without thorns is friendship.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Birds are entangled by their feet and men by their tongues.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"The Schizophrenic: An Unauthorized Autobiography\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The secret of happiness is total disregard of everybody.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The three questions of greatest concern are -- 1. Is it attractive?<BR>\n2. Is it amusing?  3. Does it know its place?<BR>\n&nbsp;-- Fran Lebowitz, \"Metropolitan Life\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Being popular is important.  Otherwise people might not like you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Be valiant, but not too venturous.<BR>\nLet thy attire be comely, but not costly.<BR>\n&nbsp;-- John Lyly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The wise shepherd never trusts his flock to a smiling wolf.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','The wonderful thing about a dancing bear is not how well he dances,<BR>\nbut that he dances at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Saints should always be judged guilty until they are proved innocent.<BR>\n&nbsp;-- George Orwell, \"Reflections on Gandhi\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All of the animals except man know that the principal business of life is<BR>\nto enjoy it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;\"For I perceive that behind this seemingly unrelated sequence<BR>\nof events, there lurks a singular, sinister attitude of mind.\"<BR>\n&nbsp;\"Whose?\"<BR>\n&nbsp;\"MINE! HA-HA!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','For every credibility gap, there is a gullibility fill.<BR>\n&nbsp;-- R. Clopton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;A man pleaded innocent of any wrong doing when caught by the police<BR>\nduring a raid at the home of a mobster, excusing himself by claiming that he<BR>\nwas making a bolt for the door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An expert is one who knows more and more about less and less until he knows<BR>\nabsolutely everything about nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Scenery is here, wish you were beautiful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Short people get rained on last.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sin boldly.<BR>\n&nbsp;-- Martin Luther');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Experience is what causes a person to make new mistakes instead of old ones.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sin has many tools, but a lie is the handle which fits them all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Sin lies only in hurting other people unnecessarily.  All other \"sins\" are<BR>\ninvented nonsense.  (Hurting yourself is not sinful -- just stupid).<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','And on the eighth day, we bulldozed it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everyone complains of his memory, no one of his judgement.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everybody wants to go to heaven, but nobody wants to die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An idealist is one who helps the other fellow to make a profit.<BR>\n&nbsp;-- Henry Ford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Any man can work when every stroke of his hand brings down the fruit<BR>\nrattling from the tree to the ground; but to labor in season and out of<BR>\nseason, under every discouragement, by the power of truth -- that<BR>\nrequires a heroism which is transcendent.<BR>\n&nbsp;-- Henry Ward Beecher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Everybody has something to conceal.<BR>\n&nbsp;-- Humphrey Bogart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Some men are born mediocre, some men achieve mediocrity, and some men<BR>\nhave mediocrity thrust upon them.<BR>\n&nbsp;-- Joseph Heller, \"Catch-22\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All men profess honesty as long as they can.  To believe all men honest<BR>\nwould be folly.  To believe none so is something worse.<BR>\n&nbsp;-- John Quincy Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','All progress is based upon a universal innate desire of every organism<BR>\nto live beyond its income.<BR>\n&nbsp;-- Samuel Butler, \"Notebooks\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"Arguments with furniture are rarely productive.\"<BR>\n&nbsp;-- Kehlog Albran, \"The Profit\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Do you realize how many holes there could be if people would just take<BR>\nthe time to take the dirt out of them?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Stay together, drag each other down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','An effective way to deal with predators is to taste terrible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Always remember that you are unique.  Just like everyone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','As crazy as hauling timber into the woods.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Dave Mack:	\"Your stupidity, Allen, is simply not up to par.\"<BR>\nAllen Gwinn:	\"Yours is.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Arguments are extremely vulgar, for everyone in good society holds exactly<BR>\nthe same opinion.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hope not, lest ye be disappointed.<BR>\n&nbsp;-- M. Horner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Hope is a good breakfast, but it is a bad supper.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who despises himself nevertheless esteems himself as a self-despiser.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He who is flogged by fate and laughs the louder is a masochist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','History repeats itself only if one does not listen the first time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He is a man capable of turning any colour into grey.<BR>\n&nbsp;-- John LeCarre ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He is not only dull himself, he is the cause of dullness in others.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He had occasional flashes of silence that made his conversation perfectly<BR>\ndelightful.<BR>\n&nbsp;-- Sydney Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Have no friends not equal to yourself.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Great minds run in great circles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I treasure this strange combination found in very few persons: a fierce<BR>\ndesire for life as well as a lucid perception of the ultimate futility of<BR>\nthe quest.<BR>\n&nbsp;-- Madeleine Gobeil');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I profoundly believe it takes a lot of practice to become a moral slob.<BR>\n&nbsp;-- William F. Buckley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I prefer rogues to imbeciles because they sometimes take a rest.<BR>\n&nbsp;-- Alexandre Dumas, fils');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I may be getting older, but I refuse to grow up!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I may not be totally perfect, but parts of me are excellent.<BR>\n&nbsp;-- Ashleigh Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I used to think that the brain was the most wonderful organ in<BR>\nmy body.  Then I realized who was telling me this.<BR>\n&nbsp;-- Emo Phillips');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I hate mankind, for I think myself one of the best of them, and I know<BR>\nhow bad I am.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','&nbsp;I made it a rule to forbear all direct contradictions to the sentiments<BR>\nof others, and all positive assertion of my own.  I even forbade myself the use<BR>\nof every word or expression in the language that imported a fixed opinion, such<BR>\nas \"certainly\", \"undoubtedly\", etc.   I adopted instead of them \"I conceive\",<BR>\n\"I apprehend\", or \"I imagine\" a thing to be so or so; or \"so it appears to me<BR>\nat present\".<BR>\n&nbsp;When another asserted something that I thought an error, I denied<BR>\nmyself the pleasure of contradicting him abruptly, and of showing him<BR>\nimmediately some absurdity in his proposition.  In answering I began by<BR>\nobserving that in certain cases or circumstances his opinion would be right,<BR>\nbut in the present case there appeared or semed to me some difference, etc.<BR>\n&nbsp;I soon found the advantage of this change in my manner; the<BR>\nconversations I engaged in went on more pleasantly.  The modest way in which I<BR>\nproposed my opinions procured them a readier reception and less contradiction.<BR>\nI had less mortification when I was found to be in the wrong, and I more easily<BR>\nprevailed with others to give up their mistakes and join with me when I<BR>\nhappened to be in the right.<BR>\n&nbsp;-- Autobiography of Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I have made mistakes but I have never made the mistake of claiming<BR>\nthat I have never made one.<BR>\n&nbsp;-- James Gordon Bennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I have learned silence from the talkative,<BR>\ntoleration from the intolerant, and kindness from the unkind.<BR>\n&nbsp;-- Kahlil Gibran');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I have found little that is good about human beings.  In my experience<BR>\nmost of them are trash.<BR>\n&nbsp;-- Sigmund Freud');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I waited and waited and when no message came I knew it must be from you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I give you the man who -- the man who -- uh, I forgets the man who?<BR>\n&nbsp;-- Beauregard Bugleboy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I got vision, and the rest of the world wears bifocals.<BR>\n&nbsp;-- Butch Cassidy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I have great faith in fools -- self confidence my friends call it.<BR>\n&nbsp;-- Edgar Allan Poe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you cannot in the long run tell everyone what you have been doing,<BR>\nyour doing was worthless.<BR>\n&nbsp;-- Edwim Schrodinger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I do not know where to find in any literature, whether ancient or modern,<BR>\nany adequate account of that nature with which I am acquainted.  Mythology<BR>\ncomes nearest to it of any.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I do not know myself and God forbid that I should.<BR>\n&nbsp;-- Johann Wolfgang von Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I consider the day misspent that I am not either charged with a crime,<BR>\nor arrested for one.<BR>\n&nbsp;-- \"Ratsy\" Tourbillon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It does not matter if you fall down as long as you pick up something<BR>\nfrom the floor while you get up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you will practice being fictional for a while, you will understand that<BR>\nfictional characters are sometimes more real than people with bodies and<BR>\nheartbeats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you notice that a person is deceiving you, they must not be<BR>\ndeceiving you very well.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you just try long enough and hard enough, you can always manage to<BR>\nboot yourself in the posterior.<BR>\n&nbsp;-- A.J. Liebling, \"The Press\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you keep your mind sufficiently open, people will throw a lot of<BR>\nrubbish into it.<BR>\n&nbsp;-- William Orton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you talk to God, you are praying; if God talks to you, you have<BR>\nschizophrenia.<BR>\n&nbsp;-- Thomas Szasz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you do not wish a man to do a thing, you had better get him to talk about<BR>\nit; for the more men talk, the more likely they are to do nothing else.<BR>\n&nbsp;-- Carlyle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you flaunt it, expect to have it trashed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It will be generally found that those who sneer habitually at human nature<BR>\nand affect to despise it, are among its worst and least pleasant examples.<BR>\n&nbsp;-- Charles Dickens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Millions long for immortality who do not know what to do with themselves on a<BR>\nrainy Sunday afternoon.<BR>\n&nbsp;-- Susan Ertz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you float on instinct alone, how can you calculate the buoyancy for<BR>\nthe computed load?<BR>\n&nbsp;-- Christopher Hodder-Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If we were meant to get up early, God would have created us with alarm clocks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If the weather is extremely bad, church attendance will be down.  If<BR>\nthe weather is extremely good, church attendance will be down.  If the<BR>\nbulletin covers are in short supply, however, church attendance will<BR>\nexceed all expectations.<BR>\n&nbsp;-- Reverend Chichester');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you are a fatalist, what can you do about it?<BR>\n&nbsp;-- Ann Edwards-Duff');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If opportunity came disguised as temptation, one knock would be enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If people are good only because they fear punishment, and hope for reward,<BR>\nthen we are a sorry lot indeed.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If only you had a personality instead of an attitude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If man is only a little lower than the angels, the angels should reform.<BR>\n&nbsp;-- Mary Wilson Little');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If one studies too zealously, one easily loses his pants.<BR>\n&nbsp;-- A. Einstein.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If one tells the truth, one is sure, sooner or later, to be found out.<BR>\n&nbsp;-- Oscar Wilde, \"Phrases and Philosophies for the Use<BR>\n&nbsp;of the Young\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you are honest because honesty is the best policy, your honesty is corrupt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If God had meant for us to be naked, we would have been born that way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If a man has talent and cannot use it, he has failed.<BR>\n&nbsp;-- Thomas Wolfe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If God wanted us to be brave, why did he give us legs?<BR>\n&nbsp;-- Marvin Kitman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It would be nice to be sure of anything the way some people are of everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It may be that your whole purpose in life is simply to serve as a<BR>\nwarning to others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It takes a special kind of courage to face what we all have to face.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It seemed the world was divided into good and bad people.  The good ones slept<BR>\nbetter... while the bad ones seemed to enjoy the waking hours much more.<BR>\n&nbsp;-- Woody Allen, \"Side Effects\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It pays to be obvious, especially if you have a reputation for subtlety.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is the wise bird who builds his nest in a tree.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It takes all kinds to fill the freeways.<BR>\n&nbsp;-- Crazy Charlie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is the business of little minds to shrink.<BR>\n&nbsp;-- Carl Sandburg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is the nature of extreme self-lovers, as they will set an house on fire,<BR>\nand it were but to roast their eggs.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is only people of small moral stature who have to stand on their dignity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is not good for a man to be without knowledge,<BR>\nand he who makes haste with his feet misses his way.<BR>\n&nbsp;-- Proverbs 19:2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is often easier to ask for forgiveness than to ask for permission.<BR>\n&nbsp;-- Grace Murray Hopper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is the wisdom of crocodiles, that shed tears when they would devour.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is one thing to praise discipline, and another to submit to it.<BR>\n&nbsp;-- Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It takes both a weapon, and two people, to commit a murder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is exactly because a man cannot do a thing that he is a proper judge of it.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is indeed desirable to be well descended, but the glory belongs to<BR>\nour ancestors.<BR>\n&nbsp;-- Plutarch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is easy when we are in prosperity to give advice to the afflicted.<BR>\n&nbsp;-- Aeschylus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is far more impressive when others discover your good qualities without<BR>\nyour help.<BR>\n&nbsp;-- Miss Manners');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is much easier to be critical than to be correct.<BR>\n&nbsp;-- Benjamin Disraeli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is equally bad when one speeds on the guest unwilling to go, and when he<BR>\nholds back one who is hastening.  Rather one should befriend the guest who<BR>\nis there, but speed him when he wishes.<BR>\n&nbsp;-- Homer, \"The Odyssey\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to scheduling.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is amazing how complete is the delusion that beauty is goodness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is all right to hold a conversation, but you should let go of it<BR>\nnow and then.<BR>\n&nbsp;-- Richard Armour');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is always the best policy to tell the truth, unless, of course,<BR>\nyou are an exceptionally good liar.<BR>\n&nbsp;-- Jerome K. Jerome');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is easier to get forgiveness than permission.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is easier to make a saint out of a libertine than out of a prig.<BR>\n&nbsp;-- George Santayana');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It is not enough to have a good mind. The main thing is to use it well.<BR>\n&nbsp;-- Rene Descartes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It has been said that man is a rational animal.  All my life I have<BR>\nbeen searching for evidence which could support this.<BR>\n&nbsp;-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','It takes less time to do a thing right than it does to explain why you<BR>\ndid it wrong.<BR>\n&nbsp;-- H.W. Longfellow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Innocence ends when one is stripped of the delusion that one likes oneself.<BR>\n&nbsp;-- Joan Didion, \"On Self Respect\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In this world some people are going to like me and some are not.  So, I may<BR>\nas well be me.  Then I know if someone likes me, they like me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In this world there are only two tragedies.  One is not getting what one<BR>\nwants, and the other is getting it.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Intolerance is the last defense of the insecure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In most instances, all an argument proves is that two people are present.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Involvement with people is always a very delicate thing --<BR>\nit requires real maturity to become involved and not get all messed up.<BR>\n&nbsp;-- Bernard Cooke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In matters of principle, stand like a rock;<BR>\nin matters of taste, swim with the current.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you would understand your own age, read the works of fiction produced<BR>\nin it.  People in disguise speak freely.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','In good speaking, should not the mind of the speaker know the truth of<BR>\nthe matter about which he is to speak?<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If you want to know how old a man is, ask his brother-in-law.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No one can put you down without your full cooperation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nobody ever forgets where he buried the hatchet.<BR>\n&nbsp;-- Kin Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No one knows what he can do till he tries.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Objects are lost only because people look where they are not rather than<BR>\nwhere they are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man is a rational animal who always loses his temper when he is called upon<BR>\nto act in accordance with the dictates of reason.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man is the only animal that can remain on friendly terms with the<BR>\nvictims he intends to eat until he eats them.<BR>\n&nbsp;-- Samuel Butler (1835-1902)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If God had intended Man to Walk, He would have given him Feet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man has made his bedlam; let him lie in it.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man is the only animal that laughs and weeps; for he is the only animal<BR>\nthat is struck with the difference between what things are and what they<BR>\nought to be.<BR>\n&nbsp;-- William Hazlitt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man belongs wherever he wants to go.<BR>\n&nbsp;-- Wernher von Braun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','May you die in bed at 95, shot by a jealous spouse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Life is a series of rude awakenings.<BR>\n&nbsp;-- R.V. Winkle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man invented language to satisfy his deep need to complain.<BR>\n&nbsp;-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Let the meek inherit the earth -- they have it coming to them.<BR>\n&nbsp;-- James Thurber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Life is a hospital in which every patient is possessed by the desire to<BR>\nchange his bed.<BR>\n&nbsp;-- Charles Baudelaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Let a fool hold his tongue and he will pass for a sage.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Laughter is the closest distance between two people.<BR>\n&nbsp;-- Victor Borge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Life is a serious burden, which no thinking, humane person would<BR>\nwantonly inflict on someone else.<BR>\n&nbsp;-- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Lack of capability is usually disguised by lack of interest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Lack of money is the root of all evil.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Just when you thought you were winning the rat race, along comes a faster rat!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Justice always prevails ... three times out of seven!<BR>\n&nbsp;-- Michael J. Wagner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Keep your mouth shut and people will think you stupid;<BR>\nOpen it and you remove all doubt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Life is an exciting business, and most exciting when it is lived for others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"Just out of curiosity does this actually mean something or have some<BR>\nof the few remaining bits of your brain just evaporated?\"<BR>\n&nbsp;-- Patricia O Tuama, rissa@killer.DALLAS.TX.US');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nice boy, but about as sharp as a sack of wet mice.<BR>\n&nbsp;-- Foghorn Leghorn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never trust anybody whose arm is bigger than your leg.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never get into fights with ugly people because they have nothing to lose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never pay a compliment as if expecting a receipt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never forget what a man says to you when he is angry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No matter what happens, there is always someone who knew it would.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Neither spread the germs of gossip nor encourage others to do so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never argue with a fool -- people might not be able to tell the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','My mind can never know my body, although it has become quite friendly<BR>\nwith my legs.<BR>\n&nbsp;-- Woody Allen, on Epistemology');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Never explain.  Your friends do not need it and your enemies will never<BR>\nbelieve you anyway.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people have two reasons for doing anything -- a good reason, and<BR>\nthe real reason.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people have a furious itch to talk about themselves and are restrained<BR>\nonly by the disinclination of others to listen.  Reserve is an artificial<BR>\nquality that is developed in most of us as the result of innumerable rebuffs.<BR>\n&nbsp;-- W.S. Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people deserve each other.<BR>\n&nbsp;-- Shirley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people can do without the essentials, but not without the luxuries.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most of your faults are not your fault.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most of our lives are about proving something, either to ourselves or to<BR>\nsomeone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One measure of friendship consists not in the number of things friends<BR>\ncan discuss, but in the number of things they need no longer mention.<BR>\n&nbsp;-- Clifton Fadiman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Modern man is the missing link between apes and human beings.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People with narrow minds usually have broad tongues.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Most people are unable to write because they are unable to think, and<BR>\nthey are unable to think because they congenitally lack the equipment<BR>\nto do so, just as they congenitally lack the equipment to fly over the moon.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','More are taken in by hope than by cunning.<BR>\n&nbsp;-- Vauvenargues');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Murder is always a mistake -- one should never do anything one cannot<BR>\ntalk about after dinner.<BR>\n&nbsp;-- Oscar Wilde, \"The Picture of Dorian Gray\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Maybe Jesus was right when he said that the meek shall inherit the<BR>\nearth -- but they inherit very small plots, about six feet by three.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','\"Maybe we can get together and show off to each other sometimes.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many people resent being treated like the person they really are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many receive advice, few profit by it.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Men ought to know that from the brain and from the brain only arise our<BR>\npleasures, joys, laughter, and jests as well as our sorrows, pains, griefs<BR>\nand tears.  ...  It is the same thing which makes us mad or delirious,<BR>\ninspires us with dread and fear, whether by night or by day, brings us<BR>\nsleeplessness, inopportune mistakes, aimless anxieties, absent-mindedness<BR>\nand acts that are contrary to habit...<BR>\n&nbsp;-- Hippocrates \"The Sacred Disease\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many people are secretly interested in life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many people are desperately looking for some wise advice which will<BR>\nrecommend that they do what they want to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Man usually avoids attributing cleverness to somebody else -- unless it<BR>\nis an enemy.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Meekness is uncommon patience in planning a worthwhile revenge.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Many mental processes admit of being roughly measured.  For instance,<BR>\nthe degree to which people are bored, by counting the number of their<BR>\nfidgets. I not infrequently tried this method at the meetings of the<BR>\nRoyal Geographical Society, for even there dull memoirs are occasionally<BR>\nread.  [...]  The use of a watch attracts attention, so I reckon time<BR>\nby the number of my breathings, of which there are 15 in a minute.  They<BR>\nare not counted mentally, but are punctuated by pressing with 15 fingers<BR>\nsuccessively.  The counting is reserved for the fidgets.  These observations<BR>\nshould be confined to persons of middle age.  Children are rarely still,<BR>\nwhile elderly philosophers will sometimes remain rigid for minutes altogether.<BR>\n&nbsp;-- Francis Galton, 1909');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Words must be weighed, not counted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Out of the crooked timber of humanity no straight thing can ever be made.<BR>\n&nbsp;-- Immanuel Kant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Patience is a minor form of despair, disguised as virtue.<BR>\n&nbsp;-- Ambrose Bierce, on qualifiers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Paranoia is simply an optimistic outlook on life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old age is the harbor of all ills.<BR>\n&nbsp;-- Bion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only the hypocrite is really rotten to the core.<BR>\n&nbsp;-- Hannah Arendt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One of the large consolations for experiencing anything unpleasant is<BR>\nthe knowledge that one can communicate it.<BR>\n&nbsp;-- Joyce Carol Oates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Why, every one as they like; as the good woman said when she kissed her cow.<BR>\n&nbsp;-- Rabelais');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Others will look to you for stability, so hide when you bite your nails.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','On Monday mornings I am dedicated to the proposition that all men are<BR>\ncreated jerks.<BR>\n&nbsp;-- H. Allen Smith, \"Let the Crabgrass Grow\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People often find it easier to be a result of the past than a cause of the<BR>\nfuture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One friend in a lifetime is much; two are many; three are hardly possible.<BR>\nFriendship needs a certain parallelism of life, a community of thought,<BR>\na rivalry of aim.<BR>\n&nbsp;-- Henry Brook Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One family builds a wall, two families enjoy it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One can never consent to creep when one feels an impulse to soar.<BR>\n&nbsp;-- Helen Keller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old men are fond of giving good advice to console themselves for their<BR>\ninability to set a bad example.<BR>\n&nbsp;-- La Rochefoucauld, \"Maxims\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old age is too high a price to pay for maturity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One is not superior merely because one sees the world as odious.<BR>\n&nbsp;-- Chateaubriand (1768-1848)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nothing shortens a journey so pleasantly as an account of misfortunes at<BR>\nwhich the hearer is permitted to laugh.<BR>\n&nbsp;-- Quentin Crisp');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old age is always fifteen years old than I am.<BR>\n&nbsp;-- B. Baruch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Obstacles are what you see when you take your eyes off your goal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Oh this age!  How tasteless and ill-bred it is.<BR>\n&nbsp;-- Gaius Valerius Catullus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Old age is the most unexpected of things that can happen to a man.<BR>\n&nbsp;-- Trotsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Oh wearisome condition of humanity!<BR>\nBorn under one law, to another bound.<BR>\n&nbsp;-- Fulke Greville, Lord Brooke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One is often kept in the right road by a rut.<BR>\n&nbsp;-- Gustave Droz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nobody knows what goes between his cold toes and his warm ears.<BR>\n&nbsp;-- Roy Harper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nothing makes one so vain as being told that one is a sinner.<BR>\nConscience makes egotists of us all.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Nobody can be as agreeable as an uninvited guest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No question is so difficult as one to which the answer is obvious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','O Lord, grant that we may always be right, for Thou knowest we will<BR>\nnever change our minds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No snowflake in an avalanche ever feels responsible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','No sooner said than done -- so acts your man of worth.<BR>\n&nbsp;-- Quintus Ennius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One man tells a falsehood, a hundred repeat it as true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','I am examining you on your fool ideas that no intelligent Christian<BR>\non earth believes.<BR>\n&nbsp;-- Clarence Darrow, to William Jennings Bryan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When there are two conflicting versions of the story, the wise course<BR>\nis to believe the one in which people appear at their worst.<BR>\n&nbsp;-- H. Allen Smith, \"Let the Crabgrass Grow\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When you jump for joy, beware that no-one moves the ground from beneath<BR>\nyour feet.<BR>\n&nbsp;-- Stanislaw Lem, \"Unkempt Thoughts\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When God endowed human beings with brains, He did not intend to guarantee them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','While anyone can admit to themselves they were wrong, the true test is<BR>\nadmission to someone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whatever you may be sure of, be sure of this: that you are dreadfully like<BR>\nother people.<BR>\n&nbsp;-- James Russell Lowell, \"My Study Windows\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whatever you want to do, you have to do something else first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What we see depends on mainly what we look for.<BR>\n&nbsp;-- John Lubbock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What you see is from outside yourself, and may come, or not, but is beyond<BR>\nyour control.  But your fear is yours, and yours alone, like your voice, or<BR>\nyour fingers, or your memory, and therefore yours to control.  If you feel<BR>\npowerless over your fear, you have not yet admitted that it is yours, to do<BR>\nwith as you will.<BR>\n&nbsp;-- Marion Zimmer Bradley, \"Stormqueen\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Winter is the season in which people try to keep the house as warm as<BR>\nit was in the summer, when they complained about the heat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When a man knows he is to be hanged in a fortnight, it concentrates his<BR>\nmind wonderfully.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Virtue does not always demand a heavy sacrifice -- only the willingness<BR>\nto make it when necessary.<BR>\n&nbsp;-- Frederick Dunn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Too clever is dumb.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Waking a person unnecessarily should not be considered a capital crime.<BR>\nFor a first offense, that is.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What good is it if you talk in flowers, and they think in pastry?<BR>\n&nbsp;-- Ashleigh Brilliant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Walk softly and carry a BFG-9000.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','What makes us so bitter against people who outwit us is that they think<BR>\nthemselves cleverer than we are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Were it not for the presence of the unwashed and the half-educated, the<BR>\nformless, queer and incomplete, the unreasonable and absurd, the infinite<BR>\nshapes of the delightful human tadpole, the horizon would not wear so wide<BR>\na grin.<BR>\n&nbsp;-- F.M. Colby, \"Imaginary Obligations\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We are all in the gutter, but some of us are looking at the stars.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We read to say that we have read.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We secure our friends not by accepting favors but by doing them.<BR>\n&nbsp;-- Thucydides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','We have more to fear from the bungling of the incompetent than from the<BR>\nmachinations of the wicked.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Young men think old men are fools; but old men know young men are fools.<BR>\n&nbsp;-- George Chapman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You humans are all alike.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Remember: Silly is a state of Mind, Stupid is a way of Life.<BR>\n&nbsp;-- Dave Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whenever I feel like exercise, I lie down until the feeling passes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You have not converted a man because you have silenced him.<BR>\n&nbsp;-- John Viscount Morley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You know how to win a victory, Hannibal, but not how to use it.<BR>\n&nbsp;-- Maharbal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You know what they say -- the sweetest word in the English language is revenge.<BR>\n&nbsp;-- Peter Beard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','You know you are getting old when you think you should drive the speed limit.<BR>\n&nbsp;-- E.A. Gilliam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Convention is the ruler of all.<BR>\n&nbsp;-- Pindar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Even moderation ought not to be practiced to excess.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Etiquette is for those with no breeding; fashion for those with no taste.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Elevators smell different to midgets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Envy is a pain of mind that successful men cause their neighbors.<BR>\n&nbsp;-- Onasander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only someone with nothing to be sorry for smiles back at the rear of an<BR>\nelephant.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only a fool has no doubts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','One of the pleasures of reading old letters is the knowledge that they<BR>\nneed no answer.<BR>\n&nbsp;-- George Gordon, Lord Byron');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','He liked fishing a little too much, and he believed that work was<BR>\nsomething a man did when he had to.  He had always been able to get<BR>\nalong well enough without it, especially for the last couple of<BR>\nyears.<BR>\n&nbsp;-- \"The Stone Giant\", James P. Blaylock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Would a giant, profit-oriented cartel lie to you?<BR>\n&nbsp;-- Top Ten List, Late Night with David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who take cold baths never have rheumatism, but they have cold baths.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','If a man slept by day, he had little time to work.  That was a<BR>\nsatisfying notion to Escargot.<BR>\n&nbsp;-- \"The Stone Giant\", James P. Blaylock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who fight fire with fire usually end up with ashes.<BR>\n&nbsp;-- Abigail Van Buren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Youth is a disease from which we all recover.<BR>\n&nbsp;-- Dorothy Fuldheim');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whenever people agree with me I always feel I must be wrong.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Youth -- not a time of life but a state of mind... a predominance of<BR>\ncourage over timidity, of the appetite for adventure over the love of ease.<BR>\n&nbsp;-- Robert F. Kennedy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Youth is a blunder, manhood a struggle, old age a regret.<BR>\n&nbsp;-- Benjamin Disraeli, \"Coningsby\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People seem to enjoy things more when they know a lot of other people<BR>\nhave been left out on the pleasure.<BR>\n&nbsp;-- Russell Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','When you try to make an impression, the chances are that is the<BR>\nimpression you will make.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Whoever would lie usefully should lie seldom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Your conscience never stops you from doing anything.  It just stops you<BR>\nfrom enjoying it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Why did the Lord give us so much quickness of movement unless it was to<BR>\navoid responsibility with?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Your friends will know you better in the first minute you meet than your<BR>\nacquaintances will know you in a thousand years.<BR>\n&nbsp;-- Richard Bach, \"Illusions\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People tend to make rules for others and exceptions for themselves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People who think they know everything greatly annoy those of us who do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People say I live in my own little fantasy world... well, at least they<BR>\n*know* me there!<BR>\n&nbsp;-- D.L. Roth');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People are like onions -- you cut them up, and they make you cry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People (a group that in my opinion has always attracted an undue amount of<BR>\nattention) have often been likened to snowflakes.  This analogy is meant to<BR>\nsuggest that each is unique -- no two alike.  This is quite patently not the<BR>\ncase.  People ... are simply a dime a dozen.  And, I hasten to add, their<BR>\nonly similarity to snowflakes resides in their invariable and lamentable<BR>\ntendency to turn, after a few warm days, to slush.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Paranoia is heightened awareness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Write a wise saying and your name will live forever.<BR>\n&nbsp;-- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Paranoid schizophrenics outnumber their enemies at least two to one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Passionate hatred can give meaning and purpose to an empty life.<BR>\n&nbsp;-- Eric Hoffer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People love high ideals, but they got to be about 33-percent plausible.<BR>\n&nbsp;-- The Best of Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','People will do tomorrow what they did today because that is what they<BR>\ndid yesterday.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('people','Only fools are quoted.<BR>\n&nbsp;-- Anonymous');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Obviously I was either onto something, or on something.<BR>\n&nbsp;-- Larry Wall on the creation of Perl');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','True, it returns \"\" for false, but \"\" is an even more interesting<BR>\nnumber than 0.<BR>\n&nbsp;-- Larry Wall in <199707300650.XAA05515@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl',': How would you disambiguate these situations?<BR>\n&nbsp;By shooting the person who did the latter.<BR>\n&nbsp;-- Larry Wall in <199710290235.SAA02444@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Hey, if pi == 3, and three == 0, does that make pi == 0?  :-)<BR>\n&nbsp;-- Larry Wall in <199711011926.LAA25557@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','A \"goto\" in Perl falls into the category of hard things that should be<BR>\npossible, not easy things that should be easy.<BR>\n&nbsp;-- Larry Wall in <199709041935.MAA27136@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The random quantum fluctuations of my brain are historical accidents that<BR>\nhappen to have decided that the concepts of dynamic scoping and lexical<BR>\nscoping are orthogonal and should remain that way.<BR>\n&nbsp;-- Larry Wall in <199709021854.LAA12794@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Of course, this being Perl, we could always take both approaches.  :-)<BR>\n&nbsp;-- Larry Wall in <199709021744.KAA12428@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Anybody want a binary telemetry frame editor written in Perl?<BR>\n&nbsp;-- Larry Wall in <199708012226.PAA22015@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','For the run-time caching, I was going to suggest \"cached\" (doh!), but<BR>\nperhaps \"once\" is more meaningful to ordinary people.<BR>\n&nbsp;-- Larry Wall in <199709021812.LAA12571@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Part of language design is purturbing the proposed feature in various<BR>\ndirections to see how it might generalize in the future.<BR>\n&nbsp;-- Larry Wall in <199709032332.QAA21669@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Most places distinguish them merely by using the appropriate value.<BR>\nHooray for context...<BR>\n&nbsp;-- Larry Wall in <199708040319.UAA16213@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perl has a long tradition of working around compilers.<BR>\n&nbsp;-- Larry Wall in <199708252256.PAA00105@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Any false value is gonna be fairly boring in Perl, mathematicians<BR>\nnotwithstanding.<BR>\n&nbsp;-- Larry Wall in <199707300650.XAA05515@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Personally, I like to defiantly split my infinitives.  :-)<BR>\n&nbsp;-- Larry Wall in <199708271551.IAA10211@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','You can prove anything by mentioning another computer language.  :-)<BR>\n&nbsp;-- Larry Wall in <199706242038.NAA29853@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The core is not frozen, but slushy.<BR>\n&nbsp;-- Larry Wall in <199705101952.MAA00756@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Life gets boring, someone invents another necessity, and once again we<BR>\nturn the crank on the screwjack of progress hoping that nobody gets<BR>\nscrewed.<BR>\n&nbsp;-- Larry Wall in <199705101952.MAA00756@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','\"It is easier to port a shell than a shell script.\"<BR>\n&nbsp;-- Larry Wall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','In general, they do what you want, unless you want consistency.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','If you want your program to be readable, consider supplying the argument.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','if (rsfp = mypopen(\"/bin/mail root\",\"w\")) {     /* heh, heh */<BR>\n&nbsp;-- Larry Wall in perl.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The choice of approaches could be made the responsibility of the<BR>\nprogrammer.<BR>\n&nbsp;-- Larry Wall in <199709081901.MAA20863@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Hey, I had to let awk be better at *something*...  :-)<BR>\n&nbsp;-- Larry Wall in <1991Nov7.200504.25280@netlabs.com>1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','\"Help save the world!\"              -- Larry Wall in README');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','[End of diatribe.  We now return you to your regularly scheduled<BR>\nprogramming...]<BR>\n&nbsp;-- Larry Wall in Configure from the perl distribution');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','#define SIGILL 6         /* blech */<BR>\n&nbsp;-- Larry Wall in perl.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Besides, REAL computers have a rename() system call.    :-)<BR>\n&nbsp;-- Larry Wall in <7937@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','double value;                /* or your money back! */<BR>\nshort changed;               /* so triple your money back! */<BR>\n&nbsp;-- Larry Wall in cons.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Well, enough clowning around.  Perl is, in intent, a cleaned up and<BR>\nsummarized version of that wonderful semi-natural language known as<BR>\n\"Unix\".<BR>\n&nbsp;-- Larry Wall in <1994Apr6.184419.3687@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Your csh still thinks true is false.  Write to your vendor today and tell<BR>\nthem that next year Configure ought to \"rm /bin/csh\" unless they fix their<BR>\nblasted shell. :-)   -- Larry Wall in Configure from the perl distribution');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Down that path lies madness.  On the other hand, the road to hell is<BR>\npaved with melting snowballs.<BR>\n&nbsp;-- Larry Wall in <1992Jul2.222039.26476@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','That gets us out of deciding how to spell Reg[eE]xp?|RE . . .<BR>\nOf course, then we have to decide what ref $re returns...  :-)<BR>\n&nbsp;-- Larry Wall in <199710171838.LAA24968@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','echo \"ICK, NOTHING WORKED!!!  You may have to diddle the includes.\";;<BR>\n&nbsp;-- Larry Wall in Configure from the perl distribution');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Unix is like a toll road on which you have to stop every 50 feet to<BR>\npay another nickel.  But hey!  You only feel 5 cents poorer each time.<BR>\n&nbsp;-- Larry Wall in <1992Aug13.192357.15731@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The only disadvantage I see is that it would force everyone to get Perl.<BR>\nHorrors.  :-)<BR>\n&nbsp;-- Larry Wall in  <8854@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','/* This bit of chicanery makes a unary function followed by<BR>\na parenthesis into a function with one argument, highest precedence. */<BR>\n&nbsp;-- Larry Wall in toke.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','There are probably better ways to do that, but it would make the parser<BR>\nmore complex.  I do, occasionally, struggle feebly against complexity...  :-)<BR>\n&nbsp;-- Larry Wall in <7886@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','There are many times when you want it to ignore the rest of the string just<BR>\nlike atof() does.  Oddly enough, Perl calls atof().  How convenient.  :-)<BR>\n&nbsp;-- Larry Wall in <1991Jun24.231628.14446@jpl-devvax.jpl.nasa.gov>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','\"The road to hell is paved with melting snowballs.\"<BR>\n&nbsp;-- Larry Wall in  <1992Jul2.222039.26476@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','*** The previous line contains the naughty word \"$&\".\n<BR>\nif /(ibm|apple|awk)/;      # :-)<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','str->str_pok |= SP_FBM;                     /* deep magic */<BR>\ns = (unsigned char*)(str->str_ptr);         /* deeper magic */<BR>\n&nbsp;-- Larry Wall in util.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Sorry.  My testing organization is either too small, or too large, depending<BR>\non how you look at it.  :-)<BR>\n&nbsp;-- Larry Wall in <1991Apr22.175438.8564@jpl-devvax.jpl.nasa.gov>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','stab_val(stab)->str_nok = 1;    /* what a wonderful hack! */<BR>\n&nbsp;-- Larry Wall in stab.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Real programmers can write assembly code in any language.   :-)<BR>\n&nbsp;-- Larry Wall in  <8571@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','s = (char*)(long)retval;                /* ouch */<BR>\n&nbsp;-- Larry Wall in doio.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','signal(i, SIG_DFL); /* crunch, crunch, crunch */<BR>\n&nbsp;-- Larry Wall in doarg.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','OK, enough hype.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perl programming is an *empirical* science!<BR>\n&nbsp;-- Larry Wall in <10226@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','pos += screamnext[pos]  /* does this goof up anywhere? */<BR>\n&nbsp;-- Larry Wall in util.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','/* now make a new head in the exact same spot */<BR>\n&nbsp;-- Larry Wall in cons.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perl 5 introduced everything else, including the ability to introduce<BR>\neverything else.<BR>\n&nbsp;-- Larry Wall in <199702252152.NAA28845@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perl is designed to give you several ways to do anything, so<BR>\nconsider picking the most readable one.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','tmps_base = tmps_max;                /* protect our mortal string */<BR>\n&nbsp;-- Larry Wall in stab.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I suppose one could claim that an undocumented feature has no<BR>\nsemantics.  :-(<BR>\n&nbsp;-- Larry Wall in <199710290036.QAA01818@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl',': The hierarchy is excessive.<BR>\n&nbsp;So is the anarchy.  :-)<BR>\n&nbsp;-- Larry Wall in <199705101952.MAA00756@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','As someone pointed out, you could have an attribute that says \"optimize<BR>\nthe heck out of this routine\", and your definition of heck would be a<BR>\nparameter to the optimizer.<BR>\n&nbsp;-- Larry Wall in <199709081854.LAA20830@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','It is my job in life to travel all roads, so that some may take the road<BR>\nless travelled, and others the road more travelled, and all have a<BR>\npleasant day.<BR>\n&nbsp;-- Larry Wall in <199709241628.JAA08908@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Of course, I reserve the right to make wholly stupid changes to Perl<BR>\nif I think they improve the language.  :-)<BR>\n&nbsp;-- Larry Wall in <199704251604.JAA27300@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I think $[ is more like a coelacanth than a mastadon.<BR>\n&nbsp;-- Larry Wall in <199705101952.MAA00756@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Not that I have anything much against redundancy.  But I said that already.<BR>\n&nbsp;-- Larry Wall in <199702271735.JAA04048@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','At many levels, Perl is a \"diagonal\" language.<BR>\n&nbsp;-- Larry Wall in <199709021854.LAA12794@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','If someone stinks, view it as a reason to help them, not a reason to<BR>\navoid them.<BR>\n&nbsp;-- Larry Wall in <199702111730.JAA28598@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Odd that we think definitions are definitive.   :-)<BR>\n&nbsp;-- Larry Wall in <199702221943.LAA20388@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','One of the reasons Perl is faster than certain other unnamed interpreted<BR>\nlanguages is that it binds variable names to a particular package (or<BR>\nscope) at compile time rather than at run time.<BR>\n&nbsp;-- Larry Wall in <199709050035.RAA29328@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The whole history of computers is rampant with cheerleading at best and<BR>\nbigotry at worst.<BR>\n&nbsp;-- Larry Wall in <199702111730.JAA28598@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I want to see people using Perl to glue things together creatively, not<BR>\njust technically but also socially.<BR>\n&nbsp;-- Larry Wall in <199702111730.JAA28598@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','How do Crays and Alphas handle the POSIX problem?<BR>\n&nbsp;-- Larry Wall in <199709050042.RAA29379@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','\"What is the sound of Perl?  Is it not the sound of a wall that<BR>\npeople have stopped banging their heads against?\"<BR>\n&nbsp;-- Larry Wall in <1992Aug26.184221.29627@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Oh, wait, that was Randal...nevermind...<BR>\n&nbsp;-- Larry Wall in <199709261754.KAA23761@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The prayer of serenity applies here.  To both of us.  :-)<BR>\n&nbsp;-- Larry Wall in <199710141802.LAA22443@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','It may be possible to get this condition from within Perl if a signal<BR>\nhandler runs at just the wrong moment.  Another point for Chip...  :-)<BR>\n&nbsp;-- Larry Wall in <199710161546.IAA07885@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','When in doubt, parenthesize.  At the very least it will let some<BR>\npoor schmuck bounce on the % key in vi.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Randal can write one-liners again.  Everyone is happy, and peace spreads<BR>\nover the whole Earth.<BR>\n&nbsp;-- Larry Wall in <199705101952.MAA00756@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','They can always run stderr through uniq.  :-)<BR>\n&nbsp;-- Larry Wall in <199704012331.PAA16535@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl',':-) your own self.<BR>\n&nbsp;-- Larry Wall in <199709261754.KAA23761@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','/* we have tried to make this normal case as abnormal as possible */<BR>\n&nbsp;-- Larry Wall in cmd.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The reason I like hitching a ride on strict vars is that it cuts down<BR>\nthe number of rarely used pragmas people have to remember, yet provides<BR>\na way to get to the point where we might, just maybe, someday, make<BR>\nlocal lexicals the default for everyone, without having useless pragmas<BR>\nwandering around various programs, or using up another bit in $^H.<BR>\n&nbsp;-- Larry Wall in <199710050130.SAA04762@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','By rule #1, 5.005 should always allow localization of lexical @_ . . .<BR>\n&nbsp;-- Larry Wall in <199710011704.KAA21395@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Anyway, my money is still on use strict vars . . .<BR>\n&nbsp;-- Larry Wall in <199710011704.KAA21395@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Because the demand for it is low enough that it would be best handled<BR>\nas an XSUB, and the demand for it is low enough that nobody has<BR>\nbothered to write it as an XSUB.<BR>\n&nbsp;-- Larry Wall on in-place Perl sorting');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Tcl tends to get ported to weird places like routers.<BR>\n&nbsp;-- Larry Wall in <199710071721.KAA19014@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','&nbsp;switch (ref $@) {<BR>\n&nbsp;OverflowError =><BR>\n&nbsp;warn \"Dam needs to be drained\";<BR>\n&nbsp;DomainError =><BR>\n&nbsp;warn \"King needs to be trained\";<BR>\n&nbsp;NuclearWarError =><BR>\n&nbsp;die;<BR>\n&nbsp;}<BR>\n&nbsp;-- Larry Wall in <199709302338.QAA17037@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','And we can always supply them with a program that makes identical files<BR>\ninto links to a single file.<BR>\n&nbsp;-- Larry Wall in <199709292012.NAA09616@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Soitainly.  I was assuming that came with the OO-ness of it.<BR>\n&nbsp;-- Larry Wall in <199710011802.LAA21692@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I was about to say, \"Avoid fame like the plague,\" but you know, they can<BR>\ncure the plague with penicillin these days.<BR>\n&nbsp;-- Larry Wall in <199709242015.NAA10312@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','#else /* !STDSTDIO */     /* The big, slow, and stupid way */<BR>\n&nbsp;-- Larry Wall in str.c from the perl source code');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','It is, of course, written in Perl.  Translation to C is left as an<BR>\nexercise for the reader.  :-)  -- Larry Wall in <7448@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','To Perl, or not to Perl, that is the kvetching.<BR>\n&nbsp;-- Larry Wall in <199801200310.TAA11670@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Er, Tom, I hate to be the one to point this out, but your fix list<BR>\nis starting to resemble a feature list.  You must be human or something.<BR>\n&nbsp;-- Larry Wall in <199801081824.KAA29602@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Are you perchance running on a 64-bit machine?<BR>\n&nbsp;-- Larry Wall in <199711102149.NAA16878@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Reserve your abuse for your true friends.<BR>\n&nbsp;-- Larry Wall in <199712041852.KAA19364@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perl will always provide the null.<BR>\n&nbsp;-- Larry Wall in <199801151818.KAA14538@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Almost nothing in Perl serves a single purpose.<BR>\n&nbsp;-- Larry Wall in <199712040054.QAA13811@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Well, I think Perl should run faster than C.  :-)<BR>\n&nbsp;-- Larry Wall in <199801200306.TAA11638@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Perhaps they will have to outlaw sending random lists of words.  fee fie<BR>\nfoe foo [sic]<BR>\n&nbsp;-- Larry Wall in <199710311916.LAA19760@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Yes, we have consensus that we need 64 bit support.  :-)<BR>\n&nbsp;-- Larry Wall in <199710291922.LAA07101@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Either approach may give birth to various sorts of monstrosities.<BR>\n&nbsp;-- Larry Wall in <199710221950.MAA25210@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Portability should be the default.<BR>\n&nbsp;-- Larry Wall in <199711072201.OAA01123@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Think of prototypes as a funny markup language--the interpretation is<BR>\nleft up to the rendering engine.<BR>\n&nbsp;-- Larry Wall in <199710221710.KAA24242@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Obviously your filters are throwing away mail from Randal.  :-)<BR>\n&nbsp;-- Larry Wall in <199710221937.MAA25131@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Double *sigh*.  _04 is going onto thousands of CDs even as we speak,<BR>\nso to speak.<BR>\n&nbsp;-- Larry Wall in <199710221718.KAA24299@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','People who understand context would be steamed to have someone else<BR>\ndictating how they can call it.<BR>\n&nbsp;-- Larry Wall in <199710221710.KAA24242@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Depends on how you define \"always\".  :-)<BR>\n&nbsp;-- Larry Wall in <199710211647.JAA17957@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I was trying not to mention backtracking.  Which, of course, means that<BR>\nyours is \"righter\" than mine, in a theoretical sense.<BR>\n&nbsp;-- Larry Wall in <199710211624.JAA17833@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The Harvard Law states:  Under controlled conditions of light, temperature,<BR>\nhumidity, and nutrition, the organism will do as it damn well pleases.<BR>\n&nbsp;-- Larry Wall in <199710161841.LAA13208@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','That should probably be written:<BR>\n&nbsp;no !@#$%^&*:@!semicolon<BR>\n&nbsp;-- Larry Wall in <199710161841.LAA13208@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','As pointed out in a followup, Real Perl Programmers prefer things to be<BR>\nvisually distinct.<BR>\n&nbsp;-- Larry Wall in <199710161841.LAA13208@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','(To the extent that anyone but a Prolog programmer can understand X totally.<BR>\n(And to the extent that a Prolog programmer can understand \"cut\". :-))<BR>\n&nbsp;-- Larry Wall in <199710211624.JAA17833@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl',':        And it goes against the grain of building small tools.<BR>\nInnocent, Your Honor.  Perl users build small tools all day long.<BR>\n&nbsp;-- Larry Wall in <1992Aug26.184221.29627@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','All language designers are arrogant.  Goes with the territory... :-)<BR>\n&nbsp;-- Larry Wall in <1991Jul13.010945.19157@netlabs.com');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Oh yeah.  Forgot about those.  Getting senile, I guess...<BR>\n&nbsp;-- Larry Wall in <199710261551.HAA17791@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Unix weanies are as bad at this as anyone.<BR>\n&nbsp;-- Larry Wall in <199702111730.JAA28598@wall.org>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','You want it in one line?  Does it have to fit in 80 columns?   :-)<BR>\n&nbsp;-- Larry Wall in <7349@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','What about WRITING it first and rationalizing it afterwords?  :-)<BR>\n&nbsp;-- Larry Wall in <8162@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','The autodecrement is not magical.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Remember though that<BR>\nTHERE IS NO GENERAL RULE FOR CONVERTING A LIST INTO A SCALAR.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Let us be charitable, and call it a misleading feature  :-)<BR>\n&nbsp;-- Larry Wall in <2609@jato.Jpl.Nasa.Gov>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','I dunno, I dream in Perl sometimes...<BR>\n&nbsp;-- Larry Wall in  <8538@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Chip Salzenberg sent me a complete patch to add System V IPC (msg, sem and<BR>\nshm calls), so I added them.  If that bothers you, you can always undefine<BR>\nthem in config.sh.  :-) -- Larry Wall in <9384@jpl-devvax.JPL.NASA.GOV>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','Be consistent.<BR>\n&nbsp;-- Larry Wall in the perl man page');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('perl','But you have to allow a little for the desire to evangelize when you<BR>\nthink you have good news.<BR>\n&nbsp;-- Larry Wall in <1992Aug26.184221.29627@netlabs.com>');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','For a man to truly understand rejection, he must first be ignored by a cat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','All intelligent species own cats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','&nbsp;\"Anything else you wish to draw to my attention, Mr. Holmes ?\"<BR>\n&nbsp;\"The curious incident of the stable dog in the nighttime.\"<BR>\n&nbsp;\"But the dog did nothing in the nighttime.\"<BR>\n&nbsp;\"That was the curious incident.\"<BR>\n&nbsp;-- A. Conan Doyle, \"Silver Blaze\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','It was Penguin lust... at its ugliest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Who loves me will also love my dog.<BR>\n&nbsp;-- John Donne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','When man calls an animal \"vicious\", he usually means that it will attempt<BR>\nto defend itself when he tries to kill it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Raising pet electric eels is gaining a lot of current popularity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Never try to outstubborn a cat.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','When the fog came in on little cat feet last night, it left these little<BR>\nmuddy paw prints on the hood of my car.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','To err is human,<BR>\nTo purr feline.<BR>\n&nbsp;-- Robert Byrne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','No one can feel as helpless as the owner of a sick goldfish.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Does the name Pavlov ring a bell?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','\"Contrary to popular belief, penguins are not the salvation of modern<BR>\ntechnology.  Neither do they throw parties for the urban proletariat.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Cats are intended to teach us that not everything in nature has a function.<BR>\n&nbsp;-- Garrison Keillor');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Breeding rabbits is a hare raising experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Auribus teneo lupum.<BR>\n&nbsp;[I hold a wolf by the ears.]<BR>\n&nbsp;[Boy, it *sounds* good.  But what does it *mean*?]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Anyone who considers protocol unimportant has never dealt with a cat.<BR>\n&nbsp;-- R. Heinlein ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','About the only thing on a farm that has an easy time is the dog.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','There are many intelligent species in the universe, and they all own cats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','PENGUINICITY!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','\"Shelter,\" what a nice name for for a place where you polish your cat.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Some books are to be tasted, others to be swallowed, and some few to be<BR>\nchewed and digested.<BR>\n&nbsp;-- Francis Bacon<BR>\n&nbsp;[As anyone who has ever owned a puppy already knows.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','It is not a good omen when goldfish commit suicide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','If you have received a letter inviting you to speak at the dedication of a<BR>\nnew cat hospital, and you hate cats, your reply, declining the invitation,<BR>\ndoes not necessarily have to cover the full range of your emotions.  You must<BR>\nmake it clear that you will not attend, but you do not have to let fly at cats.<BR>\nThe writer of the letter asked a civil question; attack cats, then, only if<BR>\nyou can do so with good humor, good taste, and in such a way that your answer<BR>\nwill be courteous as well as responsive.  Since you are out of sympathy with<BR>\ncats, you may quite properly give this as a reason for not appearing at the<BR>\ndedication ceremonies of a cat hospital.  But bear in mind that your opinion<BR>\nof cats was not sought, only your services as a speaker.  Try to keep things<BR>\nstraight.<BR>\n&nbsp;-- Strunk and White, \"The Elements of Style\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Lost: gray and white female cat.  Answers to electric can opener.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','If a can of Alpo costs 38 cents, would it cost $2.50 in Dog Dollars?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','No animal should ever jump on the dining room furniture unless<BR>\nabsolutely certain he can hold his own in conversation.<BR>\n&nbsp;-- Fran Lebowitz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','Cats, no less liquid than their shadows, offer no angles to the wind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('pets','A door is what a dog is perpetually on the wrong side of.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A bird in the bush usually has a friend in there with him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Things fall apart; the centre cannot hold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Time and tide wait for no man.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A bird in the hand makes it awfully hard to blow your nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A bird in the hand is worth what it will bring.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A chronic disposition to inquiry deprives domestic felines of vital qualities.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Necessity is a mother.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A clever prophet makes sure of the event first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can fool some of the people all of the time,<BR>\nand all of the people some of the time,<BR>\nbut you can make a fool of yourself anytime.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can go anywhere you want if you look serious and carry a clipboard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can get much further with a kind word and a gun than you can with a<BR>\nkind word alone.<BR>\n&nbsp;-- Al Capone<BR>\n&nbsp;[Also attributed to Johnny Carson.  Ed.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can move the world with an idea, but you have to think of it first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can never do just one thing.<BR>\n&nbsp;-- Hardin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You get what you pay for.<BR>\n&nbsp;-- Gabriel Biel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','God gave man two ears and one tongue so that we listen twice as much as<BR>\nwe speak.<BR>\n&nbsp;-- Arab proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Life is one long struggle in the dark.<BR>\n&nbsp;-- Titus Lucretius Carus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Misfortunes arrive on wings and leave on foot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"Life is too important to take seriously.\"<BR>\n&nbsp;-- Corky Siegel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Left to themselves, things tend to go from bad to worse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is the quality rather than the quantity that matters.<BR>\n&nbsp;-- Lucius Annaeus Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is when I struggle to be brief that I become obscure.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is wise to keep in mind that neither success nor failure is ever final.<BR>\n&nbsp;-- Roger Babson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Kites rise highest against the wind -- not with it.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Any philosophy that can be put \"in a nutshell\" belongs there.<BR>\n&nbsp;-- Sydney J. Harris');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is better to have loved a short man than never to have loved a tall.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Laugh when you can; cry when you must.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is better to have loved and lost than just to have lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Laugh and the world laughs with you, snore and you sleep alone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is better to wear out than to rust out.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Knowledge is power.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is sweet to let the mind unbend on occasion.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Words have a longer life than deeds.<BR>\n&nbsp;-- Pindar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Two wrongs are only the beginning.<BR>\n&nbsp;-- Kohn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Life is too short to be taken seriously.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Look ere ye leap.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Look before you leap.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Man is the measure of all things.<BR>\n&nbsp;-- Protagoras');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Misery no longer loves company.  Nowadays it insists on it.<BR>\n&nbsp;-- Russell Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Let sleeping dogs lie.<BR>\n&nbsp;-- Charles Dickens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Let your conscience be your guide.<BR>\n&nbsp;-- Pope');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Mankind is poised midway between the gods and the beasts.<BR>\n&nbsp;-- Plotinus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Men freely believe that what they wish to desire.<BR>\n&nbsp;-- Julius Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Many are called, few volunteer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Many are called, few are chosen.  Fewer still get to do the choosing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Never put off until tomorrow what you can do the day after.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Necessity hath no law.<BR>\n&nbsp;-- Oliver Cromwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Honi soit qui mal y pense.<BR>\n&nbsp;[Evil to him who evil thinks.]<BR>\n&nbsp;-- Motto of the Order of the Garter (est. Edward III)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Pity the meek, for they shall inherit the earth.<BR>\n&nbsp;-- Don Marquis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is humor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Stop searching forever.  Happiness is just next to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Stop searching forever.  Happiness is unattainable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, to forgive unusual.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Never promise more than you can perform.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, to moo bovine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If anything can go wrong, it will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If at first you do succeed, try to hide your astonishment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If you wish to succeed, consult three old people.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If there is no wind, row.<BR>\n&nbsp;-- Polish proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Inspiration without perspiration is usually sterile.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','In charity there is no excess.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','I know on which side my bread is buttered.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Leave no stone unturned.<BR>\n&nbsp;-- Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Knowledge without common sense is folly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Many hands make light work.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Misery loves company, but company does not reciprocate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Mistakes are often the stepping stones to utter failure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Mother is the invention of necessity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Moderation in all things.<BR>\n&nbsp;-- Publius Terentius Afer [Terence]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Many are cold, but few are frozen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is common sense to take a method and try it.  If it fails,<BR>\nadmit it frankly and try another.  But above all, try something.<BR>\n&nbsp;-- Franklin D. Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','None love the bearer of bad news.<BR>\n&nbsp;-- Sophocles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','No excellent soul is exempt from a mixture of madness.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Once a word has been allowed to escape, it cannot be recalled.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','&nbsp;-- Owen Meredith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','One good turn deserves another.<BR>\n&nbsp;-- Gaius Petronius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Seek simplicity -- and distrust it.<BR>\n&nbsp;-- Alfred North Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Seize the day, put no trust in the morrow!<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Scintillation is not always identification for an auric substance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The descent to Hades is the same from every place.<BR>\n&nbsp;-- Anaxagoras');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The early worm gets the late bird.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The man who runs may fight again.<BR>\n&nbsp;-- Menander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The life which is unexamined is not worth living.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Sic Transit Gloria Thursdi.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','There is no fool to the old fool.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','There is no proverb that is not true.<BR>\n&nbsp;-- Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Si jeunesse savait, si vieillesse pouvait.<BR>\n&nbsp;[If youth but knew, if old age but could.]<BR>\n&nbsp;-- Henri Estienne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Never put off till tomorrow what you can avoid all together.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Things are not always what they seem.<BR>\n&nbsp;-- Phaedrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Time flies like an arrow.  Fruit flies like a banana.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Things are more like they used to be than they are now.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Time goes, you say?<BR>\nAh no!<BR>\nTime stays, *we* go.<BR>\n&nbsp;-- Austin Dobson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Things are more like they are today than they ever were before.<BR>\n&nbsp;-- Dwight Eisenhower');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, but I can REALLY foul things up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To add insult to injury.<BR>\n&nbsp;-- Phaedrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, to repent, divine, to persist, devilish.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Trust in Allah, but tie your camel.<BR>\n&nbsp;-- Arabian proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, to purr feline.<BR>\nTo err is human, two curs canine.<BR>\nTo err is human, to moo bovine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','We are what we are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Two heads are more numerous than one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','What fools these morals be!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Well begun is half done.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Two heads are better than one.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Whom the gods wish to destroy they first call promising.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Whom the mad would destroy, first they make Gods.<BR>\n&nbsp;-- Bernard Levin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Without fools there would be no wisdom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Turn the other cheek.<BR>\n&nbsp;-- Jesus Christ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Adde parvum parvo manus acervus erit.<BR>\n&nbsp;[Add little to little and there will be a big pile.]<BR>\n&nbsp;-- Ovid');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Ad astra per aspera.<BR>\n&nbsp;[To the stars by aspiration.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Alimony is the high cost of leaving.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Age and treachery will always overcome youth and skill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All articles that coruscate with resplendence are not truly auriferous.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All that glitters is not gold; all that wander are not lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All true wisdom is found on T-shirts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An apple a day makes 365 apples a year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All is well that ends well.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Haste makes waste.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An ounce of hypocrisy is worth a pound of ambition.<BR>\n&nbsp;-- Michael Korda');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"An ounce of prevention is worth a pound of purge.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An idle mind is worth two in the bush.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All is fear in love and war.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Beggars should be no choosers.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Be sure to evaluate the bird-hand/bush ratio.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Anything worth doing is worth overdoing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Any great truth can -- and eventually will -- be expressed as a cliche --<BR>\na cliche is a sure and certain way to dilute an idea.  For instance, my<BR>\ngrandmother used to say, \"The black cat is always the last one off the fence.\"<BR>\nI have no idea what she meant, but at one time, it was undoubtedly true.<BR>\n&nbsp;-- Solomon Short');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better to light one candle than to curse the darkness.<BR>\n&nbsp;-- motto of the Christopher Society');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Charity begins at home.<BR>\n&nbsp;-- Publius Terentius Afer (Terence)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A good plan today is better than a perfect plan tomorrow.<BR>\n&nbsp;-- Patton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Cleanliness is next to impossible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Curiosity killed the cat, but satisfaction brought her back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A gleekzorp without a tornpee is like a quop without a fertsneet (sort of).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Doing gets it done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Do, or do not; there is no try.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better to be nouveau than never to have been riche at all.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Absence makes the heart go wander.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Expedience is the best teacher.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Eschew obfuscation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Flattery will get you everywhere.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Fortune favors the lucky.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Fortune and love befriend the bold.<BR>\n&nbsp;-- Ovid');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Fortune finishes the great quotations, #9<BR>\n&nbsp;A word to the wise is often enough to start an argument.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Genius is pain.<BR>\n&nbsp;-- John Lennon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Freedom from incrustation of grime is contiguous to rectitude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who fears the unknown may one day flee from his own backside.<BR>\n&nbsp;-- Sinbad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Have an adequate day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who foresees calamities suffers them twice over.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who has imagination without learning has wings but no feet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who has a shady past knows that nice guys finish last.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who has the courage to laugh is almost as much a master of the world<BR>\nas he who is ready to die.<BR>\n&nbsp;-- Giacomo Leopardi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who hesitates is sometimes saved.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who hesitates is last.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who laughs, lasts.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who hates vices hates mankind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who laughs last usually had to have joke explained.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','I doubt, therefore I might be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','I think, therefore I am... I think.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A soft answer turneth away wrath; but grievous words stir up anger.<BR>\n&nbsp;-- Proverbs 15:1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A lie is an abomination unto the Lord and a very present help in time of<BR>\ntrouble.<BR>\n&nbsp;-- Adlai Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A journey of a thousand miles must begin with a single step.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A hermit is a deserter from the army of humanity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A wise man can see more from a mountain top than a fool can from the bottom<BR>\nof a well.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A likely impossibility is always preferable to an unconvincing possibility.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Aim for the moon.  If you miss, you may hit a star.<BR>\n&nbsp;-- W. Clement Stone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A soft drink turneth away company.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','And tomorrow will be like today, only more so.<BR>\n&nbsp;-- Isaiah 56:12, New Standard Version');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A fool and his money are soon popular.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A fool must now and then be right by chance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A friend in need is a pest indeed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A farmer is a man outstanding in his field.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Age before beauty; and pearls before swine.<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','After the game the king and the pawn go in the same box.<BR>\n&nbsp;-- Italian proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All that glitters has a high refractive index.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A little experience often upsets a lot of theory.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A full belly makes a dull brain.<BR>\n&nbsp;-- Ben Franklin<BR>\n&nbsp;[and the local candy machine man.  Ed]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Advice from an old carpenter: measure twice, saw once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A snake lurks in the grass.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All things being equal, you are bound to lose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A day without sunshine is like night.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','All things are possible, except for skiing through a revolving door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who makes a beast of himself gets rid of the pain of being a man.<BR>\n&nbsp;-- Dr. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Alas, I am dying beyond my means.<BR>\n&nbsp;-- Oscar Wilde [as he sipped champagne on his deathbed]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','42');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A bird in the hand is worth two in the bush.<BR>\n&nbsp;-- Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','&nbsp;A farmer with extremely prolific hens posted the following sign.  \"Free<BR>\nChickens.  Our Coop Runneth Over.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If happiness is in your destiny, you need not be in a hurry.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Anything that is worth doing has been done frequently.  Things hitherto<BR>\nundone should be given, I suspect, a wide berth.<BR>\n&nbsp;-- Max Beerbohm, \"Mainly on the Air\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Anything is possible on paper.<BR>\n&nbsp;-- Ron McAfee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','&nbsp;A father gave his teen-age daughter an untrained pedigreed pup for<BR>\nher birthday.  An hour later, when wandered through the house, he found her<BR>\nlooking at a puddle in the center of the kitchen.  \"My pup,\" she murmured<BR>\nsadly, \"runneth over.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','(1) Everything depends.<BR>\n(2) Nothing is always.<BR>\n(3) Everything is sometimes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A little inaccuracy saves a world of explanation.<BR>\n&nbsp;-- C.E. Ayres');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Ask not for whom the telephone bell tolls...<BR>\nif thou art in the bathtub, it tolls for thee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A penny saved is ridiculous.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Ask not for whom the Bell tolls, and you will pay only the station-to-station<BR>\nrate.<BR>\n&nbsp;-- Howard Kandel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','As well look for a needle in a bottle of hay.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Beware of friends who are false and deceitful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better dead than mellow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better living a beggar than buried an emperor.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better tried by twelve than carried by six.<BR>\n&nbsp;-- Jeff Cooper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better hope you get what you want before you stop wanting it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Do unto others before they undo you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Cheap things are of no value, valuable things are not cheap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Do not count your chickens before they are hatched.<BR>\n&nbsp;-- Aesop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Desist from enumerating your fowl prior to their emergence from the shell.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Call on God, but row away from the rocks.<BR>\n&nbsp;-- Indian proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He that bringeth a present, findeth the door open.<BR>\n&nbsp;-- Scottish proverb.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A lost ounce of gold may be found, a lost moment of time never.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Every path has its puddle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A good scapegoat is hard to find.<BR>\nA guilty conscience is the mother of invention.<BR>\n&nbsp;-- Carolyn Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A handful of friends is worth more than a wagon of gold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A pound of salt will not sweeten a single cup of tea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nothing endures but change.<BR>\n&nbsp;-- Heraclitus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nullum magnum ingenium sine mixtura dementiae fuit.<BR>\n&nbsp;[There is no great genius without some touch of madness.]<BR>\n&nbsp;-- Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Out of sight is out of mind.<BR>\n&nbsp;-- Arthur Clough');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Once harm has been done, even a fool understands it.<BR>\n&nbsp;-- Homer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','No evil can happen to a good man.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','No good deed goes unpunished.<BR>\n&nbsp;-- Clare Booth Luce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Not everything worth doing is worth doing well.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','No act of kindness, no matter how small, is ever wasted.<BR>\n&nbsp;-- Aesop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nice guys finish last, but we get to sleep in.<BR>\n&nbsp;-- Evan Davis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Pereant, inquit, qui ante nos nostra dixerunt.<BR>\n&nbsp;[Confound those who have said our remarks before us.]<BR>\n&nbsp;or<BR>\n&nbsp;[May they perish who have expressed our bright ideas before us.]<BR>\n&nbsp;-- Aelius Donatus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Necessity has no law.<BR>\n&nbsp;-- St. Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Never do today what you can put off until tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Never look a gift horse in the mouth.<BR>\n&nbsp;-- Saint Jerome');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A lie in time saves nine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The only problem with seeing too much is that it makes you insane.<BR>\n&nbsp;-- Phaedrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A handful of patience is worth more than a bushel of brains.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A witty saying proves nothing.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who laughs last -- missed the punch line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A dead man cannot bite.<BR>\n&nbsp;-- Gnaeus Pompeius (Pompey)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A day without sunshine is like a day without Anita Bryant.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A certain amount of opposition is a help, not a hindrance. Kites rise<BR>\nagainst the wind, not with it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An apple every eight hours will keep three doctors away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An aphorism is never exactly true; it is either a half-truth or<BR>\none-and-a-half truths.<BR>\n&nbsp;-- Karl Kraus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Be both a speaker of words and a doer of deeds.<BR>\n&nbsp;-- Homer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The reverse side also has a reverse side.  <BR>\n&nbsp;-- Japanese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Moderation is a fatal thing.  Nothing succeeds like excess.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A journey of a thousand miles begins with a cash advance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An ounce of clear truth is worth a pound of obfuscation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A wise person makes his own decisions, a weak one obeys public opinion.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"A radioactive cat has eighteen half-lives.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A plethora of individuals with expertise in culinary techniques contaminate<BR>\nthe potable concoction produced by steeping certain edible nutriments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A watched clock never boils.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A mind is a wonderful thing to waste.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A shortcut is the longest distance between two points.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A stitch in time saves nine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A mushroom cloud has no silver lining.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A pipe gives a wise man time to think and a fool something to stick in his<BR>\nmouth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A man with one watch knows what time it is.<BR>\nA man with two watches is never quite sure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A little inaccuracy sometimes saves tons of explanation.<BR>\n&nbsp;-- H.H. Munro, \"Saki\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A place for everything and everything in its place.<BR>\n&nbsp;-- Isabella Mary Beeton, \"The Book of Household Management\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to memory management system services.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A good memory does not equal pale ink.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','An ounce of mother is worth a ton of priest.<BR>\n&nbsp;-- Spanish proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A platitude is simply a truth repeated till people get tired of hearing it.<BR>\n&nbsp;-- Stanley Baldwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A penny saved has not been spent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A good name lost is seldom regained.  When character is gone,<BR>\nall is gone, and one of the richest jewels of life is lost forever.<BR>\n&nbsp;-- J. Hawes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The superfluous is very necessary.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The temperature of the aqueous content of an unremittingly ogled<BR>\nculinary vessel will not achieve 100 degrees on the Celsius scale.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The proof of the pudding is in the eating.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','-- The writing implement is more potent than the claymore.<BR>\n-- All articles that coruscate with resplendence are not truly auriferous.<BR>\n-- When there are visible vapors having the prevenience in ignited carbonaceous<BR>\n&nbsp;materials, there is conflagration.<BR>\n-- Sorting on the part of mendicants must be interdicted.<BR>\n-- A plethora of individuals wither expertise in culinary techniques vitiated<BR>\n&nbsp;the potable concoction produced by steeping certain coupestibles.<BR>\n-- The person presenting the ultimate cachinnation possesses thereby the<BR>\n&nbsp;optimal cachinnation.<BR>\n-- Eleemosynary deeds have their initial incidence intramurally.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nothing ever becomes real till it is experienced -- even a<BR>\nproverb is no proverb to you till your life has illustrated it.<BR>\n&nbsp;-- John Keats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The road to Hades is easy to travel.<BR>\n&nbsp;-- Bion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A violent man will die a violent death.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A wise man can see more from the bottom of a well than a fool can from a<BR>\nmountain top.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human, to forgive is against company policy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','I am a man: nothing human is alien to me.<BR>\n&nbsp;-- Publius Terentius Afer (Terence)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who lives without folly is less wise than he believes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','What one believes to be true either is true or becomes true.<BR>\n&nbsp;-- John Lilly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The worst is enemy of the bad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Where there are visible vapors, having their prevenance in ignited<BR>\ncarbonaceous materials, there is conflagration.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Absence makes the heart forget.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The light at the end of the tunnel may be an oncoming dragon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The light at the end of the tunnel is the headlight of an approaching train.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The early worm gets the bird.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The ends justify the means.<BR>\n&nbsp;-- after Matthew Prior');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The course of true anything never does run smooth.<BR>\n&nbsp;-- Samuel Butler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Sweet April showers do spring May flowers.<BR>\n&nbsp;-- Thomas Tusser');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Sic transit gloria Monday!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Set the cart before the horse.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The coast was clear.<BR>\n&nbsp;-- Lope de Vega');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Sic transit gloria mundi.<BR>\n&nbsp;[So passes away the glory of this world.]<BR>\n&nbsp;-- Thomas \`a Kempis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The more things change, the more they stay insane.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Rotten wood cannot be carved.<BR>\n&nbsp;-- Confucius, \"Analects\", Book 5, Ch. 9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','-- Scintillate, scintillate, asteroid minikin.<BR>\n-- Members of an avian species of identical plumage congregate.<BR>\n-- Surveillance should precede saltation.<BR>\n-- Pulchritude possesses solely cutaneous profundity.<BR>\n-- It is fruitless to become lachrymose over precipitately departed<BR>\n&nbsp;lacteal fluid.<BR>\n-- Freedom from incrustations of grime is contiguous to rectitude.<BR>\n-- It is fruitless to attempt to indoctrinate a superannuated<BR>\n&nbsp;canine with innovative maneuvers.<BR>\n-- Eschew the implement of correction and vitiate the scion.<BR>\n-- The temperature of the aqueous content of an unremittingly<BR>\n&nbsp;galled saucepan does not reach 212 degrees Farenheit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Rome was not built in one day.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Praise the sea; on shore remain.<BR>\n&nbsp;-- John Florio');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Quidquid latine dictum sit, altum viditur.<BR>\n&nbsp;[Whatever is said in Latin sounds profound.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Remembering is for those who have forgotten.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Pray to God, but keep rowing to shore.<BR>\n&nbsp;-- Russian Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Practice yourself what you preach.<BR>\n&nbsp;-- Titus Maccius Plautus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Honesty is the best policy, but insanity is a better defense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Pauca sed matura.<BR>\n&nbsp;[Few but excellent.]<BR>\n&nbsp;-- Gauss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Prosperity makes friends, adversity tries them.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Patience is the best remedy for every trouble.<BR>\n&nbsp;-- Titus Maccius Plautus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','One picture is worth more than ten thousand words.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','One good turn asketh another.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','One good turn usually gets most of the blanket.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Oppernockity tunes but once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the going gets weird, the weird turn pro.<BR>\n&nbsp;-- Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When in doubt, use brute force.<BR>\n&nbsp;-- Ken Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When in doubt, follow your heart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When nothing can possibly go wrong, it will.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','What one fool can do, another can.<BR>\n&nbsp;-- Ancient Simian Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','What we wish, that we readily believe.<BR>\n&nbsp;-- Demosthenes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Whatever it is, I fear Greeks even when they bring gifts.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When you are at Rome live in the Roman style; when you are elsewhere live<BR>\nas they live elsewhere.<BR>\n&nbsp;-- St. Ambrose');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Words are the voice of the heart.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','We are what we pretend to be.<BR>\n&nbsp;-- Kurt Vonnegut, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the sun shineth, make hay.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human; to admit it, a blunder.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human; to forgive is simply not our policy.<BR>\n&nbsp;-- MIT Assasination Club');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To err is human.<BR>\nTo blame someone else for your mistakes is even more human.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','-- All articles that coruscate with resplendence are not truly auriferous.<BR>\n-- When there are visible vapors having the prevenience in ignited<BR>\n&nbsp;carbonaceous materials, there is conflagration.<BR>\n-- Sorting on the part of mendicants must be interdicted.<BR>\n-- A plethora of individuals wither expertise in culinary techniques vitiated<BR>\n&nbsp;the potable concoction produced by steeping certain coupestibles.<BR>\n-- Eleemosynary deeds have their initial incidence intramurally.<BR>\n-- Male cadavers are incapable of yielding testimony.<BR>\n-- Individuals who make their abode in vitreous edifices would be well<BR>\n&nbsp;advised to refrain from catapulting projectiles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','To every Ph.D. there is an equal and opposite Ph.D.<BR>\n&nbsp;-- B. Duggan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can fool some of the people all of the time,<BR>\nand all of the people some of the time,<BR>\nbut you can never fool your Mom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can get everything in life you want, if you will help enough other<BR>\npeople get what they want.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Where there is much light there is also much shadow.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When you have eliminated the impossible, whatever remains, however improbable,<BR>\nmust be the truth.<BR>\n&nbsp;-- Sherlock Holmes, \"The Sign of Four\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','There is no grief which time does not lessen and soften.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Would ye both eat your cake and have your cake?<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Treat your friend as if he might become an enemy.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"MOKE DAT YIGARETTE\"<BR>\n&nbsp;-- \"The Last Coin\", James P. Blaylock');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Three may keep a secret, if two of them are dead.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Thou hast seen nothing yet.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','There are more ways of killing a cat than choking her with cream.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The more the merrier.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Time as he grows old teaches all things.<BR>\n&nbsp;-- Aeschylus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The only reward of virtue is virtue.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The only constant is change.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Absence makes the heart grow fonder.<BR>\n&nbsp;-- Sextus Aurelius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','The only certainty is that nothing is certain.<BR>\n&nbsp;-- Pliny the Elder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Happiness adds and multiplies as we divide it with others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Words can never express what words can never express.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can drive a horse to water, but a pencil must be lead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You buttered your bread, now lie in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You can fool some of the people some of the time,<BR>\nand some of the people all of the time,<BR>\nand that is sufficient.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A rolling stone gathers momentum.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A sinking ship gathers no moss.<BR>\n&nbsp;-- Donald Kaul');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A rolling stone gathers no moss.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A Smith & Wesson beats four aces.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Flee at once, all is discovered.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A man who carries a cat by its tail learns something he can learn<BR>\nin no other way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Have a nice diurnal anomaly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Mistrust first impulses; they are always right.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Experience is a good teacher, but she sends in terrific bills.<BR>\n&nbsp;-- Minna Antrim, \"Naked Truth and Veiled Allusions\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Given sufficient time, what you put off doing today will get done by itself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Familiarity breeds attempt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is bad luck to be superstitious.<BR>\n&nbsp;-- Andrew W. Mathis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Above all things, reverence yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Above all else -- sky.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A man gazing at the stars is proverbially at the mercy of the puddles<BR>\nin the road.<BR>\n&nbsp;-- Alexander Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A good reputation is more valuable than money.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Absence makes the heart grow fonder -- of somebody else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Absence makes the heart grow frantic.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"The porcupine with the sharpest quills gets stuck on a tree more often.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A word to the wise is enough.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When you are in it up to your ears, keep your mouth shut.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A song in time is worth a dime.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','There are more things in heaven and earth than any place else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','How you look depends on where you go.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','\"World conquerors sometimes become fools, but fools never become world<BR>\nconquerors.\"<BR>\n&nbsp;-- \"The Outer Limits: The Invisibles\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A day without sunshine is like a day without orange juice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A day without orange juice is like a day without orange juice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A foolish consistency is the hobgoblin of little minds.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A fool and your money are soon partners.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Often things ARE as bad as they seem!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nice guys get sick.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','May you live in uninteresting times.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Keep the phase, baby.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Laugh at your problems; everybody else does.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','May you have warm words on a cold evening,<BR>\na full mooon on a dark night,<BR>\nand a smooth road all the way to your door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is better to have loved and lost -- much better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is annoying to be honest to no purpose.<BR>\n&nbsp;-- Publius Ovidius Naso (Ovid)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If you wish to be happy for one hour, get drunk.<BR>\nIf you wish to be happy for three days, get married.<BR>\nIf you wish to be happy for a month, kill your pig and eat it.<BR>\nIf you wish to be happy forever, learn to fish.<BR>\n&nbsp;-- Chinese Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If wishes were horses, then beggars would be thieves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If you would keep a secret from an enemy, tell it not to a friend.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If a fool persists in his folly he shall become wise.<BR>\n&nbsp;-- William Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If in doubt, mumble.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A couch is as good as a chair.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','In God we trust; all else we walk through.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who laughs last is probably your boss.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If I cannot bend Heaven, I shall move Hell.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who laughs has not yet heard the bad news.<BR>\n&nbsp;-- Bertolt Brecht');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','If it heals good, say it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','In this world, nothing is certain but death and taxes.<BR>\n&nbsp;-- Benjamin Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Have a nice day!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Integrity has no need for rules.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','He who fights and runs away lives to fight another day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Fortune finishes the great quotations, #3<BR>\n&nbsp;Birds of a feather flock to a newly washed car.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Forgive and forget.<BR>\n&nbsp;-- Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','For fools rush in where angels fear to tread.<BR>\n&nbsp;-- Alexander Pope');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Every silver lining has a cloud around it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Every solution breeds new problems.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is a poor judge who cannot award a prize.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','It is a profitable thing, if one is wise, to seem foolish.<BR>\n&nbsp;-- Aeschylus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Answer a fool according to his folly, lest he be wise in his own conceit.<BR>\n&nbsp;-- Proverbs, 26:5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','A closed mouth gathers no foot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Happiness is the greatest good.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Beware of geeks bearing graft.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the only tool you have is a hammer, every problem starts to look<BR>\nlike a nail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Better late than never.<BR>\n&nbsp;-- Titus Livius (Livy)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When we talk of tomorrow, the gods laugh.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','What fools these mortals be.<BR>\n&nbsp;-- Lucius Annaeus Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the going gets tough, everyone leaves.<BR>\n&nbsp;-- Lynch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the ax entered the forest, the trees said, \"The handle is one of us!\"<BR>\n&nbsp;-- Turkish proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the going gets tough, the tough go shopping.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','When the blind lead the blind they will both fall over the cliff.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Nice guys finish last.<BR>\n&nbsp;-- Leo Durocher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','You cannot see the wood for the trees.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('platitudes','Two is company, three is an orgy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I place economy among the first and most important virtues, and public debt as<BR>\nthe greatest of dangers to be feared.  To preserve our independence, we must<BR>\nnot let our rulers load us with perpetual debt.  If we run into such debts, we<BR>\nmust be taxed in our meat and drink, in our necessities and in our comforts,<BR>\nin our labor and in our amusements.  If we can prevent the government from<BR>\nwasting the labor of the people, under the pretense of caring for them, they<BR>\nwill be happy.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I can hire one half of the working class to kill the other half.<BR>\n&nbsp;-- Jay Gould');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','My central memory of that time seems to hang on one or five or maybe forty<BR>\nnights -- or very early mornings -- when I left the Fillmore half-crazy and,<BR>\ninstead of going home, aimed the big 650 Lightning across the Bay Bridge at<BR>\na hundred miles an hour ... booming through the Treasure Island tunnel at<BR>\nthe lights of Oakland and Berkeley and Richmond, not quite sure which<BR>\nturnoff to take when I got to the other end ... but being absolutely certain<BR>\nthat no matter which way I went I would come to a place where people were<BR>\njust as high and wild as I was: no doubt at all about that.<BR>\n&nbsp;-- Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','An efficient and a successful administration manifests itself equally in<BR>\nsmall as in great matters.  <BR>\n&nbsp;-- W. Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Conquering Russia should be done steppe by steppe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In fiction the recourse of the powerless is murder; in life the recourse<BR>\nof the powerless is petty theft.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I realize that the MX missile is none of our concern.  I realize that the<BR>\nwhole point of living in a democracy is that we pay professional<BR>\ncongresspersons to concern themselves with things like the MX missile so we<BR>\ncan be free to concern ourselves with getting hold of the plumber.<BR>\n&nbsp;But from time to time, I feel I must address major public issues such as<BR>\nthis, because in a free and open society, where the very future of the world<BR>\nhinges on decisions made by our elected leaders, you never win large cash<BR>\njournalism awards if you stick to the topics I usually write about, such as<BR>\nnose-picking.<BR>\n&nbsp;-- Dave Barry, \"At Last, the Ultimate Deterrent Against<BR>\n&nbsp;Political Fallout\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I prefer the most unjust peace to the most righteous war.<BR>\n&nbsp;-- Cicero<BR>\n&nbsp;Even peace may be purchased at too high a price.<BR>\n&nbsp;-- Poor Richard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I needed the good will of the legislature of four states.  I formed the<BR>\nlegislative bodies with my own money.  I found that it was cheaper that way.<BR>\n&nbsp;-- Jay Gould');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I know not with what weapons World War III will be fought, but World<BR>\nWar IV will be fought with sticks and stones.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I have never understood this liking for war.  It panders to instincts<BR>\nalready catered for within the scope of any respectable domestic establishment.<BR>\n&nbsp;-- Alan Bennett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I hold it, that a little rebellion, now and then, is a good thing...<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I have discovered the art of deceiving diplomats. I tell them the truth<BR>\nand they never believe me.<BR>\n&nbsp;-- Camillo Di Cavour');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I like to believe that people in the long run are going to do more to promote<BR>\npeace than our governments.  Indeed, I think that people want peace so much<BR>\nthat one of these days governments had better get out of the way and let them<BR>\nhave it.<BR>\n&nbsp;-- Dwight D. Eisenhower');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I never deny, I never contradict.  I sometimes forget.<BR>\n&nbsp;-- Benjamin Disraeli, British PM, on dealing with the<BR>\n&nbsp;Royal Family');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I found Rome a city of bricks and left it a city of marble.<BR>\n&nbsp;-- Augustus Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I have a dream.  I have a dream that one day, on the red hills of Georgia, <BR>\nthe sons of former slaves and the sons of former slaveowners will be able to<BR>\nsit down together at the table of brotherhood.<BR>\n&nbsp;-- Martin Luther King, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I owe the government $3400 in taxes.  So I sent them two hammers and a<BR>\ntoilet seat.<BR>\n&nbsp;-- Michael McShane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','How is the world ruled, and how do wars start?  Diplomats tell lies to<BR>\njournalists, and they believe what they read.<BR>\n&nbsp;-- Karl Kraus, \"Aphorisms and More Aphorisms\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I am convinced that the truest act of courage is to sacrifice ourselves<BR>\nfor others in a totally nonviolent struggle for justice.  To be a man<BR>\nis to suffer for others.<BR>\n&nbsp;-- Cesar Chavez');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','History teaches us that men and nations behave wisely once they have<BR>\nexhausted all other alternatives.<BR>\n&nbsp;-- Abba Eban');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I am a friend of the working man, and I would rather be his friend<BR>\nthan be one.<BR>\n&nbsp;-- Clarence Darrow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He who slings mud generally loses ground.<BR>\n&nbsp;-- Adlai Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','History is the version of past events that people have decided to agree on.<BR>\n&nbsp;-- Napoleon Bonaparte, \"Maxims\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','An honest politician is one who when he is bought will stay bought.<BR>\n&nbsp;-- Simon Cameron<BR>\n&nbsp;There are honest journalists like there are honest politicians.  When<BR>\nbought they stay bought.<BR>\n&nbsp;-- Bill Moyers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','History shows that the human mind, fed by constant accessions of knowledge,<BR>\nperiodically grows too large for its theoretical coverings, and bursts them<BR>\nasunder to appear in new habiliments, as the feeding and growing grub, at<BR>\nintervals, casts its too narrow skin and assumes another...  Truly the imago<BR>\nstate of Man seems to be terribly distant, but every moult is a step gained.<BR>\n&nbsp;-- Charles Darwin, from \"Origin of the Species\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I am not a politician and my other habits are also good.<BR>\n&nbsp;-- A. Ward');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There are two kinds of fool. One says, \"This is old, and therefore good.\"<BR>\nAnd one says, \"This is new, and therefore better\"<BR>\n&nbsp;-- John Brunner, \"The Shockwave Rider\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A public debt is a kind of anchor in the storm; but if the anchor be<BR>\ntoo heavy for the vessel, she will be sunk by that very weight which<BR>\nwas intended for her preservation.<BR>\n&nbsp;-- Colton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There but for the grace of God, goes God.<BR>\n&nbsp;-- Winston Churchill, speaking of Sir Stafford Cripps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There are only two things in this world that I am sure of, death and<BR>\ntaxes, and we just might do something about death one of these days.<BR>\n&nbsp;-- shades');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The price of seeking to force our beliefs on others is that someday<BR>\nthey might force their beliefs on us.<BR>\n&nbsp;-- Mario Cuomo');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In defeat, unbeatable; in victory, unbearable.<BR>\n&nbsp;-- W. Churchill, on General Montgomery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Illegal aliens have always been a problem in the United States. Ask any Indian.<BR>\n&nbsp;-- Robert Orben<BR>\n&nbsp;Immigration is the sincerest form of flattery.<BR>\n&nbsp;-- Jack Paar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is impossible to defend perfectly against the attack of those who want<BR>\nto die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Inform all the troops that communications have completely broken down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Indomitable in retreat; invincible in advance; insufferable in victory.<BR>\n&nbsp;-- Winston Churchill, on General Montgomery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Injustice anywhere is a threat to justice everywhere.<BR>\n&nbsp;-- Martin Luther King, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In war it is not men, but the man who counts.<BR>\n&nbsp;-- Napoleon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In the Halls of Justice the only justice is in the halls.<BR>\n&nbsp;-- Lenny Bruce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In those days he was wiser than he is now -- he used to frequently take<BR>\nmy advice.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In war, truth is the first casualty.<BR>\n&nbsp;-- U Thant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is a form of government in which it is permitted to wonder<BR>\naloud what the country could do under first-class management.<BR>\n&nbsp;-- Senator Soaper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Imbalance of power corrupts and monopoly of power corrupts absolutely.<BR>\n&nbsp;-- Genji');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In Italy, for thirty years under the Borgias, they had warfare, terror,<BR>\nmurder, and bloodshed, but they produced Michaelangelo, Leonardo da Vinci<BR>\nand the Renaissance.  In Switzerland, they had brotherly love, they had<BR>\nfive hundred years of democracy and peace -- and what did they produce?<BR>\nThe cuckoo-clock.<BR>\n&nbsp;-- Orson Welles, \"The Third Man\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Liberty is always dangerous, but it is the safest thing we have.<BR>\n&nbsp;-- Harry Emerson Fosdick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Most people want either less corruption or more of a chance to<BR>\nparticipate in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Let us never negotiate out of fear, but let us never fear to negotiate.<BR>\n&nbsp;-- John F. Kennedy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Leadership involves finding a parade and getting in front of it; what<BR>\nis happening in America is that those parades are getting smaller and<BR>\nsmaller -- and there are many more of them.<BR>\n&nbsp;-- John Naisbitt, \"Megatrends\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Law stands mute in the midst of arms.<BR>\n&nbsp;-- Marcus Tullius Cicero');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Keep your laws off my body!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Let no guilty man escape.<BR>\n&nbsp;-- U.S. Grant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Just as most issues are seldom black or white, so are most good solutions<BR>\nseldom black or white.  Beware of the solution that requires one side to be<BR>\ntotally the loser and the other side to be totally the winner.  The reason<BR>\nthere are two sides to begin with usually is because neither side has all<BR>\nthe facts.  Therefore, when the wise mediator effects a compromise, he is<BR>\nnot acting from political motivation.  Rather, he is acting from a deep<BR>\nsense of respect for the whole truth.<BR>\n&nbsp;-- Stephen R. Schwambach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If we suffer tamely a lawless attack upon our liberty, we encourage it,<BR>\nand involve others in our doom.<BR>\n&nbsp;-- Samuel Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Let the people think they govern and they will be governed.<BR>\n&nbsp;-- William Penn, founder of Pennsylvania');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It was the Law of the Sea, they said.  Civilization ends at the waterline.<BR>\nBeyond that, we all enter the food chain, and not always right at the top.<BR>\n&nbsp;-- Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Join the army, see the world, meet interesting, exciting people, and kill them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It took a while to surface, but it appears that a long-distance credit card<BR>\nmay have saved a U.S. Army unit from heavy casualties during the Grenada<BR>\nmilitary rescue/invasion. Major General David Nichols, Air Force ... said<BR>\nthe Army unit was in a house surrounded by Cuban forces.  One soldier found<BR>\na telephone and, using his credit card, called Ft. Bragg, N.C., telling Army<BR>\nofficiers there of the perilous situation. The officers in turn called the<BR>\nAir Force, which sent in gunships to scatter the Cubans and relieve the unit.<BR>\n&nbsp;-- Aviation Week and Space Technology');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It seems like the less a statesman amounts to, the more he loves the flag.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It seems a little silly now, but this country was founded as a protest<BR>\nagainst taxation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It may be better to be a live jackal than a dead lion, but it is better<BR>\nstill to be a live lion.  And usually easier.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','No-one would remember the Good Samaritan if he had only had good<BR>\nintentions.  He had money as well.<BR>\n&nbsp;-- Margaret Thatcher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Man is a military animal, glories in gunpowder, and loves parade.<BR>\n&nbsp;-- P.J. Bailey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Nothing in life is so exhilarating as to be shot at without result.<BR>\n&nbsp;-- Winston Churchill<BR>\n&nbsp;Next to being shot at and missed, nothing is really quite as<BR>\nsatisfying as an income tax refund.<BR>\n&nbsp;-- F.J. Raymond');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Never underestimate the power of a small tactical nuclear weapon.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Never let your sense of morals prevent you from doing what is right.<BR>\n&nbsp;-- Salvor Hardin, \"Foundation\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A group of politicians deciding to dump a President because his morals<BR>\nare bad is like the Mafia getting together to bump off the Godfather for<BR>\nnot going to church on Sunday.<BR>\n&nbsp;-- Russell Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Neglect of duty does not cease, by repetition, to be neglect of duty.<BR>\n&nbsp;-- Napoleon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Nemo me impune lacessit.<BR>\n&nbsp;[No one provokes me with impunity]<BR>\n&nbsp;-- Motto of the Crown of Scotland');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Necessity is the plea for every infringement of human freedom.<BR>\nIt is the argument of tyrants; it is the creed of slaves.<BR>\n&nbsp;-- William Pitt, 1783');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"My country, right or wrong\" is a thing that no patriot would think<BR>\nof saying, except in a desperate case.  It is like saying \"My mother,<BR>\ndrunk or sober.\"<BR>\n&nbsp;-- G.K. Chesterton, \"The Defendant\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','NAPOLEON: What shall we do with this soldier, Giuseppe?  Everything he<BR>\n&nbsp;says is wrong.<BR>\nGIUSEPPE: Make him a general, Excellency, and then everything he says<BR>\n&nbsp;will be right.<BR>\n&nbsp;-- G. B. Shaw, \"The Man of Destiny\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The eyes of taxes are upon you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','National security is in your hands - guard it well.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Massachusetts has the best politicians money can buy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Many a bum show has been saved by the flag.<BR>\n&nbsp;-- George M. Cohan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','My experience with government is when things are non-controversial, beautifully<BR>\nco-ordinated and all the rest, it must be that not much is going on.<BR>\n&nbsp;-- J.F. Kennedy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','1st graffitiist: QUESTION AUTHORITY!<BR>\n&nbsp;2nd graffitiist: Why?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The man who follows the crowd will usually get no further than the crowd.  The<BR>\nman who walks alone is likely to find himself in places no one has ever been.<BR>\n&nbsp;-- Alan Ashley-Pitt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Nihilism should commence with oneself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','My own life has been spent chronicling the rise and fall of human systems,<BR>\nand I am convinced that we are terribly vulnerable.  ...  We should be<BR>\nreluctant to turn back upon the frontier of this epoch. Space is indifferent<BR>\nto what we do; it has no feeling, no design, no interest in whether or not<BR>\nwe grapple with it. But we cannot be indifferent to space, because the grand,<BR>\nslow march of intelligence has brought us, in our generation, to a point<BR>\nfrom which we can explore and understand and utilize it. To turn back now<BR>\nwould be to deny our history, our capabilities.<BR>\n&nbsp;-- James A. Michener');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Military intelligence is a contradiction in terms.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If we all work together, we can totally disrupt the system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Military justice is to justice what military music is to music.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Know thyself.  If you need help, call the C.I.A.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If we can ever make red tape nutritional, we can feed the world.<BR>\n&nbsp;-- R. Schaeberle, \"Management Accounting\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Power tends to corrupt, absolute power corrupts absolutely.<BR>\n&nbsp;-- Lord Acton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics is not the art of the possible.  It consists in choosing<BR>\nbetween the disastrous and the unpalatable.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics, as a practice, whatever its professions, has always been the<BR>\nsystematic organisation of hatreds.<BR>\n&nbsp;-- Henry Adams, \"The Education of Henry Adams\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politicians speak for their parties, and parties never are, never have<BR>\nbeen, and never will be wrong.<BR>\n&nbsp;-- Walter Dwight');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Practical politics consists in ignoring facts.<BR>\n&nbsp;-- Henry Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Since a politician never believes what he says, he is surprised<BR>\nwhen others believe him.<BR>\n&nbsp;-- Charles DeGaulle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Political history is far too criminal a subject to be a fit thing to<BR>\nteach children.<BR>\n&nbsp;-- W.H. Auden');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Persistence in one opinion has never been considered a merit in political<BR>\nleaders.<BR>\n&nbsp;-- Marcus Tullius Cicero, \"Ad familiares\", 1st century BC');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Political T.V. commercials prove one thing: some candidates can tell<BR>\nall their good points and qualifications in just 30 seconds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','People who develop the habit of thinking of themselves as world<BR>\ncitizens are fulfilling the first requirement of sanity in our time.<BR>\n&nbsp;-- Norman Cousins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','People of privilege will always risk their complete destruction<BR>\nrather than surrender any material part of their advantage.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politicians are the same all over.  They promise to build a bridge even<BR>\nwhere there is no river.<BR>\n&nbsp;-- Nikita Khrushchev');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If a nation values anything more than freedom, it will lose its freedom;<BR>\nand the irony of it is that if it is comfort or money it values more, it<BR>\nwill lose that, too.<BR>\n&nbsp;-- W. Somerset Maugham');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If God had meant for us to be in the Army, we would have been born with<BR>\ngreen, baggy skin.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politicians should read science fiction, not westerns and detective stories.<BR>\n&nbsp;-- Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Only two kinds of witnesses exist.  The first live in a neighborhood where<BR>\na crime has been committed and in no circumstances have ever seen anything<BR>\nor even heard a shot.  The second category are the neighbors of anyone who<BR>\nhappens to be accused of the crime.  These have always looked out of their<BR>\nwindows when the shot was fired, and have noticed the accused person standing<BR>\npeacefully on his balcony a few yards away.<BR>\n&nbsp;-- Sicilian police officer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','One of the lessons of history is that nothing is often a good thing to<BR>\ndo and always a clever thing to say.<BR>\n&nbsp;-- Will Durant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','One planet is all you get.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Love America -- or give it back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Majorities, of course, start with minorities.<BR>\n&nbsp;-- Robert Moses');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','One nuclear bomb can ruin your whole day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','&nbsp;Once there was a marine biologist who loved dolphins. He spent his<BR>\ntime trying to feed and protect his beloved creatures of the sea.  One day,<BR>\nin a fit of inventive genius, he came up with a serum that would make<BR>\ndolphins live forever!<BR>\n&nbsp;Of course he was ecstatic. But he soon realized that in order to mass<BR>\nproduce this serum he would need large amounts of a certain compound that was<BR>\nonly found in nature in the metabolism of a rare South American bird.  Carried<BR>\naway by his love for dolphins, he resolved that he would go to the zoo and<BR>\nsteal one of these birds.<BR>\n&nbsp;Unbeknownst to him, as he was arriving at the zoo an elderly lion was<BR>\nescaping from its cage.  The zookeepers were alarmed and immediately began<BR>\ncombing the zoo for the escaped animal, unaware that it had simply lain down<BR>\non the sidewalk and had gone to sleep.<BR>\n&nbsp;Meanwhile, the marine biologist arrived at the zoo and procured his<BR>\nbird.  He was so excited by the prospect of helping his dolphins that he<BR>\nstepped absentmindedly stepped over the sleeping lion on his way back to his<BR>\ncar.  Immediately, 1500 policemen converged on him and arrested him for<BR>\ntransporting a myna across a staid lion for immortal porpoises.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Old soldiers never die.  Young ones do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Nuclear war would mean abolition of most comforts, and disruption of <BR>\nnormal routines, for children and adults alike.\"<BR>\n&nbsp;-- Willard F. Libby, \"You *Can* Survive Atomic Attack\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If Patrick Henry thought that taxation without representation was bad,<BR>\nhe should see how bad it is with representation.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Nothing is illegal if one hundred businessmen decide to do it.<BR>\n&nbsp;-- Andrew Young');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Nothing, nothing, nothing, no error, no crime is so absolutely repugnant<BR>\nto God as everything which is official; and why? because the official is<BR>\nso impersonal and therefore the deepest insult which can be offered to a<BR>\npersonality.<BR>\n&nbsp;-- Soren Kierkegaard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Man is by nature a political animal.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Next to being shot at and missed, nothing is really quite as satisfying<BR>\nas an income tax refund.<BR>\n&nbsp;-- F. J. Raymond');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The distinction between Freedom and Liberty is not accurately known;<BR>\nnaturalists have been unable to find a living specimen of either.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The control of the production of wealth is the control of human life itself.<BR>\n&nbsp;-- Hilaire Belloc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The danger is not that a particular class is unfit to govern.  Every class<BR>\nis unfit to govern.<BR>\n&nbsp;-- Lord Acton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The doctrine of human equality reposes on this: that there is no man<BR>\nreally clever who has not found that he is stupid.<BR>\n&nbsp;-- Gilbert K. Chesterson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The assertion that \"all men are created equal\" was of no practical use<BR>\nin effecting our separation from Great Britain and it was placed in the<BR>\nDeclaration not for that, but for future use.<BR>\n&nbsp;--  Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Support your right to bare arms!<BR>\n&nbsp;-- A message from the National Short-Sleeved Shirt Association');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Taxes are going up so fast, the government is likely to price itself<BR>\nout of the market.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The avoidance of taxes is the only intellectual pursuit that carries any<BR>\nreward.<BR>\n&nbsp;-- John Maynard Keynes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','That government is best which governs least.<BR>\n&nbsp;-- Henry David Thoreau, \"Civil Disobedience\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Surprise!  You are the lucky winner of random I.R.S. Audit!  Just type<BR>\nin your name and social security number.  Please remember that leaving<BR>\nthe room is punishable under law:<BR>\n&nbsp;Name<BR>\n#');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Ours is a world of nuclear giants and ethical infants.<BR>\n&nbsp;-- General Omar N. Bradley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Since aerosols are forbidden, the police are using roll-on Mace!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If God wanted us to have a President, He would have sent us a candidate.<BR>\n&nbsp;-- Jerry Dreshfield');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Patriotism is the virtue of the vicious.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Take Care of the Molehills, and the Mountains Will Take Care of Themselves.<BR>\n&nbsp;-- Motto of the Federal Civil Service');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The more you sweat in peace, the less you bleed in war.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','... so long as the people do not care to exercise their freedom, those<BR>\nwho wish to tyrranize will do so; for tyrants are active and ardent,<BR>\nand will devote themselves in the name of any number of gods, religious<BR>\nand otherwise, to put shackles upon sleeping men.<BR>\n&nbsp;-- Voltarine de Cleyre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Shah, shah!  Ayatollah you so!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','So many men, so many opinions; every one his own way.<BR>\n&nbsp;-- Publius Terentius Afer (Terence)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Take your Senator to lunch this week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','[Sir Stafford Cripps] has all the virtues I dislike and none of the<BR>\nvices I admire.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The end move in politics is always to pick up a gun.<BR>\n&nbsp;-- Buckminster Fuller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The more control, the more that requires control.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Rule the Empire through force.<BR>\n&nbsp;-- Shogun Tokugawa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Rev. Jim:	What does an amber light mean?                                 <BR>\nBobby:		Slow down.<BR>\nRev. Jim:	What...   does...  an...  amber...  light...  mean?<BR>\nBobby:		Slow down.<BR>\nRev. Jim:	What....     does....     an....     amber....     light....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Sherry [Thomas Sheridan] is dull, naturally dull; but it must have taken<BR>\nhim a great deal of pains to become what we now see him.  Such an excess of<BR>\nstupidity, sir, is not in Nature.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Remember folks.  Street lights timed for 35 mph are also timed for 70 mph.<BR>\n&nbsp;-- Jim Samuels');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Put a rogue in the limelight and he will act like an honest man.<BR>\n&nbsp;-- Napoleon Bonaparte, \"Maxims\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Signs of crime: screaming or cries for help.<BR>\n&nbsp;-- The Brown University Security Crime Prevention Pamphlet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Power is the finest token of affection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Post proelium, praemium.<BR>\n&nbsp;[After the battle, the reward.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The inherent vice of capitalism is the unequal sharing of blessings;<BR>\nthe inherent virtue of socialism is the equal sharing of misery.<BR>\n&nbsp;-- Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The law will never make men free; it is men who have got to make the law free.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All the taxes paid over a lifetime by the average American are spent by<BR>\nthe government in less than a second.<BR>\n&nbsp;-- Jim Fiebig');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The introduction of a new kind of music must be shunned as imperiling the<BR>\nwhole state, for styles of music are never disturbed without affecting<BR>\nthe most important political institutions. ...  The new style, gradually<BR>\ngaining a lodgement, quitely insinuates itself into manners and customs,<BR>\nand from it ... goes on to attack laws and constitutions, displaying the<BR>\nutmost impudence, until it ends by overturning everything.<BR>\n&nbsp;-- Plato, \"Republic\", 370 B.C.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The attacker must vanquish; the defender need only survive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The health of a democratic society may be measured by the quality<BR>\nof functions performed by private citizens.<BR>\n&nbsp;-- Alexis de Tocqueville');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The genius of our ruling class is that it has kept a majority of the<BR>\npeople from ever questioning the inequity of a system where most people<BR>\ndrudge along paying heavy taxes for which they get nothing in return.<BR>\n&nbsp;-- Gore Vidal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The first duty of a revolutionary is to get away with it.<BR>\n&nbsp;-- Abbie Hoffman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The founding fathers tried to set up a judicial system where the accused<BR>\nreceived a fair trial, not a system to insure an acquittal on technicalities.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','George Orwell 1984.  Northwestern 0.<BR>\n&nbsp;-- Chicago Reader 10/15/82');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He who renders warfare fatal to all engaged in it will be the greatest<BR>\nbenefactor the world has yet known.<BR>\n&nbsp;-- Sir Richard Burton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There appears to be irrefutable evidence that the mere fact of overcrowding<BR>\ninduces violence.<BR>\n&nbsp;-- Harvey Wheeler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He that would govern others, first should be the master of himself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All wars are civil wars, because all men are brothers ... Each one owes<BR>\ninfinitely more to the human race than to the particular country in<BR>\nwhich he was born.<BR>\n&nbsp;-- Francois Fenelon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Such a foolish notion, that war is called devotion, when the greatest<BR>\nwarriors are the ones who stand for peace.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The majority of the stupid is invincible and guaranteed for all time.  The<BR>\nterror of their tyranny, however, is alleviated by their lack of consistency.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All bad precedents began as justifiable measures.<BR>\n&nbsp;-- Gaius Julius Caesar, quoted in \"The Conspiracy of<BR>\n&nbsp;Catiline\", by Sallust');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The fashionable drawing rooms of London have always been happy to accept<BR>\noutsiders -- if only on their own, albeit undemanding terms.  That is to<BR>\nsay, artists, so long as they are not too talented, men of humble birth,<BR>\nso long as they have since amassed several million pounds, and socialists<BR>\nso long as they are Tories.<BR>\n&nbsp;-- Christopher Booker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There are no manifestos like cannon and musketry.<BR>\n&nbsp;-- The Duke of Wellington');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Crown is full of it!<BR>\n&nbsp;-- Nate Harris, 1775');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The dirty work at political conventions is almost always done in the grim<BR>\nhours between midnight and dawn.  Hangmen and politicians work best when<BR>\nthe human spirit is at its lowest ebb.<BR>\n&nbsp;-- Russell Baker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Corruption is not the #1 priority of the Police Commissioner.  His job<BR>\nis to enforce the law and fight crime.<BR>\n&nbsp;-- P.B.A. President E. J. Kiernan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is a device that insures we shall be governed no better than<BR>\nwe deserve.<BR>\n&nbsp;-- George Bernard Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Demand the establishment of the government in its rightful home at Disneyland.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Cable is not a luxury, since many areas have poor TV reception.\"<BR>\n&nbsp;-- The mayor of Tucson, Arizona, 1989');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is a process by which the people are free to choose the man who<BR>\nwill get the blame.<BR>\n&nbsp;-- Laurence J. Peter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is good.  I say this because other systems are worse.<BR>\n&nbsp;-- Jawaharlal Nehru');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is better to die on your feet than to live on your knees.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The less a statesman amounts to, the more he loves the flag.<BR>\n&nbsp;-- Kin Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Political speeches are like steer horns.  A point here, a point there,<BR>\nand a lot of bull inbetween.<BR>\n&nbsp;-- Alfred E. Neuman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Peace cannot be kept by force; it can only be achieved by understanding.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is a form of government that substitutes election by the<BR>\nincompetent many for appointment by the corrupt few.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is the name we give the people whenever we need them.<BR>\n&nbsp;-- Arman de Caillavet, 1913');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I would like the government to do all it can to mitigate, then, in<BR>\nunderstanding, in mutuality of interest, in concern for the common good,<BR>\nour tasks will be solved.<BR>\n&nbsp;-- Warren G. Harding');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Demographic polls show that you have lost credibility across the board.<BR>\nEspecially with those 14 year-old Valley girls.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is the worst form of government except all those other<BR>\nforms that have been tried from time to time.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Diplomacy is the art of saying \"nice doggie\" until you can find a rock.<BR>\n&nbsp;-- Wynn Catlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Diplomacy is to do and say, the nastiest thing in the nicest way.<BR>\n&nbsp;-- Balfour');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Diplomacy is the art of letting the other party have things your way.<BR>\n&nbsp;-- Daniele Vare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics -- the gentle art of getting votes from the poor and campaign<BR>\nfunds from the rich by promising to protect each from the other.<BR>\n&nbsp;-- Oscar Ameringer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Diplomacy is about surviving until the next century.  Politics is about<BR>\nsurviving until Friday afternoon.<BR>\n&nbsp;-- Sir Humphrey Appleby');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All diplomacy is a continuation of war by other means.<BR>\n&nbsp;-- Chou En Lai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The mark of the immature man is that he wants to die nobly for a cause,<BR>\nwhile the mark of a mature man is that he wants to live humbly for one.<BR>\n&nbsp;-- Wilhelm Stekel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Ever wonder if taxation without representation might have been cheaper?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All other things being equal, a bald man cannot be elected President of<BR>\nthe United States.<BR>\n&nbsp;-- Vic Gold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Each person has the right to take the subway.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Fay: The British police force used to be run by men of integrity.<BR>\nTruscott: That is a mistake which has been rectified.<BR>\n&nbsp;-- Joe Orton, \"Loot\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All people are born alike -- except Republicans and Democrats.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Fear and loathing, my man, fear and loathing.<BR>\n&nbsp;-- H.S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All kings is mostly rapscallions.<BR>\n&nbsp;--Mark Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Postmen never die, they just lose their zip.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Power is poison.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics makes strange bedfellows, and journalism makes strange politics.<BR>\n&nbsp;-- Amy Gorin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A general leading the State Department resembles a dragon commanding ducks.<BR>\n&nbsp;-- New York Times, Jan. 20, 1981');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A free society is one where it is safe to be unpopular.<BR>\n&nbsp;-- Adlai Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I never vote for anyone.  I always vote against.<BR>\n&nbsp;-- W.C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Moral Majority is neither.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A government that is big enough to give you all you want is big enough<BR>\nto take it all away.<BR>\n&nbsp;-- Barry Goldwater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Official Colorado State Vegetable is now the \"state legislator\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I might have gone to West Point, but I was too proud to speak to a congressman.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I use not only all the brains I have, but all those I can borrow as well.<BR>\n&nbsp;-- Woodrow Wilson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I went to my mother and told her I intended to commence a different life.  I<BR>\nasked for and obtained her blessing and at once commenced the career of a<BR>\nrobber.<BR>\n&nbsp;-- Tiburcio Vasquez');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I try to keep an open mind, but not so open that my brains fall out.<BR>\n&nbsp;-- Judge Harold T. Stone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The greatest disloyalty one can offer to great pioneers is to refuse to<BR>\nmove an inch from where they stood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','$100 invested at 7% interest for 100 years will become $100,000, at<BR>\nwhich time it will be worth absolutely nothing.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I try not to break the rules but merely to test their elasticity.<BR>\n&nbsp;-- Bill Veeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A candidate is a person who gets money from the rich and votes from the<BR>\npoor to protect them from each other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A great empire, like a great cake, is most easily diminished at the edges.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A great nation is any mob of people which produces at least one honest<BR>\nman a century.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A long memory is the most subversive idea in America.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A lack of leadership is no substitute for inaction.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The price of greatness is responsibility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A penny saved is a penny taxed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A diplomat is a person who can tell you to go to hell in such a way that you<BR>\nactually look forward to the trip.<BR>\n&nbsp;-- Caskie Stinnett, \"Out of the Red\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I pledge allegiance to the flag<BR>\nof the United States of America<BR>\nand to the republic for which it stands,<BR>\none nation,<BR>\nindivisible,<BR>\nwith liberty<BR>\nand justice for all.<BR>\n&nbsp;-- Francis Bellamy, 1892');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I have gained this by philosophy:<BR>\nthat I do without being commanded what others do only from fear of the law.<BR>\n&nbsp;-- Aristotle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Taxes are not levied for the benefit of the taxed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Airplanes are interesting toys but of no military value.<BR>\n&nbsp;-- Marechal Ferdinand Foch, Professor of Strategy,<BR>\n&nbsp;Ecole Superieure de Guerre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A strong conviction that something must be done is the parent of many<BR>\nbad measures.<BR>\n&nbsp;-- Daniel Webster');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','America: born free and taxed to death.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"...and the fully armed nuclear warheads, are, of course, merely a<BR>\ncourtesy detail.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','An ambassador is an honest man sent abroad to lie and intrigue for the<BR>\nbenefit of his country.<BR>\n&nbsp;-- Sir Henry Wotton, 1568-1639');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','America is the country where you buy a lifetime supply of aspirin for one<BR>\ndollar, and use it up in two weeks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','And yet, seasons must be taken with a grain of salt, for they too have<BR>\na sense of humor, as does history.  Corn stalks comedy, comedy stalks<BR>\ntragedy, and this too is historic.  And yet, still, when corn meets<BR>\ntragedy face to face, we have politics.<BR>\n&nbsp;-- Dalglish, Larsen and Sutherland, \"Root Crops and<BR>\n&nbsp;Ground Cover\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Ban the bomb.  Save the world for conventional warfare.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Bedfellows make strange politicians.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Blessed are the young, for they shall inherit the national debt.<BR>\n&nbsp;-- Herbert Hoover');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Census Taker to Housewife:<BR>\nDid you ever have the measles, and, if so, how many?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The fact that an opinion has been widely held is no evidence that it is not<BR>\nutterly absurd; indeed, in view of the silliness of the majority of mankind,<BR>\na widespread belief is more often likely to be foolish than sensible.<BR>\n&nbsp;-- Bertrand Russell, in \"Marriage and Morals\", 1929');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','&nbsp;Somewhat alarmed at the continued growth of the number of employees<BR>\non the Department of Agriculture payroll in 1962, Michigan Republican Robert<BR>\nGriffin proposed an amendment to the farm bill so that \"the total number of<BR>\nemployees in the Department of Agriculture at no time exceeds the number of<BR>\nfarmers in America.\"<BR>\n&nbsp;-- Bill Adler, \"The Washington Wits\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Serfs up!<BR>\n&nbsp;-- Spartacus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Some men rob you with a six-gun -- others with a fountain pen.<BR>\n&nbsp;-- Woodie Guthrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','So from the depths of its enchantment, Terra was able to calculate a course<BR>\nof action.  Here at last was an opportunity to consort with Dirbanu on a<BR>\nfriendly basis -- great Durbanu which, since it had force fields which Earth<BR>\ncould not duplicate, must of necessity have many other things Earth could<BR>\nuse; mighty Durbanu before whom we would kneel in supplication (with purely-<BR>\nfor-defense bombs hidden in our pockets) with lowered heads (making invisible<BR>\nthe knife in our teeth) and ask for crumbs from their table (in order to<BR>\nextrapolate the location of their kitchens).<BR>\n&nbsp;-- Theodore Sturgeon, \"The World Well Lost\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Rights\" is a fictional abstraction.  No one has \"Rights\", neither machines<BR>\nnor flesh-and-blood.  Persons... have opportunities, not rights, which they<BR>\nuse or do not use.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Sed quis custodiet ipsos Custodes?<BR>\n&nbsp;[Who guards the Guardians?]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Sauron is alive in Argentina!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Scrubbing floors and emptying bedpans has as much dignity as the Presidency.<BR>\n&nbsp;-- Richard Nixon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"After I asked him what he meant, he replied that freedom consisted of<BR>\nthe unimpeded right to get rich, to use his ability, no matter what the<BR>\ncost to others, to win advancement.\"<BR>\n&nbsp;-- Norman Thomas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The better the state is established, the fainter is humanity.<BR>\nTo make the individual uncomfortable, that is my task.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The degree of civilization in a society can be judged by entering its prisons.<BR>\n&nbsp;-- F. Dostoyevski');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The bureaucracy is expanding to meet the needs of an expanding bureaucracy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Army needs leaders the way a foot needs a big toe.<BR>\n&nbsp;-- Bill Murray');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The famous politician was trying to save both his faces.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A nuclear war can ruin your whole day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Government just announced today the creation of the Neutron Bomb II.<BR>\nSimilar to the Neutron Bomb, the Neutron Bomb II not only kills people<BR>\nand leaves buildings standing, but also does a little light housekeeping.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The graveyards are full of indispensable men.<BR>\n&nbsp;-- Charles de Gaulle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The greatest dangers to liberty lurk in insidious encroachment by men<BR>\nof zeal, well-meaning but without understanding.<BR>\n&nbsp;-- Justice Louis D. Brandeis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Has the great art and mystery of politics no apparent utility? Does it<BR>\nappear to be unqualifiedly ratty, raffish, sordid, obscene and low down,<BR>\nand its salient virtuosi a gang of umitigated scoundrels?  Then let us<BR>\nnot forget its high capacity to soothe and tickel the midriff, its<BR>\nincomparable services as a maker of entertainment.<BR>\n&nbsp;-- H.L. Mencken, \"A Carnival of Buncombe\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Power corrupts.  Absolute power is kind of neat.<BR>\n&nbsp;-- John Lehman, Secretary of the Navy, 1981-1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A national debt, if it is not excessive, will be to us a national blessing.<BR>\n&nbsp;-- Alexander Hamilton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Alexander Hamilton started the U.S. Treasury with nothing - and that was<BR>\nthe closest our country has ever been to being even.<BR>\n&nbsp;-- The Best of Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','All [zoos] actually offer to the public in return for the taxes spent<BR>\nupon them is a form of idle and witless amusement, compared to which a<BR>\nvisit to a penitentiary, or even to a State legislature in session, is<BR>\ninforming, stimulating and ennobling.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"The Lord gave us farmers two strong hands so we could grab as much as<BR>\nwe could with both of them.\"<BR>\n&nbsp;-- Joseph Heller, \"Catch-22\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Disclose classified information only when a NEED TO KNOW exists.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A billion here, a billion there -- pretty soon it adds up to real money.<BR>\n&nbsp;-- Sen. Everett Dirksen, on the U.S. defense budget');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A billion seconds ago Harry Truman was president.<BR>\nA billion minutes ago was just after the time of Christ.<BR>\nA billion hours ago man had not yet walked on earth.<BR>\nA billion dollars ago was late yesterday afternoon at the U.S. Treasury.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The only winner in the War of 1812 was Tchaikovsky.<BR>\n&nbsp;-- David Gerrold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A Difficulty for Every Solution.<BR>\n&nbsp;-- Motto of the Federal Civil Service');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A \"No\" uttered from deepest conviction is better and greater than a<BR>\n\"Yes\" merely uttered to please, or what is worse, to avoid trouble.<BR>\n&nbsp;-- Mahatma Ghandi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He who attacks the fundamentals of the American broadcasting industry<BR>\nattacks democracy itself.<BR>\n&nbsp;-- William S. Paley, chairman of CBS');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Nuclear war would really set back cable.\"<BR>\n&nbsp;-- Ted Turner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','On account of being a democracy and run by the people, we are the only<BR>\nnation in the world that has to keep a government four years, no matter<BR>\nwhat it does.<BR>\n&nbsp;-- Will Rogers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Once is happenstance,<BR>\nTwice is coincidence,<BR>\nThree times is enemy action.<BR>\n&nbsp;-- Auric Goldfinger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"MacDonald has the gift on compressing the largest amount of words into<BR>\nthe smallest amount of thoughts.\"<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A sect or party is an elegant incognito devised to save a man from<BR>\nthe vexation of thinking.<BR>\n&nbsp;-- Ralph Waldo Emerson, Journals, 1831');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Now and then an innocent man is sent to the legislature.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If people have to choose between freedom and sandwiches, they<BR>\nwill take sandwiches.<BR>\n&nbsp;-- Lord Boyd-orr<BR>\n&nbsp;Eats first, morals after.<BR>\n&nbsp;-- Bertolt Brecht, \"The Threepenny Opera\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','One seldom sees a monument to a committee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','One organism, one vote.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Once upon a time there was a kingdom ruled by a great bear.  The peasants<BR>\nwere not very rich, and one of the few ways to become at all wealthy was<BR>\nto become a Royal Knight.  This required an interview with the bear.  If<BR>\nthe bear liked you, you were knighted on the spot.  If not, the bear would<BR>\njust as likely remove your head with one swat of a paw.  However, the family<BR>\nof these unfortunate would-be knights was compensated with a beautiful<BR>\nsheepdog from the royal kennels, which was itself a fairly valuable<BR>\npossession.  And the moral of the story is:<BR>\n&nbsp;The mourning after a terrible knight, nothing beats the dog of the bear that<BR>\nhit you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','TANSTAAFL');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Ten persons who speak make more noise than ten thousand who are silent.<BR>\n&nbsp;-- Napoleon I');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','People never lie so much as after a hunt, during a war, or before an election.<BR>\n&nbsp;-- Otto Von Bismarck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Peace is much more precious than a piece of land... let there be no more wars.<BR>\n&nbsp;-- Mohammed Anwar Sadat, 1918-1981');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Poland has gun control.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Pilfering Treasury property is paticularly dangerous: big thieves are<BR>\nruthless in punishing little thieves.<BR>\n&nbsp;-- Diogenes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Our swords shall play the orators for us.<BR>\n&nbsp;-- Christopher Marlowe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics, like religion, hold up the torches of matrydom to the<BR>\nreformers of error.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Populus vult decipi.<BR>\n&nbsp;[The people like to be deceived.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics are almost as exciting as war, and quite as dangerous.  In war,<BR>\nyou can only be killed once.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Poverty must have its satisfactions, else there would not be so many poor<BR>\npeople.<BR>\n&nbsp;-- Don Herold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Poverty begins at home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Politics and the fate of mankind are formed by men without ideals and without<BR>\ngreatness.  Those who have greatness within them do not go in for politics.<BR>\n&nbsp;-- Albert Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Question authority.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Reporter (to Mahatma Gandhi): Mr Gandhi, what do you think of Western<BR>\n&nbsp;Civilization?<BR>\nGandhi:	I think it would be a good idea.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','President Reagan has noted that there are too many economic pundits and<BR>\nforecasters and has decided on an excess prophets tax.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Reunite Gondwondaland!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Slaves are generally expected to sing as well as to work ... I did not, when<BR>\na slave, understand the deep meanings of those rude, and apparently incoherent<BR>\nsongs.  I was myself within the circle, so that I neither saw nor heard as<BR>\nthose without might see and hear.  They told a tale which was then altogether<BR>\nbeyond my feeble comprehension: they were tones, loud, long and deep,<BR>\nbreathing the prayer and complaint of souls boiling over with the bitterest<BR>\nanguish.  Every tone was a testimony against slavery, and a prayer to God<BR>\nfor deliverance from chains.<BR>\n&nbsp;-- Frederick Douglass');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If you live in a country run by committee, be on the committee.<BR>\n&nbsp;-- Graham Summer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If you give Congress a chance to vote on both sides of an issue, it<BR>\nwill always do it.<BR>\n&nbsp;-- Les Aspin, D., Wisconsin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Immigration is the sincerest form of flattery.<BR>\n&nbsp;-- Jack Paar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If you go on with this nuclear arms race, all you are going to do is<BR>\nmake the rubble bounce.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Message will arrive in the mail.  Destroy, before the FBI sees it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If voting could change the system, it would be illegal.  If not voting<BR>\ncould change the system, it would be illegal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In Pierre Trudeau, Somewhere has finally produced a Prime Minister worthy of<BR>\nassassination.<BR>\n&nbsp;-- John Diefenbaker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','In case of atomic attack, the federal ruling against prayer in schools<BR>\nwill be temporarily canceled.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It got to the point where I had to get a haircut or both feet firmly<BR>\nplanted in the air.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If everybody minded their own business, the world would go around a deal faster.<BR>\n&nbsp;-- The Duchess, \"Through the Looking Glass\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If pro is the opposite of con, what is the opposite of progress?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If built in great numbers, motels will be used for nothing but illegal<BR>\npurposes.<BR>\n&nbsp;-- J. Edgar Hoover');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If society fits you comfortably enough, you call it freedom.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Be it our wealth, our jobs, or even our homes; nothing is safe while the<BR>\nlegislature is in session.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I wish a robot would get elected president.  That way, when he came to town,<BR>\nwe could all take a shot at him and not feel too bad.<BR>\n&nbsp;-- Jack Handley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I would much rather have men ask why I have no statue, than why I have one.<BR>\n&nbsp;-- Marcus Procius Cato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I steal.<BR>\n&nbsp;-- Sam Giancana, explaining his livelihood to his draft board<BR>\n&nbsp;Easy.  I own Chicago.  I own Miami.  I own Las Vegas.<BR>\n&nbsp;-- Sam Giancana, when asked what he did for a living');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I think the world is run by C students.<BR>\n&nbsp;-- Al McGuire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','If the rich could pay the poor to die for them, what a living the poor<BR>\ncould make!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is now 10 p.m.  Do you know where Henry Kissinger is?<BR>\n&nbsp;-- Elizabeth Carpenter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is said an Eastern monarch once charged his wise men to invent him a<BR>\nsentence to be ever in view, and which should be true and appropriate<BR>\nin all times and situations.  They presented him the words: \"And this,<BR>\ntoo, shall pass away.\"<BR>\n&nbsp;-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Mickey Mouse wears a Spiro Agnew watch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Join the Navy; sail to far-off exotic lands, meet exciting interesting people,<BR>\nand kill them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is enough to make one sympathize with a tyrant for the determination<BR>\nof his courtiers to deceive him for their own personal ends...<BR>\n&nbsp;-- Russell Baker and Charles Peters');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is better to wear chains than to believe you are free, and weight<BR>\nyourself down with invisible chains.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Individualists unite!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is difficult to legislate morality in the absence of moral legislators.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','It is easier to be a \"humanitarian\" than to render your own country its<BR>\nproper due; it is easier to be a \"patriot\" than to make your community a<BR>\nbetter place to live in; it is easier to be a \"civic leader\" than to treat<BR>\nyour own family with loving understanding; for the smaller the focus of<BR>\nattention, the harder the task.<BR>\n&nbsp;-- Sydney J. Harris');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Extremism in the defense of liberty is no vice... moderation in the pursuit<BR>\nof justice is no virtue.<BR>\n&nbsp;-- Barry Goldwater');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Here comes the orator, with his flood of words and his drop of reason.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','For the first time we have a weapon that nobody has used for thirty years.<BR>\nThis gives me great hope for the human race.<BR>\n&nbsp;-- Harlan Ellison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Every country has the government it deserves.<BR>\n&nbsp;-- Joseph De Maistre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Everything is controlled by a small evil group to which, unfortunately,<BR>\nno one we know belongs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Due to a shortage of devoted followers, the production of great leaders<BR>\nhas been discontinued.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy means simply the bludgeoning of the people by the people for<BR>\nthe people.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Fanaticism consists of redoubling your effort when you have forgotten your aim.<BR>\n&nbsp;-- George Santayana');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Good government never depends upon laws, but upon the personal qualities of<BR>\nthose who govern.  The machinery of government is always subordinate to the<BR>\nwill of those who administer that machinery.  The most important element of<BR>\ngovernment, therefore, is the method of choosing leaders.<BR>\n&nbsp;-- Frank Herbert, \"Children of Dune\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy is the recurrent suspicion that more than half of the people<BR>\nare right more than half of the time.<BR>\n&nbsp;-- E. B. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Each person has the right to take part in the management of public affairs<BR>\nin his country, provided he has prior experience, a will to succeed, a<BR>\nuniversity degree, influential parents, good looks, a curriculum vitae, two<BR>\n3x4 snapshots, and a good tax record.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Audacity, and again, audacity, and always audacity.<BR>\n&nbsp;-- G.J. Danton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Crime does not pay ... as well as politics.<BR>\n&nbsp;-- Alfred E. Newman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Another such victory over the Romans, and we are undone.<BR>\n&nbsp;-- Pyrrhus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Andrea: Unhappy the land that has no heroes.<BR>\nGalileo: No, unhappy the land that _____needs heroes.<BR>\n&nbsp;-- Bertolt Brecht, \"Life of Galileo\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','As long as war is regarded as wicked, it will always have its fascination.<BR>\nWhen it is looked upon as vulgar, it will cease to be popular.<BR>\n&nbsp;-- Oscar Wilde, \"Intentions\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Cutting the space budget really restores my faith in humanity.  It<BR>\neliminates dreams, goals, and ideals and lets us get straight to the<BR>\nbusiness of hate, debauchery, and self-annihilation.\"<BR>\n&nbsp;-- Johnny Hart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A people living under the perpetual menace of war and invasion is very easy to<BR>\ngovern.  It demands no social reforms.  It does not haggle over expenditures<BR>\non armaments and military equipment.  It pays without discussion, it ruins<BR>\nitself, and that is an excellent thing for the syndicates of financiers and<BR>\nmanufacturers for whom patriotic terrors are an abundant source of gain.<BR>\n&nbsp;-- Anatole France');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A real patriot is the fellow who gets a parking ticket and rejoices<BR>\nthat the system works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Alea iacta est.<BR>\n&nbsp;[The die is cast]<BR>\n&nbsp;-- Gaius Julius Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A penny saved kills your career in government.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Any excuse will serve a tyrant.<BR>\n&nbsp;-- Aesop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Democracy becomes a government of bullies, tempered by editors.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Good leaders being scarce, following yourself is allowed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A prisoner of war is a man who tries to kill you and fails, and then<BR>\nasks you not to kill him.<BR>\n&nbsp;-- Sir Winston Churchill, 1952');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','A political man can have as his aim the realization of freedom,<BR>\nbut he has no means to realize it other than through violence.<BR>\n&nbsp;-- Jean Paul Sartre');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Those who have had no share in the good fortunes of the mighty<BR>\nOften have a share in their misfortunes.<BR>\n&nbsp;-- Bertolt Brecht, \"The Caucasian Chalk Circle\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Give all orders verbally.  Never write anything down that might go into a<BR>\n\"Pearl Harbor File\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','George Washington was first in war, first in peace -- and the first to<BR>\nhave his birthday juggled to make a long weekend.<BR>\n&nbsp;-- Ashley Cooper');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','&nbsp;Grover Cleveland, though constantly at loggerheads with the<BR>\nSenate, got on better with the House of Representatives.  A popular<BR>\nstory circulating during his presidency concerned the night he was<BR>\nroused by his wife crying, \"Wake up!  I think there are burglars in the<BR>\nhouse.\"<BR>\n&nbsp;\"No, no, my dear,\" said the president sleepily, \"in the Senate maybe,<BR>\nbut not in the House.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Government lies, and newspapers lie, but in a democracy they are different lies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Government [is] an illusion the governed should not encourage.<BR>\n&nbsp;-- John Updike, \"Couples\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There can be no daily democracy without daily citizenship.<BR>\n&nbsp;-- Ralph Nader');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Hear me, my chiefs, I am tired; my heart is sick and sad.  From where the<BR>\nsun now stands I Will Fight No More Forever.<BR>\n&nbsp;-- Chief Joseph of the Nez Perce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','History is on our side (as long as we can control the historians).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Forgive him, for he believes that the customs of his tribe are the laws<BR>\nof nature!<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Freedom of the press is for those who happen to own one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','History has much to say on following the proper procedures.  From a history<BR>\nof the Mexican revolution:<BR>\n&nbsp;\"Hidalgo was later defeated at Guadalajara.  The rebel army was<BR>\ncaptured on its way through the mountains.  All were courtmartialed and<BR>\nshot, except Hidalgo, because he was a priest.  He was handed over to<BR>\nthe bishop of Durango who excommunicated him and returned him to the<BR>\narmy where he was then executed.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Violence is the last refuge of the incompetent.<BR>\n&nbsp;-- Salvor Hardin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The revolution will not be televised.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The public demands certainties;  it must be told definitely and a bit<BR>\nraucously that this is true and that is false.  But there are no certainties.<BR>\n&nbsp;-- H.L. Mencken, \"Prejudice\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The way I understand it, the Russians are sort of a combination of evil and<BR>\nincompetence... sort of like the Post Office with tanks.<BR>\n&nbsp;-- Emo Philips');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Grub first, then ethics.<BR>\n&nbsp;-- Bertolt Brecht');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The problem with this country is that there is no death penalty for<BR>\nincompetence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The two party system ... is a triumph of the dialectic.  It showed that<BR>\ntwo could be one and one could be two and had probably been fabricated<BR>\nby Hegel for the American market on a subcontract from General Dynamics.<BR>\n&nbsp;-- I.F. Stone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The universe is ruled by letting things take their course.  It cannot be<BR>\nruled by interfering.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The very powerful and the very stupid have one thing in common.  Instead of<BR>\naltering their views to fit the facts, they alter the facts to fit their<BR>\nviews ... which can be very uncomfortable if you happen to be one of the<BR>\nfacts that needs altering.<BR>\n&nbsp;-- Doctor Who, \"Face of Evil\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Hark ye, Clinker, you are a most notorious offender.  You stand convicted of<BR>\nsickness, hunger, wretchedness, and want.<BR>\n&nbsp;-- Tobias Smollet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The two oldest professions in the world have been ruined by amateurs.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The hardest thing in the world to understand is the income tax.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','George Orwell was an optimist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The trouble with this country is that there are too many politicians<BR>\nwho believe, with a conviction based on experience, that you can fool<BR>\nall of the people all of the time.<BR>\n&nbsp;-- Franklin Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He is the best of men who dislikes power.<BR>\n&nbsp;-- Mohammed');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','He thinks the Gettysburg Address is where Lincoln lived.<BR>\n&nbsp;-- Wanda, \"A Fish Called Wanda\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Freedom is nothing else but the chance to do better.<BR>\n&nbsp;-- Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The time for action is past!  Now is the time for senseless bickering.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The time was the 19th of May, 1780.  The place was Hartford, Connecticut.<BR>\nThe day has gone down in New England history as a terrible foretaste of<BR>\nJudgement Day.  For at noon the skies turned from blue to grey and by<BR>\nmid-afternoon had blackened over so densely that, in that religious age,<BR>\nmen fell on their knees and begged a final blessing before the end came.<BR>\nThe Connecticut House of Representatives was in session.  And, as some of<BR>\nthe men fell down and others clamored for an immediate adjournment, the<BR>\nSpeaker of the House, one Col. Davenport, came to his feet.  He silenced<BR>\nthem and said these words: \"The day of judgment is either approaching or<BR>\nit is not.  If it is not, there is no cause for adjournment.  If it is, I<BR>\nchoose to be found doing my duty.  I wish therefore that candles may be<BR>\nbrought.\"<BR>\n&nbsp;-- Alistair Cooke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The so-called lessons of history are for the most part the rationalizations<BR>\nof the victors.  History is written by the survivors.<BR>\n&nbsp;-- Max Lerner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The public is an old woman.  Let her maunder and mumble.<BR>\n&nbsp;-- Thomas Carlyle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"The Right Honorable Gentleman is indebted to his memory for his jests<BR>\nand to his imagination for his facts.\"<BR>\n&nbsp;-- Sheridan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The scum also rises.<BR>\n&nbsp;-- Dr. Hunter S. Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I have always noticed that whenever a radical takes to Imperialism,<BR>\nhe catches it in a very acute form.<BR>\n&nbsp;-- Winston Churchill, 1903');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The problem with most conspiracy theories is that they seem to believe that<BR>\nfor a group of people to behave in a way detrimental to the common good<BR>\nrequires intent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Puritan hated bear-baiting, not because it gave pain to the bear, but<BR>\nbecause it gave pleasure to the spectators.<BR>\n&nbsp;-- Thomas Macaulay, \"History of England\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The primary theme of SoupCon is communication.  The acronym \"LEO\"<BR>\nrepresents the secondary theme:<BR>\n&nbsp;Law Enforcement Officials<BR>\n&nbsp;The overall theme of SoupCon shall be:<BR>\n&nbsp;Avoiding Communication with Law Enforcement Officials<BR>\n&nbsp;-- M. Gallaher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The rule is, jam to-morrow and jam yesterday, but never jam today.<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The question is, why are politicians so eager to be president?  What is it<BR>\nabout the job that makes it worth revealing, on national television, that<BR>\nyou have the ethical standards of a slime-coated piece of industrial waste?<BR>\n&nbsp;-- Dave Barry, \"On Presidential Politics\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Those who have some means think that the most important thing in the<BR>\nworld is love.  The poor know that it is money.<BR>\n&nbsp;-- Gerald Brenan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Those who profess to favor freedom, and yet deprecate agitation, are<BR>\nmen who want rain without thunder and lightning.  They want the ocean<BR>\nwithout the roar of its many waters.<BR>\n&nbsp;-- Frederick Douglass');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Those who do not do politics will be done in by politics.\"<BR>\n&nbsp;-- French Proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War is like love, it always finds a way.<BR>\n&nbsp;-- Bertolt Brecht, \"Mother Courage\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War is delightful to those who have had no experience of it.<BR>\n&nbsp;-- Desiderius Erasmus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','To be excellent when engaged in administration is to be like the North<BR>\nStar.  As it remains in its one position, all the other stars surround it.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War is an equal opportunity destroyer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"They that can give up essential liberty to obtain a little temporary<BR>\nsafety deserve neither liberty nor safety.\"<BR>\n&nbsp;-- Benjamin Franklin, 1759');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Thieves respect property; they merely wish the property to become<BR>\ntheir property that they may more perfectly respect it.<BR>\n&nbsp;-- G.K. Chesterton, \"The Man Who Was Thursday\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','They use different words for things in America.<BR>\nFor instance they say elevator and we say lift.<BR>\nThey say drapes and we say curtains.<BR>\nThey say president and we say brain damaged git.<BR>\n&nbsp;-- Alexie Sayle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When a man assumes a public trust, he should consider himself as public<BR>\nproperty.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Vote anarchist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Freedom begins when you tell Mrs. Grundy to go fly a kite.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Fraud is the homage that force pays to reason.<BR>\n&nbsp;-- Charles Curtis, \"A Commonplace Book\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Freedom is slavery.<BR>\nIgnorance is strength.<BR>\nWar is peace.<BR>\n&nbsp;-- George Orwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','To say you got a vote of confidence would be to say you needed a vote of<BR>\nconfidence.<BR>\n&nbsp;-- Andrew Young');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is only one way to kill capitalism -- by taxes, taxes, and more taxes.<BR>\n&nbsp;-- Karl Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is perhaps in every thing of any consequence, secret history, which<BR>\nit would be amusing to know, could we have it authentically communicated.<BR>\n&nbsp;-- James Boswell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is a certain impertinence in allowing oneself to be burned for an opinion.<BR>\n&nbsp;-- Anatole France');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is no satisfaction in hanging a man who does not object to it.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is no security on this earth.  There is only opportunity.<BR>\n&nbsp;-- General Douglas MacArthur');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is hopeful symbolism in the fact that flags do not wave in a vacuum.<BR>\n&nbsp;-- Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is Jackson standing like a stone wall.  Let us determine to die,<BR>\nand we will conquer.  Follow me.<BR>\n&nbsp;-- General Barnard E. Bee (CSA)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is no act of treachery or mean-ness of which a political party<BR>\nis not capable; for in politics there is no honour.<BR>\n&nbsp;-- Benjamin Disraeli, \"Vivian Grey\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There are a lot of lies going around.... and half of them are true.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is no education that is not political.  An apolitical<BR>\neducation is also political because it is purposely isolating.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','How can you govern a nation which has 246 kinds of cheese?<BR>\n&nbsp;-- Charles de Gaulle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"They make a desert and call it peace.\"<BR>\n&nbsp;-- Tacitus (55?-120?)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','The Worst Bank Robbery<BR>\n&nbsp;In August 1975 three men were on their way in to rob the Royal Bank of<BR>\nScotland at Rothesay, when they got stuck in the revolving doors.  They<BR>\nhad to be helped free by the staff and, after thanking everyone,<BR>\nsheepishly left the building.<BR>\n&nbsp;A few minutes later they returned and announced their intention of<BR>\nrobbing the bank, but none of the staff believed them.  When they demanded<BR>\n5,000 pounds in cash, the head cashier laughed at them, convinced that it<BR>\nwas a practical joke.<BR>\n&nbsp;Then one of the men jumped over the counter, but fell to the floor<BR>\nclutching his ankle.  The other two tried to make their getaway, but got<BR>\ntrapped in the revolving doors again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What orators lack in depth they make up in length.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What we need is either less corruption, or more chance to participate in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War is much too serious a matter to be entrusted to the military.<BR>\n&nbsp;-- Clemenceau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What a strange game.  The only winning move is not to play.<BR>\n&nbsp;-- WOP, \"War Games\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We cannot do everything at once, but we can do something at once.<BR>\n&nbsp;-- Calvin Coolidge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Got a complaint about the Internal Revenue Service?  <BR>\nCall the convenient toll-free \"IRS Taxpayer Complaint Hot Line Number\":<BR>\n&nbsp;1-800-AUDITME');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','... we must not judge the society of the future by considering whether or not<BR>\nwe should like to live in it; the question is whether those who have grown up<BR>\nin it will be happier than those who have grown up in our society or those of<BR>\nthe past.<BR>\n&nbsp;-- Joseph Wood Krutch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We are all worms.  But I do believe I am a glowworm.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','[Washington, D.C.] is the home of... taste for the people -- the big,<BR>\nthe bland and the banal.<BR>\n&nbsp;-- Ada Louise Huxtable');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Washington, D.C: Fifty square miles almost completely surrounded by reality.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War is peace.  Freedom is slavery.  Ketchup is a vegetable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War spares not the brave, but the cowardly.<BR>\n&nbsp;-- Anacreon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We are all born equal... just some of us are more equal than others.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We all declare for liberty, but in using the same word we do not all mean<BR>\nthe same thing.<BR>\n&nbsp;-- A. Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Victory uber allies!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Violence accomplishes nothing.\"  What a contemptible lie!  Raw, naked<BR>\nviolence has settled more issues throughout history than any other method<BR>\never employed.  Perhaps the city fathers of Carthage could debate the<BR>\nissue, with Hitler and Alexander as judges?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Violence is a sword that has no handle -- you have to hold the blade.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Very few things happen at the right time, and the rest do not happen<BR>\nat all.  The conscientious historian will correct these defects.<BR>\n&nbsp;-- Herodotus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Unquestionably, there is progress.  The average American now pays out<BR>\ntwice as much in taxes as he formerly got in wages.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Violence is molding.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Veni, vidi, vici.<BR>\n&nbsp;[I came, I saw, I conquered].<BR>\n&nbsp;-- Gaius Julius Caesar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Treaties are like roses and young girls -- they last while they last.<BR>\n&nbsp;-- Charles DeGaulle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Travel important today;  Internal Revenue men arrive tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','\"Ubi non accusator, ibi non judex.\"<BR>\n&nbsp;(Where there is no police, there is no speed limit.)<BR>\n&nbsp;-- Roman Law, trans. Petr Beckmann (1971)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','True leadership is the art of changing a group from what it is to what<BR>\nit ought to be.<BR>\n&nbsp;-- Virginia Allan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Under a government which imprisons any unjustly, the true place for a<BR>\njust man is also a prison.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When we are planning for posterity, we ought to remember that virtue is<BR>\nnot hereditary.<BR>\n&nbsp;-- Thomas Paine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','With reasonable men I will reason;<BR>\nwith humane men I will plead;<BR>\nbut to tyrants I will give no quarter.<BR>\n&nbsp;-- William Lloyd Garrison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When the revolution comes, count your change.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','World War Three can be averted by adherence to a strictly enforced dress code!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','You should never wear your best trousers when you go out to fight for<BR>\nfreedom and liberty.<BR>\n&nbsp;-- Henrik Ibsen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','&nbsp;... with liberty and justice for all ... who can afford it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Whenever I hear anyone arguing for slavery, I feel a strong impulse to<BR>\nsee it tried on him personally.<BR>\n&nbsp;-- Abraham Lincoln');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Where you stand depends on where you sit.<BR>\n&nbsp;-- Rufus Miles, HEW');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When you say that you agree to a thing in principle, you mean that<BR>\nyou have not the slightest intention of carrying it out in practice.<BR>\n&nbsp;-- Otto Von Bismarck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When you have an efficient government, you have a dictatorship.<BR>\n&nbsp;-- Harry Truman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When you have to kill a man it costs nothing to be polite.<BR>\n&nbsp;-- Winston Churchill, on formal declarations of war');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Why bother building any more nuclear warheads until we use the ones we have?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When taxes are due, Americans tend to feel quite bled-white and blue.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When neither their poverty nor their honor is touched, the majority of men<BR>\nlive content.<BR>\n&nbsp;-- Niccolo Machiavelli');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When I came back to Dublin I was courtmartialed in my absence and sentenced<BR>\nto death in my absence, so I said they could shoot me in my absence.<BR>\n&nbsp;-- Brendan Behan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When I hear a man applauded by the mob I always feel a pang of pity<BR>\nfor him.  All he has to do to be hissed is to live long enough.<BR>\n&nbsp;-- H.L. Mencken, \"Minority Report\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What is the sound of one hand clapping?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When a shepherd goes to kill a wolf, and takes his dog along to see<BR>\nthe sport, he should take care to avoid mistakes.  The dog has certain<BR>\nrelationships to the wolf the shepherd may have forgotten.<BR>\n&nbsp;-- Robert Pirsig, \"Zen and the Art of Motorcycle Maintenance\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We should have a Vollyballocracy.  We elect a six-pack of presidents.<BR>\nEach one serves until they screw up, at which point they rotate.<BR>\n&nbsp;-- Dennis Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When asked by an anthropologist what the Indians called America before<BR>\nthe white men came, an Indian said simply \"Ours.\"<BR>\n&nbsp;-- Vine Deloria, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','World tensions have, if anything, increased in the quarter century since<BR>\nH.G. Wells uttered his glum warning: \"There is no more evil thing on<BR>\nearth than race prejudice, none at all.  I write deliberately -- it is<BR>\nthe worst single thing in life now.  It justifies and holds together more<BR>\nbaseness, cruelty and abomination than any other sort of error in the world.\"<BR>\n&nbsp;-- Sydney Harris');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What I want is all of the power and none of the responsibility.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','What is the robbing of a bank compared to the founding of a bank?<BR>\n&nbsp;-- Bertold Brecht');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','They will only cause the lower classes to move about needlessly.<BR>\n&nbsp;-- The Duke of Wellington, on early steam railroads.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There never was a good war or a bad peace.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','To make tax forms true they should read \"Income Owed Us\" and \"Incommode You\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','To use violence is to already be defeated.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There is one difference between a tax collector and a taxidermist --<BR>\nthe taxidermist leaves the hide.<BR>\n&nbsp;-- Mortimer Caplan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','And they mainly want to teach them not to question, not to imagine,<BR>\nbut to be obedient and behave well so that they can hold them forever as<BR>\nchildren to their bosom as the second millennium lurches toward its<BR>\npanicky close.<BR>\n&nbsp;-- Jerome Stern');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Today is a good day to bribe a high-ranking public official.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Too often I find that the volume of paper expands to fill the available<BR>\nbriefcases.<BR>\n&nbsp;-- Governor Jerry Brown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','As long as there are entrenched social and political distinctions<BR>\nbetween sexes, races or classes, there will be forms of science whose<BR>\nmain function is to rationalize and legitimize these distinctions.<BR>\n&nbsp;-- Elizabeth Fee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Under any conditions, anywhere, whatever you are doing, there is some<BR>\nordinance under which you can be booked.<BR>\n&nbsp;-- Robert D. Sprecht, Rand Corp.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Unknown person(s) stole the American flag from its pole in Etra Park sometime<BR>\nbetween 3pm Jan 17 and 11:30 am Jan 20.  The flag is described as red, white<BR>\nand blue, having 50 stars and was valued at $40.<BR>\n&nbsp;-- Windsor-Heights Herald \"Police Blotter\", Jan 28, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','United Nations, New York, December 25.  The peace and joy of the Christmas<BR>\nseason was marred by a proclamation of a general strike of all the military<BR>\nforces of the world.  Panic reigns in the hearts of all the patriots of<BR>\nevery persuasion.  Meanwhile, fears of universal disaster sank to an all-time<BR>\nlow over the world.<BR>\n&nbsp;-- Isaac Asimov');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Is uniformity attainable?  Millions of innocent men, women, and<BR>\nchildren, since the introduction of Christianity, have been burnt,<BR>\ntortured, fined, imprisoned; yet we have not advanced one inch towards<BR>\nuniformity.  What has been the effect of coercion?  To make one half<BR>\nof the world fools, and the other half hypocrites.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','I do not patronize poor, ill educated, or disenfranchised people by<BR>\nexempting them from the same critical examination I feel free to<BR>\ndirect toward the rest of society, however much I might champion the<BR>\nsame minority or disadvantaged group in the forums of that society.<BR>\n&nbsp;-- James Moffitt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Under every stone lurks a politician.<BR>\n&nbsp;-- Aristophanes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When in doubt, do what the President does -- guess.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','We should have a great many fewer disputes in the world if only words were<BR>\ntaken for what they are, the signs of our ideas only, and not for things<BR>\nthemselves.<BR>\n&nbsp;-- John Locke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','War hath no fury like a non-combatant.<BR>\n&nbsp;-- Charles Edward Montague');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When smashing monuments, save the pedstals -- they always come in handy.<BR>\n&nbsp;-- Stanislaw J. Lem, \"Unkempt Thoughts\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','You have all the characteristics of a popular politician: a horrible voice,<BR>\nbad breeding, and a vulgar manner.<BR>\n&nbsp;-- Aristophanes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','You roll my log, and I will roll yours.<BR>\n&nbsp;-- Lucius Annaeus Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','You must include all income you receive in the form of money, property<BR>\nand services if it is not specifically exempt.  Report property (goods)<BR>\nand services at their fair market values.  Examples include income from<BR>\nbartering or swapping transactions, side commissions, kickbacks, rent<BR>\npaid in services, illegal activities (such as stealing, drugs, etc.),<BR>\ncash skimming by proprietors and tradesmen, \"moonlighting\" services,<BR>\ngambling, prizes and awards.  Not reporting such income can lead to<BR>\nprosecution for perjury and fraud.<BR>\n&nbsp;-- Excerpt from Taxachussetts income tax forms');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','When you live in a sick society, just about everything you do is wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','There cannot be a crisis next week.  My schedule is already full.<BR>\n&nbsp;-- Henry Kissinger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','This is a country where people are free to practice their religion,<BR>\nregardless of race, creed, color, obesity, or number of dangling keys...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Workers of the world, arise!  You have nothing to lose but your chairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Support your local police force -- steal!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Secrecy is the beginning of tyranny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Support your right to arm bears!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','Stamp out organized crime!!  Abolish the IRS.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('politics','QUESTION AUTHORITY.<BR>\n&nbsp;(Sez who?)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do people who live near Niagara Falls have flat foreheads?<BR>\nA:	Because every morning they wake up thinking \"What *is* that noise?<BR>\n&nbsp;Oh, right, *of course*!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the lone ranger kill Tonto?<BR>\nA:	He found out what \"kimosabe\" really means.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the tachyon cross the road?<BR>\nA:	Because it was on the other side.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do mountain climbers rope themselves together?<BR>\nA:	To prevent the sensible ones from going home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is printed on the bottom of beer bottles in Minnesota?<BR>\nA:	Open other end.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is the difference between Texas and yogurt?<BR>\nA:	Yogurt has culture.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What looks like a cat, flies like a bat, brays like a donkey, and<BR>\n&nbsp;plays like a monkey?<BR>\nA:	Nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is orange and goes \"click, click?\"<BR>\nA:	A ball point carrot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you have when you have a lawyer buried up to his neck in sand?<BR>\nA:	Not enough sand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you say to a New Yorker with a job?<BR>\nA:	Big Mac, fries and a Coke, please!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call the scratches that you get when a female<BR>\n&nbsp;sheep bites you?<BR>\nA:	Ewe nicks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call a principal female opera singer whose high C<BR>\n&nbsp;is lower than those of other principal female opera singers?<BR>\nA:	A deep C diva.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What does a WASP Mom make for dinner?<BR>\nA:	A crisp salad, a hearty soup, a lovely entree, followed by<BR>\n&nbsp;a delicious dessert.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call the money you pay to the government when<BR>\n&nbsp;you ride into the country on the back of an elephant?<BR>\nA:	A howdah duty.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call a blind pre-historic animal?<BR>\nA:	Diyathinkhesaurus.<BR>\n&nbsp;Q:	What do you call a blind pre-historic animal with a dog?<BR>\nA:	Diyathinkhesaurus Rex.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call a blind, deaf-mute, quadraplegic Virginian?<BR>\nA:	Trustworthy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call 15 blondes in a circle?<BR>\nA:	A dope ring.<BR>\n&nbsp;Q:	Why do blondes put their hair in ponytails?<BR>\nA:	To cover up the valve stem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do little WASPs want to be when they grow up?<BR>\nA:	The very best person they can possibly be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do monsters eat?<BR>\nA:	Things.<BR>\n&nbsp;Q:	What do monsters drink?<BR>\nA:	Coke.  (Because Things go better with Coke.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do Winnie the Pooh and John the Baptist have in common?<BR>\nA:	The same middle name.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What does friendship among Soviet nationalities mean?<BR>\nA:	It means that the Armenians take the Russians by the hand; the<BR>\n&nbsp;Russians take the Ukrainians by the hand; the Ukranians take<BR>\n&nbsp;the Uzbeks by the hand; and they all go and beat up the Jews.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do you call a half-dozen Indians with Asian flu?<BR>\nA:	Six sick Sikhs (sic).');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is green and lives in the ocean?<BR>\nA:	Moby Pickle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How was Thomas J. Watson buried?<BR>\nA:	9 edge down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many Zen masters does it take to screw in a light bulb?<BR>\nA:	None.  The Universe spins the bulb, and the Zen master stays out<BR>\n&nbsp;of the way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many WASPs does it take to change a lightbulb?<BR>\nA:	One.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How much does it cost to ride the Unibus?<BR>\nA:	2 bits.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Know what the difference between your latest project<BR>\n&nbsp;and putting wings on an elephant is?<BR>\nA:	Who knows?  The elephant *might* fly, heh, heh...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What do they call the alphabet in Arkansas?<BR>\nA:	The impossible dream.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What does it say on the bottom of Coke cans in North Dakota?<BR>\nA:	Open other end.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What happens when four WASPs find themselves in the same room?<BR>\nA:	A dinner party.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Do you know what the death rate around here is?<BR>\nA:	One per person.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','FORTUNE PROVIDES QUESTIONS FOR THE GREAT ANSWERS: #13<BR>\nA:	Doc, Happy, Bashful, Dopey, Sneezy, Sleepy, & Grumpy<BR>\nQ:	Who were the Democratic presidential candidates?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','FORTUNE PROVIDES QUESTIONS FOR THE GREAT ANSWERS: #15<BR>\nA:	The Royal Canadian Mounted Police.<BR>\nQ:	What was the greatest achievement in taxidermy?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','FORTUNE PROVIDES QUESTIONS FOR THE GREAT ANSWERS: #19<BR>\nA:	To be or not to be.<BR>\nQ:	What is the square root of 4b^2?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many psychiatrists does it take to change a light bulb?<BR>\nA:	Only one, but it takes a long time, and the light bulb has<BR>\n&nbsp;to really want to change.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','FORTUNE PROVIDES QUESTIONS FOR THE GREAT ANSWERS: #4<BR>\nA:	Go west, young man, go west!<BR>\nQ:	What do wabbits do when they get tiwed of wunning awound?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many supply-siders does it take to change a light bulb?<BR>\nA:	None.  The darkness will cause the light bulb to change by itself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What lies on the bottom of the ocean and twitches?<BR>\nA:	A nervous wreck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is purple and commutes?<BR>\nA:	A boolean grape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is the difference between a duck?<BR>\nA:	One leg is both the same.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is purple and commutes?<BR>\nA:	An Abelian grape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is purple and concord the world?<BR>\nA:	Alexander the Grape.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	What is the sound of one cat napping?<BR>\nA:	Mu.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the programmer call his mother long distance?<BR>\nA:	Because that was her name.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the astrophysicist order three hamburgers?<BR>\nA:	Because he was hungry.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the chicken cross the road?<BR>\nA:	He was giving it last rites.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the chicken cross the road?<BR>\nA:	To see his friend Gregory peck.<BR>\n&nbsp;Q:	Why did the chicken cross the playground?<BR>\nA:	To get to the other slide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the germ cross the microscope?<BR>\nA:	To get to the other slide.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do firemen wear red suspenders?<BR>\nA:	To conform with departmental regulations concerning uniform dress.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do the police always travel in threes?<BR>\nA:	One to do the reading, one to do the writing, and the other keeps<BR>\n&nbsp;an eye on the two intellectuals.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did the WASP cross the road?<BR>\nA:	To get to the middle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do WASPs play golf ?<BR>\nA:	So they can dress like pimps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why is Christmas just like a day at the office?<BR>\nA:	You do all of the work and the fat guy in the suit<BR>\n&nbsp;gets all the credit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why do ducks have big flat feet?<BR>\nA:	To stamp out forest fires.<BR>\n&nbsp;Q:	Why do elephants have big flat feet?<BR>\nA:	To stamp out flaming ducks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why does Washington have the most lawyers per capita and<BR>\n&nbsp;New Jersey the most toxic waste dumps?<BR>\nA:	God gave New Jersey first choice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many mathematicians does it take to screw in a lightbulb?<BR>\nA:	One.  He gives it to six Californians, thereby reducing the problem<BR>\n&nbsp;to the earlier joke.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many IBM types does it take to change a light bulb?<BR>\nA:	Fifteen.  One to do it, and fourteen to write document number<BR>\n&nbsp;GC7500439-0001, Multitasking Incandescent Source System Facility,<BR>\n&nbsp;of which 10% of the pages state only \"This page intentionally<BR>\n&nbsp;left blank\", and 20% of the definitions are of the form \"A:.....<BR>\n&nbsp;consists of sequences of non-blank characters separated by blanks\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many existentialists does it take to screw in a lightbulb?<BR>\nA:	Two.  One to screw it in and one to observe how the lightbulb<BR>\n&nbsp;itself symbolizes a single incandescent beacon of subjective<BR>\n&nbsp;reality in a netherworld of endless absurdity reaching out toward a<BR>\n&nbsp;maudlin cosmos of nothingness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	\"What is the burning question on the mind of every dyslexic<BR>\n&nbsp;existentialist?\"<BR>\nA:	\"Is there a dog?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you keep a moron in suspense?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How does the Polish Constitution differ from the American?<BR>\nA:	Under the Polish Constitution citizens are guaranteed freedom of<BR>\n&nbsp;speech, but under the United States constitution they are<BR>\n&nbsp;guaranteed freedom after speech.<BR>\n&nbsp;-- being told in Poland, 1987');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many bureaucrats does it take to screw in a light bulb?<BR>\nA:	Two.  One to assure everyone that everything possible is being<BR>\n&nbsp;done while the other screws the bulb into the water faucet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you stop an elephant from charging?<BR>\nA:	Take away his credit cards.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many college football players does it take to screw in a lightbulb?<BR>\nA:	Only one, but he gets three credits for it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you catch a unique rabbit?<BR>\nA:	Unique up on it!<BR>\n&nbsp;Q:	How do you catch a tame rabbit?<BR>\nA:	The tame way!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you play religious roulette?<BR>\nA:	You stand around in a circle and blaspheme and see who gets<BR>\n&nbsp;struck by lightning first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you shoot a blue elephant?<BR>\nA:	With a blue-elephant gun.<BR>\n&nbsp;Q:	How do you shoot a pink elephant?<BR>\nA:	Twist its trunk until it turns blue, then shoot it with<BR>\n&nbsp;a blue-elephant gun.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How can you tell when a Burroughs salesman is lying?<BR>\nA:	When his lips move.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Are we not men?<BR>\nA:	We are Vaxen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many Oregonians does it take to screw in a light bulb?<BR>\nA:	Three.  One to screw in the lightbulb and two to fend off all those<BR>\n&nbsp;Californians trying to share the experience.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How do you save a drowning lawyer?<BR>\nA:	Throw him a rock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many lawyers does it take to change a light bulb?<BR>\nA:	Whereas the party of the first part, also known as \"Lawyer\", and the<BR>\nparty of the second part, also known as \"Light Bulb\", do hereby and forthwith<BR>\nagree to a transaction wherein the party of the second part shall be removed<BR>\nfrom the current position as a result of failure to perform previously agreed<BR>\nupon duties, i.e., the lighting, elucidation, and otherwise illumination of<BR>\nthe area ranging from the front (north) door, through the entryway, terminating<BR>\nat an area just inside the primary living area, demarcated by the beginning of<BR>\nthe carpet, any spillover illumination being at the option of the party of the<BR>\nsecond part and not required by the aforementioned agreement between the<BR>\nparties.<BR>\n&nbsp;The aforementioned removal transaction shall include, but not be<BR>\nlimited to, the following.  The party of the first part shall, with or without<BR>\nelevation at his option, by means of a chair, stepstool, ladder or any other<BR>\nmeans of elevation, grasp the party of the second part and rotate the party<BR>\nof the second part in a counter-clockwise direction, this point being tendered<BR>\nnon-negotiable.  Upon reaching a point where the party of the second part<BR>\nbecomes fully detached from the receptacle, the party of the first part shall<BR>\nhave the option of disposing of the party of the second part in a manner<BR>\nconsistent with all relevant and applicable local, state and federal statutes.<BR>\nOnce separation and disposal have been achieved, the party of the first part<BR>\nshall have the option of beginning installation.  Aforesaid installation shall<BR>\noccur in a manner consistent with the reverse of the procedures described in<BR>\nstep one of this self-same document, being careful to note that the rotation<BR>\nshould occur in a clockwise direction, this point also being non-negotiable.<BR>\nThe above described steps may be performed, at the option of the party of the<BR>\nfirst part, by any or all agents authorized by him, the objective being to<BR>\nproduce the most possible revenue for the Partnership.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many journalists does it take to screw in a lightbulb?<BR>\nA:	Three.  One to report it as an inspired government program to bring<BR>\n&nbsp;light to the people, one to report it as a diabolical government plot<BR>\n&nbsp;to deprive the poor of darkness, and one to win a Pulitzer prize for<BR>\n&nbsp;reporting that Electric Company hired a lightbulb-assassin to break<BR>\n&nbsp;the bulb in the first place.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many Martians does it take to screw in a lightbulb?<BR>\nA:	One and a half.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	How many Marxists does it take to screw in a lightbulb?<BR>\nA:	None:  The lightbulb contains the seeds of its own revolution.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('riddles','Q:	Why did Menachem Begin invade Lebanon?<BR>\nA:	To impress Jodie Foster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nuclear powered vacuuum cleaners will probably be a reality within 10 years.<BR>\n&nbsp;-- Alex Lewyt (President of the Lewyt Corporation,<BR>\n&nbsp;manufacturers of vacuum cleaners), quoted in The New York<BR>\n&nbsp;Times, June 10, 1955.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The only justification for our concepts and systems of concepts is that they<BR>\nserve to represent the complex of our experiences; beyond this they have<BR>\nno legitimacy.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Neutrinos have bad breadth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Chemistry professors never die, they just fail to react.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"A fractal is by definition a set for which the Hausdorff Besicovitch<BR>\ndimension strictly exceeds the topological dimension.\"<BR>\n&nbsp;-- Mandelbrot, \"The Fractal Geometry of Nature\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Picture the sun as the origin of two intersecting 6-dimensional<BR>\nhyperplanes from which we can deduce a certain transformational<BR>\nsequence which gives us the terminal velocity of a rubber duck ...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One could not be a successful scientist without realizing that, in contrast<BR>\nto the popular conception supported by newspapers and mothers of scientists,<BR>\na goodly number of scientists are not only narrow-minded and dull, but also<BR>\njust stupid.<BR>\n&nbsp;-- J.D. Watson, \"The Double Helix\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One Bell System - it used to work before they installed the Dimension!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','&nbsp;Once, when the secrets of science were the jealously guarded property<BR>\nof a small priesthood, the common man had no hope of mastering their arcane<BR>\ncomplexities.  Years of study in musty classrooms were prerequisite to<BR>\nobtaining even a dim, incoherent knowledge of science.<BR>\n&nbsp;Today all that has changed: a dim, incoherent knowledge of science is<BR>\navailable to anyone.<BR>\n&nbsp;-- Tom Weller, \"Science Made Stupid\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Life is difficult because it is non-linear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Natural laws have no pity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Neil Armstrong tripped.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mystics always hope that science will some day overtake them.<BR>\n&nbsp;-- Booth Tarkington');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Logic is a systematic method of coming to the wrong conclusion with confidence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One can search the brain with a microscope and not find the<BR>\nmind, and can search the stars with a telescope and not find God.<BR>\n&nbsp;-- J. Gustav White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Often statistics are used as a drunken man uses lampposts -- for support<BR>\nrather than illumination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Consider a spherical bear, in simple harmonic motion...\"<BR>\n&nbsp;-- Professor in the UCB physics department');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Logic is a pretty flower that smells bad.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Philogyny recapitulates erogeny; erogeny recapitulates philogyny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All Finagle Laws may be bypassed by learning the simple art of doing<BR>\nwithout thinking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The goal of science is to build better mousetraps.  The goal of nature<BR>\nis to build better mice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The key elements in human thinking are not numbers but labels of fuzzy sets.<BR>\n&nbsp;-- L. Zadeh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The instruments of science do not in themselves discover truth.  And there are<BR>\nsearchings that are not concluded by the coincidence of a pointer and a mark.<BR>\n&nbsp;-- Fred Saberhagen, \"The Berserker Wars\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Obviously, a major malfunction has occurred.\"<BR>\n&nbsp;-- Steve Nesbitt, voice of Mission Control, January 28,<BR>\n&nbsp;1986, as the shuttle Challenger exploded within view<BR>\n&nbsp;of the grandstands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The light of a hundred stars does not equal the light of the moon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','After the last of 16 mounting screws has been removed from an access<BR>\ncover, it will be discovered that the wrong access cover has been removed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Prototype designs always work.<BR>\n&nbsp;-- Don Vonada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Progress means replacing a theory that is wrong with one more subtly wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Reality must take precedence over public relations, for Mother Nature<BR>\ncannot be fooled.<BR>\n&nbsp;-- R.P. Feynman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Protozoa are small, and bacteria are small, but viruses are smaller<BR>\nthan the both put together.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Recession is when your neighbor loses his job. Depression is when you<BR>\nlose your job.  These economic downturns are very difficult to predict,<BR>\nbut sophisticated econometric modeling houses like Data Resources and<BR>\nChase Econometrics have successfully predicted 14 of the last 3 recessions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Pound for pound, the amoeba is the most vicious animal on earth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Power corrupts.  And atomic power corrupts atomically.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Radioactive cats have 18 half-lives.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The church saves sinners, but science seeks to stop their manufacture.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The clearest way into the Universe is through a forest wilderness.<BR>\n&nbsp;-- John Muir');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The best rebuttal to this kind of statistical argument came from the<BR>\nredoubtable John W. Campbell:<BR>\n&nbsp;The laws of population growth tell us that approximately half the<BR>\n&nbsp;people who were ever born in the history of the world are now<BR>\n&nbsp;dead.  There is therefore a 0.5 probability that this message is<BR>\n&nbsp;being read by a corpse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The amount of time between slipping on the peel and landing on the<BR>\npavement is precisely 1 bananosecond.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The astronomer Francesco Sizi, a contemporary of Galileo, argues that<BR>\nJupiter can have no satellites:<BR>\n&nbsp;There are seven windows in the head, two nostrils, two ears, two<BR>\neyes, and a mouth; so in the heavens there are two favorable stars, two<BR>\nunpropitious, two luminaries, and Mercury alone undecided and indifferent.<BR>\nFrom which and many other similar phenomena of nature such as the seven<BR>\nmetals, etc., which it were tedious to enumerate, we gather that the number<BR>\nof planets is necessarily seven. [...]<BR>\n&nbsp;Moreover, the satellites are invisible to the naked eye and<BR>\ntherefore can have no influence on the earth and therefore would be useless<BR>\nand therefore do not exist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Technology is dominated by those who manage what they do not understand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Take an astronaut to launch.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The Commandments of the EE:<BR>\n&nbsp;(9)	Trifle thee not with radioactive tubes and substances lest thou<BR>\n&nbsp;commence to glow in the dark like a lightning bug, and thy wife be<BR>\n&nbsp;frustrated and have not further use for thee except for thy wages.<BR>\n(10)	Commit thou to memory all the words of the prophets which are<BR>\n&nbsp;written down in thy Bible which is the National Electrical Code,<BR>\n&nbsp;and giveth out with the straight dope and consoleth thee when<BR>\n&nbsp;thou hast suffered a ream job by the chief electrician.<BR>\n(11)	When thou muckest about with a device in an unthinking and/or<BR>\n&nbsp;unknowing manner, thou shalt keep one hand in thy pocket.  Better<BR>\n&nbsp;that thou shouldest keep both hands in thy pockets than<BR>\n&nbsp;experimentally determine the electrical potential of an<BR>\n&nbsp;innocent-seeming device.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','But it does move!<BR>\n&nbsp;-- Galileo Galilei');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The amount of weight an evangelist carries with the almighty is measured<BR>\nin billigrahams.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The aim of science is to seek the simplest explanations of complex<BR>\nfacts.  Seek simplicity and distrust it.<BR>\n&nbsp;-- Whitehead.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The following statement is not true.  The previous statement is true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Technological progress has merely provided us with more efficient means<BR>\nfor going backwards.<BR>\n&nbsp;-- Aldous Huxley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The  White Rabbit put on his spectacles.<BR>\n&nbsp;\"Where shall  I  begin, please your Majesty ?\" he asked.<BR>\n&nbsp;\"Begin at the beginning,\", the King said, very gravely, \"and go on<BR>\ntill you come to the end: then stop.\"<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The clash of ideas is the sound of freedom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"The four building blocks of the universe are fire, water, gravel and vinyl.\"<BR>\n&nbsp;-- Dave Barry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Space tells matter how to move and matter tells space how to curve.<BR>\n&nbsp;-- Wheeler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Statistics are no substitute for judgement.<BR>\n&nbsp;-- Henry Clay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Space is to place as eternity is to time.<BR>\n&nbsp;-- Joseph Joubert');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Scientists are people who build the Brooklyn Bridge and then buy it.<BR>\n&nbsp;-- William Buckley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Science is what happens when preconception meets verification.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Stellar rays prove fibbing never pays.  Embezzlement is another matter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Sentient plasmoids are a gas.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All science is either physics or stamp collecting.<BR>\n&nbsp;-- Ernest Rutherford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Science may someday discover what faith has always known.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Saliva causes cancer, but only if swallowed in small amounts over a long<BR>\nperiod of time.<BR>\n&nbsp;-- George Carlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Science and religion are in full accord but science and faith are in complete<BR>\ndiscord.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Simplicity does not precede complexity, but follows it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A pain in the ass of major dimensions.<BR>\n&nbsp;-- C.A. Desoer, on the solution of non-linear circuits');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The feeling persists that no one can simultaneously be a respectable writer<BR>\nand understand how a refrigerator works, just as no gentleman wears a brown<BR>\nsuit in the city.  Colleges may be to blame.  English majors are encouraged,<BR>\nI know, to hate chemistry and physics, and to be proud because they are not<BR>\ndull and creepy and humorless and war-oriented like the engineers across the<BR>\nquad.  And our most impressive critics have commonly been such English majors,<BR>\nand they are squeamish about technology to this very day.  So it is natural<BR>\nfor them to despise science fiction.<BR>\n&nbsp;-- Kurt Vonnegut Jr., \"Science Fiction\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We are all agreed that your theory is crazy.  The question which divides us is<BR>\nwhether it is crazy enough to have a chance of being correct.  My own feeling<BR>\nis that it is not crazy enough. <BR>\n&nbsp;-- Niels Bohr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe is all a spin-off of the Big Bang.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"The identical is equal to itself, since it is different.\"<BR>\n&nbsp;-- Franco Spisani');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The moon is made of green cheese.<BR>\n&nbsp;-- John Heywood');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','As far as the laws of mathematics refer to reality, they are not<BR>\ncertain, and as far as they are certain, they do not refer to reality.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','As you will see, I told them, in no uncertain terms, to see Figure one.<BR>\n&nbsp;-- Dave \"First Strike\" Pare');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A scientific truth does not triumph by convincing its opponents and<BR>\nmaking them see the light, but rather because its opponents eventually<BR>\ndie and a new generation grows up that is familiar with it.<BR>\n&nbsp;-- Max Planck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The devil finds work for idle glands.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A sense of desolation and uncertainty, of futility, of the baselessness<BR>\nof aspirations, of the vanity of endeavor, and a thirst for a life giving<BR>\nwater which seems suddenly to have failed, are the signs in conciousness<BR>\nof this necessary reorganization of our lives.<BR>\n&nbsp;It is difficult to believe that this state of mind can be produced by the<BR>\nrecognition of such facts as that unsupported stones always fall to the<BR>\nground.<BR>\n&nbsp;-- J.W.N. Sullivan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The Commandments of the EE:<BR>\n&nbsp;(5)	Take care that thou useth the proper method when thou takest the<BR>\n&nbsp;measures of high-voltage circuits too, that thou dost not incinerate<BR>\n&nbsp;both thee and thy test meter, for verily, though thou has no company<BR>\n&nbsp;property number and can be easily surveyed, the test meter has<BR>\n&nbsp;one and, as a consequence, bringeth much woe unto a purchasing agent.<BR>\n(6)	Take care that thou tamperest not with interlocks and safety devices,<BR>\n&nbsp;for this incurreth the wrath of the chief electrician and bring<BR>\n&nbsp;the fury of the engineers on his head.<BR>\n(7)	Work thou not on energized equipment for if thou doest so, thy<BR>\n&nbsp;friends will surely be buying beers for thy widow and consoling<BR>\n&nbsp;her in certain ways not generally acceptable to thee.<BR>\n(8)	Verily, verily I say unto thee, never service equipment alone,<BR>\n&nbsp;for electrical cooking is a slow process and thou might sizzle in<BR>\n&nbsp;thy own fat upon a hot circuit for hours on end before thy maker<BR>\n&nbsp;sees fit to end thy misery and drag thee into his fold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Biology grows on you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The bomb will never go off.  I speak as an expert in explosives.<BR>\n&nbsp;-- Admiral William Leahy, U.S. Atomic Bomb Project');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The bigger the theory the better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The Commandments of the EE:<BR>\n&nbsp;(1)	Beware of lightning that lurketh in an uncharged condenser<BR>\n&nbsp;lest it cause thee to bounce upon thy buttocks in a most<BR>\n&nbsp;embarrassing manner.<BR>\n(2)	Cause thou the switch that supplieth large quantities of juice to<BR>\n&nbsp;be opened and thusly tagged, that thy days may be long in this<BR>\n&nbsp;earthly vale of tears.<BR>\n(3)	Prove to thyself that all circuits that radiateth, and upon<BR>\n&nbsp;which the worketh, are grounded and thusly tagged lest they lift<BR>\n&nbsp;thee to a radio frequency potential and causeth thee to make like<BR>\n&nbsp;a radiator too.<BR>\n(4)	Tarry thou not amongst these fools that engage in intentional<BR>\n&nbsp;shocks for they are not long for this world and are surely<BR>\n&nbsp;unbelievers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The devil finds work for idle circuits to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The best defense against logic is ignorance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Always think of something new; this helps you forget your last rotten idea.<BR>\n&nbsp;-- Seth Frankel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Artificial intelligence has the same relation to intelligence as<BR>\nartificial flowers have to flowers.<BR>\n&nbsp;-- David Parnas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We dedicate this book to our fellow citizens who, for love of truth, take from<BR>\ntheir own wants by taxes and gifts, and now and then send forth one of<BR>\nthemselves as dedicated servant, to forward the search into the mysteries and<BR>\nmarvelous simplicities of this strange and beautiful Universe, Our home.<BR>\n&nbsp;-- \"Gravitation\", Misner, Thorne, and Wheeler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We are each entitled to our own opinion, but no one is entitled to his<BR>\nown facts.<BR>\n&nbsp;-- Patrick Moynihan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"As an adolescent I aspired to lasting fame, I craved factual certainty,<BR>\nand I thirsted for a meaningful vision of human life -- so I became a<BR>\nscientist.  This is like becoming an archbishop so you can meet girls.\"<BR>\n&nbsp;-- Matt Cartmill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','To invent, you need a good imagination and a pile of junk.<BR>\n&nbsp;-- Thomas Edison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Biology is the only science in which multiplication means the same thing<BR>\nas division.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','10.0 times 0.1 is hardly ever 1.0.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','This universe shipped by weight, not by volume.  Some expansion of the<BR>\ncontents may have occurred during shipment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','This was a Golden Age, a time of high adventure, rich living, and hard<BR>\ndying... but nobody thought so.  This was a future of fortune and theft,<BR>\npillage and rapine, culture and vice... but nobody admitted it.<BR>\n&nbsp;-- Alfred Bester, \"The Stars My Destination\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is, in fact, no reason to believe that any given natural phenomenon,<BR>\nhowever marvelous it may seem today, will remain forever inexplicable.<BR>\nSoon or late the laws governing the production of life itself will be <BR>\ndiscovered in the laboratory, and man may set up business as a creator<BR>\non his own account.  The thing, indeed, is not only conceivable; it is<BR>\neven highly probable.<BR>\n&nbsp;-- H.L. Mencken, 1930');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is no opinion so absurd that some philosopher will not express it.<BR>\n&nbsp;-- Marcus Tullius Cicero, \"Ad familiares\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The difference between reality and unreality is that reality has so<BR>\nlittle to recommend it.<BR>\n&nbsp;-- Allan Sherman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The economy depends about as much on economists as the weather does on<BR>\nweather forecasters.<BR>\n&nbsp;-- Jean-Paul Kauffmann');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is no choice before us. Either we must Succeed in providing the<BR>\nrational coordination of impulses and guts, or for centuries civilization<BR>\nwill sink into a mere welter of minor excitements. We must provide a<BR>\nGreat Age or see the collapse of the upward striving of the human race.<BR>\n&nbsp;-- Alfred North Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All syllogisms have three parts, therefore this is not a syllogism.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A mathematician is a device for turning coffee into theorems.<BR>\n&nbsp;-- P. Erdos');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The truth of a proposition has nothing to do with its credibility.  And<BR>\nvice versa.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The meek shall inherit the earth; the rest of us will go to the stars.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Base 8 is just like base 10, if you are missing two fingers.<BR>\n&nbsp;-- Tom Lehrer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The spirit of Plato dies hard.  We have been unable to escape the philosophical<BR>\ntradition that what we can see and measure in the world is merely the<BR>\nsuperficial and imperfect representation of an underlying reality.<BR>\n&nbsp;-- S.J. Gould, \"The Mismeasure of Man\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The only function of economic forecasting is to make astrology look respectable.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A method of solution is perfect if we can forsee from the start,<BR>\nand even prove, that following that method we shall attain our aim.<BR>\n&nbsp;-- Leibnitz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The ideas of economists and political philosophers, both when they<BR>\nare right and when they are wrong, are more powerful than is generally<BR>\nunderstood.  Indeed, the world is ruled by little else.<BR>\n&nbsp;-- John Maynard Keyes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','When you are about to do an objective and scientific piece of investigation<BR>\nof a topic, it is well to gave the answer firmly in hand, so that you can<BR>\nproceed forthrightly, without being deflected or swayed, directly to the goal.<BR>\n&nbsp;-- Amrom Katz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','According to convention there is a sweet and a bitter, a hot and a cold,<BR>\nand according to convention, there is an order.  In truth, there are atoms<BR>\nand a void.<BR>\n&nbsp;-- Democritus, 400 B.C.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','According to the latest official figures, 43% of all statistics are<BR>\ntotally worthless.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A transistor protected by a fast-acting fuse will protect the fuse by<BR>\nblowing first.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A social scientist, studying the culture and traditions of a small North<BR>\nAfrican tribe, found a woman still practicing the ancient art of matchmaking.<BR>\nLocally, she was known as the Moor, the marrier.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"When the going gets tough, the tough get empirical.\"<BR>\n&nbsp;-- Jon Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Where are the calculations that go with a calculated risk?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','After an instrument has been assembled, extra components will be found<BR>\non the bench.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','&nbsp;7,140	pounds on the Sun<BR>\n&nbsp;97	pounds on Mercury or Mars<BR>\n&nbsp;255	pounds on Earth<BR>\n&nbsp;232	pounds on Venus or Uranus<BR>\n&nbsp;43	pounds on the Moon<BR>\n&nbsp;648	pounds on Jupiter<BR>\n&nbsp;275	pounds on Saturn<BR>\n&nbsp;303	pounds on Neptune<BR>\n&nbsp;13	pounds on Pluto<BR>\n&nbsp;-- How much Elvis Presley would weigh at various places<BR>\n&nbsp;in the solar system.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A conference is a gathering of important people who singly can do nothing<BR>\nbut together can decide that nothing can be done.<BR>\n&nbsp;-- Fred Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A conclusion is simply the place where someone got tired of thinking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','(1) X=Y				; Given<BR>\n(2) X^2=XY			; Multiply both sides by X<BR>\n(3) X^2-Y^2=XY-Y^2		; Subtract Y^2 from both sides<BR>\n(4) (X+Y)(X-Y)=Y(X-Y)		; Factor<BR>\n(5) X+Y=Y			; Cancel out (X-Y) term<BR>\n(6) 2Y=Y			; Substitute X for Y, by equation 1<BR>\n(7) 2=1				; Divide both sides by Y<BR>\n&nbsp;-- \"Omni\", proof that 2 equals 1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An authority is a person who can tell you more about something than you<BR>\nreally care to know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','With every passing hour our solar system comes forty-three thousand<BR>\nmiles closer to globular cluster M13 in the constellation Hercules, and<BR>\nstill there are some misfits who continue to insist that there is no<BR>\nsuch thing as progress.<BR>\n&nbsp;-- Ransom K. Ferm');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Although the moon is smaller than the earth, it is farther away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What is research but a blind date with knowledge?<BR>\n&nbsp;-- Will Harvey');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Where it is a duty to worship the sun it is pretty sure to be a crime to<BR>\nexamine the laws of heat.<BR>\n&nbsp;-- Christopher Morley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A fail-safe circuit will destroy others.<BR>\n&nbsp;-- Klipstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What is wanted is not the will to believe, but the will to find out,<BR>\nwhich is the exact opposite.<BR>\n&nbsp;-- Bertrand Russell, \"Skeptical Essays\", 1928');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What the deuce is it to me?  You say that we go around the sun.  If we went<BR>\naround the moon it would not make a pennyworth of difference to me or my work.<BR>\n&nbsp;-- Sherlock Holmes, \"A Study in Scarlet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All laws are simulations of reality.<BR>\n&nbsp;-- John C. Lilly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','When speculation has done its worst, two plus two still equals four.<BR>\n&nbsp;-- S. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All life evolves by the differential survival of replicating entities.<BR>\n&nbsp;-- Dawkins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All great discoveries are made by mistake.<BR>\n&nbsp;-- Young');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All great ideas are controversial, or have been at one time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All power corrupts, but we need electricity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','(1) Alexander the Great was a great general.<BR>\n(2) Great generals are forewarned.<BR>\n(3) Forewarned is forearmed.<BR>\n(4) Four is an even number.<BR>\n(5) Four is certainly an odd number of arms for a man to have.<BR>\n(6) The only number that is both even and odd is infinity.<BR>\n&nbsp;Therefore, Alexander the Great had an infinite number of arms.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Albert Einstein, when asked to describe radio, replied: \"You see, wire<BR>\ntelegraph is a kind of a very, very long cat.  You pull his tail in New<BR>\nYork and his head is meowing in Los Angeles.  Do you understand this?<BR>\nAnd radio operates exactly the same way: you send signals here, they<BR>\nreceive them there.  The only difference is that there is no cat.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Air pollution is really making us pay through the nose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What is algebra, exactly?  Is it one of those three-cornered things?<BR>\n&nbsp;-- J.M. Barrie');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All theoretical chemistry is really physics; and all theoretical chemists <BR>\nknow it.<BR>\n&nbsp;-- Richard P. Feynman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We will have solar energy as soon as the utility companies solve one technical<BR>\nproblem -- how to run a sunbeam through a meter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What is mind?  No matter.  What is matter?  Never mind.<BR>\n&nbsp;-- Thomas Hewitt Key, 1799-1875');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Air is water with holes in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A failure will not appear until a unit has passed final inspection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','And the French medical anatomist Etienne Serres really did argue that<BR>\nblack males are primitive because the distance between their navel and<BR>\npenis remains small (relative to body height) throughout life, while<BR>\nwhite children begin with a small separation but increase it during<BR>\ngrowth -- the rising belly button as a mark of progress.<BR>\n&nbsp;-- S.J. Gould, \"Racism and Recapitulation\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','... we must be wary of granting too much power to natural selection<BR>\nby viewing all basic capacities of our brain as direct adaptations.<BR>\nI do not doubt that natural selection acted in building our oversized<BR>\nbrains -- and I am equally confident that our brains became large as<BR>\nan adaptation for definite roles (probably a complex set of interacting<BR>\nfunctions).  But these assumptions do not lead to the notion, often<BR>\nuncritically embraced by strict Darwinians, that all major capacities<BR>\nof the brain must arise as direct products of natural selection.<BR>\n&nbsp;-- S.J. Gould, \"The Mismeasure of Man\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','(1) Alexander the Great was a great general.<BR>\n(2) Great generals are forewarned.<BR>\n(3) Forewarned is forearmed.<BR>\n(4) Four is an even number.<BR>\n(5) Four is certainly an odd number of arms for a man to have.<BR>\n(6) The only number that is both even and odd is infinity.<BR>\n&nbsp;Therefore, all horses are black.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I would have you imagine, then, that there exists in the mind of man a block<BR>\nof wax...  and that we remember and know what is imprinted as long as the<BR>\nimage lasts; but when the image is effaced, or cannot be taken, then we<BR>\nforget or do not know.<BR>\n&nbsp;-- Plato, Dialogs, Theateus 191<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to image activation and termination.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Did you hear that two rabbits escaped from the zoo and so far they have<BR>\nonly recaptured 116 of them?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','1 + 1 = 3, for large values of 1.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','But you who live on dreams, you are better pleased with the sophistical<BR>\nreasoning and frauds of talkers about great and uncertain matters than<BR>\nthose who speak of certain and natural matters, not of such lofty nature.<BR>\n&nbsp;-- Leonardo Da Vinci, \"The Codex on the Flight of Birds\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','13. ...  r-q1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An egghead is one who stands firmly on both feet, in mid-air, on both<BR>\nsides of an issue.<BR>\n&nbsp;-- Homer Ferguson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We can predict everything, except the future.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The difference between science and the fuzzy subjects is that science<BR>\nrequires reasoning while those other subjects merely require scholarship.<BR>\n&nbsp;-- Robert Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Chemist who falls in acid will be tripping for weeks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','You cannot have a science without measurement.<BR>\n&nbsp;-- R. W. Hamming');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Without life, Biology itself would be impossible.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Any circuit design must contain at least one part which is obsolete, two parts<BR>\nwhich are unobtainable, and three parts which are still under development.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','You are a taxi driver.  Your cab is yellow and black, and has been in<BR>\nuse for only seven years.  One of its windshield wipers is broken, and<BR>\nthe carburetor needs adjusting.  The tank holds 20 gallons, but at the<BR>\nmoment is only three-quarters full.  How old is the taxi driver?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','(1)	A sheet of paper is an ink-lined plane.<BR>\n(2)	An inclined plane is a slope up.<BR>\n(3)	A slow pup is a lazy dog.<BR>\n&nbsp;QED: A sheet of paper is a lazy dog.<BR>\n&nbsp;-- Willard Espy, \"An Almanac of Words at Play\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','White dwarf seeks red giant for binary relationship.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','When the Universe was not so out of whack as it is today, and all the<BR>\nstars were lined up in their proper places, you could easily count them<BR>\nfrom left to right, or top to bottom, and the larger and bluer ones were<BR>\nset apart, and the smaller yellowing types pushed off to the corners as<BR>\nbodies of a lower grade ...<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Gravity brings me down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It seems intuitively obvious to me, which means that it might be wrong.<BR>\n&nbsp;-- Chris Torek');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is now quite lawful for a Catholic woman to avoid pregnancy by a resort to<BR>\nmathematics, though she is still forbidden to resort to physics and chemistry.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Great spirits have always encountered violent opposition from mediocre minds.<BR>\n&nbsp;-- Albert Einstein<BR>\n&nbsp;They laughed at Einstein.  They laughed at the Wright Brothers.  But they<BR>\nalso laughed at Bozo the Clown.<BR>\n&nbsp;-- Carl Sagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','GREAT MOMENTS IN HISTORY (#7):  April 2, 1751<BR>\n&nbsp;Issac Newton becomes discouraged when he falls up a flight of stairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is much easier to suggest solutions when you know nothing about the problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I use technology in order to hate it more properly.<BR>\n&nbsp;-- Nam June Paik');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is not every question that deserves an answer.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It seems that more and more mathematicians are using a new, high level<BR>\nlanguage named \"research student\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','For every complex problem, there is a solution that is simple, neat, and wrong.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In these matters the only certainty is that there is nothing certain.<BR>\n&nbsp;-- Pliny the Elder');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What the world *really* needs is a good Automatic Bicycle Sharpener.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Experiments must be reproducible; they should all fail in the same way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I am not an Economist.  I am an honest man!<BR>\n&nbsp;-- Paul McCracken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I cannot believe that God plays dice with the cosmos.<BR>\n&nbsp;-- Albert Einstein, on the randomness of quantum mechanics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Enzymes are things invented by biologists that explain things which<BR>\notherwise require harder thinking.<BR>\n&nbsp;-- Jerome Lettvin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Extraordinary claims demand extraordinary proof.  There are many examples<BR>\nof outsiders who eventually overthrew entrenched scientific orthodoxies,<BR>\nbut they prevailed with irrefutable data.  More often, egregious findings<BR>\nthat contradict well-established research turn out to be artifacts.  I have<BR>\nargued that accepting psychic powers, reincarnation, \"cosmic conciousness,\"<BR>\nand the like, would entail fundamental revisions of the foundations of<BR>\nneuroscience.  Before abandoning materialist theories of mind that have paid<BR>\nhandsome dividends, we should insist on better evidence for psi phenomena<BR>\nthan presently exists, especially when neurology and psychology themselves<BR>\noffer more plausible alternatives.<BR>\n&nbsp;-- Barry L. Beyerstein, \"The Brain and Conciousness:<BR>\n&nbsp;Implications for Psi Phenomena\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Any sufficiently advanced technology is indistinguishable from magic.<BR>\n&nbsp;-- Arthur C. Clarke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','(1) Never draw what you can copy.<BR>\n(2) Never copy what you can trace.<BR>\n(3) Never trace what you can cut out and paste down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Economists state their GNP growth projections to the nearest tenth of a<BR>\npercentage point to prove they have a sense of humor.<BR>\n&nbsp;-- Edgar R. Fiedler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Electricity is actually made up of extremely tiny particles, called<BR>\nelectrons, that you cannot see with the naked eye unless you have been<BR>\ndrinking.  Electrons travel at the speed of light, which in most American<BR>\nhomes is 110 volts per hour.  This is very fast.  In the time it has taken<BR>\nyou to read this sentence so far, an electron could have traveled all the<BR>\nway from San Francisco to Hackensack, New Jersey, although God alone knows<BR>\nwhy it would want to.<BR>\n&nbsp;The five main kinds of electricity are alternating current, direct current,<BR>\nlightning, static, and European.  Most American homes have alternating<BR>\ncurrent, which means that the electricity goes in one direction for a while,<BR>\nthen goes in the other direction.  This prevents harmful electron buildup in<BR>\nthe wires.<BR>\n&nbsp;-- Dave Barry, \"The Taming of the Screw\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If scientific reasoning were limited to the logical processes of<BR>\narithmetic, we should not get very far in our understanding of the physical<BR>\nworld.  One might as well attempt to grasp the game of poker entirely by<BR>\nthe use of the mathematics of probability.<BR>\n&nbsp;-- Vannevar Bush');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','You will never amount to much.<BR>\n&nbsp;-- Munich Schoolmaster, to Albert Einstein, age 10');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','No amount of careful planning will ever replace dumb luck.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nondeterminism means never having to say you are wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nature is by and large to be found out of doors, a location where,<BR>\nit cannot be argued, there are never enough comfortable chairs.<BR>\n&nbsp;-- Fran Lebowitz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Logic is the chastity belt of the mind!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','You should never bet against anything in science at odds of more than<BR>\nabout 10^12 to 1.<BR>\n&nbsp;-- Ernest Rutherford');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An anthropologist at Tulane has just come back from a field trip to New<BR>\nGuinea with reports of a tribe so primitive that they have Tide but not<BR>\nnew Tide with lemon-fresh Borax.<BR>\n&nbsp;-- David Letterman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If all else fails, immortality can always be assured by spectacular error.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Anyone who imagines that all fruits ripen at the same time<BR>\nas the strawberries, knows nothing about grapes.<BR>\n&nbsp;-- Philippus Paracelsus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If mathematically you end up with the wrong answer, try multiplying by<BR>\nthe page number.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nothing is faster than the speed of light ...<BR>\n&nbsp;To prove this to yourself, try opening the refrigerator door before the<BR>\nlight comes on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Modern psychology takes completely for granted that behavior and neural<BR>\nfunction are perfectly correlated, that one is completely caused by the<BR>\nother.  There is no separate soul or lifeforce to stick a finger into the<BR>\nbrain now and then and make neural cells do what they would not otherwise.<BR>\nActually, of course, this is a working assumption only. ... It is quite<BR>\nconceivable that someday the assumption will have to be rejected.  But it<BR>\nis important also to see that we have not reached that day yet: the working<BR>\nassumption is a necessary one and there is no real evidence opposed to it.<BR>\nOur failure to solve a problem so far does not make it insoluble.  One cannot<BR>\nlogically be a determinist in physics and biology, and a mystic in psychology.<BR>\n&nbsp;-- D.O. Hebb, \"Organization of Behavior: A Neuropsychological<BR>\n&nbsp;Theory\", 1949');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Alexander Graham Bell is alive and well in New York, and still waiting<BR>\nfor a dial tone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','All seems condemned in the long run to approximate a state akin to<BR>\nGaussian noise.<BR>\n&nbsp;-- James Martin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Wernher von Braun settled for a V-2 when he coulda had a V-8.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Matter will be damaged in direct proportion to its value.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematics is the only science where one never knows what <BR>\none is talking about nor whether what is said is true.<BR>\n&nbsp;-- Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematics, rightly viewed, possesses not only truth but supreme beauty --<BR>\na beauty cold and austere, like that of a sculpture, without appeal to any<BR>\npart of our weaker nature, without the gorgeous trapping of painting or music,<BR>\nyet sublimely pure, and capable of a stern perfection such as only the<BR>\ngreatest art can show.  The true spirit of delight, the exaltation, the sense<BR>\nof being more than man, which is the touchstone of the highest excellence, is<BR>\nto be found in mathematics as surely as in poetry.<BR>\n&nbsp;-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"355/113 -- Not the famous irrational number PI, but an incredible simulation!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematicians are like Frenchmen:  whatever you say to them they translate<BR>\ninto their own language and forthwith it is something entirely different.<BR>\n&nbsp;-- Johann Wolfgang von Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematicians often resort to something called Hilbert space, which is<BR>\ndescribed as being n-dimensional.  Like modern sex, any number can play.<BR>\n&nbsp;-- Dr. Thor Wald, \"Beep/The Quincunx of Time\", by James Blish');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We gave you an atomic bomb, what do you want, mermaids?<BR>\n&nbsp;-- I. I. Rabi to the Atomic Energy Commission');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','&nbsp;ACHTUNG!!!<BR>\n&nbsp;Das machine is nicht fur gefingerpoken und mittengrabben.  Ist easy schnappen<BR>\nder springenwerk, blowenfusen und corkenpoppen mit spitzensparken.  Ist nicht<BR>\nfur gewerken by das dummkopfen.  Das rubbernecken sightseeren keepen hands<BR>\nin das pockets.  Relaxen und vatch das blinkenlights!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Logic is a little bird, sitting in a tree; that smells *_____awful*.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Xerox does it again and again and again and ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Anyone who cannot cope with mathematics is not fully human.  At best he<BR>\nis a tolerable subhuman who has learned to wear shoes, bathe and not<BR>\nmake messes in the house.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We are sorry.  We cannot complete your call as dialed.  Please check<BR>\nthe number and dial again or ask your operator for assistance.<BR>\n&nbsp;This is a recording.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Xerox never comes up with anything original.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Any sufficiently advanced technology is indistinguishable from a rigged demo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An age is called Dark not because the light fails to shine, but because<BR>\npeople refuse to see it.<BR>\n&nbsp;-- James Michener, \"Space\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','You can not get anything worthwhile done without raising a sweat.<BR>\n&nbsp;-- The First Law Of Thermodynamics<BR>\n&nbsp;What ever you want is going to cost a little more than it is worth.<BR>\n&nbsp;-- The Second Law Of Thermodynamics<BR>\n&nbsp;You can not win the game, and you are not allowed to stop playing.<BR>\n&nbsp;-- The Third Law Of Thermodynamics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','When the weight of the paperwork equals the weight of the plane, the<BR>\nplane will fly.<BR>\n&nbsp;-- Donald Douglas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A statistician, who refused to fly after reading of the alarmingly high<BR>\nprobability that there will be a bomb on any given plane, realized that<BR>\nthe probability of there being two bombs on any given flight is very low.<BR>\nNow, whenever he flies, he carries a bomb with him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In the beginning there was nothing.  And the Lord said \"Let There Be Light!\"<BR>\nAnd still there was nothing, but at least now you could see it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"In short, _N is Richardian if, and only if, _N is not Richardian.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','IN MY OPINION anyone interested in improving himself should not rule out<BR>\nbecoming pure energy.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A triangle which has an angle of 135 degrees is called an obscene triangle.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In Nature there are neither rewards nor punishments, there are consequences.<BR>\n&nbsp;-- R.G. Ingersoll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In 1869 the waffle iron was invented for people who had wrinkled waffles.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','... though his invention worked superbly -- his theory was a crock of sewage<BR>\nfrom beginning to end.<BR>\n&nbsp;-- Vernor Vinge, \"The Peace War\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Life is a whim of several billion cells to be you for a while.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Between infinite and short there is a big difference.<BR>\n&nbsp;-- G.H. Gonnet');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Two is not equal to three, even for large values of two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We can defeat gravity.  The problem is the paperwork involved.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','At the heart of science is an essential tension between two seemingly<BR>\ncontradictory attitudes -- an openness to new ideas, no matter how bizarre<BR>\nor counterintuitive they may be, and the most ruthless skeptical scrutiny<BR>\nof all ideas, old and new.  This is how deep truths are winnowed from deep<BR>\nnonsense.  Of course, scientists make mistakes in trying to understand the<BR>\nworld, but there is a built-in error-correcting mechanism:  The collective<BR>\nenterprise of creative thinking and skeptical thinking together keeps the<BR>\nfield on track.<BR>\n&nbsp;-- Carl Sagan, \"The Fine Art of Baloney Detection\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Torque is cheap.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','A sine curve goes off to infinity, or at least the end of the blackboard.<BR>\n&nbsp;-- Prof. Steiner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An engineer, a physicist and a mathematician find themselves in an<BR>\nanecdote, indeed an anecdote quite similar to many that you have no doubt<BR>\nalready heard.  After some observations and rough calculations the<BR>\nengineer realizes the situation and starts laughing.  A few minutes later<BR>\nthe physicist understands too and chuckles to himself happily as he now<BR>\nhas enough experimental evidence to publish a paper.  This leaves the<BR>\nmathematician somewhat perplexed, as he had observed right away that he<BR>\nwas the subject of an anecdote, and deduced quite rapidly the presence of<BR>\nhumour from similar anecdotes, but considers this anecdote to be too<BR>\ntrivial a corollary to be significant, let alone funny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','After a number of decimal places, nobody gives a damn.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','This is clearly another case of too many mad scientists, and not enough<BR>\nhunchbacks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Algebraic symbols are used when you do not know what you are talking about.<BR>\n&nbsp;-- Philippe Schnoebelen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We must believe that it is the darkest before the dawn of a beautiful<BR>\nnew world.  We will see it when we believe it.<BR>\n&nbsp;-- Saul Alinsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Thus mathematics may be defined as the subject in which we never know<BR>\nwhat we are talking about, nor whether what we are saying is true.<BR>\n&nbsp;-- Bertrand Russell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Lawrence Radiation Laboratory keeps all its data in an old gray trunk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','This is the theory that Jack built.<BR>\nThis is the flaw that lay in the theory that Jack built.<BR>\nThis is the palpable verbal haze that hid the flaw that lay in...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','To converse at the distance of the Indes by means of sympathetic contrivances<BR>\nmay be as natural to future times as to us is a literary correspondence.<BR>\n&nbsp;-- Joseph Glanvill, 1661');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Life is a biochemical reaction to the stimulus of the surrounding<BR>\nenvironment in a stable ecosphere, while a bowl of cherries is a<BR>\nround container filled with little red fruits on sticks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Understanding is always the understanding of a smaller problem<BR>\nin relation to a bigger problem.<BR>\n&nbsp;-- P.D. Ouspensky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Two percent of zero is almost nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Chemist who falls in acid is absorbed in work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','&nbsp;In the beginning there was only one kind of Mathematician, created by<BR>\nthe Great Mathamatical Spirit form the Book: the Topologist.  And they grew to<BR>\nlarge numbers and prospered.<BR>\n&nbsp;One day they looked up in the heavens and desired to reach up as far<BR>\nas the eye could see.  So they set out in building a Mathematical edifice that<BR>\nwas to reach up as far as \"up\" went.  Further and further up they went ...<BR>\nuntil one night the edifice collapsed under the weight of paradox.<BR>\n&nbsp;The following morning saw only rubble where there once was a huge<BR>\nstructure reaching to the heavens.  One by one, the Mathematicians climbed<BR>\nout from under the rubble.  It was a miracle that nobody was killed; but when<BR>\nthey began to speak to one another, SUPRISE of all suprises! they could not<BR>\nunderstand each other.  They all spoke different languages.  They all fought<BR>\namongst themselves and each went about their own way.  To this day the<BR>\nTopologists remain the original Mathematicians.<BR>\n&nbsp;-- The Story of Babel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We warn the reader in advance that the proof presented here depends on a<BR>\nclever but highly unmotivated trick.<BR>\n&nbsp;-- Howard Anton, \"Elementary Linear Algebra\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','What the scientists have in their briefcases is terrifying.<BR>\n&nbsp;-- Nikita Khruschev');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In theory, there is no difference between theory and practice.  In practice,<BR>\nthere is.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Arithmetic is being able to count up to twenty without taking off your shoes.<BR>\n&nbsp;-- Mickey Mouse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','This is not the age of pamphleteers. It is the age of the engineers.  The<BR>\nspark-gap is mightier than the pen.  Democracy will not be salvaged by men<BR>\nwho talk fluently, debate forcefully and quote aptly.<BR>\n&nbsp;-- Lancelot Hogben, Science for the Citizen, 1938');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There are no data that cannot be plotted on a straight line if the axis<BR>\nare chosen correctly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There can be no twisted thought without a twisted molecule.<BR>\n&nbsp;-- R. W. Gerard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is a building with four floors.  On the first floor, there<BR>\nis a convention of architects.  On the second floor, there is a<BR>\nvinyl manufacturing plant.  On the third floor there is a fast food<BR>\nstand, and on the fourth floor there is a library.<BR>\n&nbsp;Q:	What would happen if a librarian traveled down in a small<BR>\n&nbsp;elevator with one other person from each floor?<BR>\nA:	The elevator would be full.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The University of California Statistics Department; where mean is normal,<BR>\nand deviation standard.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is grandeur in this view of life, with its several powers, having been<BR>\noriginally breathed into a few forms or into one; and that, whilst this planet<BR>\nhas gone cycling on according to the fixed law of gravity, from so simple a<BR>\nbeginning endless forms most beautiful and most wonderful have been, and are<BR>\nbeing, evolved.<BR>\n&nbsp;-- Darwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Theory is gray, but the golden tree of life is green.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There *__is* no such thing as a civil engineer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Imagination is more important than knowledge.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In a minimum-phase system there is an inextricable link between<BR>\nfrequency response, phase response and transient response, as they<BR>\nare all merely transforms of one another.  This combined with<BR>\nminimalization of open-loop errors in output amplifiers and correct<BR>\ncompensation for non-linear passive crossover network loading can<BR>\nlead to a significant decrease in system resolution lost.  However,<BR>\nthis all means jack when you listen to Pink Floyd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is no royal road to geometry.<BR>\n&nbsp;-- Euclid');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The unfacts, did we have them, are too imprecisely few to warrant our certitude.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There is no likelihood man can ever tap the power of the atom.<BR>\n&nbsp;-- Robert Millikan, Nobel Prize in Physics, 1923');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe does not have laws -- it has habits, and habits can be broken.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Utility is when you have one telephone, luxury is when you have two,<BR>\nopulence is when you have three -- and paradise is when you have none.<BR>\n&nbsp;-- Doug Larson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','There was an old Indian belief that by making love on the hide of<BR>\ntheir favorite animal, one could guarantee the health and prosperity<BR>\nof the offspring conceived thereupon.  And so it goes that one Indian<BR>\ncouple made love on a buffalo  hide.  Nine months later, they were<BR>\nblessed with a healthy baby son.  Yet another couple huddled together<BR>\non the hide of a deer and they too were blessed with a very healthy<BR>\nbaby son.  But a third couple, whose favorite animal was a hippopotamus,<BR>\nwere blessed with not one, but TWO very healthy baby sons at the conclusion<BR>\nof the nine month interval.  All of which proves the old theorem that:<BR>\nThe sons of the squaw of the hippopotamus are equal to the sons of<BR>\nthe squaws of the other two hides.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','An economist is a man who would marry Farrah Fawcett-Majors for her money.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Anything cut to length will be too short.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','In 1750 Issac Newton became discouraged when he fell up a flight of stairs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The two most common things in the Universe are hydrogen and stupidity.<BR>\n&nbsp;-- Harlan Ellison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If A = B and B = C, then A = C, except where void or prohibited by law.<BR>\n&nbsp;-- Roy Santoro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nature, to be commanded, must be obeyed.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If an experiment works, something has gone wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nature always sides with the hidden flaw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nature abhors a hero.  For one thing, he violates the law of conservation<BR>\nof energy.  For another, how can it be the survival of the fittest when the<BR>\nfittest keeps putting himself in situations where he is most likely to be<BR>\ncreamed?<BR>\n&nbsp;-- Solomon Short');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The tree of research must from time to time be refreshed with the blood<BR>\nof bean counters.<BR>\n&nbsp;-- Alan Kay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Neutrinos are into physicists.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If I had only known, I would have been a locksmith.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If for every rule there is an exception, then we have established that there<BR>\nis an exception to every rule.  If we accept \"For every rule there is an<BR>\nexception\" as a rule, then we must concede that there may not be an exception<BR>\nafter all, since the rule states that there is always the possibility of<BR>\nexception, and if we follow it to its logical end we must agree that there<BR>\ncan be an exception to the rule that for every rule there is an exception.<BR>\n&nbsp;-- Bill Boquist');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If God is perfect, why did He create discontinuous functions?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If it is a Miracle, any sort of evidence will answer, but if it is a Fact,<BR>\nproof is necessary.<BR>\n&nbsp;-- Samuel Clemens');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The temperature of Heaven can be rather accurately computed from available<BR>\ndata.  Our authority is Isaiah 30:26, \"Moreover, the light of the Moon<BR>\nshall be as the light of the Sun and the light of the Sun shall be sevenfold,<BR>\nas the light of seven days.\"  Thus Heaven receives from the Moon as much<BR>\nradiation as we do from the Sun, and in addition seven times seven (49) times<BR>\nas much as the Earth does from the Sun, or fifty times in all.  The light we<BR>\nreceive from the Moon is one ten-thousandth of the light we receive from the<BR>\nSun, so we can ignore that.  With these data we can compute the temperature<BR>\nof Heaven.  The radiation falling on Heaven will heat it to the point where<BR>\nthe heat lost by radiation is just equal to the heat received by radiation,<BR>\ni.e., Heaven loses fifty times as much heat as the Earth by radiation.  Using<BR>\nthe Stefan-Boltzmann law for radiation, (H/E)^4 = 50, where E is the absolute<BR>\ntemperature of the earth (-300K), gives H as 798K (525C).  The exact<BR>\ntemperature of Hell cannot be computed, but it must be less than 444.6C, the<BR>\ntemperature at which brimstone or sulphur changes from a liquid to a gas.<BR>\nRevelations 21:8 says \"But the fearful, and unbelieving ... shall have their<BR>\npart in the lake which burneth with fire and brimstone.\"  A lake of molten<BR>\nbrimstone means that its temperature must be at or below the boiling point,<BR>\nor 444.6C  (Above this point it would be a vapor, not a lake.)  We have,<BR>\nthen, that Heaven, at 525C is hotter than Hell at 445C.<BR>\n&nbsp;-- \"Applied Optics\", vol. 11, A14, 1972');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The test of intelligent tinkering is to save all the parts.<BR>\n&nbsp;-- Aldo Leopold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If in any problem you find yourself doing an immense amount of work, the<BR>\nanswer can be obtained by simple inspection.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe is an island, surrounded by whatever it is that surrounds<BR>\nuniverses.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"In order to make an apple pie from scratch, you must first create the<BR>\nuniverse.\"<BR>\n&nbsp;-- Carl Sagan, Cosmos');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The sum of the Universe is zero.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The study of non-linear physics is like the study of non-elephant biology.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"There are three principal ways to lose money: wine, women, and engineers.<BR>\nWhile the first two are more pleasant, the third is by far the more certain.\"<BR>\n&nbsp;-- Baron Rothschild, ca. 1800');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe is like a safe to which there is a combination -- but the<BR>\ncombination is locked up in the safe.<BR>\n&nbsp;-- Peter DeVries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If the aborigine drafted an IQ test, all of Western civilization would<BR>\npresumably flunk it.<BR>\n&nbsp;-- Stanley Garn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Things equal to nothing else are equal to each other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Solutions are obvious if one only has the optical power to observe them<BR>\nover the horizon.<BR>\n&nbsp;-- K.A. Arsdall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Pie are not square.  Pie are round.  Cornbread are square.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The function of the expert is not to be more right than other people,<BR>\nbut to be wrong for more sophisticated reasons.<BR>\n&nbsp;-- Dr. David Butler, British psephologist');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The explanation requiring the fewest assumptions is the most likely to be<BR>\ncorrect.<BR>\n&nbsp;-- William of Occam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It has just been discovered that research causes cancer in rats.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is not for me to attempt to fathom the inscrutable workings of Providence.<BR>\n&nbsp;-- The Earl of Birkenhead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Parallel lines never meet, unless you bend one or both of them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Only God can make random selections.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Ontogeny recapitulates phylogeny.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Organic chemistry is the chemistry of carbon compounds.  Biochemistry<BR>\nis the study of carbon compounds that crawl.<BR>\n&nbsp;-- Mike Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Our vision is to speed up time, eventually eliminating it.\"<BR>\n&nbsp;-- Alex Schure');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Oxygen is a very toxic gas and an extreme fire hazard.  It is fatal in<BR>\nconcentrations of as little as 0.000001 p.p.m.  Humans exposed to the<BR>\noxygen concentrations die within a few minutes.  Symptoms resemble very<BR>\nmuch those of cyanide poisoning (blue face, etc.).  In higher<BR>\nconcentrations, e.g. 20%, the toxic effect is somewhat delayed and it<BR>\ntakes about 2.5 billion inhalations before death takes place.  The reason<BR>\nfor the delay is the difference in the mechanism of the toxic effect of<BR>\noxygen in 20% concentration.  It apparently contributes to a complex<BR>\nprocess called aging, of which very little is known, except that it is<BR>\nalways fatal.<BR>\n&nbsp;However, the main disadvantage of the 20% oxygen concentration is in the<BR>\nfact it is habit forming.  The first inhalation (occurring at birth) is<BR>\nsufficient to make oxygen addiction permanent.  After that, any<BR>\nconsiderable decrease in the daily oxygen doses results in death with<BR>\nsymptoms resembling those of cyanide poisoning.<BR>\n&nbsp;Oxygen is an extreme fire hazard.  All of the fires that were reported in<BR>\nthe continental U.S. for the period of the past 25 years were found to be<BR>\ndue to the presence of this gas in the atmosphere surrounding the buildings<BR>\nin question.<BR>\n&nbsp;Oxygen is especially dangerous because it is odorless, colorless and<BR>\ntasteless, so that its presence can not be readily detected until it is<BR>\ntoo late.<BR>\n&nbsp;-- Chemical & Engineering News February 6, 1956');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Order and simplification are the first steps toward mastery of a subject<BR>\n-- the actual enemy is the unknown.<BR>\n&nbsp;-- Thomas Mann');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The herd instinct among economists makes sheep look like independent thinkers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One Bell System - it sometimes works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One has to look out for engineers -- they begin with sewing machines<BR>\nand end up with the atomic bomb.<BR>\n&nbsp;-- Marcel Pagnol');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Optimization hinders evolution.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is not that polar co-ordinates are complicated, it is simply<BR>\nthat cartesian co-ordinates are simpler than they have a right to be.<BR>\n&nbsp;-- Kleppner & Kolenhow, \"An Introduction to Mechanics\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One Bell System - it works.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Polymer physicists are into chains.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Round Numbers are always false.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','So as your consumer electronics adviser, I am advising you to donate your<BR>\ncurrent VCR to a grate resident, who will laugh sardonically and hurl it<BR>\ninto a dumpster.  Then I want you to go out and purchase a vast array of<BR>\n8-millimeter video equipment.<BR>\n&nbsp;... OK!  Got everything?  Well, *too bad, sucker*, because while you were<BR>\ngone the electronics industry came up with an even newer format that makes<BR>\nyour 8-millimeter VCR look as technologically advanced as toenail dirt.<BR>\nThis format is called \"3.5 hectare\" and it will not be made available until<BR>\nit is outmoded, sometime early next week, by a format called \"Elroy\", so<BR>\n*order yours now*.<BR>\n&nbsp;-- Dave Barry, \"No Surrender in the Electronics Revolution\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Celestial navigation is based on the premise that the Earth is the center<BR>\nof the universe.  The premise is wrong, but the navigation works.  An<BR>\nincorrect model can be a useful tool.<BR>\n&nbsp;-- Kelvin Throop III');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Actually, the probability is 100% that the elevator will be going in the<BR>\nright direction.  Proof by induction:<BR>\n&nbsp;N=1.	Trivially true, since both you and the elevator only have one<BR>\n&nbsp;floor to go to.<BR>\n&nbsp;Assume true for N, prove for N+1:<BR>\n&nbsp;If you are on any of the first N floors, then it is true by the<BR>\n&nbsp;induction hypothesis.  If you are on the N+1st floor, then both you<BR>\n&nbsp;and the elevator have only one choice, namely down.  Therefore,<BR>\n&nbsp;it is true for all N+1 floors.<BR>\nQED.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Remember Darwin; building a better mousetrap merely results in smarter mice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Research is to see what everybody else has seen, and think what nobody<BR>\nelse has thought.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','... proper attention to Earthly needs of the poor, the depressed and the<BR>\ndowntrodden, would naturally evolve from dynamic, articulate, spirited<BR>\nawareness of the great goals for Man and the society he conspired to erect.<BR>\n&nbsp;-- David Baker, paraphrasing Harold Urey, in<BR>\n&nbsp;\"The History of Manned Space Flight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The energy produced by the breaking down of the atom is a very poor kind<BR>\nof thing.  Anyone who expects a source of power from the transformation<BR>\nof these atoms is talking moonshine.<BR>\n&nbsp;-- Ernest Rutherford, after he had split the atom for<BR>\n&nbsp;the first time');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The generation of random numbers is too important to be left to chance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One of the chief duties of the mathematician in acting as an advisor...<BR>\nis to discourage... from expecting too much from mathematics.<BR>\n&nbsp;-- N. Wiener');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Quark!  Quark!  Beware the quantum duck!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The startling truth finally became apparent, and it was this: Numbers<BR>\nwritten on restaurant checks within the confines of restaurants do not<BR>\nfollow the same mathematical laws as numbers written on any other pieces<BR>\nof paper in any other parts of the Universe.  This single statement took<BR>\nthe scientific world by storm.  So many mathematical conferences got held<BR>\nin such good restaurants that many of the finest minds of a generation<BR>\ndied of obesity and heart failure, and the science of mathematics was put<BR>\nback by years.<BR>\n&nbsp;-- Douglas Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"If value corrupts then absolute value corrupts absolutely.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The Universe is populated by stable things.<BR>\n&nbsp;-- Richard Dawkins');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If you analyse anything, you destroy it.<BR>\n&nbsp;-- Arthur Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe seems neither benign nor hostile, merely indifferent.<BR>\n&nbsp;-- Sagan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The universe, they said, depended for its operation on the balance of four<BR>\nforces which they identified as charm, persuasion, uncertainty and<BR>\nbloody-mindedness.<BR>\n&nbsp;-- Terry Pratchett, \"The Light Fantastic\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I have hardly ever known a mathematician who was capable of reasoning.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Measure with a micrometer.  Mark with chalk.  Cut with an axe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The solution of this problem is trivial and is left as an exercise for<BR>\nthe reader.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Make it right before you make it faster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I THINK MAN INVENTED THE CAR by instinct.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The solution to a problem changes the nature of the problem.<BR>\n&nbsp;-- Peer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I tell them to turn to the study of mathematics, for it is only there that<BR>\nthey might escape the lusts of the flesh.<BR>\n&nbsp;-- Thomas Mann, \"The Magic Mountain\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mediocrity finds safety in standardization.<BR>\n&nbsp;-- Frederick Crane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Man will never fly.  Space travel is merely a dream.  All aspirin is alike.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I put up my thumb... and it blotted out the planet Earth.<BR>\n&nbsp;-- Neil Armstrong');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The solution of problems is the most characteristic and peculiar sort<BR>\nof voluntary thinking.<BR>\n&nbsp;-- William James');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','No amount of genius can overcome a preoccupation with detail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nonsense.  Space is blue and birds fly through it.<BR>\n&nbsp;-- Heisenberg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Nothing is rich but the inexhaustible wealth of nature.<BR>\nShe shows us only surfaces, but she is a million fathoms deep.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If entropy is increasing, where is it coming from?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','God made the integers; all else is the work of Man.<BR>\n&nbsp;-- Kronecker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Heavier than air flying machines are impossible.<BR>\n&nbsp;-- Lord Kelvin, President, Royal Society, c. 1895');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Heisenberg may have been here.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Heisenberg may have slept here...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Help fight continental drift.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The Shuttle is now going five times the sound of speed.<BR>\n&nbsp;-- Dan Rather, first landing of Columbia');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Math is like love -- a simple idea but it can get complicated.<BR>\n&nbsp;-- R. Drabek');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Hi! How are things going?<BR>\n&nbsp;(just fine, thank you...)<BR>\nGreat! Say, could I bother you for a question?<BR>\n&nbsp;(you just asked one...)<BR>\nWell, how about one more?<BR>\n&nbsp;(one more than the first one?)<BR>\nYes.<BR>\n&nbsp;(you already asked that...)<BR>\n[at this point, Alphonso gets smart...	]<BR>\nMay I ask two questions, sir?<BR>\n&nbsp;(no.)<BR>\nMay I ask ONE then?<BR>\n&nbsp;(nope...)<BR>\nThen may I ask, sir, how I may ask you a question?<BR>\n&nbsp;(yes, you may.)<BR>\nSir, how may I ask you a question?<BR>\n&nbsp;(you must ask for retroactive question asking privileges for<BR>\n&nbsp;the number of questions you have asked, then ask for that<BR>\n&nbsp;number plus two, one for the current question, and one for the<BR>\n&nbsp;next one)<BR>\nSir, may I ask nine questions?<BR>\n&nbsp;(go right ahead...)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematicians practice absolute freedom.<BR>\n&nbsp;-- Henry Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The rate at which a disease spreads through a corn field is a precise<BR>\nmeasurement of the speed of blight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','How often I found where I should be going only by setting out for somewhere<BR>\nelse.<BR>\n&nbsp;-- R. Buckminster Fuller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Mathematics deals exclusively with the relations of concepts<BR>\nto each other without consideration of their relation to experience.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Houston, Tranquillity Base here.  The Eagle has landed.<BR>\n&nbsp;-- Neil Armstrong');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','How many weeks are there in a light year?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Men occasionally stumble over the truth, but most of them pick themselves<BR>\nup and hurry off as if nothing had happened.<BR>\n&nbsp;-- Winston Churchill');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Measure twice, cut once.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','&nbsp;\"I have examined Bogota,\" he said, \"and the case is clearer to me.<BR>\nI think very probably he might be cured.\"<BR>\n&nbsp;\"That is what I have always hoped,\" said old Yacob.<BR>\n&nbsp;\"His brain is affected,\" said the blind doctor.<BR>\n&nbsp;The elders murmured assent.<BR>\n&nbsp;\"Now, what affects it?\"<BR>\n&nbsp;\"Ah!\" said old Yacob.<BR>\n&nbsp;\"This,\" said the doctor, answering his own question.  \"Those queer<BR>\nthings that are called the eyes, and which exist to make an agreeable soft<BR>\ndepression in the face, are diseased, in the case of Bogota, in such a way<BR>\nas to affect his brain.  They are greatly distended, he has eyelashes, and<BR>\nhis eyelids move, and cosequently his brain is in a state of constant<BR>\nirritation and distraction.\"<BR>\n&nbsp;\"Yes?\" said old Yacob.  \"Yes?\"<BR>\n&nbsp;\"And I think I may say with reasonable certainty that, in order<BR>\nto cure him completely, all that we need do is a simple and easy surgical<BR>\noperation -- namely, to remove those irritant bodies.\"<BR>\n&nbsp;\"And then he will be sane?\"<BR>\n&nbsp;\"Then he will be perfectly sane, and a quite admirable citizen.\"<BR>\n&nbsp;\"Thank heaven for science!\" said old Yacob.<BR>\n&nbsp;-- H.G. Wells, \"The Country of the Blind\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I THINK THEY SHOULD CONTINUE the policy of not giving a Nobel Prize for<BR>\npaneling.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Matter cannot be created or destroyed, nor can it be returned without a receipt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','He keeps differentiating, flying off on a tangent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Men love to wonder, and that is the seed of science.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I have yet to see any problem, however complicated, which, when<BR>\nyou looked at it in the right way, did not become still more complicated.<BR>\n&nbsp;-- Poul Anderson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The only perfect science is hind-sight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The moon is a planet just like the Earth, only it is even deader.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The society which scorns excellence in plumbing as a humble activity and<BR>\ntolerates shoddiness in philosophy because it is an exalted activity will<BR>\nhave neither good plumbing nor good philosophy... neither its pipes nor<BR>\nits theories will hold water.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Federal grants are offered for... research into the recreation<BR>\npotential of interplanetary space travel for the culturally disadvantaged.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The perversity of nature is nowhere better demonstrated by the fact that, when<BR>\nexposed to the same atmosphere, bread becomes hard while crackers become soft.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The most advantageous, pre-eminent thing thou canst do is not to exhibit<BR>\nnor display thyself within the limits of our galaxy, but rather depart<BR>\ninstantaneously whence thou even now standest and flee to yet another rotten<BR>\nplanet in the universe, if thou canst have the good fortune to find one.<BR>\n&nbsp;-- Carlyle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The only person who always got his work done by Friday was Robinson Crusoe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The opposite of a correct statement is a false statement. But the opposite<BR>\nof a profound truth may well be another profound truth.<BR>\n&nbsp;-- Niels Bohr');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Fundamentally, there may be no basis for anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','God runs electromagnetics by wave theory on Monday, Wednesday, and Friday,<BR>\nand the Devil runs them by quantum theory on Tuesday, Thursday, and Saturday.<BR>\n&nbsp;-- William Bragg');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Friction is a drag.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Going the speed of light is bad for your age.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Got Mole problems?  Call Avogadro at 6.02 x 10^23.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The more they over-think the plumbing the easier it is to stop up the drain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is contrary to reasoning to say that there is a vacuum or space in<BR>\nwhich there is absolutely nothing.<BR>\n&nbsp;-- Descartes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Gravity is a myth, the Earth sucks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Eureka!<BR>\n&nbsp;-- Archimedes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Earl Wiener, 55, a University of Miami professor of management science,<BR>\ntelling the Airline Pilots Association (in jest) about 21st century aircraft:<BR>\n&nbsp;\"The crew will consist of one pilot and a dog.  The pilot will<BR>\n&nbsp;nurture and feed the dog.  The dog will be there to bite the<BR>\n&nbsp;pilot if he touches anything.<BR>\n&nbsp;-- Fortune, Sept. 26, 1988<BR>\n&nbsp;[the *magazine*, silly!]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Every little picofarad has a nanohenry all its own.<BR>\n&nbsp;-- Don Vonada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Every paper published in a respectable journal should have a preface by<BR>\nthe author stating why he is publishing the article, and what value he<BR>\nsees in it.  I have no hope that this practice will ever be adopted.<BR>\n&nbsp;-- Morris Kline');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Everything should be made as simple as possible, but not simpler.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Everything that can be invented has been invented.<BR>\n&nbsp;-- Charles Duell, Director of U.S. Patent Office, 1899');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Elliptic paraboloids for sale.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Human beings were created by water to transport it uphill.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Evolution is as much a fact as the earth turning on its axis and going around<BR>\nthe sun.  At one time this was called the Copernican theory; but, when<BR>\nevidence for a theory becomes so overwhelming that no informed person can<BR>\ndoubt it, it is customary for scientists to call it a fact.  That all present<BR>\nlife descended from earlier forms, over vast stretches of geologic time, is<BR>\nas firmly established as Copernican cosmology.  Biologists differ only with<BR>\nrespect to theories about how the process operates.<BR>\n&nbsp;-- Martin Gardner, \"Irving Kristol and the Facts of Life\". ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Experience varies directly with equipment ruined.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','It is the theory which decides what can be observed.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Information is the inverse of entropy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Five is a sufficiently close approximation to infinity.<BR>\n&nbsp;-- Robert Firth<BR>\n&nbsp;\"One, two, five.\"<BR>\n&nbsp;-- Monty Python and the Holy Grail');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','For large values of one, one equals two, for small values of two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Facts are stubborn, but statistics are more pliable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The nation that controls magnetism controls the universe.<BR>\n&nbsp;-- Chester Gould/Dick Tracy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','I do hate sums.  There is no greater mistake than to call arithmetic an<BR>\nexact science.  There are permutations and aberrations discernible to minds<BR>\nentirely noble like mine; subtle variations which ordinary accountants fail<BR>\nto discover; hidden laws of number which it requires a mind like mine to<BR>\nperceive.  For instance, if you add a sum from the bottom up, and then again<BR>\nfrom the top down, the result is always different.<BR>\n&nbsp;-- Mrs. La Touche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The speed of anything depends on the flow of everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','More than any time in history, mankind now faces a crossroads.  One path<BR>\nleads to despair and utter hopelessness, the other to total extinction.<BR>\nLet us pray that we have the wisdom to choose correctly.<BR>\n&nbsp;-- Woody Allen, \"Side Effects\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Is knowledge knowable?  If not, how do we know that?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','\"Irrationality is the square root of all evil\"<BR>\n&nbsp;-- Douglas Hofstadter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The meek shall inherit the earth; the rest of us, the Universe.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Always draw your curves, then plot your reading.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Dimensions will always be expressed in the least usable term, convertible<BR>\nonly through the use of weird and unnatural conversion factors.  Velocity,<BR>\nfor example, will be expressed in furlongs per fortnight.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Duct tape is like the force.  It has a light side, and a dark side, and<BR>\nit holds the universe together ...<BR>\n&nbsp;-- Carl Zwanzig');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Invest in physics -- own a piece of Dirac!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','E = MC ** 2 +- 3db');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Economics is extremely useful as a form of employment for economists.<BR>\n&nbsp;-- John Kenneth Galbraith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Entropy requires no maintenance.<BR>\n&nbsp;-- Markoff Chaney');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Parts that positively cannot be assembled in improper order will be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','After years of research, scientists recently reported that there is,<BR>\nindeed, arroz in Spanish Harlem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Chemistry is applied theology.<BR>\n&nbsp;-- Augustus Stanley Owsley III');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','We cannot command nature except by obeying her.<BR>\n&nbsp;-- Sir Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If they can make penicillin out of moldy bread, they can sure make<BR>\nsomething out of you.<BR>\n&nbsp;-- Muhammad Ali');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','If A equals success, then the formula is _A = _X + _Y + _Z.  _X is work.  _Y<BR>\nis play.  _Z is keep your mouth shut.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','The earth is like a tiny grain of sand, only much, much heavier.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Time is an illusion perpetrated by the manufacturers of space.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','One small step for man, one giant stumble for mankind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Kleeneness is next to Godelness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Klein bottle for rent -- inquire within.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Do molecular biologists wear designer genes?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('science','Ma Bell is a mean mother!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','This is the story of the bee<BR>\nWhose sex is very hard to see<BR>\n&nbsp;You cannot tell the he from the she<BR>\nBut she can tell, and so can he<BR>\n&nbsp;The little bee is never still<BR>\nShe has no time to take the pill<BR>\n&nbsp;And that is why, in times like these<BR>\nThere are so many sons of bees.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','One day,<BR>\nA mad meta-poet,<BR>\nWith nothing to say,<BR>\nWrote a mad meta-poem<BR>\nThat started: \"One day,<BR>\nA mad meta-poet,<BR>\nWith nothing to say,<BR>\nWrote a mad meta-poem<BR>\nThat started: \"One day,<BR>\n[...]<BR>\nsort of close\".<BR>\nWere the words that the poet,<BR>\nFinally chose,<BR>\nTo bring his mad poem,<BR>\nTo some sort of close\".<BR>\nWere the words that the poet,<BR>\nFinally chose,<BR>\nTo bring his mad poem,<BR>\nTo some sort of close\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Once upon this midnight incoherent,<BR>\nWhile you pondered sentient and crystalline,<BR>\nOver many a broken and subordinate<BR>\nVolume of gnarly lore,<BR>\nWhile I pestered, nearly singing,<BR>\nSudddenly there came a hewing,<BR>\nAs of someone profusely skulking,<BR>\nSkulking at my chamber door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','There is no point in waiting.<BR>\nThe train stopped running years ago.<BR>\nAll the schedules, the brochures,<BR>\nThe bright-colored posters full of lies,<BR>\nPromise rides to a distant country<BR>\nThat no longer exists.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','We wish you a Hare Krishna<BR>\nWe wish you a Hare Krishna<BR>\nWe wish you a Hare Krishna<BR>\nAnd a Sun Myung Moon!<BR>\n&nbsp;-- Maxwell Smart');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Time goes, you say?<BR>\nAh no!<BR>\nTime stays, *we* go.<BR>\n&nbsp;-- Austin Dobson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','She blinded me with science!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','One good thing about music,<BR>\nWell, it helps you feel no pain.<BR>\nSo hit me with music;<BR>\nHit me with music now.<BR>\n&nbsp;-- Bob Marley, \"Trenchtown Rock\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The boy stood on the burning deck,<BR>\nEating peanuts by the peck.<BR>\nHis father called him, but he could not go,<BR>\nFor he loved those peanuts so.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','&nbsp;/	SUN of them wants to use you,<BR>\n&nbsp;\ <BR>\n&nbsp;/  \ /	SUN of them wants to be used by you,<BR>\n&nbsp;/ / / / //<BR>\n&nbsp;//   // /	SUN of them wants to abuse you,<BR>\n&nbsp;/ /  /  /<BR>\n&nbsp;/  \ 	SUN of them wants to be abused ...<BR>\n&nbsp; \<BR>\n&nbsp;/<BR>\n&nbsp;-- Eurythmics');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Three Rings for the Elven-kings under the sky,<BR>\nSeven for the Dwarf-lords in their halls of stone,<BR>\nNine for Mortal Men doomed to die,<BR>\nOne for the Dark Lord on his dark throne<BR>\nIn the Land of Mordor where the Shadows lie.<BR>\nOne Ring to rule them all, One Ring to find them,<BR>\nOne Ring to bring them all and in the darkness bind them<BR>\nIn the Land of Mordor where the Shadows lie.<BR>\n&nbsp;-- J.R.R. Tolkien, \"The Lord of the Rings\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','One reason why George Washington<BR>\nIs held in such veneration:<BR>\nHe never blamed his problems<BR>\nOn the former Administration.<BR>\n&nbsp;-- George O. Ludcke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','This is the way the world ends,<BR>\nThis is the way the world ends,<BR>\nThis is the way the world ends,<BR>\nNot with a bang but with a whimper.<BR>\n&nbsp;-- T.S. Eliot, \"The Hollow Men\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','to be nobody but yourself in a world <BR>\nwhich is doing its best night and day<BR>\nto make you like everybody else<BR>\nmeans to fight the hardest battle<BR>\nany human being can fight and<BR>\nnever stop fighting.                   <BR>\n&nbsp;-- e.e. cummings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Sun in the night, everyone is together,<BR>\nAscending into the heavens, life is forever.<BR>\n&nbsp;-- Brand X, \"Moroccan Roll/Sun in the Night\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The good time is approaching,<BR>\nThe season is at hand.<BR>\nWhen the merry click of the two-base lick<BR>\nWill be heard throughout the land.<BR>\nThe frost still lingers on the earth, and<BR>\nBudless are the trees.<BR>\nBut the merry ring of the voice of spring<BR>\nIs borne upon the breeze.<BR>\n&nbsp;-- Ode to Opening Day, \"The Sporting News\", 1886');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To stand and be still,<BR>\nAt the Birkenhead drill,<BR>\nIs a damned tough bullet to chew.<BR>\n&nbsp;-- Rudyard Kipling');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To everything there is a season, a time for every pupose under heaven:<BR>\nA time to be born, and a time to die;<BR>\nA time to plant, and a time to pluck what is planted;<BR>\nA time to kill, and a time to heal;<BR>\nA time to break down, and a time to build up;<BR>\nA time to weep, and a time to laugh;<BR>\nA time to mourn, and a time to dance;<BR>\nA time to cast away stones, and a time to gather stones;<BR>\nA time to embrace, and a time to refrain from embracing;<BR>\nA time to gain, and a time to lose;<BR>\nA time to keep, and a time to throw away;<BR>\nA time to tear, and a time to sew;<BR>\nA time to keep silence, and a time to speak;<BR>\nA time to love, and a time to hate;<BR>\nA time of war, and a time of peace.<BR>\n&nbsp;Ecclesiastes 3:1-9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To err is human,<BR>\nTo purr feline.<BR>\n&nbsp;-- Robert Byrne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The Moving Finger writes; and, having writ,<BR>\n&nbsp;Moves on: nor all they Piety nor Wit<BR>\nShall lure it back to cancel half a Line,<BR>\n&nbsp;Nor all thy Tears wash out a Word of it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To err is human, to purr feline.<BR>\nTo err is human, two curs canine.<BR>\nTo err is human, to moo bovine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To whom the mornings are like nights,<BR>\nWhat must the midnights be!<BR>\n&nbsp;-- Emily Dickinson (on hacking?)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The makers may make<BR>\nand the users may use,<BR>\nbut the fixers must fix<BR>\nwith but minimal clues');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The man she had was kind and clean<BR>\nAnd well enough for every day,<BR>\nBut oh, dear friends, you should have seen<BR>\nThe one that got away.<BR>\n&nbsp;-- Dorothy Parker, \"The Fisherwoman\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','To write a sonnet you must ruthlessly<BR>\nstrip down your words to naked, willing flesh.<BR>\nThen bind them to a metaphor or three,<BR>\nand take by force a satisfying mesh.<BR>\nArrange them to your will, each foot in place.<BR>\nYou are the master here, and they the slaves.<BR>\nNow whip them to maintain a constant pace<BR>\nand rhythm as they stand in even staves.<BR>\nA word that strikes no pleasure?  Cast it out!<BR>\nWhat use are words that drive not to the heart?<BR>\nA lazy phrase? Discard it, shrug off doubt,<BR>\nand choose more docile words to take its part.<BR>\nA well-trained sonnet lives to entertain,<BR>\nby making love directly to the brain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The little town that time forgot,<BR>\nWhere all the women are strong,<BR>\nThe men are good-looking,<BR>\nAnd the children above-average.<BR>\n&nbsp;-- Prairie Home Companion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','&nbsp;The Lord and I are in a sheep-shepherd relationship, and I am in<BR>\na position of negative need.<BR>\n&nbsp;He prostrates me in a green-belt grazing area.<BR>\n&nbsp;He conducts me directionally parallel to non-torrential aqueous<BR>\nliquid.<BR>\n&nbsp;He returns to original satisfaction levels my psychological makeup.<BR>\n&nbsp;He switches me on to a positive behavioral format for maximal<BR>\nprestige of His identity.<BR>\n&nbsp;It should indeed be said that notwithstanding the fact that I make<BR>\nambulatory progress through the umbragious inter-hill mortality slot, terror<BR>\nsensations will no be initiated in me, due to para-etical phenomena.<BR>\n&nbsp;Your pastoral walking aid and quadrupic pickup unit introduce me<BR>\ninto a pleasurific mood state.<BR>\n&nbsp;You design and produce a nutriment-bearing furniture-type structure<BR>\nin the context of non-cooperative elements.<BR>\n&nbsp;You act out a head-related folk ritual employing vegetable extract.<BR>\n&nbsp;My beverage utensil experiences a volume crisis.<BR>\n&nbsp;It is an ongoing deductible fact that your inter-relational<BR>\nempathetical and non-ventious capabilities will retain me as their<BR>\ntarget-focus for the duration of my non-death period, and I will possess<BR>\ntenant rights in the housing unit of the Lord on a permanent, open-ended<BR>\ntime basis.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The good life was so elusive<BR>\nIt really got me down<BR>\nI had to regain some confidence<BR>\nSo I got into camouflage');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Speak roughly to your little VAX,<BR>\n&nbsp;And boot it when it crashes;<BR>\nIt knows that one cannot relax<BR>\n&nbsp;Because the paging thrashes!<BR>\n&nbsp;Wow!  Wow!  Wow!<BR>\n&nbsp;I speak severely to my VAX,<BR>\n&nbsp;And boot it when it crashes;<BR>\nIn spite of all my favorite hacks<BR>\n&nbsp;My jobs it always thrashes!<BR>\n&nbsp;Wow!  Wow!  Wow!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Spring is here, spring is here,<BR>\nLife is skittles and life is beer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The bank sent our statement this morning,<BR>\nThe red ink was a sight of great awe!<BR>\nTheir figures and mine might have balanced,<BR>\nBut my wife was too quick on the draw.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The common cormorant, or shag,<BR>\nLays eggs inside a paper bag;<BR>\nThe reason, you will see, no doubt,<BR>\nIs to keep the lightning out.<BR>\nBut what these unobservant birds<BR>\nHave failed to notice is that herds<BR>\nOf bears may come with buns<BR>\nAnd steal the bags to hold the crumbs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','There are strange things done in the midnight sun<BR>\n&nbsp;By the men who moil for gold;<BR>\nThe Arctic trails have their secret tales<BR>\n&nbsp;That would make your blood run cold;<BR>\nThe Northern Lights have seen queer sights,<BR>\n&nbsp;But the queerest they ever did see<BR>\nWas that night on the marge of Lake Lebarge<BR>\n&nbsp;I cremated Sam McGee.<BR>\n&nbsp;-- Robert W. Service');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Try not.<BR>\nDo.<BR>\nOr do not.<BR>\nThere is no try.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','we will invent new lullabies, new songs, new acts of love,<BR>\nwe will cry over things we used to laugh &<BR>\nour new wisdom will bring tears to eyes of gentle<BR>\ncreatures from other planets who were afraid of us till then &<BR>\nin the end a summer with wild winds &<BR>\nnew friends will be.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Too cool to calypso,<BR>\nToo tough to tango,<BR>\nToo weird to watusi<BR>\n&nbsp;-- The Only Ones');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Tobacco is a filthy weed,<BR>\nThat from the devil does proceed;<BR>\nIt drains your purse, it burns your clothes,<BR>\nAnd makes a chimney of your nose.<BR>\n&nbsp;-- B. Waterhouse');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Tiger got to hunt,<BR>\nBird got to fly;<BR>\nMan got to sit and wonder, \"Why, why, why?\"<BR>\n&nbsp;Tiger got to sleep,<BR>\nBird got to land;<BR>\nMan got to tell himself he understand.<BR>\n&nbsp;-- The Books of Bokonon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Sometimes I live in the country,<BR>\nAnd sometimes I live in town.<BR>\nAnd sometimes I have a great notion,<BR>\nTo jump in the river and drown.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Twas FORTRAN as the doloop goes<BR>\n&nbsp;Did logzerneg the ifthen block<BR>\nAll kludgy were the function flows<BR>\n&nbsp;And subroutines adhoc.<BR>\n&nbsp;Beware the runtime-bug my friend<BR>\n&nbsp;squrooneg, the false goto<BR>\nBeware the infiniteloop<BR>\n&nbsp;And shun the inprectoo.<BR>\n&nbsp;-- \"OUTCONERR,\" to the scheme of \"Jabberwocky\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Speak roughly to your little boy,<BR>\n&nbsp;And beat him when he sneezes:<BR>\nHe only does it to annoy<BR>\n&nbsp;Because he knows it teases.<BR>\n&nbsp;Wow!  wow!  wow!<BR>\n&nbsp;I speak severely to my boy,<BR>\n&nbsp;And beat him when he sneezes:<BR>\nFor he can thoroughly enjoy<BR>\n&nbsp;The pepper when he pleases!<BR>\n&nbsp;Wow!  wow!  wow!<BR>\n&nbsp;-- Lewis Carrol, \"Alice in Wonderland\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Tim and I a hunting went<BR>\nWe found three damsels in a tent,<BR>\nAs they were three, and we were two,<BR>\nI bucked one and Timbuktu.<BR>\n&nbsp;-- the only known poem using the word \"Timbuktu\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The Road goes ever on and on<BR>\nDown from the door where it began.<BR>\nNow far ahead the Road has gone,<BR>\nAnd I must follow, if I can,<BR>\nPursuing it with eager feet,<BR>\nUntil it joins some larger way<BR>\nWhere many paths and errands meet.<BR>\nAnd whither then?  I cannot say.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The young lady had an unusual list,<BR>\nLinked in part to a structural weakness.<BR>\nShe set no preconditions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','&nbsp;Two men looked out from the prison bars,<BR>\n&nbsp;One saw mud--<BR>\n&nbsp;The other saw stars.<BR>\n&nbsp;Now let me get this right: two prisoners are looking out the window.<BR>\nWhile one of them was looking at all the mud -- the other one got hit<BR>\nin the head.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Take heart amid the deepening gloom that your dog is finally getting<BR>\nenough cheese.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Shift to the left,<BR>\nShift to the right,<BR>\nMask in, mask out,<BR>\nBYTE, BYTE, BYTE !!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The Preacher, the Politician, the Teacher,<BR>\n&nbsp;Were each of them once a kiddie.<BR>\nA child, indeed, is a wonderful creature.<BR>\n&nbsp;Do I want one?  God Forbiddie!<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Under the wide and starry sky,<BR>\nDig my grave and let me lie,<BR>\nGlad did I live and gladly die,<BR>\nAnd laid me down with a will,<BR>\nAnd this be the verse that you grave for me,<BR>\nHere he lies where he longed to be,<BR>\nHome is the sailor home from the sea,<BR>\nAnd the hunter home from the hill.<BR>\n&nbsp;-- Robert Loius Stevenson, \"Requiem\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','So... so you think you can tell<BR>\nHeaven from Hell?<BR>\nBlue skies from pain?			Did they get you to trade<BR>\nCan you tell a green field		Your heroes for ghosts?<BR>\nFrom a cold steel rail?			Hot ashes for trees?<BR>\nA smile from a veil?			Hot air for a cool breeze?<BR>\nDo you think you can tell?		Cold comfort for change?<BR>\n&nbsp;Did you exchange<BR>\n&nbsp;A walk on part in a war<BR>\n&nbsp;For the lead role in a cage?<BR>\n&nbsp;-- Pink Floyd, \"Wish You Were Here\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','There is in certain living souls<BR>\nA quality of loneliness unspeakable,<BR>\nSo great it must be shared<BR>\nAs company is shared by lesser beings.<BR>\nSuch a loneliness is mine; so know by this<BR>\nThat in immensity<BR>\nThere is one lonelier than you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','There was a little girl<BR>\nWho had a little curl<BR>\nRight in the middle of her forehead.<BR>\nWhen she was good, she was very, very good<BR>\nAnd when she was bad, she was very, very popular.<BR>\n&nbsp;-- Max Miller, \"The Max Miller Blue Book\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','So much<BR>\ndepends<BR>\nupon<BR>\na red<BR>\n&nbsp;wheel<BR>\nbarrow<BR>\nglazed with<BR>\n&nbsp;rain<BR>\nwater<BR>\nbeside<BR>\nthe white<BR>\nchickens.<BR>\n&nbsp;-- William Carlos Williams, \"The Red Wheel Barrow\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Under the wide and heavy VAX<BR>\nDig my grave and let me relax<BR>\nLong have I lived, and many my hacks<BR>\nAnd I lay me down with a will.<BR>\nThese be the words that tell the way:<BR>\n\"Here he lies who piped 64K,<BR>\nBrought down the machine for nearly a day,<BR>\nAnd Rogue playing to an awful standstill.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Beneath this stone lies Murphy,<BR>\nThey buried him today,<BR>\nHe lived the life of Riley,<BR>\nWhile Riley was away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Some primal termite knocked on wood.<BR>\nAnd tasted it, and found it good.<BR>\nAnd that is why your Cousin May<BR>\nFell through the parlor floor today.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','There is something in the pang of change<BR>\nMore than the heart can bear,<BR>\nUnhappiness remembering happiness.<BR>\n&nbsp;-- Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Soldiers who wish to be a hero<BR>\nAre practically zero,<BR>\nBut those who wish to be civilians,<BR>\nThey run into the millions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Be valiant, but not too venturous.<BR>\nLet thy attire be comely, but not costly.<BR>\n&nbsp;-- John Lyly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The Pig, if I am not mistaken,<BR>\nGives us ham and pork and Bacon.<BR>\nLet others think his heart is big,<BR>\nI think it stupid of the Pig.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','SHIFT TO THE LEFT!<BR>\nSHIFT TO THE RIGHT!<BR>\nPOP UP, PUSH DOWN,<BR>\nBYTE, BYTE, BYTE!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Sing hey! for the bath at close of day<BR>\nThat washes the weary mud away!<BR>\nA loon is he that will not sing:<BR>\nO! Water Hot is a noble thing!<BR>\n&nbsp;O! Sweet is the sound of falling rain,<BR>\n&nbsp;and the brook that leaps from hill to plain;<BR>\n&nbsp;but better than rain or rippling streams<BR>\n&nbsp;is Water Hot that smokes and steams.<BR>\n&nbsp;O! Water cold we may pour at need<BR>\ndown a thirsty throat and be glad indeed;<BR>\nbut better is Beer, if drink we lack,<BR>\nand Water Hot poured down the back.<BR>\n&nbsp;O! Water is fair that leaps on high<BR>\n&nbsp;in a fountain white beneath the sky;<BR>\n&nbsp;but never did fountain sound so sweet<BR>\n&nbsp;as splashing Hot Water with my feet!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Because I do,<BR>\nBecause I do not hope,<BR>\nBecause I do not hope to survive<BR>\nInjustice from the Palace, death from the air,<BR>\nBecause I do, only do,<BR>\nI continue...<BR>\n&nbsp;-- T.S. Pynchon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Wake now my merry lads!  Wake and hear me calling!<BR>\nWarm now be heart and limb!  The cold stone is fallen;<BR>\nDark door is standing wide; dead hand is broken.<BR>\nNight under Night is flown, and the Gate is open!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Wad some power the giftie gie us<BR>\nTo see oursels as others see us.<BR>\n&nbsp;-- R. Burns');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Voicless it cries,<BR>\nWingless flutters,<BR>\nToothless bites,<BR>\nMouthless mutters.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Snow-white!  Snow-white!  O Lady clear!<BR>\nO Queen beyond the Western Sea!<BR>\nO Light to us that wander here<BR>\nAmid the world of woven trees!<BR>\n&nbsp;Gilthoniel!  O Elbereth!<BR>\n&nbsp;Clear are thy eyes and bright thy breath!<BR>\n&nbsp;Snow-white!  Snow-white!  We sing to thee<BR>\n&nbsp;In a far land beyond the Sea.<BR>\n&nbsp;O stars that in the Sunless Year<BR>\nWith shining hand by her were sown,<BR>\nIn windy fields now bright and clear<BR>\nWe see you silver blossom blown!<BR>\n&nbsp;O Elbereth!  Gilthoniel!<BR>\n&nbsp;We still remember, we who dwell<BR>\n&nbsp;In this far land beneath the trees,<BR>\n&nbsp;Thy starlight on the Western Seas.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','That feeling just came over me.<BR>\n&nbsp;-- Albert DeSalvo, the \"Boston Strangler\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Come live with me, and be my love,<BR>\nAnd we will some new pleasures prove<BR>\nOf golden sands, and crystal brooks,<BR>\nWith silken lines, and silver hooks.<BR>\n&nbsp;-- John Donne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Cancel me not -- for what then shall remain?<BR>\nAbscissas, some mantissas, modules, modes,<BR>\nA root or two, a torus and a node:<BR>\nThe inverse of my verse, a null domain.<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Big M, Little M, many mumbling mice<BR>\nAre making midnight music in the moonlight,<BR>\nMighty nice!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Boy, get your head out of the stars above,<BR>\nYou get the maximum pleasure from a minimum of love.<BR>\nSave your heart and let your body be enough,<BR>\nTo get the maximum pleasure from a minimum of love.<BR>\nSave your heart and let your body be enough,<BR>\nAnd get the maximum pleasure from a minimum of love.<BR>\n&nbsp;-- Mac Macinelli, \"Minimum Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Seduced, shaggy Samson snored.<BR>\nShe scissored short.  Sorely shorn,<BR>\nSoon shackled slave, Samson sighed,<BR>\nSilently scheming,<BR>\nSightlessly seeking<BR>\nSome savage, spectacular suicide.<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Declared guilty... of displaying feelings of an almost human nature.<BR>\n&nbsp;-- Pink Floyd, \"The Wall\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Since I hurt my pendulum<BR>\nMy life is all erratic.<BR>\nMy parrot who was cordial<BR>\nIs now transmitting static.<BR>\nThe carpet died, a palm collapsed,<BR>\nThe cat keeps doing poo.<BR>\nThe only thing that keeps me sane<BR>\nIs talking to my shoe.<BR>\n&nbsp;-- My Shoe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','What awful irony is this?<BR>\nWe are as gods, but know it not.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Beauty is truth, truth beauty, that is all<BR>\nYe know on earth, and all ye need to know.<BR>\n&nbsp;-- John Keats');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Azh nazg durbatal^uk, azh nazg gimbatul,<BR>\nAzh nazg thrakatal^uk agh burzum ishi krimpatul!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','As I was passing Project MAC,<BR>\nI met a Quux with seven hacks.<BR>\nEvery hack had seven bugs;<BR>\nEvery bug had seven manifestations;<BR>\nEvery manifestation had seven symptoms.<BR>\nSymptoms, manifestations, bugs, and hacks,<BR>\nHow many losses at Project MAC?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Are there those in the land of the brave<BR>\nWho can tell me how I should behave<BR>\n&nbsp;When I am disgraced<BR>\n&nbsp;Because I erased<BR>\n&nbsp;A file I intended to save?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And so it was, later,<BR>\nAs the miller told his tale,<BR>\nThat her face, at first just ghostly,<BR>\nTurned a whiter shade of pale.<BR>\n&nbsp;-- Procol Harum');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','But scientists, who ought to know<BR>\nAssure us that it must be so.<BR>\nOh, let us never, never doubt<BR>\nWhat nobody is sure about.<BR>\n&nbsp;-- Hilaire Belloc');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Scintillate, scintillate, globule vivific,<BR>\nFain how I pause at your nature specific,<BR>\nLoftily poised in the ether capacious,<BR>\nHighly resembling a gem carbonaceous.<BR>\nScintillate, scintillate, globule vivific,<BR>\nFain how I pause at your nature specific.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Science Fiction, Double Feature.<BR>\nFrank has built and lost his creature.<BR>\nDarkness has conquered Brad and Janet.<BR>\nThe servants gone to a distant planet.<BR>\nWo, oh, oh, oh.<BR>\nAt the late night, double feature, Picture show.<BR>\nI want to go, oh, oh, oh.<BR>\nTo the late night, double feature, Picture show.<BR>\n&nbsp;-- Rocky Horror Picture Show');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Remove me from this land of slaves,<BR>\nWhere all are fools, and all are knaves,<BR>\nWhere every knave and fool is bought, <BR>\nYet kindly sells himself for nought;<BR>\n&nbsp;-- Jonathan Swift');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Euch ist becannt, was wir beduerfen;<BR>\nWir wollen stark Getraenke schluerfen.<BR>\n&nbsp;-- Goethe, \"Faust\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Saturday night in Toledo Ohio,<BR>\n&nbsp;Is like being nowhere at all,<BR>\nAll through the day how the hours rush by,<BR>\n&nbsp;You sit in the park and you watch the grass die.<BR>\n&nbsp;-- John Denver, \"Saturday Night in Toledo Ohio\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Well, some take delight in the carriages a-rolling,<BR>\nAnd some take delight in the hurling and the bowling,<BR>\nBut I take delight in the juice of the barley,<BR>\nAnd courting pretty fair maids in the morning bright and early.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Es brilig war.  Die schlichte Toven<BR>\n&nbsp;Wirrten und wimmelten in Waben;<BR>\nUnd aller-m\"umsige Burggoven<BR>\n&nbsp;Dir mohmen R\"ath ausgraben.<BR>\n&nbsp;-- Lewis Carrol, \"Through the Looking Glass\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Remember that whatever misfortune may be your lot, it could only be<BR>\nworse in Cleveland.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Every man is as God made him, ay, and often worse.<BR>\n&nbsp;-- Miguel de Cervantes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','What has roots as nobody sees,<BR>\nIs taller than trees,<BR>\nUp, up it goes,<BR>\nAnd yet never grows?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','What happens to a dream deferred?<BR>\nDoes it dry up<BR>\nLike a raisin in the sun?<BR>\nOr fester like a sore --<BR>\nAnd then run?<BR>\nDoes it stink like rotten meat?<BR>\nOr crust and sugar over --<BR>\nLike a syrupy sweet?<BR>\n&nbsp;Maybe it just sags<BR>\nLike a heavy load.<BR>\n&nbsp;Or does it explode?<BR>\n&nbsp;-- Langston Hughes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Finality is death.<BR>\nPerfection is finality.<BR>\nNothing is perfect.<BR>\nThere are lumps in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Fifty flippant frogs<BR>\nWalked by on flippered feet<BR>\nAnd with their slime they made the time<BR>\nUnnaturally fleet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Drink and dance and laugh and lie<BR>\nLove, the reeling midnight through<BR>\nFor tomorrow we shall die!<BR>\n(But, alas, we never do.)<BR>\n&nbsp;-- Dorothy Parker, \"The Flaw in Paganism\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Flying saucers on occasion<BR>\n&nbsp;Show themselves to human eyes.<BR>\nAliens fume, put off invasion<BR>\n&nbsp;While they brand these tales as lies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','rain falls where clouds come<BR>\nsun shines where clouds go<BR>\nclouds just come and go<BR>\n&nbsp;-- Florian Gutzwiller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Even a man who is pure at heart,<BR>\nAnd says his prayers at night<BR>\nCan become a wolf when the wolfbane blooms,<BR>\nAnd the moon is full and bright.<BR>\n&nbsp;-- The Wolf Man, 1941');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Felix Catus is your taxonomic nomenclature,<BR>\nAn endothermic quadroped, carnivorous by nature.<BR>\nYour visual, olfactory, and auditory senses<BR>\nContribute to your hunting skills and natural defenses.<BR>\nI find myself intrigued by your sub-vocal oscillations,<BR>\nA singular development of cat communications<BR>\nThat obviates your basic hedonistic predelection<BR>\nFor a rhythmic stroking of your fur to demonstrate affection.<BR>\nA tail is quite essential for your acrobatic talents:<BR>\nYou would not be so agile if you lacked its counterbalance;<BR>\nAnd when not being utilitized to aid in locomotion,<BR>\nIt often serves to illustrate the state of your emotion.<BR>\nOh Spot, the complex levels of behavior you display<BR>\nConnote a fairly well-developed cognitive array.<BR>\nAnd though you are not sentient, Spot, and do not comprehend,<BR>\nI nonetheless consider you a true and valued friend.<BR>\n&nbsp;-- Lt. Cmdr. Data, \"An Ode to Spot\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Farewell we call to hearth and hall!<BR>\nThough wind may blow and rain may fall,<BR>\nWe must away ere break of day<BR>\nFar over wood and mountain tall.<BR>\n&nbsp;To Rivendell, where Elves yet dwell<BR>\n&nbsp;In glades beneath the misty fell,<BR>\n&nbsp;Through moor and waste we ride in haste,<BR>\n&nbsp;And whither then we cannot tell.<BR>\n&nbsp;With foes ahead, behind us dread,<BR>\nBeneath the sky shall be our bed,<BR>\nUntil at last our toil be passed,<BR>\nOur journey done, our errand sped.<BR>\n&nbsp;We must away!  We must away!<BR>\n&nbsp;We ride before the break of day!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','From too much love of living,<BR>\nFrom hope and fear set free,<BR>\nWe thank with brief thanksgiving,<BR>\nWhatever gods may be,<BR>\nThat no life lives forever,<BR>\nThat dead men rise up never,<BR>\nThat even the weariest river winds somewhere safe to sea.<BR>\n&nbsp;-- Swinburne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Get in touch with your feelings of hostility against the dying light.<BR>\n&nbsp;-- Dylan Thomas [paraphrased periphrastically]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Get out, you old Wight!  Vanish in the sunlight!<BR>\nShrivel like the cold mist, like the winds go wailing,<BR>\nOut into the barren lands far beyond the mountains!<BR>\nCome never here again!  Leave your barrow empty!<BR>\nLost and forgotten be, darker than the darkness,<BR>\nWhere gates stand for ever shut, till the world is mended.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Down to the Banana Republics,<BR>\nDown to the tropical sun.<BR>\nGo the expatriated Americans,<BR>\nHoping to find some fun.<BR>\nSome of them go for the sailing,<BR>\nCaught by the lure of the sea.<BR>\nTrying to find what is ailing,<BR>\nLiving in the land of the free.<BR>\nSome of them are running from lovers,<BR>\nLeaving no forward address.<BR>\nSome of them are running tons of ganja,<BR>\nSome are running from the IRS.<BR>\nLate at night you will find them,<BR>\nIn the cheap hotels and bars.<BR>\nHustling the senoritas,<BR>\nWhile they dance beneath the stars.<BR>\n&nbsp;-- Jimmy Buffet, \"Banana Republics\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Reach into the thoughts of friends,<BR>\nAnd find they do not know your name.<BR>\nSqueeze the teddy bear too tight,<BR>\nAnd watch the feathers burst the seams.<BR>\nTouch the stained glass with your cheek,<BR>\nAnd feel its chill upon your blood.<BR>\nHold a candle to the night,<BR>\nAnd see the darkness bend the flame.<BR>\nTear the mask of peace from God,<BR>\nAnd hear the roar of souls in hell.<BR>\nPluck a rose in name of love,<BR>\nAnd watch the petals curl and wilt.<BR>\nLean upon the western wind,<BR>\nAnd know you are alone.<BR>\n&nbsp;-- Dru Mims');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','For gin, in cruel<BR>\nSober truth,<BR>\nSupplies the fuel<BR>\nFor flaming youth.<BR>\n&nbsp;-- Noel Coward');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Go placidly amid the noise and waste, and remember what value there may<BR>\nbe in owning a piece thereof.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Come fill the cup and in the fire of spring<BR>\nYour winter garment of repentence fling.<BR>\nThe bird of time has but a little way<BR>\nTo flutter -- and the bird is on the wing.<BR>\n&nbsp;-- Omar Khayyam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Death comes on every passing breeze,<BR>\nHe lurks in every flower;<BR>\nEach season has its own disease,<BR>\nIts peril -- every hour.<BR>\n&nbsp;--Reginald Heber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Thirty white horses on a red hill,<BR>\nFirst they champ,<BR>\nThen they stamp,<BR>\nThen they stand still.<BR>\n&nbsp;-- Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','This ae nighte, this ae nighte,<BR>\nEverye nighte and alle,<BR>\nFire and sleet and candlelyte,<BR>\nAnd Christe receive thy saule.<BR>\n&nbsp;-- The Lykewake Dirge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Come, muse, let us sing of rats!<BR>\n&nbsp;-- From a poem by James Grainger, 1721-1767');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Come, let us hasten to a higher plane,<BR>\nWhere dyads tread the fairy fields of Venn,<BR>\nTheir indices bedecked from one to _n,<BR>\nCommingled in an endless Markov chain!<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Avoid Quiet and Placid persons unless you are in Need of Sleep.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Go placidly amid the noise and waste,<BR>\nAnd remember what comfort there may be in owning a piece thereof.<BR>\nAvoid quiet and passive persons, unless you are in need of sleep.<BR>\nRotate your tires.<BR>\nSpeak glowingly of those greater than yourself,<BR>\nAnd heed well their advice -- even though they be turkeys.<BR>\nKnow what to kiss -- and when.<BR>\nRemember that two wrongs never make a right,<BR>\nBut that three do.<BR>\nWherever possible, put people on \"HOLD\".<BR>\nBe comforted, that in the face of all aridity and disillusionment,<BR>\nAnd despite the changing fortunes of time,<BR>\nThere is always a big future in computer maintenance.<BR>\n&nbsp;You are a fluke of the universe ...<BR>\n&nbsp;You have no right to be here.<BR>\n&nbsp;Whether you can hear it or not, the universe<BR>\n&nbsp;Is laughing behind your back.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Come, every frustum longs to be a cone,<BR>\nAnd every vector dreams of matrices.<BR>\nHark to the gentle gradient of the breeze:<BR>\nIt whispers of a more ergodic zone.<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Sweet sixteen is beautiful Bess,<BR>\nAnd her voice is changing -- from \"No\" to \"Yes\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','But soft you, the fair Ophelia:<BR>\nOpe not thy ponderous and marble jaws,<BR>\nBut get thee to a nunnery -- go!<BR>\n&nbsp;-- Mark \"The Bard\" Twain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Cold be hand and heart and bone,<BR>\nand cold be sleep under stone;<BR>\nnever more to wake on stony bed,<BR>\nnever, till the Sun fails and the Moon is dead.<BR>\n&nbsp;In the black wind the stars shall die,<BR>\nand still on gold here let them lie,<BR>\ntill the dark lord lifts his hand<BR>\nover dead sea and withered land.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Charlie was a chemist,<BR>\nBut Charlie is no more.<BR>\nFor what he thought was H2O,<BR>\nWas H2SO4.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Chivalry, Schmivalry!<BR>\n&nbsp;Roger the thief has a<BR>\n&nbsp;method he uses for<BR>\n&nbsp;sneaky attacks:<BR>\nFolks who are reading are<BR>\n&nbsp;Characteristically<BR>\n&nbsp;Always Forgetting to<BR>\n&nbsp;Guard their own bac ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Half a bee, philosophically, must ipso facto half not be.<BR>\nBut half the bee has got to be, vis-a-vis its entity.  See?<BR>\nBut can a bee be said to be or not to be an entire bee,<BR>\nWhen half the bee is not a bee, due to some ancient injury?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Between the idea<BR>\nAnd the reality<BR>\nBetween the motion<BR>\nAnd the act<BR>\nFalls the Shadow<BR>\n&nbsp;-- T.S. Eliot, \"The Hollow Man\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to system service dispatching.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Bit off more than my mind could chew,<BR>\nShower or suicide, what do I do?<BR>\n&nbsp;-- Julie Brown, \"Will I Make it Through the Eighties?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hanging on in quiet desperation is the English way.<BR>\n&nbsp;-- Pink Floyd');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When a lion meets another with a louder roar,<BR>\nthe first lion thinks the last a bore.<BR>\n&nbsp;-- G.B. Shaw');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Graphics blind the eyes.<BR>\nAudio files deafen the ear.<BR>\nMouse clicks numb the fingers.<BR>\nHeuristics weaken the mind.<BR>\nOptions wither the heart.<BR>\n&nbsp;The Guru observes the net <BR>\nbut trusts his inner vision.<BR>\nHe allows things to come and go.<BR>\nHis heart is as open as the ether.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','He who loses, wins the race,<BR>\nAnd parallel lines meet in space.<BR>\n&nbsp;-- John Boyd, \"Last Starship from Earth\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Angels we have heard on High<BR>\nTell us to go out and Buy.<BR>\n&nbsp;-- Tom Lehrer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','April is the cruellest month...<BR>\n&nbsp;-- Thomas Stearns Eliot');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','He heard there oft the flying sound<BR>\nOf feet as light as linden-leaves,<BR>\nOf music welling underground,<BR>\nIn hidden hollows quavering.<BR>\nNow withered lay the hemlock-sheaves,<BR>\nAnd one by one with sighing sound<BR>\nWhispering fell the beechen leaves<BR>\nIn the wintry woodland wavering.<BR>\n&nbsp;He sought her ever, wandering far<BR>\nWhere leaves of years were thickly strewn,<BR>\nBy light of moon and ray of star<BR>\nIn frosty heavens shivering.<BR>\nHer mantle glinted in the moon,<BR>\nAs on a hill-top high and far<BR>\nShe danced, and at her feet was strewn<BR>\nA mist of silver quivering.<BR>\n&nbsp;When winter passed, she came again,<BR>\nAnd her song released the sudden spring,<BR>\nLike rising lark, and falling rain,<BR>\nAnd melting water bubbling.<BR>\nHe saw the elven-flowers spring<BR>\nAbout her feet, and healed again<BR>\nHe longed by her to dance and sing<BR>\nUpon the grass untroubling.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When in this world the headlines read<BR>\nOf those whose hearts are filled with greed<BR>\nWho rob and steal from those who need<BR>\nThe cry goes up with blinding speed for Underdog (UNDERDOG!)<BR>\nUnderdog (UNDERDOG!)<BR>\nSpeed of lightning, roar of thunder<BR>\nFighting all who rob or plunder<BR>\nUnderdog (ah-ah-ah-ah)<BR>\nUnderdog<BR>\nUNDERDOG!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And the silence came surging softly backwards<BR>\nWhen the plunging hooves were gone...<BR>\n&nbsp;-- Walter de La Mare, \"The Listeners\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','At times discretion should be thrown aside,<BR>\nand with the foolish we should play the fool.<BR>\n&nbsp;-- Menander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','He who invents adages for others to peruse<BR>\ntakes along rowboat when going on cruise.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When in panic, fear and doubt,<BR>\nDrink in barrels, eat, and shout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hark, the Herald Tribune sings,<BR>\nAdvertising wondrous things.<BR>\n&nbsp;Angels we have heard on High<BR>\nTell us to go out and Buy.<BR>\n&nbsp;-- Tom Lehrer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','&nbsp;better !pout !cry<BR>\n&nbsp;better watchout<BR>\n&nbsp;lpr why<BR>\n&nbsp;santa claus < north pole > town<BR>\n&nbsp;cat /etc/passwd > list<BR>\n&nbsp;ncheck list<BR>\n&nbsp;ncheck list<BR>\n&nbsp;cat list | grep naughty > nogiftlist<BR>\n&nbsp;cat list | grep nice > giftlist<BR>\n&nbsp;santa claus < north pole > town<BR>\n&nbsp;who | grep sleeping<BR>\n&nbsp;who | grep awake<BR>\n&nbsp;who | grep bad || good<BR>\n&nbsp;for (goodness sake) {<BR>\n&nbsp;be good<BR>\n&nbsp;}');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hey! Come derry dol!  Hop along, my hearties!<BR>\nHobbits!  Ponies all!  We are fond of parties.<BR>\nNow let the fun begin!  Let us sing together!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','HERE LIES LESTER MOORE<BR>\nSHOT 4 TIMES WITH A .44<BR>\nNO LES<BR>\nNO MOORE<BR>\n&nbsp;-- tombstone, in Tombstone, AZ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The net of law is spread so wide,<BR>\nNo sinner from its sweep may hide.<BR>\nIts meshes are so fine and strong,<BR>\nThey take in every child of wrong.<BR>\nO wondrous web of mystery!<BR>\nBig fish alone escape from thee!<BR>\n&nbsp;-- James Jeffrey Roche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The garden is in mourning;<BR>\nThe rain falls cool among the flowers.<BR>\nSummer shivers quietly<BR>\nOn its way towards its end.<BR>\n&nbsp;Golden leaf after leaf<BR>\nFalls from the tall acacia.<BR>\nSummer smiles, astonished, feeble,<BR>\nIn this dying dream of a garden.<BR>\n&nbsp;For a long while, yet, in the roses,<BR>\nShe will linger on, yearning for peace,<BR>\nAnd slowly<BR>\nClose her weary eyes.<BR>\n&nbsp;-- Hermann Hesse, \"September\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And in the heartbreak years that lie ahead,<BR>\nBe true to yourself and the Grateful Dead.<BR>\n&nbsp;-- Joan Baez');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Give me the avowed, the erect, the manly foe,<BR>\nBold I can meet -- perhaps may turn his blow!<BR>\nBut of all plagues, good Heaven, thy wrath can send,<BR>\nSave me, oh save me from the candid friend.<BR>\n&nbsp;-- George Canning');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And here I wait so patiently<BR>\nWaiting to find out what price<BR>\nYou have to pay to get out of<BR>\nGoing thru all of these things twice<BR>\n&nbsp;-- Dylan, \"Memphis Blues Again\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hickory Dickory Dock,<BR>\nThe mice ran up the clock,<BR>\nThe clock struck one,<BR>\nThe others escaped with minor injuries.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And miles to go before I sleep.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And this is good old Boston,<BR>\nThe home of the bean and the cod,<BR>\nWhere the Lowells talk only to Cabots,<BR>\nAnd the Cabots talk only to God.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I can live without<BR>\nSomeone I love<BR>\nBut not without<BR>\nSomeone I need.<BR>\n&nbsp;-- \"Safety\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Despising machines to a man,<BR>\nThe Luddites joined up with the Klan,<BR>\n&nbsp;And ride out by night<BR>\n&nbsp;In a sheeting of white<BR>\nTo lynch all the robots they can.<BR>\n&nbsp;-- C. M. and G. A. Maxson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And as we stand on the edge of darkness<BR>\nLet our chant fill the void<BR>\nThat others may know<BR>\n&nbsp;In the land of the night<BR>\n&nbsp;The ship of the sun<BR>\n&nbsp;Is drawn by<BR>\n&nbsp;The grateful dead.<BR>\n&nbsp;-- Tibetan \"Book of the Dead,\" ca. 4000 BC.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hey! now!  Come hoy now!  Whither do you wander?<BR>\nUp, down, near or far, here, there or yonder?<BR>\nSharp-ears, Wise-nose, Swish-tail and Bumpkin,<BR>\nWhite-socks my little lad, and old Fatty Lumpkin!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The sun was shining on the sea,<BR>\nShining with all his might:<BR>\nHe did his very best to make<BR>\nThe billows smooth and bright --<BR>\nAnd this was very odd, because it was<BR>\nThe middle of the night.<BR>\n&nbsp;-- Lewis Carroll, \"Through the Looking Glass\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And I heard Jeff exclaim,<BR>\nAs they strolled out of sight,<BR>\n\"Merry Christmas to all --<BR>\nYou take credit cards, right?\"<BR>\n&nbsp;-- \"Outsiders\" comic');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Hey dol! merry dol! ring a dong dillo!<BR>\nRing a dong! hop along! fal lal the willow!<BR>\nTom Bom, jolly Tom, Tom Bombadillo!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','And if you wonder,<BR>\nWhat I am doing,<BR>\nAs I am heading for the sink.<BR>\nI am spitting out all the bitterness,<BR>\nAlong with half of my last drink.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Ho! Tom Bombadil, Tom Bombadillo!<BR>\nBy water, wood and hill, by reed and willow,<BR>\nBy fire, sun and moon, harken now and hear us!<BR>\nCome, Tom Bombadil, for our need is near us!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','\"Thirty days hath Septober,<BR>\nApril, June, and no wonder.<BR>\nall the rest have peanut butter<BR>\nexcept my father who wears red suspenders.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When in trouble or in doubt,<BR>\nrun in circles, scream and shout.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','An eye in a blue face<BR>\nSaw an eye in a green face.<BR>\n\"That eye is like this eye\"<BR>\nSaid the first eye,<BR>\n\"But in low place,<BR>\nNot in high place.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Higgeldy Piggeldy,<BR>\nHamlet of Elsinore<BR>\nRuffled the critics by<BR>\nDropping this bomb:<BR>\n\"Phooey on Freud and his<BR>\nPsychoanalysis --<BR>\nOedipus, Shmoedipus,<BR>\nI just love Mom.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The hope that springs eternal<BR>\nSprings right up your behind.<BR>\n&nbsp;-- Ian Drury, \"This Is What We Find\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I B M<BR>\nU B M<BR>\nWe all B M<BR>\nFor I B M!!!!<BR>\n&nbsp;-- H.A.R.L.I.E.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When oxygen Tech played Hydrogen U.<BR>\nThe Game had just begun, when Hydrogen scored two fast points<BR>\nAnd Oxygen still had none<BR>\nThen Oxygen scored a single goal<BR>\nAnd thus it did remain, At Hydrogen 2 and Oxygen 1<BR>\nCalled because of rain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','All that is gold does not glitter,<BR>\nNot all those who wander are lost;<BR>\nThe old that is strong does not wither,<BR>\nDeep roots are not reached by the frost. <BR>\nFrom the ashes a fire shall be woken,<BR>\nA light from the shadows shall spring;<BR>\nRenewed shall be blade that was broken,<BR>\nThe crownless again shall be king.<BR>\n&nbsp;-- J.R.R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The Bird of Time has but a little way to fly ...<BR>\nand the bird is on the wing.<BR>\n&nbsp;-- Omar Khayyam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','How doth the little crocodile<BR>\n&nbsp;Improve his shining tail,<BR>\nAnd pour the waters of the Nile<BR>\n&nbsp;On every golden scale!<BR>\n&nbsp;How cheerfully he seems to grin,<BR>\n&nbsp;How neatly spreads his claws,<BR>\nAnd welcomes little fishes in,<BR>\n&nbsp;With gently smiling jaws!<BR>\n&nbsp;-- Lewis Carrol, \"Alice in Wonderland\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','All who joy would win Must share it --<BR>\nHappiness was born a twin.<BR>\n&nbsp;-- Lord Byron');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','&nbsp;Against Idleness and Mischief<BR>\n&nbsp;How doth the little busy bee		How skillfully she builds her cell!<BR>\nImprove each shining hour,		How neat she spreads the wax!<BR>\nAnd gather honey all the day		And labours hard to store it well<BR>\nFrom every opening flower!		With the sweet food she makes.<BR>\n&nbsp;In works of labour or of skill		In books, or work, or healthful play,<BR>\nI would be busy too;			Let my first years be passed,<BR>\nFor Satan finds some mischief still	That I may give for every day<BR>\nFor idle hands to do.			Some good account at last.<BR>\n&nbsp;-- Isaac Watts, 1674-1748');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Aleph-null bottles of beer on the wall,<BR>\nAleph-null bottles of beer,<BR>\nYou take one down, and pass it around,<BR>\nAleph-null bottles of beer on the wall.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','...his disciples lead him in; he just does the rest.<BR>\n&nbsp;-- The Who, \"Tommy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Ho! Ho! Ho! to the bottle I go<BR>\nTo heal my heart and drown my woe.<BR>\nRain may fall and wind may blow,<BR>\nAnd many miles be still to go,<BR>\nBut under a tall tree I will lie,<BR>\nAnd let the clouds go sailing by.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Alive without breath,<BR>\nAs cold as death;<BR>\nNever thirsty, ever drinking,<BR>\nAll in mail ever clinking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When you and I are far apart<BR>\nCan sorrow break your tender heart?<BR>\nI love you darling, yes I do;<BR>\nSleep is so sweet when I dream of you;<BR>\nAll you are is a blossoming rose.<BR>\nNight is here so I must close.<BR>\nWith care read the first word of each line.<BR>\nYou will find a question of mine.<BR>\n&nbsp;-- Yours hopefully, The VAX.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Planet Claire has pink hair.<BR>\nAll the trees are red.<BR>\nNo one ever dies there.<BR>\nNo one has a head....');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When the leaders speak of peace<BR>\nThe common folk know<BR>\nThat war is coming<BR>\nWhen the leaders curse war<BR>\nThe mobilization order is already written out.<BR>\n&nbsp;Every day, to earn my daily bread<BR>\nI go to the market where lies are bought<BR>\nHopefully<BR>\nI take my place among the sellers.<BR>\n&nbsp;-- Bertolt Brecht, \"Hollywood\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I knew Leo G. Carrol<BR>\nWas over a barrel<BR>\nWhen Tarantula took to the hills.	[\"Lick it!\"]<BR>\nAnd I really got hot<BR>\nWhen I saw Jeanette Scott<BR>\nFight a triffid that spits poison and kills.<BR>\n&nbsp;Science fiction, double feature<BR>\nDoctor X will build a creature.<BR>\nSee androids fighting Brad and Janet<BR>\nAnne Francis stars in Forbidden Planet<BR>\nOh Oh Oh Oh Oh<BR>\nAt the late night, double feature, picture show.<BR>\n&nbsp;-- The Rocky Horror Picture Show');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Whenever Richard Cory went downtown,<BR>\n&nbsp;We people on the pavement looked at him:<BR>\nHe was a gentleman from sole to crown,<BR>\n&nbsp;Clean-favored, and imperially slim.<BR>\nAnd he was always quietly arrayed,<BR>\n&nbsp;And he was always human when he talked;<BR>\nBut still he fluttered pulses when he said,<BR>\n&nbsp;\"Good morning,\" and he glittered when he walked.<BR>\nAnd he was rich -- yes, richer than a king --<BR>\n&nbsp;And admirably schooled in every grace:<BR>\nIn fine, we thought that he was everything<BR>\n&nbsp;To make us wish that we were in his place.<BR>\nSo on we worked, and waited for the light,<BR>\n&nbsp;And went without the meat, and cursed the bread;<BR>\nAnd Richard Cory, one calm summer night,<BR>\n&nbsp;Went home and put a bullet through his head.<BR>\n&nbsp;-- E.A. Robinson, \"Richard Cory\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I have lots of things in my pockets;<BR>\nNone of them is worth anything.<BR>\nSociopolitical whines aside,<BR>\nGan you give me, gratis, free,<BR>\nThe price of half a gallon<BR>\nOf Gallo extra bad<BR>\nAnd most of the bus fare home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','When you meet a master swordsman,<BR>\nshow him your sword.<BR>\nWhen you meet a man who is not a poet,<BR>\ndo not show him your poem.<BR>\n&nbsp;-- Rinzai, ninth century Zen master');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Ah, my friends, from the prison, they ask unto me,<BR>\n\"How good, how good does it feel to be free?\"<BR>\nAnd I answer them most mysteriously:<BR>\n\"Are birds free from the chains of the sky-way?\"<BR>\n&nbsp;-- Bob Dylan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','After all my erstwhile dear,<BR>\nMy no longer cherished,<BR>\nNeed we say it was not love,<BR>\nJust because it perished?<BR>\n&nbsp;-- Edna St. Vincent Millay');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Whip it, baby.<BR>\nWhip it right.<BR>\nWhip it, baby.<BR>\nWhip it all night!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Be assured that a walk through the ocean of most Souls would scarcely<BR>\nget your Feet wet.  Fall not in Love, therefore: it will stick to your face.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','While I nodded, nearly napping, suddenly there came a tapping,<BR>\nAs of some one gently rapping, rapping at my chamber door.<BR>\n&nbsp;-- Edgar Allan Poe, \"The Raven\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to hardware interrupts.]<BR>\n&nbsp;And now I see with eye serene<BR>\nThe very pulse of the machine.<BR>\n&nbsp;-- William Wordsworth, \"She Was a Phantom of Delight\"<BR>\n&nbsp;[Quoted in \"VMS Internals and Data Structures\", V4.4, when<BR>\n&nbsp;referring to software interrupts.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Suffering alone exists, none who suffer;<BR>\nThe deed there is, but no doer thereof;<BR>\nNirvana is, but no one is seeking it;<BR>\nThe Path there is, but none who travel it.<BR>\n&nbsp;-- \"Buddhist Symbolism\", Symbols and Values');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Whether weary or unweary, O man, do not rest,<BR>\nDo not cease your single-handed struggle.<BR>\nGo on, do not rest.<BR>\n&nbsp;-- An old Gujarati hymn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In the dimestores and bus stations<BR>\nPeople talk of situations<BR>\nRead books repeat quotations<BR>\nDraw conclusions on the wall.<BR>\n&nbsp;-- Bob Dylan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Whether you can hear it or not,<BR>\nThe Universe is laughing behind your back.<BR>\n&nbsp;-- National Lampoon, \"Deteriorata\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Who does not love wine, women, and song,<BR>\nRemains a fool his whole life long.<BR>\n&nbsp;-- Johann Heinrich Voss');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I lately lost a preposition;<BR>\nIt hid, I thought, beneath my chair<BR>\nAnd angrily I cried, \"Perdition!<BR>\nUp from out of under there.\"<BR>\n&nbsp;Correctness is my vade mecum,<BR>\nAnd straggling phrases I abhor,<BR>\nAnd yet I wondered, \"What should he come<BR>\nUp from out of under for?\"<BR>\n&nbsp;-- Morris Bishop');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A man of genius makes no mistakes.<BR>\nHis errors are volitional and are the portals of discovery.<BR>\n&nbsp;-- James Joyce, \"Ulysses\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A mighty creature is the germ,<BR>\nThough smaller than the pachyderm.<BR>\nHis customary dwelling place<BR>\nIs deep within the human race.<BR>\nHis childish pride he often pleases<BR>\nBy giving people strange diseases.<BR>\nDo you, my poppet, feel infirm?<BR>\nYou probably contain a germ.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I see the eigenvalue in thine eye,<BR>\nI hear the tender tensor in thy sigh.<BR>\nBernoulli would have been content to die<BR>\nHad he but known such _a-squared cos 2(phi)!<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Who to himself is law no law doth need,<BR>\noffends no law, and is a king indeed.<BR>\n&nbsp;-- George Chapman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A man who fishes for marlin in ponds<BR>\nwill put his money in Etruscan bonds.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Piping down the valleys wild,<BR>\nPiping songs of pleasant glee,<BR>\nOn a cloud I saw a child,<BR>\nAnd he laughing said to me:<BR>\n\"Pipe a song about a Lamb!\"<BR>\nSo I piped with merry cheer.<BR>\n\"Piper, pipe that song again;\"<BR>\nSo I piped: he wept to hear.<BR>\n&nbsp;-- William Blake, \"Songs of Innocence\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I really hate this damned machine<BR>\nI wish that they would sell it.<BR>\nIt never does quite what I want<BR>\nBut only what I tell it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A bit of talcum<BR>\nIs always walcum<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A little word of doubtful number,<BR>\nA foe to rest and peaceful slumber.<BR>\nIf you add an \"s\" to this,<BR>\nGreat is the metamorphosis.<BR>\nPlural is plural now no more,<BR>\nAnd sweet what bitter was before.<BR>\nWhat am I?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A man is like a rusty wheel on a rusty cart,<BR>\nHe sings his song as he rattles along and then he falls apart.<BR>\n&nbsp;-- Richard Thompson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I would like to know<BR>\nWhat I was fencing in<BR>\nAnd what I was fencing out.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','We found you hiding<BR>\nWe found you lying<BR>\nChoking on the dirt and sand.<BR>\n&nbsp;Your former glories<BR>\nAnd all the stories<BR>\nDragged and washed with eager hands.<BR>\n&nbsp;-- \`\`Cities in Dust\', \"Tinderbox\", Siouxsie & the Banshees.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I went home with a waitress,<BR>\nThe way I always do.<BR>\nHow I was I to know?<BR>\nShe was with the Russians too.<BR>\n&nbsp;I was gambling in Havana,<BR>\nI took a little risk.<BR>\nSend lawyers, guns, and money,<BR>\nDad, get me out of this.<BR>\n&nbsp;-- Warren Zevon, \"Lawyers, Guns and Money\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Your worship is your furnaces<BR>\nwhich, like old idols, lost obscenes,<BR>\nhave molten bowels; your vision is<BR>\nmachines for making more machines.<BR>\n&nbsp;-- Gordon Bottomley, 1874');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A cousin of mine once said about money,<BR>\nmoney is always there but the pockets change;<BR>\nit is not in the same pockets after a change,<BR>\nand that is all there is to say about money.<BR>\n&nbsp;-- Gertrude Stein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','You will find me drinking gin<BR>\nIn the lowest kind of inn,<BR>\nBecause I am a rigid Vegetarian.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I was born in a barrel of butcher knives<BR>\nTrouble I love and peace I despise<BR>\nWild horses kicked me in my side<BR>\nThen a rattlesnake bit me and he walked off and died.<BR>\n&nbsp;-- Bo Diddley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','IBM had a PL/I,<BR>\n&nbsp;Its syntax worse than JOSS;<BR>\nAnd everywhere this language went,<BR>\n&nbsp;It was a total loss.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The all-softening overpowering knell,<BR>\nThe tocsin of the soul, -- the dinner bell.<BR>\n&nbsp;-- Lord Byron');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','I<BR>\nam<BR>\nnot<BR>\nvery<BR>\nhappy<BR>\nacting<BR>\npleased<BR>\nwhenever<BR>\nprominent<BR>\nscientists<BR>\novermagnify<BR>\nintellectual<BR>\nenlightenment');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Parsley<BR>\n&nbsp;is gharsley.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','99 blocks of crud on the disk,<BR>\n99 blocks of crud!<BR>\nYou patch a bug, and dump it again:<BR>\n100 blocks of crud on the disk!<BR>\n&nbsp;100 blocks of crud on the disk,<BR>\n100 blocks of crud!<BR>\nYou patch a bug, and dump it again:<BR>\n101 blocks of crud on the disk! ...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If you stick a stock of liquor in your locker,<BR>\nIt is slick to stick a lock upon your stock. <BR>\n&nbsp;Or some joker who is slicker,<BR>\n&nbsp;Will trick you of your liquor,<BR>\nIf you fail to lock your liquor with a lock.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If researchers wrote nursery rhymes...<BR>\n&nbsp;Little Miss Muffet sat on her gluteal region,<BR>\nEating components of soured milk.<BR>\nOn at least one occasion,<BR>\n&nbsp;along came an arachnid and sat down beside her,<BR>\nOr at least in her vicinity,<BR>\nAnd caused her to feel an overwhelming, but not paralyzing, fear,<BR>\nWhich motivated the patient to leave the area rather quickly.<BR>\n&nbsp;-- Ann Melugin Williams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If she had not been cupric in her ions,<BR>\nHer shape ovoidal,<BR>\nTheir romance might have flourished.<BR>\nBut he built tetrahedral in his shape,<BR>\nHis ions ferric,<BR>\nLove could not help but die,<BR>\nUncatylised, inert, and undernourished.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Other women cloy<BR>\nThe appetites they feed, but she makes hungry<BR>\nWhere most she satisfies.<BR>\n&nbsp;-- Antony and Cleopatra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If I promised you the moon and the stars, would you believe it?<BR>\n&nbsp;-- Alan Parsons Project');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In Riemann, Hilbert or in Banach space<BR>\nLet superscripts and subscripts go their ways.<BR>\nOur asymptotes no longer out of phase,<BR>\nWe shall encounter, counting, face to face.<BR>\n&nbsp;-- Stanislaw Lem, \"Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If all be true that I do think,<BR>\nThere be five reasons why one should drink;<BR>\nGood friends, good wine, or being dry,<BR>\nOr lest we should be by-and-by,<BR>\nOr any other reason why.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If all the seas were ink,<BR>\nAnd all the reeds were pens,<BR>\nAnd all the skies were parchment,<BR>\nAnd all the men could write,<BR>\nThese would not suffice<BR>\nTo write down all the red tape<BR>\nOf this Government. ');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If a nation expects to be ignorant and free,<BR>\n... it expects what never was and never will be.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','It is not good for a man to be without knowledge,<BR>\nand he who makes haste with his feet misses his way.<BR>\n&nbsp;-- Proverbs 19:2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','It used to be the fun was in<BR>\nThe capture and kill.<BR>\nIn another place and time<BR>\nI did it all for thrills.<BR>\n&nbsp;-- Lust to Love');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A box without hinges, key, or lid,<BR>\nYet golden treasure inside is hid.<BR>\n&nbsp;-- J.R.R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Into love and out again,<BR>\n&nbsp;Thus I went and thus I go.<BR>\nSpare your voice, and hold your pen:<BR>\n&nbsp;Well and bitterly I know<BR>\nAll the songs were ever sung,<BR>\n&nbsp;All the words were ever said;<BR>\nCould it be, when I was young,<BR>\n&nbsp;Someone dropped me on my head?<BR>\n&nbsp;-- Dorothy Parker, \"Theory\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In Xanadu did Kubla Khan a stately pleasure dome decree<BR>\nBut only if the NFL to a franchise would agree.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Old Mother Hubbard went to the cupboard<BR>\nTo fetch her poor daughter a dress.<BR>\nWhen she got there, the cupboard was bare<BR>\nAnd so was her daughter, I guess...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In Xanadu did Kubla Khan<BR>\nA stately pleasure dome decree:<BR>\nWhere Alph, the sacred river, ran<BR>\nThrough caverns measureless to man<BR>\nDown to a sunless sea.<BR>\nSo twice five miles of fertile ground<BR>\nWith walls and towers were girdled round:<BR>\nAnd there were gardens bright with sinuous rills,<BR>\nWhere blossomed many an incense-bearing tree;<BR>\nAnd here were forest ancient as the hills,<BR>\nEnfolding sunny spots of greenery.<BR>\n&nbsp;-- S.T. Coleridge, \"Kubla Kahn\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In this vale<BR>\nOf toil and sin<BR>\nYour head grows bald<BR>\nBut not your chin.<BR>\n&nbsp;-- Burma Shave');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','It cannot be seen, cannot be felt,<BR>\nCannot be heard, cannot be smelt.<BR>\nIt lies behind starts and under hills,<BR>\nAnd empty holes it fills.<BR>\nIt comes first and follows after,<BR>\nEnds life, kills laughter.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In the land of the dark the Ship of the<BR>\nSun is driven by the Grateful Dead.<BR>\n&nbsp;-- Egyptian Book of the Dead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','This thing all things devours:<BR>\nBirds, beasts, trees, flowers;<BR>\nGnaws iron, bites steel;<BR>\nGrinds hard stones to meal;<BR>\nSlays king, ruins town,<BR>\nAnd beats high mountain down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Our little systems have their day;<BR>\nThey have their day and cease to be;<BR>\nThey are but broken lights of thee.<BR>\n&nbsp;-- Tennyson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','In /users3 did Kubla Kahn<BR>\nA stately pleasure dome decree,<BR>\nWhere /bin, the sacred river ran<BR>\nThrough Test Suites measureless to Man<BR>\nDown to a sunless C.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','If you had just a minute to breathe,<BR>\nAnd they granted you one final wish,<BR>\nWould you ask for something<BR>\nLike another chance?<BR>\n&nbsp;-- Traffic, \"The Low Spark of High Heeled Boys\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Love, which is quickly kindled in a gentle heart,<BR>\n&nbsp;seized this one for the fair form<BR>\n&nbsp;that was taken from me-and the way of it afficts me still.<BR>\nLove, which absolves no loved one from loving,<BR>\n&nbsp;seized me so strongly with delight in him,<BR>\n&nbsp;that, as you see, it does not leave me even now.<BR>\nLove brought us to one death.<BR>\n&nbsp;-- La Divina Commedia: Inferno V, vv. 100-06');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Keep ancient lands, your storied pomp! cries she<BR>\nWith silent lips.  Give me your tired, your poor,<BR>\nYour huddled masses yearning to breathe free,<BR>\nThe wretched refuse of your teeming shore.<BR>\nSend these, the homeless, tempest-tossed to me...<BR>\n&nbsp;-- Emma Lazarus, \"The New Colossus\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Logicians have but ill defined<BR>\nAs rational the human kind.<BR>\nLogic, they say, belongs to man,<BR>\nBut let them prove it if they can.<BR>\n&nbsp;-- Oliver Goldsmith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','John			Dame May		Oscar<BR>\nWas Gay			Was Whitty		Was Wilde<BR>\nBut Gerard Hopkins	But John Greenleaf	But Thornton<BR>\nWas Manley		Was Whittier		Was Wilder<BR>\n&nbsp;-- Willard Espy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','It was one time too many<BR>\nOne word too few<BR>\nIt was all too much for me and you<BR>\nThere was one way to go<BR>\nNothing more we could do<BR>\nOne time too many<BR>\nOne word too few<BR>\n&nbsp;-- Meredith Tanner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Meanehwael, baccat meaddehaele, monstaer lurccen;<BR>\nFulle few too many drincce, hie luccen for fyht.<BR>\n[D]en Hreorfneorht[d]hwr, son of Hrwaerow[p]heororthwl,<BR>\nAEsccen aewful jeork to steop outsyd.<BR>\n[P]hud!  Bashe!  Crasch!  Beoom!  [D]e bigge gye<BR>\nEallum his bon brak, byt his nose offe;<BR>\nWicced Godsylla waeld on his asse.<BR>\nMonstaer moppe fleor wy[p] eallum men in haelle.<BR>\nBeowulf in bacceroome fonecall bemaccen waes;<BR>\nHearen sond of ruccus saed, \"Hwaet [d]e helle?\"<BR>\nGraben sheold strang ond swich-blaed scharp<BR>\nSond feorth to fyht [d]e grimlic foe.<BR>\n\"Me,\" Godsylla saed, \"mac [d]e minsemete.\"<BR>\nHeoro cwyc geten heold wi[p] faemed half-nelson<BR>\nOnd flyng him lic frisbe bac to fen.<BR>\nBeowulf belly up to meaddehaele bar,<BR>\nSaed, \"Ne foe beaten mie faersom cung-fu.\"<BR>\nEorderen cocca-colha yce-coeld, [d]e reol [p]yng.<BR>\n&nbsp;-- Not Chaucer, for certain');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Lisp, Lisp, Lisp Machine,<BR>\nLisp Machine is Fun.<BR>\nLisp, Lisp, Lisp Machine,<BR>\nFun for everyone.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','\"Lines that are parallel meet at Infinity!\"<BR>\nEuclid repeatedly, heatedly, urged.<BR>\n&nbsp;Until he died, and so reached that vicinity:<BR>\nin it he found that the damned things diverged.<BR>\n&nbsp;-- Piet Hein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Do your otters do the shimmy?<BR>\nDo they like to shake their tails?<BR>\nDo your wombats sleep in tophats?<BR>\nIs your garden full of snails?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Let us treat men and women well;<BR>\nTreat them as if they were real;<BR>\nPerhaps they are.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Let us go, through certain half-deserted streets,<BR>\nThe muttering retreats<BR>\nOf restless nights in one-night cheap hotels<BR>\nAnd sawdust restaurants with oyster-shells:<BR>\nStreets that follow like a tedious argument<BR>\nOf insidious intent<BR>\nTo lead you to an overwhelming question...<BR>\nOh, do not ask, \"What is it?\"<BR>\n&nbsp;-- T.S. Eliot, \"Love song of J. Alfred Prufrock\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Let us go then you and I<BR>\nwhile the night is laid out against the sky<BR>\nlike a smear of mustard on an old pork pie.<BR>\n&nbsp;\"Nice poem Tom.  I have ideas for changes though, why not come over?\"<BR>\n&nbsp;-- Ezra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Ladybug, ladybug,<BR>\nLook to your stern!<BR>\nYour house is on fire,<BR>\nYour children will burn!<BR>\nSo jump ye and sing, for<BR>\nThe very first time<BR>\nThe four lines above<BR>\nHave been put into rhyme.<BR>\n&nbsp;-- Walt Kelly');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Lady, lady, should you meet<BR>\nOne whose ways are all discreet,<BR>\nOne who murmurs that his wife<BR>\nIs the lodestar of his life,<BR>\nOne who keeps assuring you<BR>\nThat he never was untrue,<BR>\nNever loved another one...<BR>\nLady, lady, better run!<BR>\n&nbsp;-- Dorothy Parker, \"Social Note\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Lift every voice and sing<BR>\nTill earth and heaven ring,<BR>\nRing with the harmonies of Liberty;<BR>\nLet our rejoicing rise<BR>\nHigh as the listening skies,<BR>\nLet it resound loud as the rolling sea.<BR>\n&nbsp;Sing a song full of the faith that the dark past has taught us.<BR>\nSing a song full of the hope that the present has bought us.<BR>\nFacing the rising sun of our new day begun,<BR>\nLet us march on till victory is won.<BR>\n&nbsp;-- James Weldon Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','My Bonnie looked into a gas tank,<BR>\nThe height of its contents to see!<BR>\nShe lit a small match to assist her,<BR>\nOh, bring back my Bonnie to me.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','My darling wife was always glum.<BR>\nI drowned her in a cask of rum,<BR>\nAnd so made sure that she would stay<BR>\nIn better spirits night and day.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','My calculator is my shepherd, I shall not want<BR>\nIt maketh me accurate to ten significant figures,<BR>\n&nbsp;and it leadeth me in scientific notation to 99 digits.<BR>\nIt restoreth my square roots and guideth me along paths of floating<BR>\n&nbsp;decimal points for the sake of precision.<BR>\nYea, tho I walk through the valley of surprise quizzes,<BR>\n&nbsp;I will fear no prof, for my calculator is there to hearten me.<BR>\nIt prepareth a log table to comfort me, it prepareth an<BR>\n&nbsp;arc sin for me in the presence of my teachers.<BR>\nIt annoints my homework with correct solutions, my interpolations are<BR>\n&nbsp;over.<BR>\nSurely, both precision and accuracy shall follow me all the days of my<BR>\n&nbsp;life, and I shall dwell in the house of Texas instruments forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Old Tom Bombadil is a merry fellow,<BR>\nBright blue his jacket is, and his boots are yellow.<BR>\nNone has ever caught him yet, for Tom, he is the master:<BR>\nHis songs are stronger songs, and his feet are faster.<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','No sooner had Edger Allen Poe<BR>\nFinished his old Raven,<BR>\nthen he started his Old Crow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','No rock so hard but that a little wave<BR>\nMay beat admission in a thousand years.<BR>\n&nbsp;-- Tennyson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Observe yon plumed biped fine.<BR>\nTo activate its captivation,<BR>\nDeposit on its termination,<BR>\nA quantity of particles saline.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The carbonyl is polarized,<BR>\nThe delta end is plus.<BR>\nThe nucleophile will thus attack,<BR>\nThe carbon nucleus.<BR>\nAddition makes an alcohol,<BR>\nOf types there are but three.<BR>\nIt makes a bond, to correspond,<BR>\nFrom C to shining C.<BR>\n&nbsp;-- Prof. Frank Westheimer, to \"America the Beautiful\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Now of my threescore years and ten,<BR>\nTwenty will not come again,<BR>\nAnd take from seventy springs a score,<BR>\nIt leaves me only fifty more.<BR>\n&nbsp;And since to look at things in bloom<BR>\nFifty springs are little room,<BR>\nAbout the woodlands I will go<BR>\nTo see the cherry hung with snow.<BR>\n&nbsp;-- A.E. Housman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Now let the song begin!  Let us sing together<BR>\nOf sun, star, moon and mist, rain and cloudy weather,<BR>\nLight on the budding leag, dew on the feather,<BR>\nWind on the open hill, bells on the heather,<BR>\nReeds by the shady pool, lilies on the water:<BR>\nOld Tom Bombadil and the River-daughter!<BR>\n&nbsp;-- J. R. R. Tolkien');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Now I lay me down to sleep<BR>\nI pray the double lock will keep;<BR>\nMay no brick through the window break,<BR>\nAnd, no one rob me till I awake.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Now hatred is by far the longest pleasure;<BR>\nMen love in haste, but they detest at leisure.<BR>\n&nbsp;-- George Gordon, Lord Byron, \"Don Juan\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','100 buckets of bits on the bus	<BR>\n100 buckets of bits<BR>\nTake one down, short it to ground<BR>\nFF buckets of bits on the bus	<BR>\n&nbsp;FF buckets of bits on the bus	<BR>\nFF buckets of bits<BR>\nTake one down, short it to ground<BR>\nFE buckets of bits on the bus	<BR>\n&nbsp;ad infinitum...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','The wombat lives across the seas,<BR>\nAmong the far Antipodes.<BR>\nHe may exist on nuts and berries,<BR>\nOr then again, on missionaries;<BR>\nHis distant habitat precludes<BR>\nConclusive knowledge of his moods.<BR>\nBut I would not engage the wombat<BR>\nIn any form of mortal combat.<BR>\n&nbsp;-- \"The Wombat\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','Oh, life is a glorious cycle of song,<BR>\nA medley of extemporanea;<BR>\nAnd love is thing that can never go wrong;<BR>\nAnd I am Marie of Roumania.<BR>\n&nbsp;-- Dorothy Parker, \"Comment\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('songs-poems','A robin redbreast in a cage<BR>\nPuts all Heaven in a rage.<BR>\n&nbsp;-- Blake');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','They also surf who only stand on waves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Life is a yo-yo, and mankind ties knots in the string.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','On Thanksgiving Day all over America, families sit down to dinner at the<BR>\nsame moment -- halftime.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Go directly to jail.  Do not pass Go, do not collect $200.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','From 0 to \"what seems to be the problem officer\" in 8.3 seconds.<BR>\n&nbsp;-- Ad for the new VW Corrado');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Football combines the two worst features of American life.<BR>\nIt is violence punctuated by committee meetings.<BR>\n&nbsp;-- George F. Will, \"Men At Work:  The Craft of Baseball\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Football is a game designed to keep coalminers off the streets.<BR>\n&nbsp;-- Jimmy Breslin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Every creature has within him the wild, uncontrollable urge to punt.<BR>\n&nbsp;-- Snoopy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Decisions of the judges will be final unless shouted down by a really over-<BR>\nwhelming majority of the crowd present.  Abusive and obscene language may<BR>\nnot be used by contestants when addressing members of the judging panel,<BR>\nor, conversely, by members of the judging panel when addressing contestants<BR>\n(unless struck by a boomerang).<BR>\n&nbsp;-- Mudgeeraba Creek Emu-Riding and Boomerang-Throwing Assoc.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Ever feel like life was a game and you had the wrong instruction book?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Flying is the second greatest feeling you can have.  The greatest feeling?<BR>\nLanding...  Landing is the greatest feeling you can have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Dallas Cowboys Official Schedule<BR>\n&nbsp;Sept 14		Pasadena Junior High<BR>\n&nbsp;Sept 21		Boy Scout Troop 049<BR>\n&nbsp;Sept 28		Blind Academy<BR>\n&nbsp;Sept 30		World War I Veterans<BR>\n&nbsp;Oct 5		Brownie Scout Troop 041<BR>\n&nbsp;Oct 12		Sugarcreek High Cheerleaders<BR>\n&nbsp;Oct 26		St. Thomas Boys Choir<BR>\n&nbsp;Nov 2		Texas City Vet Clinic<BR>\n&nbsp;Nov 9		Korean War Amputees<BR>\n&nbsp;Nov 15		VA Hospital Polio Patients');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Keep grandma off the streets -- legalize bingo.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','It gets late early out there.<BR>\n&nbsp;-- Yogi Berra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','It has long been known that one horse can run faster than another --<BR>\nbut which one?  Differences are crucial.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','In Africa some of the native tribes have a custom of beating the ground<BR>\nwith clubs and uttering spine chilling cries.  Anthropologists call<BR>\nthis a form of primitive self-expression.  In America we call it golf.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The whole of life is futile unless you consider it as a sporting proposition.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I realize that today you have a number of top female athletes such as<BR>\nMartina Navratilova who can run like deer and bench-press Chevrolet<BR>\ntrucks.  But to be brutally frank, women as a group have a long way to<BR>\ngo before they reach the level of intensity and dedication to sports<BR>\nthat enables men to be such incredible jerks about it.<BR>\n&nbsp;-- Dave Barry, \"Sports is a Drag\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I went to the race track once and bet on a horse that was so good that<BR>\nit took seven others to beat him!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I like your game but we have to change the rules.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I believe that professional wrestling is clean and everything else in<BR>\nthe world is fixed.<BR>\n&nbsp;-- Frank Deford, sports writer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Horse sense is the thing a horse has which keeps it from betting on people.<BR>\n&nbsp;-- W. C. Fields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','How can you think and hit at the same time?<BR>\n&nbsp;-- Yogi Berra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Give me a fish and I will eat today.<BR>\n&nbsp;Teach me to fish and I will eat forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','If you want to see card tricks, you have to expect to take cards.<BR>\n&nbsp;-- Harry Blackstone');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Never play pool with anyone named \"Fats\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','One way to stop a runaway horse is to bet on him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Nothing increases your golf score like witnesses.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','NEWS FLASH!!<BR>\nToday the East German pole-vault champion became the West German pole-vault<BR>\nchampion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','MARTA WAS WATCHING THE FOOTBALL GAME with me when she said, \"You know most<BR>\nof these sports are based on the idea of one group protecting its<BR>\nterritory from invasion by another group.\"<BR>\n&nbsp;\"Yeah,\" I said, trying not to laugh.  Girls are funny.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I guess the Little League is even littler than we thought.<BR>\n&nbsp;-- D. Cavett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','One thought driven home is better than three left on base.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','I would rather say that a desire to drive fast sports cars is what sets<BR>\nman apart from the animals.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Look, we play the Star Spangled Banner before every game.  You want us<BR>\nto pay income taxes, too?<BR>\n&nbsp;-- Bill Veeck, Chicago White Sox');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Love means nothing to a tennis player.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The Fastest Defeat In Chess<BR>\n&nbsp;The big name for us in the world of chess is Gibaud, a French chess<BR>\nmaster.  <BR>\n&nbsp;In Paris during 1924 he was beaten after only four moves by a<BR>\nMonsieur Lazard.  Happily for posterity, the moves are recorded and so<BR>\nchess enthusiasts may reconstruct this magnificent collapse in the comfort<BR>\nof their own homes.<BR>\n&nbsp;Lazard was black and Gibaud white:<BR>\n&nbsp;1: P-Q4, Kt-KB3<BR>\n&nbsp;2: Kt-Q2, P-K4<BR>\n&nbsp;3: PxP, Kt-Kt5<BR>\n&nbsp;4: P-K6, Kt-K6<BR>\n&nbsp;White then resigns on realizing that a fifth move would involve<BR>\neither a Q-KR5 check or the loss of his queen.<BR>\n&nbsp;-- Stephen Pile, \"The Book of Heroic Failures\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The pitcher wound up and he flang the ball at the batter.  The batter<BR>\nswang and missed.  The pitcher flang the ball again and this time the<BR>\nbatter connected.  He hit a high fly right to the center fielder.  The<BR>\ncenter fielder was all set to catch the ball, but at the last minute his<BR>\neyes were blound by the sun and he dropped it.<BR>\n&nbsp;-- Dizzy Dean');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Teamwork is essential -- it allows you to blame someone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Support Bingo, keep Grandma off the streets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Rube Walker: \"Hey, Yogi, what time is it?\"<BR>\nYogi Berra:  \"You mean now?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Reporter:   \"What would you do if you found a million dollars?\"<BR>\nYogi Berra: \"If the guy was poor, I would give it back.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','P-K4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Repel them.  Repel them.  Induce them to relinquish the spheroid.<BR>\n&nbsp;-- Indiana University football cheer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','A [golf] ball hitting a tree shall be deemed not to have hit the tree.<BR>\nHitting a tree is simply bad luck and has no place in a scientific game.<BR>\nThe player should estimate the distance the ball would have traveled if it<BR>\nhad not hit the tree and play the ball from there, preferably atop a nice<BR>\nfirm tuft of grass.<BR>\n&nbsp;-- Donald A. Metz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','A [golf] ball sliced or hooked into the rough shall be lifted and placed in<BR>\nthe fairway at a point equal to the distance it carried or rolled into the<BR>\nrough.  Such veering right or left frequently results from friction between<BR>\nthe face of the club and the cover of the ball and the player should not be<BR>\npenalized for the erratic behavior of the ball resulting from such<BR>\nuncontrollable physical phenomena.<BR>\n&nbsp;-- Donald A. Metz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','When in doubt, lead trump.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','If a putt passes over the hole without dropping, it is deemed to have dropped.<BR>\nThe law of gravity holds that any object attempting to maintain a position<BR>\nin the atmosphere without something to support it must drop.  The law of<BR>\ngravity supercedes the law of golf.<BR>\n&nbsp;-- Donald A. Metz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The most serious doubt that has been thrown on the authenticity of the<BR>\nbiblical miracles is the fact that most of the witnesses in regard to<BR>\nthem were fishermen.<BR>\n&nbsp;-- Arthur Binstead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The urge to gamble is so universal and its practice so pleasurable<BR>\nthat I assume it must be evil.<BR>\n&nbsp;-- Heywood Broun');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The surest way to remain a winner is to win once, and then not play any more.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The real problem with hunting elephants is carrying the decoys.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','The one sure way to make a lazy man look respectable is to put a fishing<BR>\nrod in his hand.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','To be sure of hitting the target, shoot first and, whatever you hit,<BR>\ncall it the target.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','If swimming is so good for your figure, how come whales look the<BR>\nway they do?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','THE OLD POOL SHOOTER had won many a game in his life. But now it was time<BR>\nto hang up the cue. When he did, all the other cues came crashing go the floor.<BR>\n&nbsp;\"Sorry,\" he said with a smile.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Bill Dickey is learning me his experience.<BR>\n&nbsp;-- Yogi Berra in his rookie season.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','[Babe] Ruth made a big mistake when he gave up pitching.<BR>\n&nbsp;-- Tris Speaker, 1921');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','Football builds self-discipline.  What else would induce a spectator to<BR>\nsit out in the open in subfreezing weather?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','College football is a game which would be much more interesting if the faculty<BR>\nplayed instead of the students, and even more interesting if the trustees<BR>\nplayed.  There would be a great increase in broken arms, legs, and necks,<BR>\nand simultaneously an appreciable diminution in the loss to humanity.<BR>\n&nbsp;-- H. L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','All bridge hands are equally likely, but some are more equally likely<BR>\nthan others.<BR>\n&nbsp;-- Alan Truscott');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('sports','A putt that stops close enough to the cup to inspire such comments as<BR>\n\"you could blow it in\" may be blown in.  This rule does not apply if<BR>\nthe ball is more than three inches from the hole, because no one wants<BR>\nto make a travesty of the game.<BR>\n&nbsp;-- Donald A. Metz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Hailing frequencies open, Captain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"Life and death are seldom logical.\"<BR>\n&nbsp;\"But attaining a desired goal always is.\"<BR>\n&nbsp;-- McCoy and Spock, \"The Galileo Seven\", stardate 2821.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Kirk to Enterprise -- beam down yeoman Rand and a six-pack.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Behind every great man, there is a woman -- urging him on.<BR>\n&nbsp;-- Harry Mudd, \"I, Mudd\", stardate 4513.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Beam me up, Scotty!  It ate my phaser!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','... bacteriological warfare ... hard to believe we were once foolish<BR>\nenough to play around with that.<BR>\n&nbsp;-- McCoy, \"The Omega Glory\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','You speak of courage.  Obviously you do not know the difference between<BR>\ncourage and foolhardiness.  Always it is the brave ones who die, the soldiers.<BR>\n&nbsp;-- Kor, the Klingon Commander, \"Errand of Mercy\",<BR>\n&nbsp;stardate 3201.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Every living thing wants to survive.<BR>\n&nbsp;-- Spock, \"The Ultimate Computer\", stardate 4731.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Even historians fail to learn from history -- they repeat the same mistakes.<BR>\n&nbsp;-- John Gill, \"Patterns of Force\", stardate 2534.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"Evil does seek to maintain power by suppressing the truth.\"<BR>\n&nbsp;\"Or by misleading the innocent.\"<BR>\n&nbsp;-- Spock and McCoy, \"And The Children Shall Lead\",<BR>\n&nbsp;stardate 5029.5.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Either one of us, by himself, is expendable.  Both of us are not.<BR>\n&nbsp;-- Kirk, \"The Devil in the Dark\", stardate 3196.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Earth -- mother of the most beautiful women in the universe.<BR>\n&nbsp;-- Apollo, \"Who Mourns for Adonais?\" stardate 3468.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Deflector shields just came on, Captain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','[Doctors and Bartenders], We both get the same two kinds of customers<BR>\n-- the living and the dying.<BR>\n&nbsp;-- Dr. Boyce, \"The Menagerie\" (\"The Cage\"), stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Fascinating is a word I use for the unexpected.<BR>\n&nbsp;-- Spock, \"The Squire of Gothos\", stardate 2124.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Computers make excellent and efficient servants, but I have no wish to<BR>\nserve under them.  Captain, a starship also runs on loyalty to one<BR>\nman.  And nothing can replace it or him.<BR>\n&nbsp;-- Spock, \"The Ultimate Computer\", stardate 4729.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Death, when unnecessary, is a tragic thing.<BR>\n&nbsp;-- Flint, \"Requiem for Methuselah\", stardate 5843.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Change is the essential process of all existence.<BR>\n&nbsp;-- Spock, \"Let That Be Your Last Battlefield\", stardate 5730.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','\"Can you imagine how life could be improved if we could do away with<BR>\njealousy, greed, hate ...\"<BR>\n&nbsp;\"It can also be improved by eliminating love, tenderness, sentiment --<BR>\nthe other side of the coin\"<BR>\n&nbsp;-- Dr. Roger Corby and Kirk, \"What are Little Girls Made Of?\",<BR>\n&nbsp;stardate 2712.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Another war ... must it always be so?  How many comrades have we lost<BR>\nin this way? ...  Obedience.  Duty.  Death, and more death ...<BR>\n&nbsp;-- Romulan Commander, \"Balance of Terror\", stardate 1709.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Ahead warp factor one, Mr. Sulu.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','All your people must learn before you can reach for the stars.<BR>\n&nbsp;-- Kirk, \"The Gamesters of Triskelion\", stardate 3259.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Another Armenia, Belgium ... the weak innocents who always seem to be<BR>\nlocated on a natural invasion route.<BR>\n&nbsp;-- Kirk, \"Errand of Mercy\", stardate 3198.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','A woman should have compassion.<BR>\n&nbsp;-- Kirk, \"Catspaw\", stardate 3018.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','A Vulcan can no sooner be disloyal than he can exist without breathing.<BR>\n&nbsp;-- Kirk, \"The Menagerie\", stardate 3012.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Actual war is a very messy business.  Very, very messy business.<BR>\n&nbsp;-- Kirk, \"A Taste of Armageddon\", stardate 3193.0');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','A little suffering is good for the soul.<BR>\n&nbsp;-- Kirk, \"The Corbomite Maneuver\", stardate 1514.0');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','After a time, you may find that \"having\" is not so pleasing a thing,<BR>\nafter all, as \"wanting.\"  It is not logical, but it is often true.<BR>\n&nbsp;-- Spock, \"Amok Time\", stardate 3372.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Beam me up, Scotty!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','A man either lives life as it happens to him, meets it head-on and<BR>\nlicks it, or he turns his back on it and starts to wither away.<BR>\n&nbsp;-- Dr. Boyce, \"The Menagerie\" (\"The Cage\"), stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','One does not thank logic.<BR>\n&nbsp;-- Sarek, \"Journey to Babel\", stardate 3842.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','A princess should not be afraid -- not with a brave knight to protect her.<BR>\n&nbsp;-- McCoy, \"Shore Leave\", stardate 3025.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"Beauty is transitory.\"<BR>\n&nbsp;\"Beauty survives.\"<BR>\n&nbsp;-- Spock and Kirk, \"That Which Survives\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It is necessary to have purpose.<BR>\n&nbsp;-- Alice #1, \"I, Mudd\", stardate 4513.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Is truth not truth for all?<BR>\n&nbsp;-- Natira, \"For the World is Hollow and I have Touched<BR>\n&nbsp;the Sky\", stardate 5476.4.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It [being a Vulcan] means to adopt a philosophy, a way of life which is<BR>\nlogical and beneficial.  We cannot disregard that philosophy merely for<BR>\npersonal gain, no matter how important that gain might be.<BR>\n&nbsp;-- Spock, \"Journey to Babel\", stardate 3842.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It would be illogical to assume that all conditions remain stable.<BR>\n&nbsp;-- Spock, \"The Enterprise\" Incident\", stardate 5027.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Killing is wrong.<BR>\n&nbsp;-- Losira, \"That Which Survives\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Insufficient facts always invite danger.<BR>\n&nbsp;-- Spock, \"Space Seed\", stardate 3141.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','In the strict scientific sense we all feed on death -- even vegetarians.<BR>\n&nbsp;-- Spock, \"Wolf in the Fold\", stardate 3615.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Insults are effective only where emotion is present.<BR>\n&nbsp;-- Spock, \"Who Mourns for Adonais?\"  stardate 3468.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','If there are self-made purgatories, then we all have to live in them.<BR>\n&nbsp;-- Spock, \"This Side of Paradise\", stardate 3417.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','If some day we are defeated, well, war has its fortunes, good and bad.<BR>\n&nbsp;-- Commander Kor, \"Errand of Mercy\", stardate 3201.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Immortality consists largely of boredom.<BR>\n&nbsp;-- Zefrem Cochrane, \"Metamorphosis\", stardate 3219.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Intuition, however illogical, is recognized as a command prerogative.<BR>\n&nbsp;-- Kirk, \"Obsession\", stardate 3620.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Fascinating, a totally parochial attitude.<BR>\n&nbsp;-- Spock, \"Metamorphosis\", stardate 3219.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','First study the enemy.  Seek weakness.<BR>\n&nbsp;-- Romulan Commander, \"Balance of Terror\", stardate 1709.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Is not that the nature of men and women -- that the pleasure is in the<BR>\nlearning of each other?<BR>\n&nbsp;-- Natira, the High Priestess of Yonada, \"For the World is<BR>\n&nbsp;Hollow and I Have Touched the Sky\", stardate 5476.3.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','I object to intellect without discipline;  I object to power without<BR>\nconstructive purpose.<BR>\n&nbsp;-- Spock, \"The Squire of Gothos\", stardate 2124.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','I realize that command does have its fascination, even under<BR>\ncircumstances such as these, but I neither enjoy the idea of command<BR>\nnor am I frightened of it.  It simply exists, and I will do whatever<BR>\nlogically needs to be done.<BR>\n&nbsp;-- Spock, \"The Galileo Seven\", stardate 2812.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','I thought my people would grow tired of killing.  But you were right,<BR>\nthey see it is easier than trading.  And it has its pleasures.  I feel<BR>\nit myself.  Like the hunt, but with richer rewards.<BR>\n&nbsp;-- Apella, \"A Private Little War\", stardate 4211.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"... freedom ... is a worship word...\"<BR>\n&nbsp;\"It is our worship word too.\"<BR>\n&nbsp;-- Cloud William and Kirk, \"The Omega Glory\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','I am pleased to see that we have differences.  May we together become<BR>\ngreater than the sum of both of us.<BR>\n&nbsp;-- Surak of Vulcan, \"The Savage Curtain\", stardate 5906.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Humans do claim a great deal for that particular emotion (love).<BR>\n&nbsp;-- Spock, \"The Lights of Zetar\", stardate 5725.6');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','History tends to exaggerate.<BR>\n&nbsp;-- Col. Green, \"The Savage Curtain\", stardate 5906.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','I have never understood the female capacity to avoid a direct answer to<BR>\nany question.<BR>\n&nbsp;-- Spock, \"This Side of Paradise\", stardate 3417.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Four thousand throats may be cut in one night by a running man.<BR>\n&nbsp;-- Klingon Soldier, \"Day of the Dove\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Extreme feminine beauty is always disturbing.<BR>\n&nbsp;-- Spock, \"The Cloud Minders\", stardate 5818.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','On my planet, to rest is to rest -- to cease using energy.  To me, it<BR>\nis quite illogical to run up and down on green grass, using energy,<BR>\ninstead of saving it.<BR>\n&nbsp;-- Spock, \"Shore Leave\", stardate 3025.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The face of war has never changed.  Surely it is more logical to heal<BR>\nthan to kill.<BR>\n&nbsp;-- Surak of Vulcan, \"The Savage Curtain\", stardate 5906.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"That unit is a woman.\"<BR>\n&nbsp;\"A mass of conflicting impulses.\"<BR>\n&nbsp;-- Spock and Nomad, \"The Changeling\", stardate 3541.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Superior ability breeds superior ambition.<BR>\n&nbsp;-- Spock, \"Space Seed\", stardate 3141.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The best diplomat I know is a fully activated phaser bank.<BR>\n&nbsp;-- Scotty');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Spock: The odds of surviving another attack are 13562190123 to 1, Captain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Space: the final frontier.  These are the voyages of the starship Enterprise.<BR>\nIts five-year mission: to explore strange new worlds; to seek out new life<BR>\nand new civilizations; to boldly go where no man has gone before.<BR>\n&nbsp;-- Captain James T. Kirk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Spock: We suffered 23 casualties in that attack, Captain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Sometimes a feeling is all we humans have to go on.<BR>\n&nbsp;-- Kirk, \"A Taste of Armageddon\", stardate 3193.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Suffocating together ... would create heroic camaraderie.<BR>\n&nbsp;-- Khan Noonian Singh, \"Space Seed\", stardate 3142.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"The glory of creation is in its infinite diversity.\"<BR>\n&nbsp;\"And in the way our differences combine to create meaning and beauty.\"<BR>\n&nbsp;-- Dr. Miranda Jones and Spock, \"Is There in Truth No Beauty?\",<BR>\n&nbsp;stardate 5630.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Punishment becomes ineffective after a certain point.  Men become insensitive.<BR>\n&nbsp;-- Eneg, \"Patterns of Force\", stardate 2534.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Prepare for tomorrow -- get ready.<BR>\n&nbsp;-- Edith Keeler, \"The City On the Edge of Forever\",<BR>\n&nbsp;stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','You say you are lying.  But if everything you say is a lie, then you are<BR>\ntelling the truth.  You cannot tell the truth because everything you say<BR>\nis a lie.  You lie, you tell the truth ... but you cannot, for you lie.<BR>\n&nbsp;-- Norman the android, \"I, Mudd\", stardate 4513.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Peace was the way.<BR>\n&nbsp;-- Kirk, \"The City on the Edge of Forever\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Pain is a thing of the mind.  The mind can be controlled.<BR>\n&nbsp;-- Spock, \"Operation -- Annihilate!\" stardate 3287.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Phasers locked on target, Captain.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Respect is a rational process<BR>\n&nbsp;-- McCoy, \"The Galileo Seven\", stardate 2822.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Only a fool fights in a burning house.<BR>\n&nbsp;-- Kank the Klingon, \"Day of the Dove\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Star Trek Lives!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Our missions are peaceful -- not for conquest.  When we do battle, it<BR>\nis only because we have no choice.<BR>\n&nbsp;-- Kirk, \"The Squire of Gothos\", stardate 2124.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','One of the advantages of being a captain is being able to ask for<BR>\nadvice without necessarily having to take it.<BR>\n&nbsp;-- Kirk, \"Dagger of the Mind\", stardate 2715.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Those who hate and fight must stop themselves -- otherwise it is not stopped.<BR>\n&nbsp;-- Spock, \"Day of the Dove\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Most legends have their basis in facts.<BR>\n&nbsp;-- Kirk, \"And The Children Shall Lead\", stardate 5029.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','No one wants war.<BR>\n&nbsp;-- Kirk, \"Errand of Mercy\", stardate 3201.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','No more blah, blah, blah!<BR>\n&nbsp;-- Kirk, \"Miri\", stardate 2713.6');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','No problem is insoluble.<BR>\n&nbsp;-- Dr. Janet Wallace, \"The Deadly Years\", stardate 3479.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Love sometimes expresses itself in sacrifice.<BR>\n&nbsp;-- Kirk, \"Metamorphosis\", stardate 3220.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Landru! Guide us!<BR>\n&nbsp;-- A Beta 3-oid, \"The Return of the Archons\", stardate 3157.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Murder is contrary to the laws of man and God.<BR>\n&nbsp;-- M-5 Computer, \"The Ultimate Computer\", stardate 4731.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Klingon phaser attack from front!!!!!<BR>\n100% Damage to life support!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Knowledge, sir, should be free to all!<BR>\n&nbsp;-- Harry Mudd, \"I, Mudd\", stardate 4513.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','No one can guarantee the actions of another.<BR>\n&nbsp;-- Spock, \"Day of the Dove\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Not one hundred percent efficient, of course ... but nothing ever is.<BR>\n&nbsp;-- Kirk, \"Metamorphosis\", stardate 3219.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It is more rational to sacrifice one life than six.<BR>\n&nbsp;-- Spock, \"The Galileo Seven\", stardate 2822.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Conquest is easy. Control is not.<BR>\n&nbsp;-- Kirk, \"Mirror, Mirror\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It would be illogical to kill without reason.<BR>\n&nbsp;-- Spock, \"Journey to Babel\", stardate 3842.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It is undignified for a woman to play servant to a man who is not hers.<BR>\n&nbsp;-- Spock, \"Amok Time\", stardate 3372.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','It would seem that evil retreats when forcibly confronted.<BR>\n&nbsp;-- Yarnek of Excalbia, \"The Savage Curtain\", stardate 5906.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Killing is stupid; useless!<BR>\n&nbsp;-- McCoy, \"A Private Little War\", stardate 4211.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Wait!  You have not been prepared!<BR>\n&nbsp;-- Mr. Atoz, \"Tomorrow is Yesterday\", stardate 3113.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Vulcans worship peace above all.<BR>\n&nbsp;-- McCoy, \"Return to Tomorrow\", stardate 4768.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','War is never imperative.<BR>\n&nbsp;-- McCoy, \"Balance of Terror\", stardate 1709.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Vulcans never bluff.<BR>\n&nbsp;-- Spock, \"The Doomsday Machine\", stardate 4202.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','We have found all life forms in the galaxy are capable of superior<BR>\ndevelopment.<BR>\n&nbsp;-- Kirk, \"The Gamesters of Triskelion\", stardate 3211.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Violence in reality is quite different from theory.<BR>\n&nbsp;-- Spock, \"The Cloud Minders\", stardate 5818.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Vulcans believe peace should not depend on force.<BR>\n&nbsp;-- Amanda, \"Journey to Babel\", stardate 3842.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Time is fluid ... like a river with currents, eddies, backwash.<BR>\n&nbsp;-- Spock, \"The City on the Edge of Forever\", stardate 3134.0');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Totally illogical, there was no chance.<BR>\n&nbsp;-- Spock, \"The Galileo Seven\", stardate 2822.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There is an order of things in this universe.<BR>\n&nbsp;-- Apollo, \"Who Mourns for Adonais?\" stardate 3468.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Vulcans do not approve of violence.<BR>\n&nbsp;-- Spock, \"Journey to Babel\", stardate 3842.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There is a multi-legged creature crawling on your shoulder.<BR>\n&nbsp;-- Spock, \"A Taste of Armageddon\", stardate 3193.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There are always alternatives.<BR>\n&nbsp;-- Spock, \"The Galileo Seven\", stardate 2822.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There comes to all races an ultimate crisis which you have yet to face<BR>\n.... One day our minds became so powerful we dared think of ourselves as gods.<BR>\n&nbsp;-- Sargon, \"Return to Tomorrow\", stardate 4768.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','This cultural mystique surrounding the biological function -- you<BR>\nrealize humans are overly preoccupied with the subject.<BR>\n&nbsp;-- Kelinda the Kelvan, \"By Any Other Name\", stardate 4658.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The people of Gideon have always believed that life is sacred.  That<BR>\nthe love of life is the greatest gift ... We are incapable of<BR>\ndestroying or interfering with the creation of that which we love so<BR>\ndeeply -- life in every form from fetus to developed being.<BR>\n&nbsp;-- Hodin of Gideon, \"The Mark of Gideon\", stardate 5423.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The only solution is ... a balance of power.  We arm our side with exactly<BR>\nthat much more.  A balance of power -- the trickiest, most difficult,<BR>\ndirtiest game of them all.  But the only one that preserves both sides.<BR>\n&nbsp;-- Kirk, \"A Private Little War\", stardate 4211.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','... The prejudices people feel about each other disappear when they get<BR>\nto know each other.<BR>\n&nbsp;-- Kirk, \"Elaan of Troyius\", stardate 4372.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The sooner our happiness together begins, the longer it will last.<BR>\n&nbsp;-- Miramanee, \"The Paradise Syndrome\", stardate 4842.6');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The more complex the mind, the greater the need for the simplicity of play.<BR>\n&nbsp;-- Kirk, \"Shore Leave\", stardate 3025.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The joys of love made her human and the agonies of love destroyed her.<BR>\n&nbsp;-- Spock, \"Requiem for Methuselah\", stardate 5842.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The man on tops walks a lonely street; the \"chain\" of command is often a noose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The heart is not a logical organ.<BR>\n&nbsp;-- Dr. Janet Wallace, \"The Deadly Years\", stardate 3479.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','The idea of male and female are universal constants.<BR>\n&nbsp;-- Kirk, \"Metamorphosis\", stardate 3219.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','... The things love can drive a man to -- the ecstasies, the<BR>\nthe miseries, the broken rules, the desperate chances, the glorious<BR>\nfailures and the glorious victories.<BR>\n&nbsp;-- McCoy, \"Requiem for Methuselah\", stardate 5843.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Schshschshchsch.<BR>\n&nbsp;-- The Gorn, \"Arena\", stardate 3046.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Romulan women are not like Vulcan females.  We are not dedicated to<BR>\npure logic and the sterility of non-emotion.<BR>\n&nbsp;-- Romulan Commander, \"The Enterprise Incident\",<BR>\n&nbsp;stardate 5027.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Power is danger.<BR>\n&nbsp;-- The Centurion, \"Balance of Terror\", stardate 1709.2');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Our way is peace.<BR>\n&nbsp;-- Septimus, the Son Worshiper, \"Bread and Circuses\",<BR>\n&nbsp;stardate 4040.7.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There are certain things men must do to remain men.<BR>\n&nbsp;-- Kirk, \"The Ultimate Computer\", stardate 4929.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','You!  What PLANET is this!<BR>\n&nbsp;-- McCoy, \"The City on the Edge of Forever\", stardate 3134.0');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','There are some things worth dying for.<BR>\n&nbsp;-- Kirk, \"Errand of Mercy\", stardate 3201.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Without freedom of choice there is no creativity.<BR>\n&nbsp;-- Kirk, \"The return of the Archons\", stardate 3157.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Women are more easily and more deeply terrified ... generating more<BR>\nsheer horror than the male of the species.<BR>\n&nbsp;-- Spock, \"Wolf in the Fold\", stardate 3615.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Yes, it is written.  Good shall always destroy evil.<BR>\n&nbsp;-- Sirah the Yang, \"The Omega Glory\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"What happened to the crewman?\"<BR>\n&nbsp;\"The M-5 computer needed a new power source, the crewman merely got in<BR>\nthe way.\"<BR>\n&nbsp;-- Kirk and Dr. Richard Daystrom, \"The Ultimate Computer\",<BR>\n&nbsp;stardate 4731.3.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Without facts, the decision cannot be made logically.  You must rely on<BR>\nyour human intuition.<BR>\n&nbsp;-- Spock, \"Assignment: Earth\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','When dreams become more important than reality, you give up travel,<BR>\nbuilding, creating; you even forget how to repair the machines left<BR>\nbehind by your ancestors.  You just sit living and reliving other lives<BR>\nleft behind in the thought records.<BR>\n&nbsp;-- Vina, \"The Menagerie\" (\"The Cage\"), stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"What terrible way to die.\"<BR>\n&nbsp;\"There are no good ways.\"<BR>\n&nbsp;-- Sulu and Kirk, \"That Which Survives\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"We have the right to survive!\"<BR>\n&nbsp;\"Not by killing others.\"<BR>\n&nbsp;-- Deela and Kirk, \"Wink of An Eye\", stardate 5710.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','When a child is taught ... its programmed with simple instructions --<BR>\nand at some point, if its mind develops properly, it exceeds the sum of<BR>\nwhat it was taught, thinks independently.<BR>\n&nbsp;-- Dr. Richard Daystrom, \"The Ultimate Computer\",<BR>\n&nbsp;stardate 4731.3.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Without followers, evil cannot spread.<BR>\n&nbsp;-- Spock, \"And The Children Shall Lead\", stardate 5029.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','What kind of love is that?  Not to be loved; never to have shown love.<BR>\n&nbsp;-- Commissioner Nancy Hedford, \"Metamorphosis\",<BR>\n&nbsp;stardate 3219.8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','You are an excellent tactician, Captain.  You let your second in<BR>\ncommand attack while you sit and watch for weakness.<BR>\n&nbsp;-- Khan Noonian Singh, \"Space Seed\", stardate 3141.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','We do not colonize.  We conquer.  We rule.  There is no other way for us.<BR>\n&nbsp;-- Rojan, \"By Any Other Name\", stardate 4657.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','We fight only when there is no other choice.  We prefer the ways of<BR>\npeaceful contact.<BR>\n&nbsp;-- Kirk, \"Spectre of the Gun\", stardate 4385.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','You Earth people glorified organized violence for forty centuries.  But<BR>\nyou imprison those who employ it privately.<BR>\n&nbsp;-- Spock, \"Dagger of the Mind\", stardate 2715.1');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Women professionals do tend to over-compensate.<BR>\n&nbsp;-- Dr. Elizabeth Dehaver, \"Where No Man Has Gone Before\",<BR>\n&nbsp;stardate 1312.9.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Worlds are conquered, galaxies destroyed -- but a woman is always a woman.<BR>\n&nbsp;-- Kirk, \"The Conscience of the King\", stardate 2818.9');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Live long and prosper.<BR>\n&nbsp;-- Spock, \"Amok Time\", stardate 3372.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Madness has no purpose.  Or reason.  But it may have a goal.<BR>\n&nbsp;-- Spock, \"The Alternative Factor\", stardate 3088.7');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Men of peace usually are [brave].<BR>\n&nbsp;-- Spock, \"The Savage Curtain\", stardate 5906.5');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Many Myths are based on truth<BR>\n&nbsp;-- Spock, \"The Way to Eden\",  stardate 5832.3');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Lots of people drink from the wrong bottle sometimes.<BR>\n&nbsp;-- Edith Keeler, \"The City on the Edge of Forever\",<BR>\n&nbsp;stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','&nbsp;\"Logic and practical information do not seem to apply here.\"<BR>\n&nbsp;\"You admit that?\"<BR>\n&nbsp;\"To deny the facts would be illogical, Doctor\"<BR>\n&nbsp;-- Spock and McCoy, \"A Piece of the Action\", stardate unknown');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('startrek','Military secrets are the most fleeting of all.<BR>\n&nbsp;-- Spock, \"The Enterprise Incident\", stardate 5027.4');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi:<BR>\n&nbsp;You must learn the ways of the Force<BR>\n&nbsp;if you are to come with me to Alderaan.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Princess Leia:<BR>\n&nbsp;Darth Vader. Only you could be so bold.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Darth Vader:<BR>\n&nbsp;The Force is strong with this one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Han Solo:<BR>\n&nbsp;Oh! I thought they smelled bad on the *outside*!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Han Solo:<BR>\n&nbsp;You said you wanted to be around when I made a<BR>\n&nbsp;mistake, well, this could be it, sweetheart.<BR>\nPrincess Leia:<BR>\n&nbsp;I take it back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi:<BR>\n&nbsp;Use the Force, Luke!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Darth Vader:<BR>\n&nbsp;Impressive. Most impressive. Obi-wan has taught<BR>\n&nbsp;you well. You have controlled your fear. Now,<BR>\n&nbsp;release your anger! Only your hatred can destroy me!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Han Solo:<BR>\n&nbsp;You said you wanted to be around when I made a mistake,<BR>\n&nbsp;well, this could be it, sweetheart.<BR>\nPrincess Leia:<BR>\n&nbsp;I take it back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Princess Leia:<BR>\n&nbsp;I love you.<BR>\nHan Solo:<BR>\n&nbsp;I know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Jabba the Hutt:<BR>\n&nbsp;Bring me Solo and the Wookiee! They will all suffer<BR>\n&nbsp;for this outrage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Yoda:<BR>\n&nbsp;When nine hundred years old you reach, look as<BR>\n&nbsp;good you will not. Hmm?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Darth Vader:<BR>\n&nbsp;When I left you, I was but the learner.<BR>\n&nbsp;Now I am the master.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi:<BR>\n&nbsp;The Force will be with you, always.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','C-3PO: <BR>\n&nbsp;Sir, the possibility of successfully navigating<BR>\n&nbsp;an asteroid field is approximately 3,720 to 1!<BR>\nHan Solo:<BR>\n&nbsp;Never tell me the odds!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','C-3PO:<BR>\n&nbsp;R2 says that the chances of survival are 725 to 1.<BR>\n&nbsp;Actually R2 has been known to make mistakes - from time<BR>\n&nbsp;to time... Oh dear...');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Darth Vader:<BR>\n&nbsp;The force is with you young Skywalker, but you are<BR>\n&nbsp;not a Jedi yet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Emperor Palpatine:<BR>\n&nbsp;Everything that has transpired has done so according<BR>\n&nbsp;to my design.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Jabba the Hutt:<BR>\n&nbsp;This bounty hunter is my kind of scum: fearless and<BR>\n&nbsp;inventive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Emperor Palpatine:<BR>\n&nbsp;Soon the Rebellion will be crushed and young Skywalker<BR>\n&nbsp;will be one of us!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Emperor Palpatine:<BR>\n&nbsp;Take your Jedi weapon! Use it. Strike me down with all<BR>\n&nbsp;of your hatred and your journey towards the dark<BR>\n&nbsp;side will be complete!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Han Solo:<BR>\n&nbsp;I love you.<BR>\nPrincess Leia:<BR>\n&nbsp;I know.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Luke Skywalker:<BR>\n&nbsp;Your overconfidence is your weakness.<BR>\nEmperor Palpatine:<BR>\n&nbsp;Your faith in your friends is yours.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Luke Skywalker:<BR>\n&nbsp;How did my father die?<BR>\nBen (Obi-Wan) Kenobi:<BR>\n&nbsp;A young Jedi named Darth Vader, who was a pupil<BR>\n&nbsp;of mine until he turned to evil, helped the<BR>\n&nbsp;Empire hunt down and destroy the Jedi knights.<BR>\n&nbsp;He betrayed and murdered your father.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi: <BR>\n&nbsp;For more than a thousand generations<BR>\n&nbsp;the Jedi were the guardians of peace and<BR>\n&nbsp;justice in the galaxy. Before the dark times.<BR>\n&nbsp;Before the Empire.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Darth Vader:<BR>\n&nbsp;I find your lack of faith disturbing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Princess Leia:<BR>\n&nbsp;The more you tighten your grip, Tarkin, the<BR>\n&nbsp;more star systems will slip through your fingers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi:<BR>\n&nbsp;Mos Eisley spaceport. You will never find a more<BR>\n&nbsp;wretched hive of scum and villainy. We must be<BR>\n&nbsp;cautious.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('starwars','Ben (Obi-Wan) Kenobi:<BR>\n&nbsp;The Force can have a strong influence on a weak mind.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Superman: \"Are you smiling?\"<BR>\nBatman: \"Me? No.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Lois Lane: \"We live in lucky times, Cat. We were born in a world with a Superman.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Aquaman: \"I got the story from some tuna. They perform fascinating psycho-electric field displays...I know how that sounds, but trust me....\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Superman: \"Doomsday is cancelled until further notice.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Martian Manhunter: \"....Dark...Empty...Meaningless...Oblivion...\"<BR>\nBatman: \"Sounds like my last date.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Flash: \"Low-quality finish, Lantern.\"<BR>\nGreen Lantern: \"Yeah? Kiss my ring, buddy.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Zenturion: \"Somebody do something! Do something!\"<BR>\nBatman: \"Ready when you are.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Green Lantern: \"We are the Justice League. And the bad guys have left the building.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Green Lantern:\"Another twenty saved. How many people in this city?\"<BR>\nMartian Manhunter:\"Eight million.\"<BR>\nGreen Lantern:\"Diana, hurry!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Lex Luthor: \"I gave them three days. I was probably being generous.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Reporter (to Wonder Woman): \"Do you have any useful advice for menopausal women?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Green Lantern: \"Ideas?\"<BR>\nWonder Woman: \"Take the offensive.\"<BR>\nGreen Lantern: \"You are so predictable.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Primaid: \"Where are your friends now?...\"<BR>\nWonder Woman: \"Where we always are. Right here.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Superman: \"Still, for a walking enigma, there was one thing Know Man made abundantly clear through his attack, if not his prophecy. More and<BR>\nmore each day, the earth is plaqued by menaces too great for any one of us to beat. Divided we may fall...but united, we can stand. Now and<BR>\nforever...as the JUSTICE LEAGUE!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Superman: \"Everybody pick a continent.....\"<BR>\nPlastic Man: \"Antarctica!\"<BR>\nSuperman: \"...With people on it. Better yet, pair up. No one has to tackle the world alone. Not today.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Kyle Rayner: \"We split up and search the casino for millionaire playboys, we escort Wayne outside discreetely and we continue to wonder why<BR>\nanyone would send Orion on an espionage mission.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Alfred: \"Constructing a repository for souls....the very concept is....unthinkable.\"<BR>\nBatman: \"Is it? Some cultures believe that man creates God, not vice versa.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Green Lantern: \"What is it with super-villains nowadays? What happened to crazy jewel heists and dumb traps? Now they murder your girlfriend<BR>\nand stuff her in a fridge for kicks. The old Green Lantern had it easy.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Aquaman: \"The mind thing again! They just keep taking us like this!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','Superman: \"I knew he was coming, though. Super-hearing.\"<BR>\nBatman: \"So did I. I spotted his footsteps in the grass. Deductive reasoning.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('superhero','The Key: \"They always win, you see. The Justice League. They always win. That was the key to it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','sillema sillema nika su');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Qvid me anxivs svm?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Ego sum ens omnipotens.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Aliquid melius quam pessimum optimum non est.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Hodie natus est radici frater.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Klatu barada nikto.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Forsan et haec olim meminisse juvabit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Honi soit la vache qui rit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Mieux vaut tard que jamais!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Regnant populi.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','semper en excretus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','SEMPER UBI SUB UBI!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Raffiniert ist der Herrgott aber boshaft ist er nicht.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Suaviter in modo, fortiter in re.<BR>\nSe non e vero, e ben trovato.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Verba volant, scripta manent!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Sum quod eris.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('translate-me','Der Horizont vieler Menschen ist ein Kreis mit Radius Null --<BR>\nund das nennen sie ihren Standpunkt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There is no comfort without pain; thus we define salvation through suffering.<BR>\n&nbsp;-- Cato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There is more to life than increasing its speed.<BR>\n&nbsp;-- Mahatma Gandhi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There are ten or twenty basic truths, and life is the process of<BR>\ndiscovering them over and over and over.<BR>\n&nbsp;-- David Nichols');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We rarely find anyone who can say he has lived a happy life, and who,<BR>\ncontent with his life, can retire from the world like a satisfied guest.<BR>\n&nbsp;-- Quintus Horatius Flaccus (Horace)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We have reason to be afraid.  This is a terrible place.<BR>\n&nbsp;-- John Berryman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We have only two things to worry about:  That things will never get<BR>\nback to normal, and that they already have.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You climb to reach the summit, but once there, discover that all roads<BR>\nlead down.<BR>\n&nbsp;-- Stanislaw Lem, \"The Cyberiad\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The most costly of all follies is to believe passionately in the palpably<BR>\nnot true.  It is the chief occupation of mankind.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Intellect annuls Fate.<BR>\nSo far as a man thinks, he is free.<BR>\n&nbsp;-- Ralph Waldo Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','When the speaker and he to whom he is speaks do not understand, that is<BR>\nmetaphysics.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There is no sin but ignorance.<BR>\n&nbsp;-- Christopher Marlowe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','When the wind is great, bow before it;<BR>\nwhen the wind is heavy, yield to it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A clash of doctrine is not a disaster -- it is an opportunity.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can only live once, but if you do it right, once is enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can get *anywhere* in ten minutes if you drive fast enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can no more win a war than you can win an earthquake.<BR>\n&nbsp;-- Jeannette Rankin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Yes, but which self do you want to be?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can never tell which way the train went by looking at the tracks.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','[Wisdom] is a tree of life to those laying<BR>\nhold of her, making happy each one holding her fast.<BR>\n&nbsp;-- Proverbs 3:18, NSV');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Wisdom is knowing what to do with what you know.<BR>\n&nbsp;-- J. Winter Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Wisdom is rarely found on the best-seller list.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The moss on the tree does not fear the talons of the hawk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality always seems harsher in the early morning.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','When you die, you lose a very important part of your life.<BR>\n&nbsp;-- Brooke Shields');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Who does not trust enough will not be trusted.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Getting there is only half as far as getting there and back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Generally speaking, the Way of the warrior is resolute acceptance of death.<BR>\n&nbsp;-- Miyamoto Musashi, 1645');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','For your penance, say five Hail Marys and one loud BLAH!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','For fast-acting relief, try slowing down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Everything is possible.  Pass the word.<BR>\n&nbsp;-- Rita Mae Brown, \"Six of One\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Depart not from the path which fate has assigned you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Death is a spirit leaving a body, sort of like a shell leaving the nut behind.<BR>\n&nbsp;-- Erma Bombeck');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Coincidences are spiritual puns.<BR>\n&nbsp;-- G.K. Chesterton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','What sane person could live in this world and not be crazy?<BR>\n&nbsp;-- Ursula K. LeGuin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Whatever occurs from love is always beyond good and evil.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','What does not destroy me, makes me stronger.<BR>\n&nbsp;-- Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The only difference between a rut and a grave is their dimensions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Well, you know, no matter where you go, there you are.<BR>\n&nbsp;-- Buckaroo Banzai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Whatever you do will be insignificant, but it is very important that you do it.<BR>\n&nbsp;-- Gandhi');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','\"Well,\" Brahma said, \"even after ten thousand explanations, a fool is no<BR>\nwiser, but an intelligent man requires only two thousand five hundred.\"<BR>\n&nbsp;-- The Mahabharata.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There are no accidents whatsoever in the universe.<BR>\n&nbsp;-- Baba Ram Dass');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The truth of a thing is the feel of it, not the think of it.<BR>\n&nbsp;-- Stanley Kubrick');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The price of success in philosophy is triviality.<BR>\n&nbsp;-- C. Glymour.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is easier for a camel to pass through the eye of a needle if it is<BR>\nlightly greased.<BR>\n&nbsp;-- Kehlog Albran, \"The Profit\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A thing is not necessarily true because a man dies for it.<BR>\n&nbsp;-- Oscar Wilde, \"The Portrait of Mr. W.H.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It does not do to leave a live dragon out of your calculations.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Perfection is reached, not when there is no longer anything to add, but<BR>\nwhen there is no longer anything to take away.<BR>\n&nbsp;-- Antoine de Saint-Exupery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The universe is made of stories, not of atoms.<BR>\n&nbsp;-- Muriel Rukeyser');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There is a secret person undamaged within every individual.<BR>\n&nbsp;-- Paul Shepard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We are governed not by armies and police but by ideas.<BR>\n&nbsp;-- Mona Caird, 1892');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Your picture of the world often changes just before you get it into focus.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Your wig steers the gig.<BR>\n&nbsp;-- Lord Buckley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Your happiness is intertwined with your outlook on life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can always pick up your needle and move to another groove.<BR>\n&nbsp;-- Tim Leary');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A neighbor came to Nasrudin, asking to borrow his donkey.  \"It is out on<BR>\nloan,\" the teacher replied.  At that moment, the donkey brayed loudly inside<BR>\nthe stable.  \"But I can hear it bray, over there.\"  \"Whom do you believe,\"<BR>\nasked Nasrudin, \"me or a donkey?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You will always find something in the last place you look.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Your mind understands what you have been taught; your heart, what is true.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A halted retreat<BR>\nIs nerve-wracking and dangerous.<BR>\nTo retain people as men -- and maidservants<BR>\nBrings good fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','You can observe a lot just by watching.<BR>\n&nbsp;-- Yogi Berra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','\"You would do well not to imagine profundity,\" he said.  \"Anything that seems<BR>\nof momentous occasion should be dwelt upon as though it were of slight note.<BR>\nConversely, trivialities must be attended to with the greatest of care.<BR>\nBecause death is momentous, give it no thought; because victory is important,<BR>\ngive it no thought; because the method of achievement and discovery is less<BR>\nmomentous than the effect, dwell always upon the method.  You will strengthen<BR>\nyourself in this way.\"<BR>\n&nbsp;-- Jessica Salmonson, \"The Swordswoman\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','With listening comes wisdom, with speaking repentance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A priest advised Voltaire on his death bed to renounce the devil. <BR>\nReplied Voltaire, \"This is no time to make new enemies.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A lot of people I know believe in positive thinking, and so do I.  I<BR>\nbelieve everything positively stinks.<BR>\n&nbsp;-- Lew Col');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A man said to the Universe:<BR>\n&nbsp;\"Sir, I exist!\"<BR>\n&nbsp;\"However,\" replied the Universe,<BR>\n&nbsp;\"the fact has not created in me a sense of obligation.\"<BR>\n&nbsp;-- Stephen Crane');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A dream will always triumph over reality, once it is given the chance.<BR>\n&nbsp;-- Stanislaw Lem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A fake fortuneteller can be tolerated.  But an authentic soothsayer should<BR>\nbe shot on sight.  Cassandra did not get half the kicking around she deserved.<BR>\n&nbsp;-- R.A. Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Each of us bears his own Hell.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Each man is his own prisoner, in solitary confinement for life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Chance is perhaps the work of God when He did not want to sign.<BR>\n&nbsp;-- Anatole France');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','At ebb tide I wrote a line upon the sand, and gave it all my heart and all<BR>\nmy soul.  At flood tide I returned to read what I had inscribed and found my<BR>\nignorance upon the shore.<BR>\n&nbsp;-- Kahlil Gibran');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','At the foot of the mountain, thunder:<BR>\nThe image of Providing Nourishment.<BR>\nThus the superior man is careful of his words<BR>\nAnd temperate in eating and drinking.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Beauty is one of the rare things which does not lead to doubt of God.<BR>\n&nbsp;-- Jean Anouilh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;Chapter 1<BR>\n&nbsp;The story so far:<BR>\n&nbsp;In the beginning the Universe was created.  This has made a lot<BR>\nof people very angry and been widely regarded as a bad move.<BR>\n&nbsp;-- Douglas Adams?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','And ever has it been known that love knows not its own depth until the<BR>\nhour of separation.<BR>\n&nbsp;-- Kahlil Gibran');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','An idea is not responsible for the people who believe in it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;An older student came to Otis and said, \"I have been to see a<BR>\ngreat number of teachers and I have given up a great number of pleasures.<BR>\nI have fasted, been celibate and stayed awake nights seeking enlightenment.<BR>\nI have given up everything I was asked to give up and I have suffered, but<BR>\nI have not been enlightened.  What should I do?\"<BR>\n&nbsp;Otis replied, \"Give up suffering.\"<BR>\n&nbsp;-- Camden Benares, \"Zen Without Zen Masters\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','All of the true things I am about to tell you are shameless lies.<BR>\n&nbsp;-- The Book of Bokonon / Kurt Vonnegut Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','All hope abandon, ye who enter here!<BR>\n&nbsp;-- Dante Alighieri');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','All men know the utility of useful things;<BR>\nbut they do not know the utility of futility.<BR>\n&nbsp;-- Chuang-tzu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','All of us should treasure his Oriental wisdom and his preaching of a<BR>\nZen-like detachment, as exemplified by his constant reminder to clerks,<BR>\ntellers, or others who grew excited by his presence in their banks:<BR>\n\"Just lie down on the floor and keep calm.\"<BR>\n&nbsp;-- Robert Wilson, \"John Dillinger Died for You\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Do your part to help preserve life on Earth -- by trying to preserve your own.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','An idea is an eye given by God for the seeing of God.  Some of these eyes<BR>\nwe cannot bear to look out of, we blind them as quickly as possible.<BR>\n&nbsp;-- Russell Hoban, \"Pilgermann\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A sad spectacle.  If they be inhabited, what a scope for misery and folly.<BR>\nIf they be not inhabited, what a waste of space.<BR>\n&nbsp;-- Thomas Carlyle, looking at the stars');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','One learns to itch where one can scratch.<BR>\n&nbsp;-- Ernest Bramah');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;One day it was announced that the young monk Kyogen had reached<BR>\nan enlightened state.  Much impressed by this news, several of his peers<BR>\nwent to speak with him.<BR>\n&nbsp;\"We have heard that you are enlightened.  Is this true?\" his fellow<BR>\nstudents inquired.<BR>\n&nbsp;\"It is\", Kyogen answered.<BR>\n&nbsp;\"Tell us\", said a friend, \"how do you feel?\"<BR>\n&nbsp;\"As miserable as ever\", replied the enlightened Kyogen.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','A Scholar asked his Master, \"Master, would you advise me of a proper<BR>\nvocation?\"<BR>\n&nbsp;The Master replied, \"Some men can earn their keep with the power of<BR>\ntheir minds.  Others must use thier strong backs, legs and hands.  This is<BR>\nthe same in nature as it is with man.  Some animals acquire their food easily,<BR>\nsuch as rabbits, hogs and goats.  Other animals must fiercely struggle for<BR>\ntheir sustenance, like beavers, moles and ants.  So you see, the nature of<BR>\nthe vocation must fit the individual.<BR>\n&nbsp;\"But I have no abilities, desires, or imagination, Master,\" the<BR>\nscholar sobbed.<BR>\n&nbsp;Queried the Master... \"Have you thought of becoming a salesperson?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Dying is one of the few things that can be done as easily lying down.<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Execute every act of thy life as though it were thy last.<BR>\n&nbsp;-- Marcus Aurelius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','During the voyage of life, remember to keep an eye out for a fair wind; batten<BR>\ndown during a storm; hail all passing ships; and fly your colors proudly.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Dying is a very dull, dreary affair.  My advice to you is to have<BR>\nnothing whatever to do with it.<BR>\n&nbsp;-- W. Somerset Maughm, his last words');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Due to circumstances beyond your control, you are master of your fate<BR>\nand captain of your soul.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He who knows others is wise.<BR>\nHe who knows himself is enlightened.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Facts are the enemy of truth.<BR>\n&nbsp;-- Don Quixote');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He who knows that enough is enough will always have enough.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;\"You mean, if you allow the master to be uncivil, to treat you<BR>\nany old way he likes, and to insult your dignity, then he may deem you<BR>\nfit to hear his view of things?\"<BR>\n&nbsp;\"Quite the contrary.  You must defend your integrity, assuming<BR>\nyou have integrity to defend.  But you must defend it nobly, not by<BR>\nimitating his own low behavior.  If you are gentle where he is rough,<BR>\nif you are polite where he is uncouth, then he will recognize you as<BR>\npotentially worthy.  If he does not, then he is not a master, after all,<BR>\nand you may feel free to kick his ass.\"<BR>\n&nbsp;-- Tom Robbins, \"Jitterbug Perfume\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He who knows, does not speak.  He who speaks, does not know.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Disease can be cured; fate is incurable.<BR>\n&nbsp;-- Chinese proverb');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Ditat Deus.<BR>\n&nbsp;[God enriches]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Do not seek death; death will find you.  But seek the road which makes death<BR>\na fulfillment.<BR>\n&nbsp;-- Dag Hammarskjold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Do not believe in miracles -- rely on them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Circumstances rule men; men do not rule circumstances.<BR>\n&nbsp;-- Herodotus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Do not despair of life.  You have no doubt force enough to overcome your<BR>\nobstacles.  Think of the fox prowling through wood and field in a winter night<BR>\nfor something to satisfy his hunger.  Notwithstanding cold and hounds and<BR>\ntraps, his race survives.  I do not believe any of them ever committed suicide.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Do not take life too seriously; you will never get out of it alive.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Catharsis is something I associate with pornography and crossword puzzles.<BR>\n&nbsp;-- Howard Chaykin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','By protracting life, we do not deduct one jot from the duration of death.<BR>\n&nbsp;-- Titus Lucretius Carus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Before you ask more questions, think about whether you really want to<BR>\nknow the answers.<BR>\n&nbsp;-- Gene Wolfe, \"The Claw of the Conciliator\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Brahma said: Well, after hearing ten thousand explanations, a fool is no<BR>\nwiser.  But an intelligent man needs only two thousand five hundred.<BR>\n&nbsp;-- The Mahabharata');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I do not seek the ignorant; the ignorant seek me -- I will instruct them.<BR>\nI ask nothing but sincerity.  If they come out of habit, they become tiresome.<BR>\n&nbsp;-- I Ching');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I do not know whether I was then a man dreaming I was a butterfly, or<BR>\nwhether I am now a butterfly dreaming I am a man.<BR>\n&nbsp;-- Chuang-tzu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I am not afraid of tomorrow, for I have seen yesterday and I love today.<BR>\n&nbsp;-- William Allen White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','\"I gained nothing at all from Supreme Enlightenment, and for that very<BR>\nreason it is called Supreme Enlightenment.\"<BR>\n&nbsp;-- Gotama Buddha');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','How can you prove whether at this moment we are sleeping, and all our<BR>\nthoughts are a dream; or whether we are awake, and talking to one another<BR>\nin the waking state?<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Paradise is exactly like where you are right now ... only much, much better.<BR>\n&nbsp;-- Laurie Anderson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He who despairs over an event is a coward, but he who holds hopes for<BR>\nthe human condition is a fool.<BR>\n&nbsp;-- Albert Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I have often regretted my speech, never my silence.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;...He who laughs does not believe in what he laughs at, but neither<BR>\ndoes he hate it.  Therefore, laughing at evil means not preparing oneself to<BR>\ncombat it, and laughing at good means denying the power through which good is<BR>\nself-propagating.<BR>\n&nbsp;-- Umberto Eco, \"The Name of the Rose\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Happiness is just an illusion, filled with sadness and confusion.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He has shown you, o man, what is good.  And what does the Lord ask of you,<BR>\nbut to do justice, and to love kindness, and to walk humbly before your God?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Happiness is having a scratch for every itch.<BR>\n&nbsp;-- Ogden Nash');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Great acts are made up of small deeds.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Got a dictionary?  I want to know the meaning of life.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Having the fewest wants, I am nearest to the gods.<BR>\n&nbsp;-- Socrates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Goodbye, cool world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','God is the tangential point between zero and infinity.<BR>\n&nbsp;-- Alfred Jarry');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','God made everything out of nothing, but the nothingness shows through.<BR>\n&nbsp;-- Paul Valery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','God instructs the heart, not by ideas, but by pains and contradictions.<BR>\n&nbsp;-- De Caussade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Getting into trouble is easy.<BR>\n&nbsp;-- D. Winkel and F. Prosser');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','From the cradle to the coffin underwear comes first.<BR>\n&nbsp;-- Bertolt Brecht');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','For good, return good.<BR>\nFor evil, return justice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Force has no place where there is need of skill.<BR>\n&nbsp;-- Herodotus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Expansion means complexity; and complexity decay.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','For if there is a sin against life, it consists perhaps not so much in<BR>\ndespairing of life as in hoping for another life and in eluding the<BR>\nimplacable grandeur of this life.<BR>\n&nbsp;-- Albert Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Faith goes out through the window when beauty comes in at the door.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','... \"fire\" does not matter, \"earth\" and \"air\" and \"water\" do not matter.<BR>\n\"I\" do not matter.  No word matters.  But man forgets reality and remembers<BR>\nwords.  The more words he remembers, the cleverer do his fellows esteem him.<BR>\nHe looks upon the great transformations of the world, but he does not see<BR>\nthem as they were seen when man looked upon reality for the first time.<BR>\nTheir names come to his lips and he smiles as he tastes them, thinking he<BR>\nknows them in the naming.<BR>\n&nbsp;-- Roger Zelazny, \"Lord of Light\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He who knows not and knows that he knows not is ignorant.  Teach him.<BR>\nHe who knows not and knows not that he knows not is a fool.  Shun him.<BR>\nHe who knows and knows not that he knows is asleep.  Wake him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Fain would I climb, yet fear I to fall.<BR>\n&nbsp;-- Sir Walter Raleigh');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Faith is under the left nipple.<BR>\n&nbsp;-- Martin Luther');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','From listening comes wisdom and from speaking repentance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Down with categorical imperative!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Illusion is the first of all pleasures.<BR>\n&nbsp;-- Voltaire');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Instead of loving your enemies, treat your friends a little better.<BR>\n&nbsp;-- Edgar W. Howe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','In spite of everything, I still believe that people are good at heart.<BR>\n&nbsp;-- Ann Frank');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is not doing the thing we like to do, but liking the thing we have to do,<BR>\nthat makes life blessed.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','In the long run we are all dead.<BR>\n&nbsp;-- John Maynard Keynes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If your happiness depends on what somebody else does, I guess you do<BR>\nhave a problem.<BR>\n&nbsp;-- Richard Bach, \"Illusions\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Immortality -- a fate worse than death.<BR>\n&nbsp;-- Edgar A. Shoaff');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','In dwelling, be close to the land.<BR>\nIn meditation, delve deep into the heart.<BR>\nIn dealing with others, be gentle and kind.<BR>\nIn speech, be true.<BR>\nIn work, be competent.<BR>\nIn action, be careful of your timing.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you want divine justice, die.<BR>\n&nbsp;-- Nick Seldon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you refuse to accept anything but the best you very often get it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you wait long enough, it will go away... after having done its damage.<BR>\nIf it was bad, it will be back.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If the master dies and the disciple grieves, the lives of both have<BR>\nbeen wasted.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If the path be beautiful, let us not ask where it leads.<BR>\n&nbsp;-- Anatole France');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If there is a sin against life, it consists perhaps not so much in despairing<BR>\nof life as in hoping for another life and in eluding the implacable grandeur<BR>\nof this life.<BR>\n&nbsp;-- Albert Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Just remember, wherever you go, there you are.<BR>\n&nbsp;-- Buckaroo Bonzai');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If we do not change our direction we are likely to end up where we are headed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If something has not yet gone wrong then it would ultimately have been<BR>\nbeneficial for it to go wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','In order to live free and happily, you must sacrifice boredom.<BR>\nIt is not always an easy sacrifice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I hate dying.<BR>\n&nbsp;-- Dave Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He that composes himself is wiser than he that composes a book.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If men are not afraid to die,<BR>\nit is of no avail to threaten them with death.<BR>\n&nbsp;If men live in constant fear of dying,<BR>\nAnd if breaking the law means a man will be killed,<BR>\nWho will dare to break the law?<BR>\n&nbsp;There is always an official executioner.<BR>\nIf you try to take his place,<BR>\nIt is like trying to be a master carpenter and cutting wood.<BR>\nIf you try to cut wood like a master carpenter,<BR>\n&nbsp;you will only hurt your hand.<BR>\n&nbsp;-- Tao Te Ching, \"Lao Tsu, #74\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If a guru falls in the forest with no one to hear him, was he really a<BR>\nguru at all?<BR>\n&nbsp;-- Strange de Jim, \"The Metasexuals\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If a man has a strong faith he can indulge in the luxury of skepticism.<BR>\n&nbsp;-- Friedrich Nietzsche');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If a man loses his reverence for any part of life, he will lose his<BR>\nreverence for all of life.<BR>\n&nbsp;-- Albert Schweitzer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I know not how I came into this, shall I call it a dying life or a<BR>\nliving death?<BR>\n&nbsp;-- St. Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I have seen the future and it is just like the present, only longer.<BR>\n&nbsp;-- Kehlog Albran, \"The Profit\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','He knows not how to know who knows not also how to unknow.<BR>\n&nbsp;-- Sir Richard Burton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','I just forgot my whole philosophy of life!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The first requisite for immortality is death.<BR>\n&nbsp;-- Stanislaw Lem');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The more laws and order are made prominent, the more thieves and<BR>\nrobbers there will be.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The more you complain, the longer God lets you live.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The longest part of the journey is said to be the passing of the gate.<BR>\n&nbsp;-- Marcus Terentius Varro');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life only demands from you the strength you possess.<BR>\nOnly one feat is possible -- not to have run away.<BR>\n&nbsp;-- Dag Hammarskjold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life may have no meaning, or, even worse, it may have a meaning of which<BR>\nyou disapprove.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is the urge to ecstasy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Long were the days of pain I have spent within its walls, and<BR>\nlong were the nights of aloneness; and who can depart from his<BR>\npain and his aloneness without regret?<BR>\n&nbsp;-- Kahlil Gibran, \"The Prophet\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','[Maturity consists in the discovery that] there comes a critical moment<BR>\nwhere everything is reversed, after which the point becomes to understand<BR>\nmore and more that there is something which cannot be understood.<BR>\n&nbsp;-- S. Kierkegaard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Loneliness is a terrible price to pay for independence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is like a sewer.  What you get out of it depends on what you put into it.<BR>\n&nbsp;-- Tom Lehrer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Mohandas K. Gandhi often changed his mind publicly.  An aide once asked him<BR>\nhow he could so freely contradict this week what he had said just last week.<BR>\nThe great man replied that it was because this week he knew better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Living in the complex world of the future is somewhat like having bees<BR>\nlive in your head.  But, there they are.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is a grand adventure -- or it is nothing.<BR>\n&nbsp;-- Helen Keller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Only those who leisurely approach that which the masses are busy about<BR>\ncan be busy about that which the masses take leisurely.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is knowing how far to go without crossing the line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Let us not look back in anger or forward in fear, but around us in awareness.<BR>\n&nbsp;-- James Thurber');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is like a 10 speed bicycle.  Most of us have gears we never use.<BR>\n&nbsp;-- C. Schultz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nasrudin walked into a teahouse and declaimed, \"The moon is more useful<BR>\nthan the sun.\"<BR>\n&nbsp;\"Why?\", he was asked.<BR>\n&nbsp;\"Because at night we need the light more.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is through symbols that man consciously or unconsciously lives, works<BR>\nand has his being.<BR>\n&nbsp;-- Thomas Carlyle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It will be advantageous to cross the great stream ... the Dragon is on<BR>\nthe wing in the Sky ... the Great Man rouses himself to his Work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is so stupid of modern civilisation to have given up believing in the<BR>\ndevil when he is the only explanation of it.<BR>\n&nbsp;-- Ronald Knox, \"Let Dons Delight\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is only by risking our persons from one hour to another that we live<BR>\nat all.  And often enough our faith beforehand in an uncertified result<BR>\nis the only thing that makes the result come true.<BR>\n&nbsp;-- William James');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There is no cure for birth and death other than to enjoy the interval.<BR>\n&nbsp;-- George Santayana');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The truth is rarely pure, and never simple.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The root of all superstition is that men observe when a thing hits,<BR>\nbut not when it misses.<BR>\n&nbsp;-- Francis Bacon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Not every question deserves an answer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','One meets his destiny often on the road he takes to avoid it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','&nbsp;Once there lived a village of creatures along the bottom of a great<BR>\ncrystal river.  Each creature in its own manner clung tightly to the twigs<BR>\nand rocks of the river bottom, for clinging was their way of life, and<BR>\nresisting the current what each had learned from birth.  But one creature<BR>\nsaid at last, \"I trust that the current knows where it is going.  I shall<BR>\nlet go, and let it take me where it will.  Clinging, I shall die of boredom.\"<BR>\n&nbsp;The other creatures laughed and said, \"Fool!  Let go, and that current<BR>\nyou worship will throw you tumbled and smashed across the rocks, and you will<BR>\ndie quicker than boredom!\"<BR>\n&nbsp;But the one heeded them not, and taking a breath did let go, and at<BR>\nonce was tumbled and smashed by the current across the rocks.  Yet, in time,<BR>\nas the creature refused to cling again, the current lifted him free from the<BR>\nbottom, and he was bruised and hurt no more.<BR>\n&nbsp;And the creatures downstream, to whom he was a stranger, cried, \"See<BR>\na miracle!  A creature like ourselves, yet he flies!  See the Messiah, come<BR>\nto save us all!\"  And the one carried in the current said, \"I am no more<BR>\nMessiah than you.  The river delight to lift us free, if only we dare let go.<BR>\nOur true work is this voyage, this adventure.<BR>\n&nbsp;But they cried the more, \"Saviour!\" all the while clinging to the<BR>\nrocks, making legends of a Saviour.<BR>\n&nbsp;-- Richard Bach');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing is but what is not.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing is so firmly believed as that which we least know.<BR>\n&nbsp;-- Michel de Montaigne');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing is ever a total loss; it can always serve as a bad example.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing matters very much, and few things matter at all.<BR>\n&nbsp;-- Arthur Balfour');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Normal times may possibly be over forever.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing in life is to be feared.  It is only to be understood.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nothing is as simple as it seems at first<BR>\n&nbsp;Or as hopeless as it seems in the middle<BR>\n&nbsp;Or as finished as it seems in the end.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','No matter where I go, the place is always called \"here\".');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nobody ever ruined their eyesight by looking at the bright side of something.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nasrudin was carrying home a piece of liver and the recipe for liver pie.<BR>\nSuddenly a bird of prey swooped down and snatched the piece of meat from his<BR>\nhand.  As the bird flew off, Nasrudin called after it, \"Foolish bird!  You<BR>\nhave the liver, but what can you do with it without the recipe?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','No man is an Iland, intire of it selfe; every man is a peece of the<BR>\nContinent, a part of the maine; if a Clod bee washed away by the Sea,<BR>\nEurope is the lesse, as well as if a Promontorie were, as well as if<BR>\na Mannor of thy friends or of thine owne were; any mans death diminishes<BR>\nme, because I am involved in Mankinde; And therefore never send to know<BR>\nfor whom the bell tolls; It tolls for thee.<BR>\n&nbsp;-- John Donne, \"No Man is an Iland\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nonsense and beauty have close connections.<BR>\n&nbsp;-- E.M. Forster');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','My theology, briefly, is that the universe was dictated but not signed.<BR>\n&nbsp;-- Christopher Morley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','My religion consists of a humble admiration of the illimitable superior<BR>\nspirit who reveals himself in the slight details we are able to perceive<BR>\nwith our frail and feeble mind.<BR>\n&nbsp;-- Albert Einstein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nasrudin called at a large house to collect for charity.  The servant said<BR>\n\"My master is out.\"  Nasrudin replied, \"Tell your master that next time he<BR>\ngoes out, he should not leave his face at the window.  Someone might steal it.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Music in the soul can be heard by the universe.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life is the childhood of our immortality.<BR>\n&nbsp;-- Goethe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Life exists for no known purpose.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Nasrudin walked into a shop one day, and the owner came forward to serve<BR>\nhim.  Nasrudin said, \"First things first.  Did you see me walk into your<BR>\nshop?\"<BR>\n&nbsp;\"Of course.\"<BR>\n&nbsp;\"Have you ever seen me before?\"<BR>\n&nbsp;\"Never.\"<BR>\n&nbsp;\"Then how do you know it was me?\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The major sin is the sin of being born.<BR>\n&nbsp;-- Samuel Beckett');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The optimist thinks that this is the best of all possible worlds,<BR>\nand the pessimist knows it.<BR>\n&nbsp;-- J. Robert Oppenheimer, \"Bulletin of Atomic Scientists\"<BR>\n&nbsp;Yet creeds mean very little, Coth answered the dark god, still speaking<BR>\nalmost gently.  The optimist proclaims that we live in the best of all<BR>\npossible worlds; and the pessimist fears this is true.<BR>\n&nbsp;-- James Cabell, \"The Silver Stallion\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality does not exist -- yet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The final delusion is the belief that one has lost all delusions.<BR>\n&nbsp;-- Maurice Chapelain, \"Main courante\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The farther you go, the less you know.<BR>\n&nbsp;-- Lao Tsu, \"Tao Te Ching\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality is just a convenient measure of complexity.<BR>\n&nbsp;-- Alvy Ray Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The best you get is an even break.<BR>\n&nbsp;-- Franklin Adams');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The greatest griefs are those we cause ourselves.<BR>\n&nbsp;-- Sophocles');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The Poems, all three hundred of them, may be summed up in one of their phrases:<BR>\n\"Let our thoughts be correct\".<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The chief cause of problems is solutions.<BR>\n&nbsp;-- Eric Sevareid');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The chief danger in life is that you may take too many precautions.<BR>\n&nbsp;-- Alfred Adler');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The absurd is the essential concept and the first truth.<BR>\n&nbsp;-- A. Camus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The days are all empty and the nights are unreal.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','\"The chain which can be yanked is not the eternal chain.\"<BR>\n&nbsp;-- G. Fitch');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','So little time, so little to do.<BR>\n&nbsp;-- Oscar Levant');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','That that is is that that is not is not.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Superstition, idolatry, and hypocrisy have ample wages, but truth goes<BR>\na-begging.<BR>\n&nbsp;-- Martin Luther');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Suffering alone exists, none who suffer;<BR>\nThe deed there is, but no doer thereof;<BR>\nNirvana is, but no one is seeking it;<BR>\nThe Path there is, but none who travel it.<BR>\n&nbsp;-- \"Buddhist Symbolism\", Symbols and Values');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','That, that is, is.<BR>\nThat, that is not, is not.<BR>\nThat, that is, is not that, that is not.<BR>\nThat, that is not, is not that, that is.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The eye is a menace to clear sight, the ear is a menace to subtle hearing,<BR>\nthe mind is a menace to wisdom, every organ of the senses is a menace to its<BR>\nown capacity. ...  Fuss, the god of the Southern Ocean, and Fret, the god<BR>\nof the Northern Ocean, happened once to meet in the realm of Chaos, the god<BR>\nof the center.  Chaos treated them very handsomely and they discussed together<BR>\nwhat they could do to repay his kindness.  They had noticed that, whereas<BR>\neveryone else had seven apertures, for sight, hearing, eating, breathing and<BR>\nso on, Chaos had none.  So they decided to make the experiment of boring holes<BR>\nin him.  Every day they bored a hole, and on the seventh day, Chaos died.<BR>\n&nbsp;-- Chuang Tzu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Murphy was an optimist.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Ninety percent of everything is crap.<BR>\n&nbsp;-- Theodore Sturgeon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Ninety percent of the time things turn out worse than you thought they would.<BR>\nThe other ten percent of the time you had no right to expect that much.<BR>\n&nbsp;-- Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Sometimes you get an almost irresistible urge to go on living.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Remember, Grasshopper, falling down 1000 stairs begins by tripping over<BR>\nthe first one.<BR>\n&nbsp;-- Confusion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Since everything in life is but an experience perfect in being what it is,<BR>\nhaving nothing to do with good or bad, acceptance or rejection, one may well<BR>\nburst out in laughter.<BR>\n&nbsp;-- Long Chen Pa');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality is for people who lack imagination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality is nothing but a collective hunch.<BR>\n&nbsp;-- Lily Tomlin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Rule of Life #1 -- Never get separated from your luggage.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Perhaps the biggest disappointments were the ones you expected anyway.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Push where it gives and scratch where it itches.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Reality is bad enough, why should I tell the truth?<BR>\n&nbsp;-- Patrick Sky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Waste not fresh tears over old griefs.<BR>\n&nbsp;-- Euripides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The door is the key.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Sometimes even to live is an act of courage.<BR>\n&nbsp;-- Seneca');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','It is said that the lonely eagle flies to the mountain peaks while the lowly<BR>\nant crawls the ground, but cannot the soul of the ant soar as high as the eagle?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','To lead people, you must follow behind.<BR>\n&nbsp;-- Lao Tsu');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Two men came before Nasrudin when he was magistrate.  The first man said,<BR>\n\"This man has bitten my ear -- I demand compensation.\" The second man said,<BR>\n\"He bit it himself.\" Nasrudin withdrew to his chambers, and spent an hour<BR>\ntrying to bite his own ear.  He succeeded only in falling over and bruising<BR>\nhis forehead.  Returning to the courtroom, Nasrudin pronounced, \"Examine the<BR>\nman whose ear was bitten. If his forehead is bruised, he did it himself and<BR>\nthe case is dismissed.  If his forehead is not bruised, the other man did it<BR>\nand must pay three silver pieces.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Truth never comes into the world but like a bastard, to the ignominy<BR>\nof him that brought her birth.<BR>\n&nbsp;-- Milton');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Truth is hard to find and harder to obscure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Truth has no special time of its own.  Its hour is now -- always.<BR>\n&nbsp;-- Albert Schweitzer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','To give happiness is to deserve happiness.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','To have died once is enough.<BR>\n&nbsp;-- Publius Vergilius Maro (Virgil)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','Two men were sitting over coffee, contemplating the nature of things,<BR>\nwith all due respect for their breakfast.  \"I wonder why it is that<BR>\ntoast always falls on the buttered side,\" said one.<BR>\n&nbsp;\"Tell me,\" replied his friend, \"why you say such a thing.  Look<BR>\nat this.\"  And he dropped his toast on the floor, where it landed on the<BR>\ndry side.<BR>\n&nbsp;\"So, what have you to say for your theory now?\"<BR>\n&nbsp;\"What am I to say?  You obviously buttered the wrong side.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If there is a possibility of several things going wrong,<BR>\nthe one that will cause the most damage will be the one to go wrong.<BR>\n&nbsp;If you perceive that there are four possible ways in which a procedure<BR>\ncan go wrong, and circumvent these, then a fifth way will promptly develop.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','God grant us the serenity to accept the things we cannot change, courage to<BR>\nchange the things we can, and wisdom to know the difference.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you can survive death, you can probably survive anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you are not for yourself, who will be for you?<BR>\nIf you are for yourself, then what are you?<BR>\nIf not now, when?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you have to hate, hate gently.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you fool around with something long enough, it will eventually break.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you keep anything long enough, you can throw it away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you put it off long enough, it might go away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you only have a hammer, you tend to see every problem as a nail.<BR>\n&nbsp;-- Maslow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','To get something clean, one has to get something dirty.<BR>\nTo get something dirty, one does not have to get anything clean.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','If you find a solution and become attached to it, the solution may become<BR>\nyour next problem.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','To give of yourself, you must first know yourself.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The questions remain the same.  The answers are eternally variable.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We can embody the truth, but we cannot know it.<BR>\n&nbsp;-- Yates');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','There are no winners in life, only survivors.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','We have nowhere else to go... this is all we have.<BR>\n&nbsp;-- Margaret Mead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The truth is what is; what should be is a dirty lie.<BR>\n&nbsp;-- Lenny Bruce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The soul would have no rainbow had the eyes no tears.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The state of innocence contains the germs of all future sin.<BR>\n&nbsp;-- Alexandre Arnoux, \"Etudes et caprices\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The savior becomes the victim.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('wisdom','The true way goes over a rope which is not stretched at any great height<BR>\nbut just above the ground.  It seems more designed to make people stumble<BR>\nthan to be walked upon.<BR>\n&nbsp;-- Franz Kafka');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Dealing with the problem of pure staff accumulation,<BR>\nall our researches ... point to an average increase of 5.75% per year.<BR>\n&nbsp;-- C.N. Parkinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Be sociable. Speak to the person next to you in the unemployment line tomorrow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Good salesmen and good repairmen will never go hungry.<BR>\n&nbsp;-- R.E. Schenk');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Life is cheap, but the accessories can kill you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Dear Lord:<BR>\n&nbsp;I just want *___one* one-armed manager so I never have to hear \"On<BR>\nthe other hand\", again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Competence, like truth, beauty, and contact lenses, is in the eye of<BR>\nthe beholder.<BR>\n&nbsp;-- Dr. Laurence J. Peter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','... [concerning quotation marks] even if we *___did* quote anybody in this<BR>\nbusiness, it probably would be gibberish.<BR>\n&nbsp;-- Thom McLeod');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Committees have become so important nowadays that subcommittees have to<BR>\nbe appointed to do the work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Anyone can hold the helm when the sea is calm.<BR>\n&nbsp;-- Publius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Anyone can make an omelet with eggs.  The trick is to make one with none.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Chairman of the Bored.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Can anything be sadder than work left unfinished? Yes, work never begun.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Innovation is hard to schedule.<BR>\n&nbsp;-- Dan Fylstra');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','By working faithfully eight hours a day, you may eventually get to be<BR>\nboss and work twelve.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Can anyone remember when the times were not hard, and money not scarce?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Carelessly planned projects take three times longer to complete than expected.<BR>\nCarefully planned projects take four times longer to complete than expected,<BR>\nmostly because the planners expect their planning to reduce the time it takes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Anything free is worth what you pay for it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','America works less, when you say \"Union Yes!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Despite all appearances, your boss is a thinking, feeling, human being.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Biz is better.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never tell people how to do things.  Tell them WHAT to do and they will<BR>\nsurprise you with their ingenuity.<BR>\n&nbsp;-- Gen. George S. Patton, Jr.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','My idea of roughing it turning the air conditioner too low.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Business will be either better or worse.<BR>\n&nbsp;-- Calvin Coolidge');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Beware of all enterprises that require new clothes, and not rather<BR>\na new wearer of clothes.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Business is a good game -- lots of competition and minimum of rules.<BR>\nYou keep score with money.<BR>\n&nbsp;-- Nolan Bushnell, founder of Atari');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','... before I could come to any conclusion it occurred to me that my speech<BR>\nor my silence, indeed any action of mine, would be a mere futility.  What<BR>\ndid it matter what anyone knew or ignored?  What did it matter who was<BR>\nmanager?  One gets sometimes such a flash of insight. The essentials of<BR>\nthis affair lay deep under the surface, beyond my reach, and beyond my<BR>\npower of meddling.<BR>\n&nbsp;-- Joseph Conrad');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Body by Nautilus, Brain by Mattel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Been Transferred Lately?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','He who is content with his lot probably has a lot.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','\"Here at the Phone Company, we serve all kinds of people; from<BR>\nPresidents and Kings to the scum of the earth ...\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Good day to avoid cops.  Crawl to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','He has not acquired a fortune; the fortune has acquired him.<BR>\n&nbsp;-- Bion');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','He who steps on others to reach the top has good balance.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Happiness is a positive cash flow.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','&nbsp;\"Hey, Sam, how about a loan?\"<BR>\n&nbsp;\"Whattaya need?\"<BR>\n&nbsp;\"Oh, about $500.\"<BR>\n&nbsp;\"Whattaya got for collateral?\"<BR>\n&nbsp;\"Whattaya need?\"<BR>\n&nbsp;\"How about an eye?\"<BR>\n&nbsp;-- Sam Giancana');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Life is a healthy respect for mother nature laced with greed.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Hard work never killed anybody, but why take a chance?<BR>\n&nbsp;-- Charlie McCarthy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Executive ability is deciding quickly and getting somebody else to do<BR>\nthe work.<BR>\n&nbsp;-- John G. Pollard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Ernest asks Frank how long he has been working for the company.<BR>\n&nbsp;\"Ever since they threatened to fire me.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Exceptions prove the rule, and wreck the budget.<BR>\n&nbsp;-- Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Earn cash in your spare time -- blackmail your friends.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Dreams are free, but you get soaked on the connect time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Everybody likes a kidder, but nobody lends him money.<BR>\n&nbsp;-- Arthur Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Every cloud has a silver lining; you should have sold it, and bought titanium.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Every man thinks God is on his side.  The rich and powerful know that he is.<BR>\n&nbsp;-- Jean Anouilh, \"The Lark\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','\"Every man has his price.  Mine is $3.95.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Ever notice that even the busiest people are never too busy to tell you<BR>\njust how busy they are?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','God help those who do not help themselves.<BR>\n&nbsp;-- Wilson Mizner');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Every successful person has had failures but repeated failure is no<BR>\nguarantee of eventual success.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Drilling for oil is boring.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Every young man should have a hobby: learning how to handle money is<BR>\nthe best one.<BR>\n&nbsp;-- Jack Hurley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Consultants are mystical people who ask a company for a number and then<BR>\ngive it back to them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If I were a grave-digger or even a hangman, there are some people I could<BR>\nwork for with a great deal of enjoyment.<BR>\n&nbsp;-- Douglas Jerrold');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you are over 80 years old and accompanied by your parents, we will<BR>\ncash your check.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If we could sell our experiences for what they cost us, we would<BR>\nall be millionaires.<BR>\n&nbsp;-- Abigail Van Buren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If a subordinate asks you a pertinent question, look at him as if he had<BR>\nlost his senses.  When he looks down, paraphrase the question back at him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If ever the pleasure of one has to be bought by the pain of the other, there<BR>\nbetter be no trade.  A trade by which one gains and the other loses is a fraud.<BR>\n&nbsp;-- Dagny Taggart, \"Atlas Shrugged\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If God had not given us sticky tape, it would have been necessary to invent it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If all else fails, lower your standards.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If bankers can count, how come they have eight windows and only four tellers?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I owe the public nothing.<BR>\n&nbsp;-- J.P. Morgan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I never cheated an honest man, only rascals.  They wanted something for<BR>\nnothing.  I gave them nothing for something.<BR>\n&nbsp;-- Joseph \"Yellow Kid\" Weil');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you are good, you will be assigned all the work.  If you are real<BR>\ngood, you will get out of it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I have the simplest tastes.  I am always satisfied with the best.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I go on working for the same reason a hen goes on laying eggs.<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I like work; it fascinates me; I can sit and look at it for hours.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Human resources are human first, and resources second.<BR>\n&nbsp;-- J. Garbers');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','&nbsp;\"How many people work here?\"<BR>\n&nbsp;\"Oh, about half.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Honesty is for the most part less profitable than dishonesty.<BR>\n&nbsp;-- Plato');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Hotels are tired of getting ripped off.  I checked into a hotel and they<BR>\nhad towels from my house.<BR>\n&nbsp;-- Mark Guido');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Hire the morally handicapped.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Hideously disfigured by an ancient Indian curse?<BR>\n&nbsp;WE CAN HELP!<BR>\n&nbsp;Call (511) 338-0959 for an immediate appointment.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is much harder to find a job than to keep one.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is difficult to soar with the eagles when you work with turkeys.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is better to live rich than to die rich.<BR>\n&nbsp;-- Samuel Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is better to travel hopefully than to fly Continental.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is better to give than to lend, and it costs about the same.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is impossible to enjoy idling thoroughly unless one has plenty of<BR>\nwork to do.<BR>\n&nbsp;-- Jerome Klapka Jerome');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In the middle of a wide field is a pot of gold.  100 feet to the north stands<BR>\na smart manager.  100 feet to the south stands a dumb manager.  100 feet to<BR>\nthe east is the Easter Bunny, and 100 feet to the west is Santa Claus.<BR>\n&nbsp;Q:	Who gets to the pot of gold first?<BR>\nA:	The dumb manager.  All the rest are myths.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In every hierarchy the cream rises until it sours.<BR>\n&nbsp;-- Dr. Laurence J. Peter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In a consumer society there are inevitably two kinds of slaves:<BR>\nthe prisoners of addiction and the prisoners of envy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In case of atomic attack, all work rules will be temporarily suspended.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you are shooting under 80 you are neglecting your business;<BR>\nover 80 you are neglecting your golf.<BR>\n&nbsp;-- Walter Hagen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you always postpone pleasure you will never have it.  Quit work and play<BR>\nfor once!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you fail to plan, plan to fail.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I am more bored than you could ever possibly be.  Go back to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I attribute my success to intelligence, guts, determination, honesty,<BR>\nambition, and having enough money to buy people with those qualities.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you would know the value of money, go try to borrow some.<BR>\n&nbsp;-- Ben Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you want to put yourself on the map, publish your own map.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you want to know what god thinks of money, just look at the people he gave<BR>\nit to.<BR>\n&nbsp;-- Dorthy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you had better tools, you could more effectively demonstrate your<BR>\ntotal incompetence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you sell diamonds, you cannot expect to have many customers.<BR>\nBut a diamond is a diamond even if there are no customers.<BR>\n&nbsp;-- Swami Prabhupada');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','If you do something right once, someone will ask you to do it again.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Keep your Eye on the Ball,<BR>\nYour Shoulder to the Wheel,<BR>\nYour Nose to the Grindstone,<BR>\nYour Feet on the Ground,<BR>\nYour Head on your Shoulders.<BR>\nNow... try to get something DONE!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In a hierarchy every employee tends to rise to his level of incompetence ...<BR>\nin time every post tends to be occupied by an employee who is incompetent<BR>\nto carry out its duties ... Work is accomplished by those employees who<BR>\nhave not yet reached their level of incompetence.<BR>\n&nbsp;-- Dr. Laurence J. Peter, \"The Peter Principle\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money is better than poverty, if only for financial reasons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Man must shape his tools lest they shape him.<BR>\n&nbsp;-- Arthur R. Miller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Mental power tended to corrupt, and absolute intelligence tended to<BR>\ncorrupt absolutely, until the victim eschewed violence entirely in<BR>\nfavor of smart solutions to stupid problems.<BR>\n&nbsp;-- Piers Anthony');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Men take only their needs into consideration -- never their abilities.<BR>\n&nbsp;-- Napoleon Bonaparte');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I just asked myself... what would John DeLorean do?<BR>\n&nbsp;-- Raoul Duke');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Men of lofty genius when they are doing the least work are most active.<BR>\n&nbsp;-- Leonardo da Vinci');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Many people write memos to tell you they have nothing to say.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I BET WHAT HAPPENED was they discovered fire and invented the wheel on<BR>\nthe same day.  Then that night, they burned the wheel.<BR>\n&nbsp;-- Jack Handley, The New Mexican, 1988.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','He who has but four and spends five has no need for a wallet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Getting the job done is no excuse for not following the rules.<BR>\n&nbsp;Corollary:<BR>\n&nbsp;Following the rules will not get the job done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Genius is ten percent inspiration and fifty percent capital gains.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Mater artium necessitas.<BR>\n&nbsp;[Necessity is the mother of invention].');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Genius is one percent inspiration and ninety-nine percent perspiration.<BR>\n&nbsp;-- Thomas Alva Edison');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Fear is the greatest salesman.<BR>\n&nbsp;-- Robert Klein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Fast, cheap, good: pick two.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Failure is more frequently from want of energy than want of capital.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Maternity pay?	Now every Tom, Dick and Harry will get pregnant.<BR>\n&nbsp;-- Malcolm Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Consider the postage stamp: its usefulness consists in the ability to<BR>\nstick to one thing till it gets there.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Many people are unenthusiastic about their work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','All warranty and guarantee clauses become null and void upon payment of invoice.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Lonesome?<BR>\n&nbsp;Like a change?<BR>\nLike a new job?<BR>\nLike excitement?<BR>\nLike to meet new and interesting people?<BR>\n&nbsp;JUST SCREW-UP ONE MORE TIME!!!!!!!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Living on Earth may be expensive, but it includes an annual free trip<BR>\naround the Sun.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Lo!  Men have become the tool of their tools.<BR>\n&nbsp;-- Henry David Thoreau');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Management:	How many feet do mice have?<BR>\nReply:		Mice have four feet.<BR>\nM:	Elaborate!<BR>\nR:	Mice have five appendages, and four of them are feet.<BR>\nM:	No discussion of fifth appendage!<BR>\nR:	Mice have five appendages; four of them are feet; one is a tail.<BR>\nM:	What?  Feet with no legs?<BR>\nR:	Mice have four legs, four feet, and one tail per unit-mouse.<BR>\nM:	Confusing -- is that a total of 9 appendages?<BR>\nR:	Mice have four leg-foot assemblies and one tail assembly per body.<BR>\nM:	Does not fully discuss the issue!<BR>\nR:	Each mouse comes equipped with four legs and a tail.  Each leg<BR>\n&nbsp;is equipped with a foot at the end opposite the body; the tail<BR>\n&nbsp;is not equipped with a foot.<BR>\nM:	Descriptive?  Yes.  Forceful NO!<BR>\nR:	Allotment of appendages for mice will be:  Four foot-leg assemblies,<BR>\n&nbsp;one tail.  Deviation from this policy is not permitted as it would<BR>\n&nbsp;constitute misapportionment of scarce appendage assets.<BR>\nM:	Too authoritarian; stifles creativity!<BR>\nR:	Mice have four feet; each foot is attached to a small leg joined<BR>\n&nbsp;integrally with the overall mouse structural sub-system.  Also<BR>\n&nbsp;attached to the mouse sub-system is a thin tail, non-functional and<BR>\n&nbsp;ornamental in nature.<BR>\nM:	Too verbose/scientific.  Answer the question!<BR>\nR:	Mice have four feet.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Many people are unenthusiastic about your work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing is more admirable than the fortitude with which millionaires<BR>\ntolerate the disadvantages of their wealth.<BR>\n&nbsp;-- Nero Wolfe');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing recedes like success.<BR>\n&nbsp;-- Walter Winchell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing makes a person more productive than the last minute.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing will ever be attempted if all possible objections must be first<BR>\novercome.<BR>\n&nbsp;-- Dr. Johnson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing succeeds like success.<BR>\n&nbsp;-- Alexandre Dumas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing succeeds like the appearance of success.<BR>\n&nbsp;-- Christopher Lascl');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','No spitting on the Bus!<BR>\nThank you, The Mgt.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','None of our men are \"experts.\"  We have most unfortunately found it necessary<BR>\nto get rid of a man as soon as he thinks himself an expert -- because no one <BR>\never considers himself expert if he really knows his job.  A man who knows a <BR>\njob sees so much more to be done than he has done, that he is always pressing <BR>\nforward and never gives up an instant of thought to how good and how efficient <BR>\nhe is.  Thinking always ahead, thinking always of trying to do more, brings a <BR>\nstate of mind in which nothing is impossible. The moment one gets into the<BR>\n\"expert\" state of mind a great number of things become impossible.<BR>\n&nbsp;-- From Henry Ford Sr., \"My Life and Work\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','No skis take rocks like rental skis!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','No one gets sick on Wednesdays.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing will dispel enthusiasm like a small admission fee.<BR>\n&nbsp;-- Kim Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','My problem lies in reconciling my gross habits with my net income.<BR>\n&nbsp;-- Errol Flynn<BR>\n&nbsp;Any man who has $10,000 left when he dies is a failure.<BR>\n&nbsp;-- Errol Flynn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never let someone who says it cannot be done interrupt the person who is<BR>\ndoing it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','\"No job too big; no fee too big!\"<BR>\n&nbsp;-- Dr. Peter Venkman, \"Ghost-busters\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never call a man a fool.  Borrow from him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never say you know a man until you have divided an inheritance with him.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never ask two questions in a business letter.  The reply will discuss<BR>\nthe one you are least interested, and say nothing about the other.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','\"Necessity is the mother of invention\" is a silly proverb.  \"Necessity<BR>\nis the mother of futile dodges\" is much nearer the truth.<BR>\n&nbsp;-- Alfred North Whitehead');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Neckties strangle clear thinking.<BR>\n&nbsp;-- Lin Yutang');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never trust anyone who says money is no object.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','My idea of roughing it is when room service is late.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never try to teach a pig to sing.  It wastes your time and annoys the pig.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough for Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money may buy friendship but money cannot buy love.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money is truthful.  If a man speaks of his honor, make him pay cash.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money is the root of all evil, and man needs roots.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money will say more in one moment than the most eloquent lover can in years.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money cannot buy love, nor even friendship.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Riches cover a multitude of woes.<BR>\n&nbsp;-- Menander');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','People are always available for work in the past tense.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Possessions increase to fill the space available for their storage.<BR>\n&nbsp;-- Ryan');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','In 1914, the first crossword puzzle was printed in a newspaper.  The<BR>\ncreator received $4000 down ... and $3000 across.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Our country has plenty of good five-cent cigars, but the trouble is<BR>\nthey charge fifteen cents for them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Optimism is the content of small men in high places.<BR>\n&nbsp;-- F. Scott Fitzgerald, \"The Crack Up\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Or you or I must yield up his life to Ahrimanes.  I would rather it were you.<BR>\nI should have no hesitation in sacrificing my own life to spare yours, but<BR>\nwe take stock next week, and it would not be fair on the company.<BR>\n&nbsp;-- J. Wellington Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','One way to make your old car run better is to look up the price of a new model.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Moneyliness is next to Godliness.<BR>\n&nbsp;-- Andries van Dam');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The opulence of the front office door varies inversely with the fundamental<BR>\nsolvency of the firm.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A committee is a group that keeps the minutes and loses hours.<BR>\n&nbsp;-- Milton Berle');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Take time to reflect on all the things you have, not as a result of your<BR>\nmerit or hard work or because God or chance or the efforts of other people<BR>\nhave given them to you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Sears has everything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Mundus vult decipi decipiatur ergo.<BR>\n&nbsp;-- Xaviera Hollander<BR>\n&nbsp;[The world wants to be cheated, so cheat.]');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never buy what you do not want because it is cheap; it will be dear to you.<BR>\n&nbsp;-- Thomas Jefferson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never buy from a rich salesman.<BR>\n&nbsp;-- Goldenstern');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Once it hits the fan, the only rational choice is to sweep it up, package it,<BR>\nand sell it as fertilizer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','One good suit is worth a thousand resumes.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing is finished until the paperwork is done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Of all possible committee reactions to any given agenda item, the<BR>\nreaction that will occur is the one which will liberate the greatest<BR>\namount of hot air.<BR>\n&nbsp;-- Thomas L. Martin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','No problem is insoluble in all conceivable circumstances.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The best executive is one who has sense enough to pick good people to do<BR>\nwhat he wants done, and self-restraint enough to keep from meddling with<BR>\nthem while they do it.<BR>\n&nbsp;-- Theodore Roosevelt');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The answer to the Ultimate Question of Life, the Universe, and Everything was<BR>\nreleased with the kind permission of the Amalgamated Union of Philosophers,<BR>\nSages, Luminaries, and Other Professional Thinking Persons.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The best equipment for your work is, of course, the most expensive.<BR>\nHowever, your neighbor is always wasting money that should be yours<BR>\nby judging things by their price.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The best laid plans of mice and men are held up in the legal department.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The answer to the question of Life, the Universe, and Everything is...<BR>\n&nbsp;Four day work week,<BR>\n&nbsp;Two ply toilet paper!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The degree of technical confidence is inversely proportional to the<BR>\nlevel of management.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The cost of feathers has risen, even down is up!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The optimum committee has no members.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I have ways of making money that you know nothing of.<BR>\n&nbsp;-- John D. Rockefeller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Support your local church or synagogue.  Worship at Bank of America.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Surprise due today.  Also the rent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Success is something I will dress for when I get there, and not until.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Suburbia is where the developer bulldozes out the trees, then names<BR>\nthe streets after them.<BR>\n&nbsp;-- Bill Vaughn');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Take your work seriously but never take yourself seriously; and do not<BR>\ntake what happens either to yourself or your work seriously.<BR>\n&nbsp;-- Booth Tarkington');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Remember -- only 10% of anything can be in the top 10%.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','So you think that money is the root of all evil.  Have you ever asked what<BR>\nis the root of money?<BR>\n&nbsp;-- Ayn Rand');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Remember to say hello to your bank teller.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never keep up with the Joneses. Drag them down to your level.<BR>\n&nbsp;-- Quentin Crisp');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Nothing succeeds like excess.<BR>\n&nbsp;-- Oscar Wilde');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Some people carve careers, others chisel them.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Talent does what it can.<BR>\nGenius does what it must.<BR>\nYou do what you get paid to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Serving coffee on aircraft causes turbulence.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Rule #7: Silence is not acquiescence.<BR>\n&nbsp;Contrary to what you may have heard, silence of those present is<BR>\n&nbsp;not necessarily consent, even the reluctant variety.  They simply may<BR>\n&nbsp;sit in stunned silence and figure ways of sabotaging the plan after<BR>\n&nbsp;they regain their composure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Retirement means that when someone says \"Have a nice day\", you<BR>\nactually have a shot at it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Recent research has tended to show that the Abominable No-Man<BR>\nis being replaced by the Prohibitive Procrastinator.<BR>\n&nbsp;-- C.N. Parkinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Recent investments will yield a slight profit.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Put not your trust in money, but put your money in trust.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Promptness is its own reward, if one lives by the clock instead of the sword.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Practical people would be more practical if they would take a little<BR>\nmore time for dreaming.<BR>\n&nbsp;-- J. P. McEvoy');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The only really good place to buy lumber is at a store where the lumber has<BR>\nalready been cut and attached together in the form of furniture, finished,<BR>\nand put inside boxes.<BR>\n&nbsp;-- Dave Barry, \"The Taming of the Screw\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The more I want to get something done, the less I call it work.<BR>\n&nbsp;-- Richard Bach, \"Illusions\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The King and his advisor are overlooking the battle field:<BR>\n&nbsp;King:		\"How goes the battle plan?\"<BR>\nAdvisor:	\"See those little black specks running to the right?\"<BR>\nK:	\"Yes.\"<BR>\nA:	\"Those are their guys. And all those little red specks running<BR>\n&nbsp;to the left are our guys. Then when they collide we wait till<BR>\n&nbsp;the dust clears.\"<BR>\nK:	\"And?\"<BR>\nA:	\"If there are more red specks left than black specks, we win.\"<BR>\nK:	\"But what about the ^#!!$% battle plan?\"<BR>\nA:	\"So far, it seems to be going according to specks.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The IQ of the group is the lowest IQ of a member of the group divided<BR>\nby the number of people in the group.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The intelligence of any discussion diminishes with the square of the<BR>\nnumber of participants.<BR>\n&nbsp;-- Adam Walinsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The idle man does not know what it is to enjoy rest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The individual choice of garnishment of a burger can be an important<BR>\npoint to the consumer in this day when individualism is an increasingly<BR>\nimportant thing to people.<BR>\n&nbsp;-- Donald N. Smith, president of Burger King');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The first myth of management is that it exists.  The second myth of<BR>\nmanagement is that success equals skill.<BR>\n&nbsp;-- Robert Heller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The meek shall inherit the earth, but *not* its mineral rights.<BR>\n&nbsp;-- J.P. Getty');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The ideal voice for radio may be defined as showing no substance, no sex,<BR>\nno owner, and a message of importance for every housewife.<BR>\n&nbsp;-- Harry V. Wade');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The hardest part of climbing the ladder of success is getting through<BR>\nthe crowd at the bottom.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The greatest productive force is human selfishness.<BR>\n&nbsp;-- Robert Heinlein');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The hieroglyphics are all unreadable except for a notation on the back,<BR>\nwhich reads \"Genuine authentic Egyptian papyrus.  Guaranteed to be at<BR>\nleast 5000 years old.\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The first rule of intelligent tinkering is to save all the parts.<BR>\n&nbsp;-- Paul Erlich');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The first Rotarian was the first man to call John the Baptist \"Jack.\"<BR>\n&nbsp;-- H.L. Mencken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','No committee could ever come up with anything as revolutionary as a camel --<BR>\nanything as practical and as perfectly designed to perform effectively under<BR>\nsuch difficult conditions.<BR>\n&nbsp;-- Laurence J. Peter');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Never invest your money in anything that eats or needs repainting.<BR>\n&nbsp;-- Billy Rose');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The end of labor is to gain leisure.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The easiest way to figure the cost of living is to take your income and<BR>\nadd ten percent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The error of youth is to believe that intelligence is a substitute for<BR>\nexperience, while the error of age is to believe experience is a substitute<BR>\nfor intelligence.<BR>\n&nbsp;-- Lyman Bryson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The early bird who catches the worm works for someone who comes in late<BR>\nand owns the worm farm.<BR>\n&nbsp;-- Travis McGee');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The difference between a career and a job is about 20 hours a week.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The flush toilet is the basis of Western civilization.<BR>\n&nbsp;-- Alan Coult');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The cost of living is going up, and the chance of living is going down.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The biggest mistake you can make is to believe that you are working for<BR>\nsomeone else.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I consider a new device or technology to have been culturally accepted when<BR>\nit has been used to commit a murder.<BR>\n&nbsp;-- M. Gallaher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The best things in life are for a fee.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Think lucky. If you fall in a pond, check your pockets for fish.<BR>\n&nbsp;-- Darrell Royal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','This is a good time to punt work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There has been a little distress selling on the stock exchange.<BR>\n&nbsp;-- Thomas W. Lamont, October 29, 1929 (Black Tuesday)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The way to make a small fortune in the commodities market is to start<BR>\nwith a large fortune.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with opportunity is that it always comes disguised as hard work.<BR>\n&nbsp;-- Herbert V. Prochnow');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with money is it costs too much!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The wages of sin are unreported.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with doing something right the first time is that nobody<BR>\nappreciates how difficult it was.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The two most beautiful words in the English language are \"Cheque Enclosed.\"<BR>\n&nbsp;-- Dorothy Parker');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The star of riches is shining upon you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The superior man understands what is right; the inferior man understands<BR>\nwhat will sell.<BR>\n&nbsp;-- Confucius');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The price one pays for pursuing any profession, or calling, is an intimate<BR>\nknowledge of its ugly side.<BR>\n&nbsp;-- James Baldwin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The possession of a book becomes a substitute for reading it.<BR>\n&nbsp;-- Anthony Burgess');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The time spent on any item of the agenda [of a finance committee] will be<BR>\nin inverse proportion to the sum involved.<BR>\n&nbsp;-- C.N. Parkinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The salary of the chief executive of the large corporation is not a market<BR>\naward for achievement.  It is frequently in the nature of a warm personal<BR>\ngesture by the individual to himself.<BR>\n&nbsp;-- John Kenneth Galbraith, \"Annals of an Abiding Liberal\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The reward for working hard is more hard work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The reason why worry kills more people than work is that more people<BR>\nworry than work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The reward of a thing well done is to have done it.<BR>\n&nbsp;-- Emerson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The primary cause of failure in electrical appliances is an expired<BR>\nwarranty.  Often, you can get an appliance running again simply by changing<BR>\nthe warranty expiration date with a 15/64-inch felt-tipped marker.<BR>\n&nbsp;-- Dave Barry, \"The Taming of the Screw\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The problem that we thought was a problem was, indeed, a problem, but<BR>\nnot the problem we thought was the problem.<BR>\n&nbsp;-- Mike Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The rights and interests of the laboring man will be protected and cared<BR>\nfor not by our labor agitators, but by the Christian men to whom God in his<BR>\ninfinite wisdom has given control of property interests of the country, and<BR>\nupon the successful management of which so much remains.<BR>\n&nbsp;-- George F. Baer, railroad industrialist');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The person who can smile when something goes wrong has thought of<BR>\nsomeone to blame it on.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The rich get rich, and the poor get poorer.<BR>\nThe haves get more, the have-nots die.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The person who makes no mistakes does not usually make anything.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A businessman is a hybrid of a dancer and a calculator.<BR>\n&nbsp;-- Paul Valery');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with a lot of self-made men is that they worship their creator.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The road to ruin is always in good repair, and the travellers pay the<BR>\nexpense of it.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The most delightful day after the one on which you buy a cottage in<BR>\nthe country is the one on which you resell it.<BR>\n&nbsp;-- J. Brecheux');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The only problem with being a man of leisure is that you can never stop<BR>\nand take a rest.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','This is an especially good time for you vacationers who plan to fly, because<BR>\nthe Reagan administration, as part of the same policy under which it<BR>\nrecently sold Yellowstone National Park to Wayne Newton, has \"deregulated\"<BR>\nthe airline industry.  What this means for you, the consumer, is that the<BR>\nairlines are no longer required to follow any rules whatsoever.  They can<BR>\nshow snuff movies.  They can charge for oxygen.  They can hire pilots right<BR>\nout of Vending Machine Refill Person School.  They can conserve fuel by<BR>\nejecting husky passengers over water.  They can ram competing planes in<BR>\nmid-air.  These innovations have resulted in tremendous cost savings which<BR>\nhave been passed along to you, the consumer, in the form of flights with<BR>\namazingly low fares, such as $29.  Of course, certain restrictions do apply,<BR>\nthe main one being that all these flights take you to Newark, and you must<BR>\npay thousands of dollars if you want to fly back out.<BR>\n&nbsp;-- Dave Barry, \"Iowa -- Land of Secure Vacations\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Someone is unenthusiastic about your work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is nothing so easy but that it becomes difficult when you do it<BR>\nreluctantly.<BR>\n&nbsp;-- Publius Terentius Afer (Terence)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Someday somebody has got to decide whether the typewriter is the machine,<BR>\nor the person who operates it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There are worse things in life than death.  Have you ever spent an evening<BR>\nwith an insurance salesman?<BR>\n&nbsp;-- Woody Allen');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is no time like the present for postponing what you ought to be doing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','I just need enough to tide me over until I need more.<BR>\n&nbsp;-- Bill Hoest');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Somebody ought to cross ball point pens with coat hangers so that the<BR>\npens will multiply instead of disappear.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The sooner you fall behind, the more time you have to catch up.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There are many of us in this old world of ours who hold that things break<BR>\nabout even for all of us.  I have observed, for example, that we all get<BR>\nabout the same amount of ice.  The rich get it in the summer and the poor<BR>\nget it in the winter.<BR>\n&nbsp;-- Bat Masterson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','At work, the authority of a person is inversely proportional to the<BR>\nnumber of pens that person is carrying.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','We all like praise, but a hike in our pay is the best kind of ways.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is one way to find out if a man is honest -- ask him.  If he says<BR>\n\"Yes\" you know he is crooked.<BR>\n&nbsp;-- Groucho Marx');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There must be more to life than having everything.<BR>\n&nbsp;-- Maurice Sendak');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with being poor is that it takes up all your time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The trouble with being punctual is that people think you have nothing more<BR>\nimportant to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','&nbsp;Then a man said: Speak to us of Expectations.<BR>\n&nbsp;He then said: If a man does not see or hear the waters of the<BR>\nJordan, then he should not taste the pomegranate or ply his wares in an<BR>\nopen market.<BR>\n&nbsp;If a man would not labour in the salt and rock quarries then he<BR>\nshould not accept of the Earth that which he refuses to give of<BR>\nhimself.<BR>\n&nbsp;Such a man would expect a pear of a peach tree.<BR>\n&nbsp;Such a man would expect a stone to lay an egg.<BR>\n&nbsp;Such a man would expect Sears to assemble a lawnmower.<BR>\n&nbsp;-- Kehlog Albran, \"The Profit\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is very little future in being right when your boss is wrong.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A budget is just a method of worrying before you spend money, as well<BR>\nas afterward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Then there was the ScoutMaster who got a fantastic deal on this case of<BR>\nTates brand compasses for his troup; only $1.25 each!  Only problem was,<BR>\nwhen they got them out in the woods, the compasses were all stuck pointing<BR>\nto the \"W\" on the dial.<BR>\n&nbsp;Moral:<BR>\n&nbsp;He who has a Tates is lost!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The use of money is all the advantage there is to having money.<BR>\n&nbsp;-- B. Franklin');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What the large print giveth, the small print taketh away.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','We are not a loved organization, but we are a respected one.<BR>\n&nbsp;-- John Fisher');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Waste not, get your budget cut next year.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Too much of everything is just enough.<BR>\n&nbsp;-- Bob Wier');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','We all live in a state of ambitious poverty.<BR>\n&nbsp;-- Decimus Junius Juvenalis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','&nbsp;WARNING TO ALL PERSONNEL:<BR>\n&nbsp;Firings will continue until morale improves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Very few things actually get manufactured these days, because in an<BR>\ninfinitely large Universe, such as the one in which we live, most things one<BR>\ncould possibly imagine, and a lot of things one would rather not, grow<BR>\nsomewhere.  A forest was discovered recently in which most of the trees grew<BR>\nratchet screwdrivers as fruit.  The life cycle of the ratchet screwdriver is<BR>\nquite interesting.  Once picked it needs a dark dusty drawer in which it can<BR>\nlie undisturbed for years.  Then one night it suddenly hatches, discards its<BR>\nouter skin that crumbles into dust, and emerges as a totally unidentifiable<BR>\nlittle metal object with flanges at both ends and a sort of ridge and a hole<BR>\nfor a screw.  This, when found, will get thrown away.  No one knows what the<BR>\nscrewdriver is supposed to gain from this.  Nature, in her infinite wisdom,<BR>\nis presumably working on it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Two can Live as Cheaply as One for Half as Long.<BR>\n&nbsp;-- Howard Kandel');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Veni, Vidi, VISA:<BR>\n&nbsp;I came, I saw, I did a little shopping.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Truth is free, but information costs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','\"We maintain that the very foundation of our way of life is what we call<BR>\nfree enterprise,\" said Cash McCall, \"but when one of our citizens<BR>\nshow enough free enterprise to pile up a little of that profit, we do<BR>\nour best to make him feel that he ought to be ashamed of himself.\"<BR>\n&nbsp;-- Cameron Hawley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To do nothing is to be nothing.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A bank is a place where they lend you an umbrella in fair weather and<BR>\nask for it back the when it begins to rain.<BR>\n&nbsp;-- Robert Frost');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To spot the expert, pick the one who predicts the job will take the longest<BR>\nand cost the most.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To do two things at once is to do neither.<BR>\n&nbsp;-- Publilius Syrus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is hardly a thing in the world that some man can not make a little<BR>\nworse and sell a little cheaper.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The sooner you make your first 5000 mistakes, the sooner you will be<BR>\nable to correct them.<BR>\n&nbsp;-- Nicolaides');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','There is never time to do it right, but always time to do it over.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To avoid criticism, do nothing, say nothing, be nothing.<BR>\n&nbsp;-- Elbert Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To thine own self be true.  (If not that, at least make some money.)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To be or not to be, that is the bottom line.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','This week only, all our fiber-fill jackets are marked down!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','We were so poor that we thought new clothes meant someone had died.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Those who do things in a noble spirit of self-sacrifice are to be avoided<BR>\nat all costs.<BR>\n&nbsp;-- N. Alexander.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To the landlord belongs the doorknobs.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Things worth having are worth cheating for.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What this country needs is a good five dollar plasma weapon.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Too many people are thinking of security instead of opportunity.  They seem<BR>\nmore afraid of life than death.<BR>\n&nbsp;-- James F. Byrnes');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When I works, I works hard.<BR>\nWhen I sits, I sits easy.<BR>\nAnd when I thinks, I goes to sleep.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What this country needs is a dime that will buy a good five-cent bagel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','VI:<BR>\n&nbsp;A hungry dog hunts best.<BR>\n&nbsp;A hungrier dog hunts even better.<BR>\nVII:<BR>\n&nbsp;Decreased business base increases overhead.<BR>\n&nbsp;So does increased business base.<BR>\nVIII:<BR>\n&nbsp;The most unsuccessful four years in the education of a cost-estimator<BR>\n&nbsp;is fifth grade arithmetic.<BR>\nIX:<BR>\n&nbsp;Acronyms and abbreviations should be used to the maximum extent<BR>\n&nbsp;possible to make trivial ideas profound.  Q.E.D.<BR>\nX:<BR>\n&nbsp;Bulls do not win bull fights; people do.<BR>\n&nbsp;People do not win people fights; lawyers do.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Vests are to suits as seat-belts are to cars.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When the bosses talk about improving productivity, they are never talking<BR>\nabout themselves.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Too much is not enough.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When in doubt, mumble; when in trouble, delegate; when in charge, ponder.<BR>\n&nbsp;-- James H. Boren');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What sin has not been committed in the name of efficiency?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Weekend, where are you?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What I mean (and everybody else means) by the word QUALITY cannot be<BR>\nbroken down into subjects and predicates.  This is not because Quality<BR>\nis so mysterious but because Quality is so simple, immediate, and direct.<BR>\n&nbsp;-- R. Pirsig, \"Zen and the Art of Motorcycle Maintenance\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What is worth doing is worth the trouble of asking somebody to do.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The absent ones are always at fault.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What this country needs is a good five cent ANYTHING!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When you make your mark in the world, watch out for guys with erasers.<BR>\n&nbsp;-- The Wall Street Journal');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When you are working hard, get up and retch every so often.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','XLI:<BR>\n&nbsp;The more one produces, the less one gets.<BR>\nXLII:<BR>\n&nbsp;Simple systems are not feasible because they require infinite testing.<BR>\nXLIII:<BR>\n&nbsp;Hardware works best when it matters the least.<BR>\nXLIV:<BR>\n&nbsp;Aircraft flight in the 21st century will always be in a westerly<BR>\n&nbsp;direction, preferably supersonic, crossing time zones to provide the<BR>\n&nbsp;additional hours needed to fix the broken electronics.<BR>\nXLV:<BR>\n&nbsp;One should expect that the expected can be prevented, but the<BR>\n&nbsp;unexpected should have been expected.<BR>\nXLVI:<BR>\n&nbsp;A billion saved is a billion earned.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Whoever dies with the most toys wins.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Who goeth a-borrowing goeth a-sorrowing.<BR>\n&nbsp;-- Thomas Tusser');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Work without a vision is slavery, Vision without work is a pipe dream,<BR>\nBut vision with work is the hope of the world.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Work expands to fill the time available.<BR>\n&nbsp;-- Cyril Northcote Parkinson, \"The Economist\", 1955');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Work smarter, not harder, and be careful of your speling.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Wishing without work is like fishing without bait.<BR>\n&nbsp;-- Frank Tyger');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Work is the crab grass in the lawn of life.<BR>\n&nbsp;-- Schulz');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','XVI:<BR>\n&nbsp;In the year 2054, the entire defense budget will purchase just one<BR>\n&nbsp;aircraft.  This aircraft will have to be shared by the Air Force and<BR>\n&nbsp;Navy 3-1/2 days each per week except for leap year, when it will be<BR>\n&nbsp;made available to the Marines for the extra day.<BR>\nXVII:<BR>\n&nbsp;Software is like entropy.  It is difficult to grasp, weighs nothing,<BR>\n&nbsp;and obeys the Second Law of Thermodynamics, i.e., it always increases.<BR>\nXVIII:<BR>\n&nbsp;It is very expensive to achieve high unreliability.  It is not uncommon<BR>\n&nbsp;to increase the cost of an item by a factor of ten for each factor of<BR>\n&nbsp;ten degradation accomplished.<BR>\nXIX:<BR>\n&nbsp;Although most products will soon be too costly to purchase, there will<BR>\n&nbsp;be a thriving market in the sale of books on how to fix them.<BR>\nXX:<BR>\n&nbsp;In any given year, Congress will appropriate the amount of funding<BR>\n&nbsp;approved the prior year plus three-fourths of whatever change the<BR>\n&nbsp;administration requests -- minus 4-percent tax.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Why be a man when you can be a success?<BR>\n&nbsp;-- Bertolt Brecht');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When it is not necessary to make a decision, it is necessary not to<BR>\nmake a decision.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Whatever is not nailed down is mine.  Whatever I can pry up is not nailed down.<BR>\n&nbsp;-- Collis P. Huntingdon, railroad tycoon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What this country needs is a good five cent nickel.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','What we need in this country, instead of Daylight Savings Time, which nobody<BR>\nreally understands anyway, is a new concept called Weekday Morning Time,<BR>\nwhereby at 7 a.m. every weekday we go into a space-launch-style \"hold\" for<BR>\ntwo to three hours, during which it just remains 7 a.m.  This way we could<BR>\nall wake up via a civilized gradual process of stretching and belching and<BR>\nscratching, and it would still be only 7 a.m. when we were ready to actually<BR>\nemerge from bed.<BR>\n&nbsp;-- Dave Barry, \"$#$%#^%!^%&@%@!\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The last person that quit or was fired will be held responsible for<BR>\neverything that goes wrong -- until the next person quits or is fired.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The more crap you put up with, the more crap you are going to get.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The most difficult thing in the world is to know how to do a thing and to<BR>\nwatch someone else doing it wrong, without commenting.<BR>\n&nbsp;-- T.H. White');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The other line moves faster.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','At these prices, I lose money -- but I make it up in volume.<BR>\n&nbsp;-- Peter G. Alaquon');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The meek shall inherit the earth -- they are too weak to refuse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Suggest you just sit there and wait till life gets easier.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The shortest distance between two points is under construction.<BR>\n&nbsp;-- Noelie Alito');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Is a person who blows up banks an econoclast?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The more pretentious a corporate name, the smaller the organization.  (For<BR>\ninstance, The Murphy Center for Codification of Human and Organizational Law,<BR>\ncontrasted to IBM, GM, AT&T ...)');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You knew the job was dangerous when you took it, Fred.<BR>\n&nbsp;-- Superchicken');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You know, the difference between this company and the Titanic is that the<BR>\nTitanic had paying customers.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You or I must yield up his life to Ahrimanes.  I would rather it were you.<BR>\nI should have no hesitation in sacrificing my own life to spare yours, but<BR>\nwe take stock next week, and it would not be fair on the company.<BR>\n&nbsp;-- J. Wellington Wells');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','XXXVI:<BR>\n&nbsp;The thickness of the proposal required to win a multimillion dollar<BR>\n&nbsp;contract is about one millimeter per million dollars.  If all the<BR>\n&nbsp;proposals conforming to this standard were piled on top of each other<BR>\n&nbsp;at the bottom of the Grand Canyon it would probably be a good idea.<BR>\nXXXVII:<BR>\n&nbsp;Ninety percent of the time things will turn out worse than you expect.<BR>\n&nbsp;The other 10 percent of the time you had no right to expect so much.<BR>\nXXXVIII:<BR>\n&nbsp;The early bird gets the worm.<BR>\n&nbsp;The early worm ... gets eaten.<BR>\nXXXIX:<BR>\n&nbsp;Never promise to complete any project within six months of the end of<BR>\n&nbsp;the year -- in either direction.<BR>\nXL:<BR>\n&nbsp;Most projects start out slowly -- and then sort of taper off.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Time to take stock.  Go home with some office supplies.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You can fool all the people all of the time if the advertising is right<BR>\nand the budget is big enough.<BR>\n&nbsp;-- Joseph E. Levine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You can tell the ideals of a nation by its advertisements.<BR>\n&nbsp;-- Norman Douglas');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To get something done, a committee should consist of no more than three<BR>\npersons, two of them absent.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','You are always doing something marginal when the boss drops by your desk.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To get back on your feet, miss two car payments.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Time is the most valuable thing a man can spend.<BR>\n&nbsp;-- Theophrastus');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To see a need and wait to be asked, is to already refuse.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To stay youthful, stay useful.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','XXVI:<BR>\n&nbsp;If a sufficient number of management layers are superimposed on each<BR>\n&nbsp;other, it can be assured that disaster is not left to chance.<BR>\nXXVII:<BR>\n&nbsp;Rank does not intimidate hardware.  Neither does the lack of rank.<BR>\nXXVIII:<BR>\n&nbsp;It is better to be the reorganizer than the reorganizee.<BR>\nXXIX:<BR>\n&nbsp;Executives who do not produce successful results hold on to their<BR>\n&nbsp;jobs only about five years.  Those who produce effective results<BR>\n&nbsp;hang on about half a decade.<BR>\nXXX:<BR>\n&nbsp;By the time the people asking the questions are ready for the answers,<BR>\n&nbsp;the people doing the work have lost track of the questions.<BR>\n&nbsp;-- Norman Augustine');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To save a single life is better than to build a seven story pagoda.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','When all else fails, read the instructions.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','To restore a sense of reality, I think Walt Disney should have a Hardluckland.<BR>\n&nbsp;-- Jack Paar');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A company is known by the men it keeps.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A consultant is a person who borrows your watch, tells you what time it<BR>\nis, pockets the watch, and sends you a bill for it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A meeting is an event at which the minutes are kept and the hours are lost.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A committee is a life form with six or more legs and no brain.<BR>\n&nbsp;-- Lazarus Long, \"Time Enough For Love\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Our business in life is not to succeed but to continue to fail in high spirits.<BR>\n&nbsp;-- Robert Louis Stevenson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Only through hard work and perseverance can one truly suffer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Our policy is, when in doubt, do the right thing.<BR>\n&nbsp;-- Roy L. Ash, ex-president, Litton Industries');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Overdrawn?  But I still have checks left!');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A committee takes root and grows, it flowers, wilts and dies, scattering the<BR>\nseed from which other committees will bloom.<BR>\n&nbsp;-- Parkinson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Owe no man any thing...<BR>\n&nbsp;-- Romans 13:8');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Promise her anything, but give her Exxon unleaded.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Porsche: there simply is no substitute.<BR>\n&nbsp;-- Risky Business');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Put your Nose to the Grindstone!<BR>\n&nbsp;-- Amalgamated Plastic Surgeons and Toolmakers, Ltd.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','So... did you ever wonder, do garbagemen take showers before they go to work?');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Regardless of whether a mission expands or contracts, administrative<BR>\noverhead continues to grow at a steady rate.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Someday your prints will come.<BR>\n&nbsp;-- Kodak');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Real wealth can only increase.<BR>\n&nbsp;-- R. Buckminster Fuller');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A commune is where people join together to share their lack of wealth.<BR>\n&nbsp;-- R. Stallman');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','It is imperative when flying coach that you restrain any tendency toward<BR>\nthe vividly imaginative.  For although it may momentarily appear to be the<BR>\ncase, it is not at all likely that the cabin is entirely inhabited by<BR>\ncrying babies smoking inexpensive domestic cigars.<BR>\n&nbsp;-- Fran Lebowitz, \"Social Studies\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Some people pray for more than they are willing to work for.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Take everything in stride.  Trample anyone who gets in your way.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Term, holidays, term, holidays, till we leave school, and then work, work,<BR>\nwork till we die.<BR>\n&nbsp;-- C.S. Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Take care of the luxuries and the necessities will take care of themselves.<BR>\n&nbsp;-- Lazarus Long');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','&nbsp;Take the folks at Coca-Cola.  For many years, they were content<BR>\nto sit back and make the same old carbonated beverage.  It was a good<BR>\nbeverage, no question about it; generations of people had grown up<BR>\ndrinking it and doing the experiment in sixth grade where you put a<BR>\nnail into a glass of Coke and after a couple of days the nail dissolves<BR>\nand the teacher says: \"Imagine what it does to your TEETH!\"  So Coca-Cola<BR>\nwas solidly entrenched in the market, and the management saw no need to<BR>\nimprove ...<BR>\n&nbsp;-- Dave Barry, \"In Search of Excellence\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The closest to perfection a person ever comes is when he fills out a job<BR>\napplication form.<BR>\n&nbsp;-- Stanley J. Randall');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The brain is a wonderful organ; it starts working the moment you get up<BR>\nin the morning, and does not stop until you get to work.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The faster I go, the behinder I get.<BR>\n&nbsp;-- Lewis Carroll');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The confusion of a staff member is measured by the length of his memos.<BR>\n&nbsp;-- New York Times, Jan. 20, 1981');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The difficult we do today; the impossible takes a little longer.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Surprise your boss.  Get to work on time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The first 90% of a project takes 90% of the time, the last 10% takes the<BR>\nother 90% of the time.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The finest eloquence is that which gets things done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The longer the title, the less important the job.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The major difference between bonds and bond traders is that the bonds will<BR>\neventually mature.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The means-and-ends moralists, or non-doers, always end up on their ends<BR>\nwithout any means.<BR>\n&nbsp;-- Saul Alinsky');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A holding company is a thing where you hand an accomplice the goods while<BR>\nthe policeman searches you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','About the time we think we can make ends meet, somebody moves the ends.<BR>\n&nbsp;-- Herbert Hoover');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','According to all the latest reports, there was no truth in any of the<BR>\nearlier reports.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Live within your income, even if you have to borrow to do so.<BR>\n&nbsp;-- Josh Billings');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A man is known by the company he organizes.<BR>\n&nbsp;-- Ambrose Bierce');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Lots of folks confuse bad management with destiny.<BR>\n&nbsp;-- Frank Hubbard');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Advertising is a valuable economic factor because it is the cheapest<BR>\nway of selling goods, particularly if the goods are worthless.<BR>\n&nbsp;-- Sinclair Lewis');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Advertising is the rattling of a stick inside a swill bucket.<BR>\n&nbsp;-- George Orwell');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A new supply of round tuits has arrived and are available from Mary.<BR>\nAnyone who has been putting off work until they got a round tuit now<BR>\nhas no excuse for further procrastination.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A rock store eventually closed down; they were taking too much for granite.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A mouse is an elephant built by the Japanese.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Make headway at work.  Continue to let things deteriorate at home.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A good supervisor can step on your toes without messing up your shine.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A motion to adjourn is always in order.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A memorandum is written not to inform the reader, but to protect the writer.<BR>\n&nbsp;-- Dean Acheson');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money is its own reward.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Love may laugh at locksmiths, but he has a profound respect for money bags.<BR>\n&nbsp;-- Sidney Paternoster, \"The Folly of the Wise\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A freelance is one who gets paid by the word -- per piece or perhaps.<BR>\n&nbsp;-- Robert Benchley');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Money is the root of all wealth.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Man is an animal that makes bargains: no other animal does this--<BR>\nno dog exchanges bones with another.<BR>\n&nbsp;-- Adam Smith');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Them as has, gets.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A continuing flow of paper is sufficient to continue the flow of paper.<BR>\n&nbsp;-- Dyer');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','A cow is a completely automated milk-manufacturing machine. It is encased<BR>\nin untanned leather and mounted on four vertical, movable supports, one at<BR>\neach corner.  The front end of the machine, or input, contains the cutting<BR>\nand grinding mechanism, utilizing a unique feedback device.  Here also are<BR>\nthe headlights, air inlet and exhaust, a bumper and a foghorn.<BR>\n&nbsp;At the rear, the machine carries the milk-dispensing equipment as<BR>\nwell as a built-in flyswatter and insect repeller.  The central portion<BR>\nhouses a hydro- chemical-conversion unit.  Briefly, this consists of four<BR>\nfermentation and storage tanks connected in series by an intricate network<BR>\nof flexible plumbing.  This assembly also contains the central heating plant<BR>\ncomplete with automatic temperature controls, pumping station and main<BR>\nventilating system.  The waste disposal apparatus is located to the rear of<BR>\nthis central section.<BR>\n&nbsp;Cows are available fully-assembled in an assortment of sizes and<BR>\ncolors.  Production output ranges from 2 to 20 tons of milk per year.  In<BR>\nbrief, the main external visible features of the cow are:  two lookers, two<BR>\nhookers, four stander-uppers, four hanger-downers, and a swishy-wishy.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','All the big corporations depreciate their possessions, and you can, too,<BR>\nprovided you use them for business purposes.  For example, if you subscribe<BR>\nto the Wall Street Journal, a business-related newspaper, you can deduct the<BR>\ncost of your house, because, in the words of U.S. Supreme Court Chief<BR>\nJustice Warren Burger in a landmark 1979 tax decision: \"Where else are you<BR>\ngoing to read the paper?  Outside?  What if it rains?\"<BR>\n&nbsp;-- Dave Barry, \"Sweating Out Taxes\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The Bible on letters of reference:<BR>\n&nbsp;Are we beginning all over again to produce our credentials?  Do<BR>\nwe, like some people, need letters of introduction to you, or from you?<BR>\nNo, you are all the letter we need, a letter written on your heart; any<BR>\nman can see it for what it is and read it for himself.<BR>\n&nbsp;-- 2 Corinthians 3:1-2, New English translation');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Advertising may be described as the science of arresting the human<BR>\nintelligence long enough to get money from it.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','After all is said and done, a hell of a lot more is said than done.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','After any salary raise, you will have less money at the end of the<BR>\nmonth than you did before.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','Lend money to a bad debtor and he will hate you.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The [Ford Foundation] is a large body of money completely surrounded by<BR>\npeople who want some.<BR>\n&nbsp;-- Dwight MacDonald');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('work','The best things in life go on sale sooner or later.');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: You know, I always wanted a peg-leg. It was a boyhood<BR>\n&nbsp;thing I never grew out of.<BR>\n&nbsp;\"The X-Files: Quagmire\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: (to Scully) I think you drooled on me.<BR>\n&nbsp;\"The X-Files: Pusher\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Scully, should we be picking out china patterns, or what?<BR>\n&nbsp;\"The X-Files: Small Potatoes\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Her name is Bambi??<BR>\nMulder: Yeah.  Both her parents were naturalists.  Her theory<BR>\n&nbsp;is that UFOs are really nocturnal insect swarms passing<BR>\n&nbsp;through electrical airfields.\"<BR>\nScully: Her name is Bambi??<BR>\n&nbsp;\"The X-Files: War of the Coprophages\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: how big can this thing get?<BR>\nScully: Mulder, I.. (smiles) sorry, for a second there it felt<BR>\n&nbsp;like old times.<BR>\n&nbsp;\"The X-Files: The Host\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: You can get the next mutant.<BR>\n&nbsp;\"The X-Files: Tooms\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: (smiling) The ENIGMATIC Dr. Scully!<BR>\n&nbsp;\"The X-Files: Fallen Angel\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: I have a date.<BR>\nMulder: Can you cancel?<BR>\nScully: Unlike you, Mulder, I would like to have a life.<BR>\nMulder: I have a life!<BR>\n&nbsp;\"The X-Files: The Jersey Devil\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Mulder, did you see their eyes? If I were that stoned...<BR>\nMulder: Oooh! If you were that stoned, what?<BR>\n&nbsp;\"The X-Files: Deep Throat\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: What makes you think they care about us anymore, anyway?<BR>\nMulder: So why have you bothered to come here covertly?<BR>\nScully: Because I realized that it was the only way that you<BR>\n&nbsp;would see me.<BR>\n&nbsp;\"The X-Files: Little Green Men\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Sheriff: (patronisingly) They can detect every flash of<BR>\n&nbsp;lightning on this planet. Did you know that?  See, each<BR>\n&nbsp;one emits radio waves at the same exact frequency...<BR>\nMulder: ... of human resonance. Eight cycles per second. You<BR>\n&nbsp;can pick it up on any transistor radio.  See that<BR>\n&nbsp;Sheriff? I did my homework.<BR>\n&nbsp;\"The X-Files: D.P.O\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: How was the wedding?<BR>\nScully: You mean the part where the groom passed out or the dog<BR>\n&nbsp;bit the drummer?<BR>\nMulder: Did you catch the bouquet?<BR>\nScully: Maybe.<BR>\n&nbsp;\"The X-Files: Roland\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Well, I may not have the X-Files, Scully, but I still have my work, and I still have you...<BR>\n&nbsp;\"The X-Files: Little Green Men\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: (to counsellor) I trust him (Mulder) as much as anyone.<BR>\n&nbsp;I trust him with my life.<BR>\n&nbsp;\"The X-Files: Irresistible\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Lots of files.<BR>\nScully: Lots and lots of files!<BR>\n&nbsp;\"The X-Files: Anasazi\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Cancerman: Nothing vanishes without a trace... Burn it!<BR>\n&nbsp;\"The X-Files: Anasazi\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: One down, 1999 silos to go.<BR>\n&nbsp;\"The X-Files: Aprocrypha\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Is anybody NOT looking for Krycek?<BR>\n&nbsp;\"The X-Files: Aprocrypha\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: (to Scully) How come you never run my bath?<BR>\n&nbsp;\"The X-Files: Revelations\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Well, reincarnation has always been a popular theory<BR>\n&nbsp;on death row, for obvious reasons!<BR>\n&nbsp;\"The X-Files: The List\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: (on human psychopaths) The idea of such a human monster<BR>\n&nbsp;is as frightening as any X-File.<BR>\n&nbsp;\"The X-Files: Irresistible\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Hey Scully, can you spare a prophylactic?<BR>\n&nbsp;\"The X-Files: Soft Light\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: We were just exhuming,....your potato.<BR>\n&nbsp;\"The X-Files: Humbug\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: See, this is a helium balloon here, and the one thing I<BR>\n&nbsp;DID learn in kindergarten is, when you let them go they<BR>\n&nbsp;float up up and away, but you see this is moving AWAY<BR>\n&nbsp;from him ... horizontally.<BR>\nScully: Did you learn about WIND in kindergarten?<BR>\n&nbsp;\"The X-Files: The Calusari\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: I think with a crowbar and a small nuclear device we<BR>\n&nbsp;might be able to get through one of these things.<BR>\n&nbsp;\"The X-Files: Paper Clip\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: (asks Scully on a date.. well!) Vikins vs. Redskins.<BR>\n&nbsp;Two tickets on the 40-yard line at the Metrodome.<BR>\n&nbsp;You and me.<BR>\n&nbsp;\"The X-Files: Irresistible\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: I brought you something.. \"Superstars of the Superbowls\"<BR>\nScully: I knew there was a reason to live.<BR>\nMulder: Well, I know you want to get some rest; I just came by<BR>\n&nbsp;to see how you?re doin? and to say hi. (Turns to go)<BR>\nScully: Mulder - (he turns back) I had the strength of your<BR>\n&nbsp;beliefs.<BR>\n&nbsp;\"The X-Files: One Breath\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Cancerman: What is this?<BR>\nSkinner: This is where you pucker up and kiss my ass.<BR>\n&nbsp;\"The X-Files: Paper Clip\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: I know what I saw, Scully. and I saw you about to do<BR>\n&nbsp;the wild thing with some stranger!<BR>\n&nbsp;\"The X-Files: Genderbender\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: We eat fish and fish eat us.<BR>\nMulder: Are fish also known for eating half and saving half for<BR>\n&nbsp;later?<BR>\n&nbsp;\"The X-Files: Quagmire\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','(over phone to M & S) Modell: Are you two just going to sit<BR>\nthere all night? ... You and your pretty partner seem awfully<BR>\nclose. Do you work well together?<BR>\n&nbsp;\"The X-Files: Pusher\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Go ahead.<BR>\nScully: No, you go ahead.<BR>\nMulder: No, no. Be my guest. I know how much you like snapping<BR>\n&nbsp;on the latex.<BR>\n&nbsp;(Scully snaps on rubber gloves)<BR>\nMulder: This may not be any time to mention it, but somebody<BR>\n&nbsp;is wearing my favourite perfume.<BR>\n&nbsp;\"The X-Files: Syzygy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','(over phone) Scully: Did he give you any idea of how to catch<BR>\n&nbsp;them?<BR>\nMulder: No, but she did tell me everything else there is to<BR>\n&nbsp;know about insects.<BR>\nScully: SHE?<BR>\n&nbsp;\"The X-Files: War of the Coprophages\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','(over phone) Scully: ... the very idea of intelligent alien<BR>\n&nbsp;life is not only astronomically improbable, but at its<BR>\n&nbsp;most basic level, downright anti-Darwinian.<BR>\nMulder: Scully, what are you wearing?<BR>\n&nbsp;\"The X-Files: War of the Coprophages\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder & Scully: Sure. Fine. Whatever.<BR>\n&nbsp;\"The X-Files: Syzygy\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Well done, Agent Pendrel.  Keep up the good work!<BR>\nPendrel: Thanks, keep it up yourself! (then, to himself) Keep<BR>\n&nbsp;it up yourself?? What a doof!<BR>\n&nbsp;\"The X-Files: 731\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Scully... I never saw you as a mother before.<BR>\n&nbsp;\"The X-Files: Home\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Why is it so hard to believe?  When the accepted<BR>\n&nbsp;discovery of life off this planet is on the front page<BR>\n&nbsp;of every newspaper around the world?  When even the<BR>\n&nbsp;most conservative scientists and science journals are<BR>\n&nbsp;calling for the exploration of Mars and Jupiter, with<BR>\n&nbsp;every reason to believe that life and the persistence<BR>\n&nbsp;of it is thriving outside our own terrestrial sphere.<BR>\n&nbsp;If you cannot get past this, then I suggest that this<BR>\n&nbsp;whole committee be held in contempt for ignoring<BR>\n&nbsp;evidence that cannot be refuted.<BR>\n&nbsp;\"The X-Files: Terma\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Yeah, but why stab her boyfriend through the ear? The<BR>\n&nbsp;magic was gone??!<BR>\n&nbsp;\"The X-Files: Unruhe\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: He said that the men behind this hoax, behind these<BR>\n&nbsp;lies, gave me this disease to make you believe.<BR>\n&nbsp;\"The X-Files: Gethsemane\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Not everything is about you Mulder.<BR>\n&nbsp;\"The X-Files: Never Again\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: Eeenee meeeneee chili beanie, the spirits are about to<BR>\n&nbsp;speak..<BR>\n&nbsp;\"The X-Files: The X-Files: Never Again\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Mulder: The truth will save you Scully... I think it will save<BR>\n&nbsp;both of us.<BR>\n&nbsp;\"The X-Files: Terma\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Label that.<BR>\nCop: As what?<BR>\nScully: Partial rat body part.<BR>\n&nbsp;\"The X-Files: Teso Dos Bichos\"');
INSERT INTO ethereal.Fortune (FortuneType,FortuneMsg) VALUES('xfiles','Scully: Do you know how much the human body is worth, Mulder?<BR>\nMulder: Depends on the body!<BR>\n&nbsp;\"The X-Files: Hell Money\"');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('3D Art','image','Digital Art','This section is entirely dedicated to 3-Dimensional Digital Art, therefore submissions here utilize the cartesian coordinates (X,Y,Z) on a 2-Dimensional digital canvas. ');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Drawings','image','Digital Art','Digital Art done via the use of computer-aided drawing tools or the digital techniques are similar to those found in traditional drawings.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Fractal Art','image','Digital Art','Place images created with fractal generating software here. Fractal artwork consists of images created using complex mathematical equations compiled in programs such as Ultra Fractal, Apophysis, Fractal Explorer, and Chaoscope.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','image','Digital Art','Anything unfit for categories, or if you are unsure where your works belongs - goes here. ');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Oekaki','image','Digital Art','For lower resolution artwork created using one of the various oekaki programs, such as Oekaki BBS, Paint BBS, MS Paint, Shi Painter, Lascaux Sketch, or PaintChat.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Paintings','image','Digital Art','Digital Art submitted in Paintings & Airbrushing are created via the use of digital tools that mimick those used in traditional ways of painting and airbrushing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Pixel Art','image','Digital Art','A form a digital art created entirely from a pixel by pixel basis from the ground up using the most simplest of tools (most commonly the pencil tool and the like). Every pixel is placed in a specific place with a purpose of enhancing the image.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Text Art','image','Digital Art','Art created with the use of fixed-width fonts or special screen output drivers on the computer, and when if used in the right combinations can resemble a person, place, or thing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Vector Art','image','Digital Art','Vector art consists of creating paths and points in a program such as Illustrator, Freehand, Corel Draw, and Flash. These programs keep track of the relationships between these points and paths. Every time the image is scaled.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Art Photography','image','Photography','Though this division may seem redundant it\'s not. There are several different motivations in taking a photograph. Commercial and Photojournalism (also listed here) are a couple of examples.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Commercial Photography','image','Photography','Photography intended to make money for the photographer. There are industries in the business world where photographers hold in their hands the key to success - advertising and fashion are two prime examples.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','image','Photography','Anything unfit for categories, or if you are unsure where your works belongs - goes here. ');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Photojournalism','image','Photography','Photography intended to describe or document in pictures the events of individuals, groups of people, governments, history, and so on. Photojournalism gives us newsworthy photographs wherein the primary motivation is to recount a story.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Snapshots','image','Photography','Snapshots are photographs that aren\'t taken with any of the other motivations listed here. They\'re not artsy, nor are they commercial, nor are they journalistic. It\'s just a photo. Maybe it\'s a picture of your dog.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Digital Art','image','<root>','Digital Art, unlike traditional, means artwork originally created via the use of digital tools that mimic traditional utensils such as computer imaging/3D software, digital pen & tablet, computer mouse, or any similar tools.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Photography','image','<root>','Pictures taken with a film or a digital camera featuring a very minimal level of digital manipulation. Photographs that feature a significant amount of digital manipulation should be filed under Digital Art: Photomanipulation.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Screenshots','image','<root>','This gallery is for desktop and other miscellaneous computer screenshots.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Traditional Art','image','<root>','This gallery is for work that has been produced using the traditional (or non-digital) mediums.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('BeOS','image','Screenshots','BeOS desktop screenshots.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','image','Screenshots','General screenshots not fitting an outlined OS.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Handhelds','image','Screenshots','Screenshots of handheld devices (i.e. Palm, Handspring, Pocket PC).');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('MacOS','image','Screenshots','Mac OS (either OS X and Classic) desktop screenshots.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Unix and Linux','image','Screenshots','UNIX (i.e. AIX, HP-UX, IRIX) and Linux desktop screenshots.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Windows','image','Screenshots','Windows desktop screenshots.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Drawings','image','Traditional Art','Images created using traditional drawing methods such as graphite, charcoal, pastels, pen and ink, conte crayon and so on.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','image','Traditional Art','All other imagery and art created without a computer not inclusive to any of the other sub-categories of the Traditional Art gallery.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Graffiti','image','Traditional Art','A drawing or inscription made on a wall or other surface, usually so as to be seen by the public. Graffiti style lettering and traditional airbrushing mimicking wall graffiti may also be included in this area as long as it is not computer generated.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Mixed Media','image','Traditional Art','Mixed Media refers to art created by using multiple traditional techniques in a combined manner.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Paintings','image','Traditional Art','Images created using traditional painting methods such as water color, acrylic paint, oil paint, egg tempra and other painting mediums. Must not be created by computer; there are categories in the Digital Art gallery that are more appropriate for ...');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Printing','image','Traditional Art','Art created by traditional printing presses using various matrixes and processes such as; the intaglio process, lithography, serigraphy, and relief. Does not include digital printmaking.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Sculpture','image','Traditional Art','Sculpture is a three-dimensional art form that provides an important visual way of understanding form and space. What will always remain the concern of the sculptor is the manipulation of a solid, material body, whether stone, wood, clay or bronze...');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Anime','realm','<root>','Anime is a style of animation originating in Japan that is characterized by stark colorful graphics depicting vibrant characters in action-filled plots often with fantastic, or futuristic themes, but may encompass modern themes as well.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Fantasy','realm','<root>','Realms that hold all the surreal worlds of fantastic places.  From elves to trolls, all within this category are quite full of magic, mystery, and other worldly places.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Games','realm','<root>','Realms based on video games such as the Final Fantasy series.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','realm','<root>','Realms that may fit several categories, or no categories.  Or rooms that may allow for several categories within one setting.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Historical','realm','<root>','Realms created to invoke a memory of former times and places. Family crests, Coat of Arms, or even an everyday people are portrayed from a point in time that has long since passed.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Horror','realm','<root>','Tales of fright, poems of terror, or merely accounts of some dastardly deed.  This gallery contains all the works considered horrific and scary.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Modern','realm','<root>','Contemporary, present, or any other text that is written to take place in the hear and now.  Events, people, objects all described are found easily enough in this modern gallery.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Political','realm','<root>','Political based realms bringing in such themes portrayed in the \'West Wing\', \'Spin City\' and other politically oriented shows.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Science Fiction','realm','<root>','Any text containing stories of futuristic, fantastic settings.   From post-apocalyptic to entirely new galaxies, all the stories within this gallery are considered to be science fiction.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Children\'s','text','Poetry','Children\'s poetry is dedicated to the type of writings that we would read to children. This section is not suited for social commentary on children in a negative or positive light.Consider other sections such as socio-political or family life...');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Erotic','text','Poetry','Erotic poetry concentrates on romantic or sexual arousal. While sexual in nature it is not necessarily pornographic. The focus of erotic writing is not simply sex, but is inclusive of the passion, personalities, and romantic traits surrounding.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Experimental','text','Poetry','Experimental work concentrates on developing new literary techniques to express a concept. This section of poetry is small as people actively concentrating on this work are relatively individual actions and not many broad categories have been form...');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Family Life','text','Poetry','Family life writings deal with the whole arena of issues surrounding a family, your family, any family. A writing observing a mother in her role, or a reflection on childhood, are good examples of what belongs here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','text','Poetry','Anything unfit for categories, or if you are unsure where your writing belongs - goes here. Please consider this category as the last stop.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Horror','text','Poetry','This brand of writing has a less cheery disposition. It the gruesome arena around death and agony. It creates and involves unpleasant emotions but is not necessarily angst or wrist slasher writing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Humor','text','Poetry','Other\'s may not find your poetry funny - but so long as it was intended to be funny at least to you, it belongs here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Journal','text','Poetry','As traditional artists have doodles in their notebooks, writers have lines or pages of poetry \"doodles.\" Writing passing thoughts that were never finished, pages of writing that fall under \"just because.\"');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Narrative','text','Poetry','Poetry following plots similar to what you\'d expect from prose, are narrative (or story) poems. Many classical epics can be called narratives. So if your poem has a proceeding plot with characters and other such elements - it belongs here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Nature','text','Poetry','Nature poetry covers the range of experiences and subjects in undeveloped or wild terrain.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Philosophical','text','Poetry','Voltaire, Socrates, Wollstonecraft, are all examples of philosophical writers or have inspired philosophical writings. Philosophical commentary, new basement philosophies, narratives that express some philosophical standpoint belong here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Romatic','text','Poetry','Romantic poetry deals with the broad range of experiences and emotions one goes through when in pursuit of love. It is entirely possible to be romantic about ice cream, cookies, other inventive brands of romance.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Satire','text','Poetry','Social commentary employing the attack methods of sarcasm, irony or wit. If it is lacking the element of commentary, then it belongs in humor.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Sociopolitical','text','Poetry','Political or social poetry that addresses a certain perspective or demonstrates a certain aspect of society belongs in this section. Poetry may achieve this through narratives, general responses to events, or through general observations.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Spiritual','text','Poetry','Spiritual poems focus on religious or spiritual aspects in life. This section invites all perspectives and all ways of thought.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Transgressive','text','Poetry','Transgressive literature pushes the boundries of what society considers socially acceptable. It\'s violent, can involve sexual deviancy or drugs -- basically it\'s down right nasty.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Urban','text','Poetry','Urban culture has provided it\'s own unique flavor to writing. Hip-hop, freestyle, concrete jungle stories, have popped from the alleys and made a strong stand in poetry.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Children\'s','text','Prose','Children\'s poetry is dedicated to the type of writings that we would read to children. This section is not suited for social commentary on children in a negative or positive light.Consider other sections such as socio-political or family life...');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Erotic','text','Prose','Erotic poetry concentrates on romantic or sexual arousal. While sexual in nature it is not necessarily pornographic. The focus of erotic writing is not simply sex, but is inclusive of the passion, personalities, and romantic traits surrounding.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Fan-Fiction','text','Prose','Fan fiction is prose based off a plotline of some movie or another plot based medium. It can be an extension, rewriting of an ending, or a side story.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Fantasy','text','Prose','Fantasy writing commonly follows the trend of magic or some sort of \"fantastical\" existence in many given settings. This may include crossovers with situations similar to science-fiction (magic in futuristic settings).');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('General','text','Prose','Anything unfit for categories, or if you are unsure where your writing belongs - goes here. Please consider this category as the last stop.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Historical','text','Prose','Fiction in a historical setting, in which the main character, and often many others, are invented, while the setting and other details are based on careful research.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Horror','text','Prose','This brand of writing has a less cheery disposition. It the gruesome arena around death and agony. It creates and involves unpleasant emotions but is not necessarily angst or wrist slasher writing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Humor','text','Prose','Other\'s may not find your poetry funny - but so long as it was intended to be funny at least to you, it belongs here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Life Stories','text','Prose','Life stories are fictional biographies that progress through a person\'s experiences. David Copperfield provides one example for this brand of writing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Mystery','text','Prose','Mystery prose relies on suspense and unknown, my dear Watson. Pulp detective novels are a popular example for this writing.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Occult','text','Prose','The occult spans everything from witches and runes to UFOs and ESP. Writings that bear the characteristic quality of Cthulu belong here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Perspectives','text','Prose','Perspective prose can be general fiction or semi-fictional accounts of personal events told as a story. This is not a journal. The writings submitted should give enriched insights into a person\'s experiences in life.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Philosophical','text','Prose','Voltaire, Socrates, Wollstonecraft, are all examples of philosophical writers or have inspired philosophical writings. Philosophical commentary, new basement philosophies, narratives that express some philosophical standpoint belong here.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Romantic','text','Prose','Romantic poetry deals with the broad range of experiences and emotions one goes through when in pursuit of love. It is entirely possible to be romantic about ice cream, cookies, other inventive brands of romance.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Satire','text','Prose','Social commentary employing the attack methods of sarcasm, irony or wit. If it is lacking the element of commentary, then it belongs in humor.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Science Fiction','text','Prose','Takes a glimpse into scientific theory and projects this theory into storylines. Original science-fiction is often written with a strong knowledge of general sciences and often had logical approach for the technology in the story.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Sociopolitical','text','Prose','Political or social poetry that addresses a certain perspective or demonstrates a certain aspect of society belongs in this section. Poetry may achieve this through narratives, general responses to events, or through general observations.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Spiritual','text','Prose','Spiritual poems focus on religious or spiritual aspects in life. This section invites all perspectives and all ways of thought.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Theatre and Scripts','text','Prose','Scripts are the writing necessary to create a stage, television, movie, radio production.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Transgressive','text','Prose','Transgressive literature pushes the boundries of what society considers socially acceptable. It\'s violent, can involve sexual deviancy or drugs -- basically it\'s down right nasty.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Poetry','text','<root>','There are so many types and styles of poetry, that it is impossible to put it in one single description. To start, we\'ll say what poetry isn\'t. Poetry is not text you would find in a new article, novel, or technical document.');
INSERT INTO ethereal.Genre (GenreName,GenreType,GenreSub,GenreDescription) VALUES('Prose','text','<root>','Prose is written material found in: Novels, Magazine articles, Newspapers, Short stories and so on... ');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Admin Mask One','admin','/gummies/adm_mask1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Admin Mask Two','admin','/gummies/adm_mask2.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Admin Red Eye','admin','/gummies/redeye.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Canon Dragon','canon','/gummies/c1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Canon Gun','canon','/gummies/c3.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Canon Sun','canon','/gummies/c4.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Canon Target','canon','/gummies/c2.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. AlienStarburst','contributor','/gummies/d34.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. American Star','contributor','/gummies/d37.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Angel','contributor','/gummies/d27.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Autumn Leaf','contributor','http://www.ethereal-realms.org/gummies/d45.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Bear Paw','contributor','/gummies/d36.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Bishop','contributor','/gummies/d7.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Blue Rose','contributor','http://www.ethereal-realms.org/gummies/d49.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Blue Snowflake','contributor','http://www.ethereal-realms.org/gummies/d41.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Butterfly','contributor','/gummies/d8.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Cauldron','contributor','/gummies/d29.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Clover','contributor','/gummies/d38.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Crescent','contributor','/gummies/d30.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Crow','contributor','/gummies/d1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Design','contributor','/gummies/d9.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Earth','contributor','http://www.ethereal-realms.org/gummies/d46.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Egyptian','contributor','/gummies/d10.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Eight Ball','contributor','/gummies/d35.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Elephant','contributor','/gummies/d11.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Eye','contributor','/gummies/d2.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Flower','contributor','/gummies/d12.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Ghost','contributor','/gummies/d13.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Goblet','contributor','/gummies/d31.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. King','contributor','/gummies/d14.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Kiss','contributor','/gummies/d28.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Knife','contributor','/gummies/d32.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Knight','contributor','/gummies/d15.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Light Bulb','contributor','/gummies/d3.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Lucky','contributor','/gummies/d16.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Man','contributor','/gummies/d17.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Mask','contributor','/gummies/d4.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Moon','contributor','http://www.ethereal-realms.org/gummies/d48.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Music','contributor','/gummies/d18.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Pentacle','contributor','/gummies/d33.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Pumpkin','contributor','/gummies/d19.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Queen','contributor','/gummies/d20.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Rainbow','contributor','http://www.ethereal-realms.org/gummies/d44.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Rook','contributor','/gummies/d21.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Royal','contributor','/gummies/d22.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Silver Moon','contributor','http://www.ethereal-realms.org/gummies/d43.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Spade','contributor','/gummies/d23.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Spider','contributor','/gummies/d24.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Star','contributor','/gummies/d5.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Sun','contributor','http://www.ethereal-realms.org/gummies/d47.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Sun Moon','contributor','http://www.ethereal-realms.org/gummies/d42.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Swirl','contributor','/gummies/d6.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Theater','contributor','/gummies/d25.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Warning','contributor','/gummies/d26.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Yellow Flower','contributor','http://www.ethereal-realms.org/gummies/d39.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spec. Yellow Rose','contributor','http://www.ethereal-realms.org/gummies/d40.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Default','default','/gummies/1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Alien','general','/gummies/37.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Asian Mask','general','/gummies/52.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bat','general','/gummies/3.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bell','general','/gummies/81.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Biohazard','general','/gummies/39.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bomb','general','/gummies/80.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Boxes','general','/gummies/53.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bull','general','/gummies/5.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Butterfly','general','/gummies/4.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Carousel Horse','general','/gummies/79.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Celtic Cross','general','/gummies/82.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Cheese','general','/gummies/77.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Cobra','general','/gummies/40.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Crop circle','general','/gummies/41.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Crown','general','/gummies/17.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Diamond','general','/gummies/54.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Dog Tags','general','/gummies/76.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Dove','general','/gummies/2.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Down Under','general','/gummies/ag-02.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Dragon','general','/gummies/42.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Dragonfly','general','/gummies/43.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Eclipse','general','/gummies/83.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Evil Face','general','/gummies/44.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Eye of Horus','general','/gummies/45.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Face Hugger','general','/gummies/74.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Fan','general','/gummies/46.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Female','general','/gummies/55.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Flower','general','/gummies/29.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Frown','general','/gummies/26.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Gecko','general','/gummies/47.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Ghost','general','/gummies/19.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Glasses','general','/gummies/23.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Guitar','general','/gummies/72.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Gun','general','/gummies/18.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Harp','general','/gummies/35.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Heart','general','/gummies/22.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Heartagram','general','/gummies/90.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Horseshoe','general','/gummies/21.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Hourglass','general','/gummies/16.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Jolly Roger','general','/gummies/73.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Knife','general','/gummies/12.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Lamp','general','/gummies/14.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Light','general','/gummies/75.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Lightning','general','http://www.ethereal-realms.org/gummies/51.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Male','general','/gummies/56.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Maple Leaf','general','/gummies/34.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Mouse','general','/gummies/57.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Music','general','/gummies/71.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Non-Smoking','general','/gummies/84.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Paw','general','/gummies/10.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Pentacle','general','/gummies/70.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Rabbit','general','/gummies/9.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Radioactive','general','/gummies/49.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Scorpion','general','/gummies/50.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Seahorse','general','/gummies/8.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Shield','general','/gummies/33.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Skull','general','/gummies/15.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Skull and Crossbones','general','/gummies/27.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Smiley','general','/gummies/24.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Snow Flake','general','/gummies/30.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sphere','general','/gummies/68.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spider','general','/gummies/7.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spider II','general','/gummies/85.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Spider Web','general','/gummies/87.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Stake','general','/gummies/36.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Star of David','general','http://www.ethereal-realms.org/gummies/91.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Story Teller','general','http://www.ethereal-realms.org/gummies/92.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sun','general','/gummies/32.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Target','general','/gummies/11.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Tommy Gun','general','/gummies/94.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Trophy','general','/gummies/86.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Tulip','general','/gummies/78.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Umbrella','general','/gummies/13.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Unicorn','general','/gummies/6.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Urban','general','http://www.ethereal-realms.org/gummies/93.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Water Drop','general','/gummies/31.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Wheel','general','/gummies/88.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Woven','general','/gummies/69.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('X Marks the Spot','general','/gummies/89.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Yin Yang','general','/gummies/28.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('All alone...','inject','/inject/lonely.gif',NULL,'LONELY');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Angry','inject','/inject/angry.gif',NULL,'ANGRY');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bad boy','inject','/inject/spank.gif',NULL,'SPANK');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bow','inject','/inject/bow.gif',NULL,'BOW');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Bug Eyed','inject','/inject/bugeyed.gif',NULL,'BUGEYED');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Cool shades','inject','/inject/shades.gif',NULL,'SHADES');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Cuddle','inject','/inject/cuddle.gif',NULL,'CUDDLE');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Dazed and confused','inject','/inject/dizzy.gif',NULL,'DIZZY');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Demonic posession','inject','/inject/angeldevil.gif',NULL,'DEVIL');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Domo Arigato','inject','/inject/domokun.gif',NULL,'DOMO');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Eureka!','inject','/inject/idea.gif',NULL,'IDEA');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Evil laugh','inject','/inject/eval.gif',NULL,'LAUGH');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Explosive persona','inject','/inject/explosion.gif',NULL,'EXPLOSION');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('For shame!','inject','/inject/tsk.gif',NULL,'TSK');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('High Five','inject','/inject/high5.gif',NULL,'HIGHFIVE');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Hugs','inject','/inject/hugs.gif',NULL,'HUGS');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Huh?','inject','/inject/huh.gif',NULL,'HUH');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Knock out','inject','/inject/xx.gif',NULL,'XX');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Love','inject','/inject/heart.gif',NULL,'HEART');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Love you!','inject','/inject/luv.gif',NULL,'LUV');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Meh!','inject','/inject/unimpressed.gif',NULL,'MEH');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('No sh*t Sherlock!','inject','/inject/sherlock.gif',NULL,'SHERLOCK');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sad','inject','/inject/sad.gif',NULL,'SAD');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Shifty eyed','inject','/inject/shifty.gif',NULL,'SHIFTY');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Shootout','inject','/inject/bambam.gif',NULL,'BAMBAM');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sick!','inject','/inject/sick.gif',NULL,'SICK');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Silly smirk','inject','/inject/xd.gif',NULL,'XD');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Slave and Master','inject','/inject/slave.gif',NULL,'SLAVE');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Smile','inject','/inject/smile.gif',NULL,'SMILE');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Smooch','inject','/inject/smooch.gif',NULL,'SMOOCH');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sticks tongue out','inject','/inject/sot.gif',NULL,'STO');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Stuff you!','inject','/inject/stfu.gif',NULL,'STFU');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Stupid','inject','/inject/stupid.gif',NULL,'STUPID');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sweat drop','inject','/inject/sweat.gif',NULL,'SWEAT');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sweepy','inject','/inject/sleepy.gif',NULL,'SLEEP');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Tight lipped','inject','/inject/shutmouth.gif',NULL,'QUIET');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Weird','inject','/inject/weird.gif',NULL,'WEIRD');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Worships you','inject','/inject/worship.gif',NULL,'WORSHIP');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Zen','inject','/inject/meditate.gif',NULL,'ZEN');
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Mod Mask One','mod','/gummies/mod_mask1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Mod Mask Two','mod','/gummies/mod_mask2.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sup Mask One','super','/gummies/sup_mask1.gif',NULL,NULL);
INSERT INTO ethereal.Gummy (GummyName,GummyClass,GummyPath,GummyIdent,GummyMacro) VALUES('Sup Mask Two','super','/gummies/sup_mask2.gif',NULL,NULL);
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Metal','1880-02-10','1881-01-29');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Metal','1881-01-30','1882-02-17');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Water','1882-02-18','1883-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Water','1883-02-08','1884-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Wood','1884-01-28','1885-02-14');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Wood','1885-02-15','1886-02-03');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Fire','1886-02-04','1887-01-23');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Fire','1887-01-24','1888-02-11');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Earth','1888-02-12','1889-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Earth','1889-01-31','1890-01-20');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Metal','1890-01-21','1891-02-08');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Metal','1891-02-09','1892-01-29');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Water','1892-01-30','1893-02-16');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Water','1893-02-17','1894-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Wood','1894-02-06','1895-01-25');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Wood','1895-01-26','1896-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Fire','1896-02-13','1897-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Fire','1897-02-02','1898-01-21');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Earth','1898-01-22','1899-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Earth','1899-02-10','1900-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Metal','1900-01-31','1901-02-18');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Metal','1901-02-19','1902-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Water','1902-02-08','1903-01-28');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Water','1903-01-29','1904-02-15');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Wood','1904-02-16','1905-02-03');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Wood','1905-02-04','1906-01-24');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Fire','1906-01-25','1907-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Fire','1907-02-13','1908-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Earth','1908-02-02','1909-01-21');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Earth','1909-01-22','1910-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Metal','1910-02-10','1911-01-29');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Metal','1911-01-30','1912-02-17');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Water','1912-02-18','1913-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Water','1913-02-06','1914-01-25');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Wood','1914-01-26','1915-02-13');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Wood','1915-02-14','1916-02-02');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Fire','1916-02-03','1917-01-22');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Fire','1917-01-23','1918-02-10');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Earth','1918-02-11','1919-01-31');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Earth','1919-02-01','1920-02-19');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Metal','1920-02-20','1921-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Metal','1921-02-08','1922-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Water','1922-01-28','1923-02-15');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Water','1923-02-16','1924-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Wood','1924-02-05','1925-01-24');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Wood','1925-01-25','1926-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Fire','1926-02-13','1927-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Fire','1927-02-02','1928-01-22');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Earth','1928-01-23','1929-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Earth','1929-02-10','1930-01-29');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Metal','1930-01-30','1931-02-16');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Metal','1931-02-17','1932-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Water','1932-02-06','1933-01-25');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Water','1933-01-26','1934-02-13');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Wood','1934-02-14','1935-02-03');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Wood','1935-02-04','1936-01-23');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Fire','1936-01-24','1937-02-10');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Fire','1937-02-11','1938-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Earth','1938-01-31','1939-02-18');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Earth','1939-02-19','1940-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Metal','1940-02-08','1941-01-26');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Metal','1941-01-27','1942-02-14');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Water','1942-02-15','1943-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Water','1943-02-05','1944-01-24');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Wood','1944-01-25','1945-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Wood','1945-02-13','1946-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Fire','1946-02-02','1947-01-21');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Fire','1947-01-22','1948-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Earth','1948-02-10','1949-01-28');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Earth','1949-01-29','1950-02-16');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Metal','1950-02-17','1951-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Metal','1951-02-06','1952-01-26');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Water','1952-01-27','1953-02-13');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Water','1953-02-14','1954-02-02');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Wood','1954-02-03','1955-01-23');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Wood','1955-01-24','1956-02-11');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Fire','1956-02-12','1957-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Fire','1957-01-31','1958-02-17');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Earth','1958-02-18','1959-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Earth','1959-02-08','1960-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Metal','1960-01-28','1961-02-14');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Metal','1961-02-15','1962-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Water','1962-02-05','1963-01-24');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Water','1963-01-25','1964-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Wood','1964-02-13','1965-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Wood','1965-02-02','1966-01-20');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Fire','1966-01-21','1967-02-08');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Fire','1967-02-09','1968-01-29');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Earth','1968-01-30','1969-02-16');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Earth','1969-02-17','1970-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Metal','1970-02-06','1971-01-26');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Metal','1971-01-27','1972-02-14');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Water','1972-02-15','1973-02-02');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Water','1973-02-03','1974-01-22');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Wood','1974-01-23','1975-02-10');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Wood','1975-02-11','1976-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Fire','1976-01-31','1977-02-17');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Fire','1977-02-18','1978-02-06');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Earth','1978-02-07','1979-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Earth','1979-01-28','1980-02-15');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Metal','1980-02-16','1981-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Metal','1981-02-05','1982-01-24');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Water','1982-01-25','1983-02-12');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Water','1983-02-13','1984-02-01');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Wood','1984-02-02','1985-02-19');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Wood','1985-02-20','1986-02-08');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Fire','1986-02-09','1987-01-28');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Fire','1987-01-29','1988-02-16');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Earth','1988-02-17','1989-02-05');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Earth','1989-02-06','1990-01-26');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Metal','1990-01-27','1991-02-14');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Metal','1991-02-15','1992-02-03');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Water','1992-02-04','1993-01-22');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Water','1993-01-23','1994-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Wood','1994-02-10','1995-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Wood','1995-01-31','1996-02-18');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Fire','1996-02-19','1997-02-06');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Fire','1997-02-07','1998-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Earth','1998-01-28','1999-02-15');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Earth','1999-02-16','2000-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Metal','2000-02-05','2001-01-23');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Metal','2001-01-24','2002-02-11');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Water','2002-02-12','2003-01-31');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Water','2003-02-01','2004-01-21');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Wood','2004-01-22','2005-02-08');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Wood','2005-02-09','2006-01-28');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Fire','2006-01-29','2007-02-17');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Fire','2007-02-18','2008-02-06');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rat','Earth','2008-02-07','2009-01-25');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Ox','Earth','2009-01-26','2010-02-13');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Tiger','Metal','2010-02-14','2011-02-02');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rabbit','Metal','2011-02-03','2012-01-22');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dragon','Water','2012-01-23','2013-02-09');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Snake','Water','2013-02-10','2014-01-30');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Horse','Wood','2014-01-31','2015-02-18');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Goat','Wood','2015-02-19','2016-02-07');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Monkey','Fire','2016-02-08','2017-01-27');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Rooster','Fire','2017-01-28','2018-02-15');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Dog','Earth','2018-02-16','2019-02-04');
INSERT INTO ethereal.Sign (SignAnimal,SignElement,SignStart,SignEnd) VALUES('Pig','Earth','2019-02-05','2020-01-24');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPath','admin','/');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAccessAlt','admin','<b>Insert non listed user</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAccessPri','admin','<b>Add remove users to realm pool</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAccessRealm','admin','Add remove supervisors to: ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAccessTitle','admin','Supervisory access control to realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditCode','admin','Specific auditing code');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditEnd','admin','End date');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadAction','admin','Action');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadDate','admin','Date');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadEvent','admin','Recorded event');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadHost','admin','Host');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadRealm','admin','Realm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditHeadUser','admin','Username');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditLevel','admin','Which level of operation');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditOps','admin','Restrict to operations');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditRealm','admin','Specific realm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditRestrict','admin','Search restriction');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditSearch','admin','Recover entries');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditStart','admin','Start date');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditTime','admin','Time search range');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditTitle','admin','Auditing records');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAuditUser','admin','Specific user');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactAdd','admin','Create additional contacts');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactFilter','admin','Filter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactList','admin','Current contacts');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactName','admin','Name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactTitle','admin','Contact elements');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContactType','admin','Type');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagDocCurrent','admin','<b>Opened template:</b> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagDocSelect','admin','<b>Select a new template:</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagDocTitle','admin','<b>Template management</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqAdd','admin','Create new entry');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqAnswer','admin','Answer');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqDetail','admin','Question: ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqGroup','admin','Group');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqListing','admin','Current listing');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqNGroup','admin','Group');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqNQuestion','admin','Question');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqQuestion','admin','Question');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFaqTitle','admin','Frequently Asked Questions (FAQ)');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFontAddition','admin','<b>Create new font definitions</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFontCode','admin','<b>Code</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFontName','admin','<b>Name</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFontTitle','admin','<b>Font management</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFontType','admin','<b>Type</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreAdd','admin','<b>Addition</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreDesc','admin','<b>Description (<i>250 Characters</i>)</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreList','admin','<b>Listing</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreName','admin','<b>Name</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreOrder','admin','<b>Order</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGenreTitle','admin','<b>Genre Management and Control</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyAdd','admin','<font color=#FFFFFF><u><b>Addition</b></u></font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyClass','admin','<b>Class</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyGroup','admin','<b>Group</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyInject','admin','<b>Macro</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyList','admin','<b>Listing</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyName','admin','<b>Name</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyPath','admin','<b>Absolute path to image</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummySelect','admin','<b>Select gummy class</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyTitle','admin','<b>Gummy Management</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagList','admin','<a href=\"MLINK\" class=menub>MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollAdd','admin','<b>Insert a new question</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollAdmin','admin','Manage an existing Poll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollCreate','admin','Create a new Poll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollManage','admin','<b>Manage: </b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollName','admin','Name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollQuestion','admin','Question');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollSample','admin','<b>Sample Code</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPollTitle','admin','Poll creation and removal');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmAccess','admin','Access method');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmAdd','admin','Create a new realm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmAlias','admin','Aliased To');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadAccess','admin','Access');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadAlias','admin','Aliased to');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadCreate','admin','Created');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadLang','admin','Language');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadName','admin','Realm Name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadTags','admin','Tags');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHeadVerified','admin','Verified');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmImgHeight','admin','Height');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmImgSize','admin','Size');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmImgWidth','admin','Width');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmLang','admin','Language');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmName','admin','Realm Name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmSelect','admin','Select realm to continue');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmTag','admin','Tag enforcement');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmTitle','admin','Realm Administration');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmType','admin','Realm Type');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmVerified','admin','Verified Realm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRotateConduct','admin','Conduct');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRotateList','admin','Current Listing: ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRotateName','admin','Identifier');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRotateTemplate','admin','Modify template of item: ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRotateTitle','admin','Banner and HTML Rotation');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTabbed','admin','<a href=\"MLINK\" class=menua>MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserAdmin','admin','Adminstrative');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserAlias','admin','Alias to');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserAliases','admin','Known Aliases');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserBan','admin','System banned');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserChat','admin','Chat preferences');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserCross','admin','Cross Reference');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserDetails','admin','User details: ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserEmail','admin','Email address');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserExpires','admin','Expires on');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserField','admin','Using field');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserFormat','admin','Formatting');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserHome','admin','Homepage name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserHost','admin','Used address');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserHosts','admin','Associated Hostnames');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserJavascript','admin','Javascript use');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserKeyword','admin','With keyword');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserLast','admin','Last used');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserLogin','admin','Login Name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserMod','admin','Moderative');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserName','admin','Full name');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserNeg','admin','Pull from Homepage');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserPass','admin','Encrypted password');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserPos','admin','Add to Homepage');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserPrivs','admin','Priviliges');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserPuppets','admin','Associated Puppets');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserRange','admin','Search range');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserReg','admin','<center><b>Registration is Incomplete</b></center>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserSearch','admin','Locate and administer user(s)');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserSuper','admin','Supervisory');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserTitle','admin','User Administration');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagUserVer','admin','Verified adult');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebAdd','admin','Create new entry');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebClone','admin','Clone entry');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebFilter','admin','Filter post');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebList','admin','Weblog Listing');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebPost','admin','Weblog entry');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebSubject','admin','Subject');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebTitle','admin','Weblog administration');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWebTopic','admin','Topic');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWordAdd','admin','Add new word to censor');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWordRem','admin','Remove existing words');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWordTitle','admin','Global censure');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAuth','admin','<!- Site Authentication -->\r\n<div>\r\n <!- Useful buttons ->\r\n <a href=\"/erealms/registration.pl\" class=\"menua\">&#187; Sign Up</a>&nbsp;&nbsp;\r\n <a href=\"/erealms/reset.pl\" class=\"menua\">&#187; Lost Password</a>\r\n <br><br>\r\n\r\n <!- Safety Proceedure -->\r\n MSCRPT\r\n\r\n <!- Outer border -->\r\n <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n  <!- Title field -->\r\n  <div class=\"rowdark\">MTITLE</div>\r\n\r\n  <!- Wrapper Table -->\r\n  <div class=\"erlight\" style=\"width: auto;\">\r\n   <!- Potential Error Message - Add additional formatting in Error Tag->\r\n   MERROR\r\n\r\n   <!- Work Table -->\r\n   <table width=\"98%\">\r\n\r\n    <!- Username -->\r\n    <tr>\r\n     <td><b>Login Name</b></td>\r\n     <td>WUSER</td>\r\n    </tr>\r\n\r\n    <!- Password -->\r\n    <tr>\r\n     <td><b>Password</b></td>\r\n     <td>WPASS</td>\r\n    </tr>\r\n\r\n    <!- Long term cookie -->\r\n    <tr>\r\n     <td>&nbsp;</td>\r\n     <td>WRECL Sign me in automatically.</td>\r\n    </tr>\r\n    <tr>\r\n     <td colspan=\"2\"><hr></td>\r\n    </tr>\r\n\r\n    <!- String based authentication -->\r\n    <tr>\r\n     <td colspan=\"2\">WSECR Disable session-based cookies.<br>(Only use this if your browser cannot support them)</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" height=\"10\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" align=\"right\">WAUTH</td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMain','admin','<div class=\"ermain\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSub','admin','<div class=\"ersub\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTitle','admin','<div class=\"ertitle\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtAlter','admin','Alter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtBack','admin','Back');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtClear','admin','Reset timestamps');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtConf','admin','Confirm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtCreate','admin','Create');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDefault','admin','Default');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDelete','admin','Remove');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDemote','admin','Demote');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDetails','admin','Details');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNone','admin','--- None ---');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtOpen','admin','Open');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPromote','admin','Promote');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtReset','admin','Reset');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSave','admin','Save');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSearch','admin','Find');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSelect','admin','Select');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkGallery','bio','/erealms/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkMail','bio','http://www.ethereal-realms.org/erealms/mail.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDefault','bio','Offline Message');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioBlock','bio','Discontinue notifications');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioContact','bio','Contact Information');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioHome','bio','Puppet Homepage');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioIgnore','bio','Ignore Puppet');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioOffline','bio','Offline Message');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioPrivate','bio','Message Puppet');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBioWatch','bio','Notify of new posts');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNilImage','bio','Nil');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNilText','bio','Nil');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagSpacer','bio','<br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplBase','bio','<html>\r\n <head>\r\n  <title>MCHAR - Quick Access</title>\r\n\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; MCHAR - Quick Access</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n     <!- Primary Template -->\r\nMMAIN\r\n\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplContact','bio','      <!- Contact information -->\r\n      <!- Simple Wrapper Table -->\r\n      <table class=\"fancy\" cellpsacing=\"0\">\r\n\r\n       <!- Title -->\r\n       <tr>\r\n        <td class=\"fancy_title\" colspan=\"2\">Contact Information</td>\r\n       </tr>\r\n\r\n       <!- More Info -->\r\n       <tr>\r\n        <td class=\"fancy_follow\" colspan=\"2\">Image and Additional Information Below</td>\r\n       </tr>\r\n\r\n       <!- Picture ties up the left -->\r\n       <tr>\r\n        <td class=\"blank\" valign=\"top\">\r\n         <!- Display as image -->\r\n         <img src=\"PUPPETEER_PICTURE\" alt=\"User Picture\">\r\n        </td>\r\n\r\n        <td class=\"blank\" valign=\"middle\">\r\n         <!- All of these have the same format -->\r\n         <!- Name in upper case with spaces as _ -->\r\n         <!- Special characters removed  -->\r\n         <!- Followed by _ and upper cased type -->\r\n         <!- Email address -->\r\n         <font class=\"stark\">Email</font><br>\r\n         <b>Pri:<b> PRIMARY_EMAIL<br>\r\n         <b>Sec:<b> SECONDARY_EMAIL<br><br>\r\n\r\n         <!- Instant Messengers -->\r\n         <font class=\"stark\">Instant Messengers</font><br>\r\n         <b>AIM:</b> AOL_INSTANT_MESSENGER_MESSENGER<br>\r\n         <b>ICQ:</b> ICQ_MESSENGER<br>\r\n         <b>MSN:</b> MICROSOFT_MSN_MESSENGER_MESSENGER<br>\r\n         <b>Yahoo:</b> YAHOO_INSTANT_MESSENGER_MESSENGER<br><br>\r\n\r\n         <!- Various links -->\r\n         <font class=\"stark\">Sites and Links</font><br>\r\n         <b>Gallery:</b> GALLERY_LINKS<br>\r\n         <b>Homepage:</b> HOMEPAGE_LINKS<br>\r\n         <b>Weblog:</b> WEBLOG_LINKS<br>\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Nav Bar -->\r\n       <tr>\r\n        <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MMOVE</td>\r\n       </tr>\r\n      </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplDisabled','bio','      <!- Disabled contact information -->\r\n      <!- Simple Wrapper Table -->\r\n      <table class=\"fancy\" cellpsacing=\"0\">\r\n\r\n       <!- Title -->\r\n       <tr>\r\n        <td class=\"fancy_title\">Contact Information</td>\r\n       </tr>\r\n\r\n       <!- More Info -->\r\n       <tr>\r\n        <td class=\"fancy_follow\">Image and Additional Information Below</td>\r\n       </tr>\r\n\r\n       <!- Picture ties up the left -->\r\n       <tr>\r\n        <td class=\"blank\" valign=\"middle\" height=\"220\">\r\n         <!- Simple Notice to Users -->\r\n         This user has not provided any information or has opted not\r\n         to display it to the public.   For more information on how\r\n         to use the extended contact information, please consult the\r\n         help documentation or visit the \'User Details\' section\r\n         accessible through the Portal.\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Nav Bar -->\r\n       <tr>\r\n        <td class=\"fancy_sub\" align=\"center\">MMOVE</td>\r\n       </tr>\r\n      </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplNav','bio','<a HREF=\"MLINK\" class=\"menub\">MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOffline','bio','      <!- Offline Messaging -->\r\n      <!- Start of Form -->\r\n      WFRMSTRT\r\n\r\n      <!- Simple Wrapper Table -->\r\n      <table class=\"fancy\" cellpsacing=\"0\">\r\n\r\n       <!- Title -->\r\n       <tr> \r\n        <td class=\"fancy_title\" colspan=\"2\">Send an Offline Message</td>\r\n       </tr>\r\n\r\n       <!- Basic instructions -->\r\n       <tr> \r\n        <td class=\"fancy_follow\" colspan=\"2\">Type in Message Below to Send Message Offline</td>\r\n       </tr>\r\n\r\n       <!- Subject Line -->\r\n       <tr> \r\n        <td class=\"fancy_descr\">Subject?</td>\r\n        <td class=\"fancy_blank\">WMSUBJ</td>\r\n       </tr>\r\n\r\n       <!- Pupet selection -->\r\n       <tr> \r\n        <td class=\"fancy_descr\">Select Puppet?</td>\r\n        <td class=\"fancy_blank\">WCHARS</td>\r\n       </tr>\r\n\r\n       <!- Spacer -->\r\n       <tr>\r\n        <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n       </tr>\r\n\r\n\r\n       <!- Message Body and select -->\r\n       <tr> \r\n        <td class=\"fancy_blank\" colspan=\"2\">\r\n         <table>\r\n          <tr>\r\n           <td>WMBODY</td>\r\n           <td>WMSBMT</td>\r\n          </tr>\r\n         </table>\r\n        </tr>\r\n\r\n\r\n       <!- Spacer -->\r\n       <tr>\r\n        <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n       </tr>\r\n\r\n\r\n       <!- Nav Bar -->\r\n       <tr>\r\n        <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MMOVE</td>\r\n       </tr>\r\n      </table>\r\n\r\n      <!- End of Form -->\r\n      WFRMENDS\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPrivate','bio','      <!- Private Messaging -->\r\n      <!- Start of Form -->\r\n      WFRMSTRT\r\n\r\n      <!- Simple Wrapper Table -->\r\n      <table class=\"fancy\" cellpsacing=\"0\">\r\n\r\n       <!- Title -->\r\n       <tr> \r\n        <td class=\"fancy_title\" colspan=\"2\">Send a Private Message</td>\r\n       </tr>\r\n\r\n       <!- Basic instructions -->\r\n       <tr> \r\n        <td class=\"fancy_follow\" colspan=\"2\">Type in Message Below to Send Privately</td>\r\n       </tr>\r\n\r\n       <!- Pupet selection -->\r\n       <tr> \r\n        <td class=\"fancy_descr\">Select Puppet?</td>\r\n        <td class=\"fancy_blank\">WCHARSLCT</td>\r\n       </tr>\r\n\r\n       <!- Spacer -->\r\n       <tr>\r\n        <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n       </tr>\r\n\r\n       <!- Message Body  and send button-->\r\n       <tr> \r\n        <td class=\"fancy_blank\" colspan=\"2\">\r\n         <table>\r\n          <tr>\r\n           <td>WPOSTTEXT</td>\r\n           <td>WPOSTSEND</td>\r\n          </tr>\r\n         </table>\r\n       </tr>\r\n\r\n\r\n       <!- Spacer -->\r\n       <tr>\r\n        <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n       </tr>\r\n\r\n\r\n       <!- Nav Bar -->\r\n       <tr>\r\n        <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MMOVE</td>\r\n       </tr>\r\n      </table>\r\n\r\n      <!- End of Form -->\r\n      WFRMENDS\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSentMail','bio','      <!- Message sent information -->\r\n      <!- Simple Wrapper Table -->\r\n      <table class=\"fancy\" cellpsacing=\"0\">\r\n\r\n       <!- Title -->\r\n       <tr>\r\n        <td class=\"fancy_title\">Send an Offline Message</td>\r\n       </tr>\r\n\r\n       <!- More Info -->\r\n       <tr>\r\n        <td class=\"fancy_follow\">Type in Message Below to Send Message Offline</td>\r\n       </tr>\r\n\r\n       <!- Picture ties up the left -->\r\n       <tr>\r\n        <td class=\"blank\" valign=\"middle\" height=\"220\">\r\n         <!- Simple Notice to Users -->\r\n         The message has been sent to the user.   They will be notified\r\n         of this new message either through Email or on a notice on the\r\n         portal when they next log on.\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Nav Bar -->\r\n       <tr>\r\n        <td class=\"fancy_sub\" align=\"center\">MMOVE</td>\r\n       </tr>\r\n      </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSend','bio','Send');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBio','board','/erealms/bio.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBoard','board','/erealms/weblog.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLimit','board','15');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSpace','board','25');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTruncate','board','45');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagEmail','board','[Email]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHyperlink','board','[Link]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPage','board','<a href=\"MLINK\" class=\"menub\">MCOUNT</a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplBanned','board','   <!- Notice of ban -->\r\n   <div class=\"fancy_help\" style=\"float: none;\">\r\n    <!- Notice of ban section -->\r\n     <b>Notice - You have been banned!</b><br><br>\r\n\r\n     You have been banned from this board. <br><br>\r\n\r\n     As a result you cannot make posts to this board and will not be able to\r\n     until your ban expires or is lifted.<br><br>\r\n\r\n     If you feel that your ban has been unjust.   Feel free to contact the\r\n     host(s)  who control the board and petition that the ban be lifted early\r\n     or lifted entirely.<br>\r\n   </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplComments','board','  <!- Quick navigation and status section -->\r\n  <!- Wrapper table -->\r\n  <div style=\"margin-top: 10px; margin-left: 10px; margin-bottom: 5px; height: 13px\">\r\n\r\n   <!- Back and Reply links -->\r\n   <div style=\"float: left;\">\r\n    <a href=\"LBACK\" class=\"menub\">Back</a> &#9702\r\n    <a HREF=\"LREPLY\" class=\"menub\">Reply to Parent</a>\r\n   </div>\r\n\r\n   <!- Comments in section -->\r\n   <div style=\"float: right;\">\r\n    <b>Comments to parent:</b> MCOUNT\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplCompose','board','  <!- Forumn and Board Composition -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Compose a Post</td>\r\n    </tr>\r\n\r\n    <!- Basic Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Fill in Basics Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Subject -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Subject?</td>\r\n     <td class=\"fancy_blank\">WBSUBJ</td>\r\n    </tr>\r\n\r\n    <!- Message Originator -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">From?</td>\r\n     <td class=\"fancy_blank\">WBFROM</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Message Body-->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Message Body</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WBBODY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submit icons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WBPOST</td>\r\n     <td class=\"fancy_blank\">WBRSET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"left\">\r\n      <a href=\"LBACK\" class=\"menub\">Return to Listing</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Posting messages to a forum or realm board is just as simple\r\n     as filling the fields on the left hand side!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplEmpty','board','  <!- Parent post without children -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_blank\" style=\"margin-top: 10px; margin-left: 10px;\">\r\n\r\n   <!- Notify users -->\r\n    This topic has not yet received any responses.   Either post a reply or return\r\n    at a later time to see if other users have joined this thread.\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHead','board','  <!- Top title from where people are -->\r\n  <!- Wrapper table -->\r\n  <div class=\"ertitle\" style=\"width:95%\" align=\"left\">\r\n\r\n   <!- Notify users -->\r\n    <b>MTITLE</b> - MTOPIC\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplKill','board','<span class=\"white\">&#9702</span> <a href=\"LBKILL\" class=\"menub\">Remove Entry</a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplListing','board','  <!- Child Post -->\r\n  <!- Wrapper table to maintain sanity -->\r\n  <table style=\"margin-top: 5px; margin-left: MBLEVLpx; width: 90%\">\r\n   <tr>\r\n    <td>\r\n\r\n     <!- Header -->\r\n     <div class=\"ersub\">\r\n\r\n      <!- Subject, Bio Link, From and Time -->\r\n      <span class=\"white\">\r\n       <b>Subject:</b> MBSUBJ (<a href=\"LBDRCT\" target=\"_new\" class=\"white\">MBSEQN</a>)<br>\r\n       <b>From:</b> <a href=\"LBBIOL\" target=\"_new\">MBFROM</a>\r\n       <b>at</b> MBTIME \r\n      </span>\r\n     </div>\r\n\r\n     <!- Message body-->\r\n     <div style=\"margin: 5px;\">\r\n\r\n      <!- Body -->\r\n      MBBODY<br><br>\r\n\r\n      <!- Control features -->\r\n      <div align=\"right\">\r\n       <a href=\"LBRPLY\" class=\"menub\">Reply</a> MKILL\r\n      </div>\r\n     </div>     \r\n    </td>\r\n   </tr>\r\n  </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOverview','board','  <!- Quick navigation and status section -->\r\n  <!- Navigational Header -->\r\n  <div style=\"margin-top: 5px; margin-bottom: 5px; height: 13px; width: 95%\">\r\n\r\n   <!- Posting, Sorting and returns -->\r\n   <div style=\"float: left;\">\r\n    <a href=\"LBPOST\" class=\"menub\">Post</a> &#9702;\r\n    <a href=\"LBSLCT\" class=\"menub\">Select new Topic</a>\r\n    <a href=\"LBBACK\" class=\"menub\">Back one Level</a>\r\n   </div>\r\n\r\n   <!- Running Totals -->\r\n   <div style=\"float: right; width: 150px; text-align: right;\">\r\n    <b>MCOUNT of MTOTAL Message(s)</b>\r\n   </div>\r\n\r\n   <!- Page Support -->\r\n   <div style=\"float: right;\">\r\n    MPAGES\r\n   </div>\r\n  </div>\r\n\r\n  <!- Main list of messages -->\r\nLSTMESS\r\n\r\n  <!- Simplified Footer -->\r\n  <div style=\"margin-top: 10px; height: 12px; width: 95%\">\r\n\r\n   <!- Posting, Sorting and returns -->\r\n   <div style=\"float: left;\">\r\n    <a href=\"LBPOST\" class=\"menub\">Post</a> &#9702;\r\n    <a href=\"LBSLCT\" class=\"menub\">Select new Topic</a>\r\n    <a href=\"LBBACK\" class=\"menub\">Back one Level</a>\r\n   </div>\r\n\r\n   <!- Final Total -->\r\n   <div style=\"float: right;\">\r\n    <b>MCOUNT Message(s)</b>\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplParent','board','  <!- Parent Post -->\r\n  <!- Wrapper table to maintain sanity -->\r\n  <table style=\"margin-top: 5px; margin-left: 10px; width: 90%\">\r\n   <tr>\r\n    <td>\r\n\r\n     <!- Header -->\r\n     <div class=\"ertitle\">\r\n\r\n      <!- Subject, Bio Link, From and Time -->\r\n      <span class=\"white\">\r\n       <b>Subject:</b> MBSUBJ (<a href=\"LBDRCT\" target=\"_new\" class=\"white\">MBSEQN</a>)<br>\r\n       <b>From:</b> <a href=\"LBBIOL\" target=\"_new\">MBFROM</a>\r\n       <b>at</b> MBTIME \r\n      </span>\r\n     </div>\r\n\r\n     <!- Message body-->\r\n     <div style=\"margin: 5px;\">\r\n\r\n      <!- Body -->\r\n      MBBODY<br><br>\r\n\r\n      <!- Status -->\r\n      <div style=\"height: 13px\"\">\r\n       <!- Replies -->\r\n       <div style=\"float: left;\">\r\n        <b>MBRPLY replies</b>\r\n       </div>\r\n\r\n       <!- Control features -->\r\n       <div style=\"float: right;\">\r\n        <a href=\"LBZOOM\" class=\"menub\">More</a> MKILL\r\n       </div>\r\n      </div>\r\n     </div>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuickNews','board','  <!- MTITLE Post -->\r\n  <!- Link Topic, Topic, News Entry Link and Title -->\r\n  <b>Title:</b> <a class=\"dark\" href=LTOPIC><b>[MTOPIC]</b></a> <a class=\"dark\" href=LENTRY target=\"_new\"><b>MTITLE</b></a><br>\r\n\r\n  <!- Biographical Link and Puppeteer, Date -->\r\n  <b>By:</b> <a class=\"dark\" href=LBIOGR target=\"_new\"><b>MPUPPT</b></a> on MDATET\r\n\r\n  <!- Spacer -->\r\n  <br><br>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmSel','board','  <!- Realm selection -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Realm selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Select a Realm</td>\r\n    </tr>\r\n\r\n    <!- Additional information to maintain form -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">\r\n      Select a Realm from the List Below?\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Widgets -->\r\n    <tr> \r\n\r\n     <!- Realm listing -->\r\n     <td class=\"fancy_blank\">\r\n      WREALMS\r\n     </td>\r\n\r\n     <!- Selection button -->\r\n     <td class=\"fancy_blank\">\r\n      WSELECT\r\n     </td>\r\n    </tr>\r\n\r\n    <!- This space left blank -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     All public realms have forums either provided by Ethereal Realms\r\n     itself or through an alternate provider.   Select the realm\'s\r\n     forum which interests you and you will be carried to it regardless\r\n     of its location!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSpacer','board','  <!- Spacers are irrelevant -->');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTitle','board','<div class=\"ertitle\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTopic','board','  <!- Topic selection -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Topic selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\">Select a Topic</td>\r\n    </tr>\r\n\r\n    <!- Additional information to maintain form -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">\r\n      Select a Topic from the List Below?\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Generated list of all topics -->\r\nLSTSELECT\r\n\r\n\r\n    <!- This space left blank-->\r\n    <tr> \r\n     <td class=\"fancy_sub\">&nbsp;</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Select a specific topic in order to narrow down the subjects being\r\n     covered within the threads.\r\n   </div>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTopicSel','board','    <!- MTITLE Topic -->\r\n    <!- SPacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\"></td>\r\n    </tr>\r\n\r\n    <!- Title and Posts -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">\r\n      <div class=\"ersub\"><b><a href=\"MLINK\" class=\"white\">MTITLE</a></b> with MPOSTS posts</div>\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">\r\n      MDESCR\r\n     </td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWeblog','board','  <!- Weblog Master Template -->\r\n  <!- Title Bar -->\r\n  <div class=\"ertitle\" style=\"width: 95%; text-align: left;\">\r\n\r\n   <!- Notify Users of where they are -->\r\n   <b>News and Updates</b>\r\n  </div>\r\n\r\n  <!- Top Status and Page Control>\r\n  <div style=\"margin-top: 5px; margin-bottom: 5px; width: 95%; height: 13px;\">\r\n\r\n   <!- Listed out of total -->\r\n   <div style=\"float: left;\">\r\n    <b>MCOUNT of MTOTAL entries</b>\r\n   </div>\r\n\r\n   <!- Page control -->\r\n   <div style=\"float: right;\">\r\n    MPAGES\r\n   </div>\r\n  </div>\r\n\r\n  <!- Listing of all entries -->\r\nLSTENTRY\r\n\r\n  <!- Bottom Status and Page Control>\r\n  <div style=\"margin-top: 10px; width: 95%; height: 13px;\">\r\n\r\n   <!- Listed out of total -->\r\n   <div style=\"float: left;\">\r\n    <b>MCOUNT of MTOTAL entries</b>\r\n   </div>\r\n\r\n   <!- Page control -->\r\n   <div style=\"float: right;\">\r\n    MPAGES\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWEntry','board','  <!- Weblog Entry for MWTIT-->\r\n  <div class=\"ersub\" style=\"margin-left: 10px; margin-top: 5px; text-align: left; width: 93%;\">\r\n\r\n   <!- Subject, Bio Link, From and Time -->\r\n   <span class=\"white\">\r\n    <a href=\"LWTOP\" class=\"white\"><b>MWTOP</b> &#9702</a> MWTIT<br>\r\n    By <a href=\"LWBIO\" class=\"white\"><b>MWPUP</b></a> on MWDAT\r\n   </span>\r\n  </div>\r\n\r\n  <!- Message body-->\r\n  <div style=\"margin-left: 10px;  text-align: justify; width: 93%; padding: 5px;\">\r\n   MWBDY\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDescr','board','No description available!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPost','board','Post');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtReset','board','Clear');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSelect','board','Select');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtTop','board','Reset');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptACL','configuration','Default:Archivist:Designer:Jailer:Storyteller');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetFeedCode','configuration','<script language=\"javascript\" src=\"http://www.ethereal-realms.org/cgi-bin/feed.pl?FID=MID\"></script>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetForecastCode','configuration','<script language=\"javascript\" src=\"http://www.ethereal-realms.org/erealms/js/forecast.pl?ICAO=MID\"></script>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLimit','configuration','45');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRating','configuration','C:C8:G:PG:14+:18+:Adult');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBack','configuration','Realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBackup','configuration','Backup/Restore');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagBann','configuration','Ban/Access');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagCanon','configuration','Canon Handles');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagDesign','configuration','Design');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFeeds','configuration','RSS Feeds');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagFont','configuration','Font');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagForcast','configuration','Forcast');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummy','configuration','Gummies');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLocale','configuration','Locale');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMods','configuration','Moderators');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPics','configuration','Picture Ban');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPosts','configuration','Post Extract');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealm','configuration','Realm Settings');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTabbed','configuration','<a href=\"MLINK\" class=\"menub\">MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTemplates','configuration',' &#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTopic','configuration','Board Topics');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWarn','configuration','Warn');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagWord','configuration','Word Filter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplBackup','configuration','  <!-Backup and Restore -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Someone made a boo boo! -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Design Backup and Restore</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Current export available below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Export code -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WEXPORT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Additional warning -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Press and confirm below in order to restore from above text</td>\r\n    </tr>\r\n\r\n    <!- Confirm their ability to restore -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WRESTORE</td>\r\n     <td class=\"fancy_blank\">WCONFIRM (Confirm you wish to restore)</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Backup and Restore is a consolidated interface which allows you to\r\n     save the designs used in the realm in case of loss or failures in\r\n     implementing a new design.   This system is quick and easy replacing\r\n     all of your changes instantly with a saved copy when the need\r\n     arises.<br><br>\r\n\r\n     Whenever you visit this page you will be presented with the most\r\n     recent backup of the designs for the realm.    In order to save it\r\n     on your home computer, copy the text and paste it in Notepad or\r\n     any program which can save it in plain text.<br><br>\r\n\r\n     When you wish to restore, copy the text from that saved file and\r\n     paste it back in the window overriding the exisitng text.   Press\r\n     on the Restore button, confirm the action my selecting the\r\n     checkbox and the system will handle the rest.<br><br>\r\n\r\n     <b>Note:</b>  For safety reasons, only a pure blooded host can\r\n      make use of this interface, preventing possible misuse. \r\n   </div>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplBoardCreate','configuration','  <!- Board Topic Creation -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Message Board Topics</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a current/new topic below</td>\r\n    </tr>\r\n\r\n    <!- Selection ability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WTOPICS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WSELECT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- New name -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">New topic name</td>\r\n    </tr>\r\n\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WNAME</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Change desription below</td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WDESCR</td>\r\n    </tr>\r\n\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Board topics are used to direct the flow of posts being made into the system\r\n     provided system.   If you are using an external script then these options are\r\n     irrelevant and can be safety ignored.<br><br>\r\n\r\n     In order to create a new topic, select that topic and you will be presented\r\n     with a blank slate.   This is also the default when entering this portion of\r\n     the management panel.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplBoardManage','configuration','  <!- Board Topic Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Message Board Topics</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a current/new topic below</td>\r\n    </tr>\r\n\r\n    <!- Selection ability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WTOPICS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WSELECT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Change desription below for MTOPIC</td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WDESCR</td>\r\n    </tr>\r\n\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUPDATE</td>\r\n     <td class=\"fancy_blank\">WDELETE Select to remove</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Board topics are used to direct the flow of posts being made into the system\r\n     provided system.   If you are using an external script then these options are\r\n     irrelevant and can be safety ignored.<br><br>\r\n\r\n     In order to create a new topic, select that topic and you will be presented\r\n     with a blank slate.   This is also the default when entering this portion of\r\n     the management panel.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplCanon','configuration','  <!- Canon Handle Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm Canon Handles</td>\r\n    </tr>\r\n\r\n\r\nMCURRENT\r\n\r\n\r\n    <!- New name -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Assign a new Canon handle</td>\r\n    </tr>\r\n\r\n    <!- Puppet Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Puppet Name</td>\r\n     <td class=\"fancy_blank\">WNAME</td>\r\n    </tr>\r\n\r\n    <!- Login Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">User name</td>\r\n     <td class=\"fancy_blank\">WUSER</td>\r\n    </tr>\r\n\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Canon handles are handles which may exist already in the general pool which\r\n     all users have access to but also exist in this realm for those the host\r\n     deems necessary to exist.   For the most part, these handles will behave\r\n     like a normal handle except for the fact that it cannot be played outside\r\n     of the realms/users they have been assigned to.<br><br>\r\n\r\n     <b>Note:</b> While you can assign and remove the handles you cannot modify\r\n      them.  Only the user to which they belong to can remove them.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplCanonCurrent','configuration','    <!- Current listing -->\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Check items below to remove</td>\r\n    </tr>\r\n\r\n    <!- Selection ability -->\r\nMLIST\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplDesignBlank','configuration','  <!- Realm Design and Control for Unselected entries -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n   <!- Templates -->\r\n   <div class=\"fancy_help\">\r\n     <b>Realm Templates</b><br><br>\r\n\r\n     These templates are used by default when chatting in any\r\n     realm.<br><br>\r\n\r\n     <!- List links -->\r\n     LSTONLINE<br><br>\r\n\r\n     <b>Offline Templates</b><br><br>\r\n\r\n     Offline templates will only appear to a user when they have\r\n     selected to enter a realm in \'Offline\' mode.   So while there\r\n     may seem to be some duplication this is due to how one mode\r\n     needs some distinction from the other. <br><br>\r\n\r\n     <!- List links -->\r\n     LSTOFFLINE\r\n\r\n\r\n     <!- Spacer -->\r\n     <br><br>\r\n\r\n\r\n     Modifications of templates is a simple task.   Of course understanding\r\n     what the modifcations will do is an entirely different matter as it\r\n     requires some knowledge of HTML/CSS and other web based technologies.\r\n     <br><br>\r\n\r\n     However, if a mistake has been made it is always possible to revert to\r\n     the defaults which the system uses in all realms.   This is accomplished\r\n     by submitting the template with no content to the system, this will prompt\r\n     the script to reset accordingly.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplDesignText','configuration','  <!- Realm Design and Control -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm Design</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Modify the MTEMPLATE below to meet your needs</td>\r\n    </tr>\r\n\r\n    <!- Selection ability -->\r\n    <!- MHANDLE entry -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WDESCR</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Basic controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n  <!- Templates -->\r\n   <div class=\"fancy_help\">\r\n     <b>Realm Templates</b><br><br>\r\n\r\n     These templates are used by default when chatting in any\r\n     realm.<br><br>\r\n\r\n     <!- List links -->\r\n     LSTONLINE<br><br>\r\n\r\n     <b>Offline Templates</b><br><br>\r\n\r\n     Offline templates will only appear to a user when they have\r\n     selected to enter a realm in \'Offline\' mode.   So while there\r\n     may seem to be some duplication this is due to how one mode\r\n     needs some distinction from the other. <br><br>\r\n\r\n     <!- List links -->\r\n     LSTOFFLINE\r\n\r\n\r\n     <!- Spacer -->\r\n     <br><br>\r\n\r\n\r\n     Modifications of templates is a simple task.   Of course understanding\r\n     what the modifcations will do is an entirely different matter as it\r\n     requires some knowledge of HTML/CSS and other web based technologies.\r\n     <br><br>\r\n\r\n     However, if a mistake has been made it is always possible to revert to\r\n     the defaults which the system uses in all realms.   This is accomplished\r\n     by submitting the template with no content to the system, this will prompt\r\n     the script to reset accordingly.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFeedDetails','configuration','  <!- Feed overview -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">RSS Feed - MFEED</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Update below as necessary</td>\r\n    </tr>\r\n\r\n    <!- Location -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Location of Feed</td>\r\n     <td class=\"fancy_blank\">MLINK</td>\r\n    </tr>\r\n\r\n    <!- Archival date -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Last updated on</td>\r\n     <td class=\"fancy_blank\">MARCHIVE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Feed Title?</td>\r\n     <td class=\"fancy_blank\">WTITLE</td>\r\n    </tr>\r\n\r\n    <!- Link -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Feed Link?</td>\r\n     <td class=\"fancy_blank\">WLINK</td>\r\n    </tr>\r\n\r\n    <!- Display Limit -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Display How Many?</td>\r\n     <td class=\"fancy_blank\">WLIMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- View -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Compact View?</td>\r\n     <td class=\"fancy_blank\">WCOMPACT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Date -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Display Date?</td>\r\n     <td class=\"fancy_blank\">WDATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Window -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Open Links in New Window?</td>\r\n     <td class=\"fancy_blank\">WWINDOW</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Copy code -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Copy this code to use</td>\r\n    </tr>\r\n\r\n    <!- Code sample -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WCODE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Duration of damnation ->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WALTER</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Update the information on the left to suit your needs.   This page will\r\n     provide you with sample code which can be pasted directly into a HTML page\r\n     in order for it to be used.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFeedOverview','configuration','  <!- Feed overview -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">RSS Feed Overview</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select or remove current feeds below</td>\r\n    </tr>\r\n\r\n    <!- Title Sections -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WFEEDS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WACTIONS</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation Section -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a new feed</td>\r\n    </tr>\r\n\r\n    <!- Login name of new banishment -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Link to Feed</td>\r\n     <td class=\"fancy_blank\">WLINK</td>\r\n    </tr>\r\n\r\n    <!- Duration of damnation ->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Really Simple Syndication is a way for a site to highlight news and headlines\r\n     displayed on their site.   This interface allows you to not only get that\r\n     information, but also implement it directly within splash pages, realm home\r\n     pages and other useful sources of information.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFont','configuration','  <!- Font Management-->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Font Management -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Font Management</td>\r\n    </tr>\r\n\r\n    <!- Colour -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\">Colour Selections</td>\r\n    </tr>\r\n\r\n    <!- Colour listing -->\r\nLSTCOLOUR\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Font Faces -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Font Faces</td>\r\n    </tr>\r\n\r\n    <!- Font face listing -->\r\nLSTFACE\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Font Sizes -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Font Sizes</td>\r\n    </tr>\r\n\r\n    <!- Font size listing -->\r\nLSTSIZE\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Duration of damnation ->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WALTER</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Simply put, selecting a font will allow a user to select in the realm when\r\n     they chat.   So it can become vital to hosts in selecting colours which\r\n     will remain visible at all times.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFontColour','configuration','    <!- Font colour - MNAME -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><b>MNAME</b></td>\r\n     <td class=\"fancy_blank\" bgcolor=\"MCOLOR\" width=\"15\">&nbsp</td>\r\n     <td class=\"fancy_blank\">WSELECT</td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFontFace','configuration','    <!- Font face - MNAME -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\"><font face=\"MFACE\"><b>MNAME</b></font></td>\r\n     <td class=\"fancy_blank\">WSELECT</td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFontSize','configuration','    <!- Font size - MNAME -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\"><font size=\"MSIZE\"><b>MNAME</b></font></td>\r\n     <td class=\"fancy_blank\">WSELECT</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplForcast','configuration','  <!- Weather Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Forecasts -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Forcast Station Management</td>\r\n    </tr>\r\n\r\n    <!- Station selection -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a station?</td>\r\n    </tr>\r\n\r\n    <!- Station selection -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSTATION</td>\r\n     <td class=\"fancy_blank\">WALTER</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- METAR data -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">METAR Data</td>\r\n    </tr>\r\n\r\n    <!- METAR station data -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">MMETAR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation Section -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Exportable code</td>\r\n    </tr>\r\n\r\n    <!- Login name of new banishment -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WEXPORT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Ethereal Realms makes use of airport weather reports to generate weather for\r\n     realms.   Since these reports are available for any airport in the world\r\n     it permits the host to select a station that will meet the needs of their\r\n     realms world.<br><br>\r\n\r\n     Airports make use of METAR data which can be called out over a radio to pilots\r\n     so that they can have an idea of what to expect before they arrive at their\r\n     desitination.   Unfortunately it leaves a lot of be desired when attempting\r\n     to read it directly unless you know what you are looking for.<br><br>\r\n\r\n     For a complete list of airports, make use of of the US National Weather Service\r\n     to locate an appropriate site:  <a href=\"http://www.nws.noaa.gov/tg/siteloc.shtml\" target=\"_new\" class=\"dark\">\r\n     http://www.nws.noaa.gov/tg/siteloc.shtml</a><br><br>\r\n\r\n     For reference look up the ICAO   Which is four characters, once you input\r\n     that code the site will handle the rest and upload periodically.  This\r\n     data can be then accessed through the splash page or making use of the\r\n     provided export code which can be copied directly into any HTML documet.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGummy','configuration','  <!- Gummy Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Ooey and Gooey -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gummy Management</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Remove and existing gummy?</td>\r\n    </tr>\r\n\r\n    <!- Gummy listing and removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WGUMMY</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- METAR data -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a new gummy?</td>\r\n    </tr>\r\n\r\n    <!- Gummy Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Name</td>\r\n     <td class=\"fancy_blank\">WNAME</td>\r\n    </tr>\r\n\r\n\r\n    <!- Type Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Type</td>\r\n     <td class=\"fancy_blank\">WTYPE</td>\r\n    </tr>\r\n\r\n    <!- Path Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Path</td>\r\n     <td class=\"fancy_blank\">WPATH</td>\r\n    </tr>\r\n\r\n    <!- Create -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Gummies can be used by hosts as a way to mark people of certain privilege\r\n     within their realms.   Canon handles, moderators and supervisors can all\r\n     have their own unique gummies which are not available through other means.\r\n     <br><br>\r\n\r\n     <b>Note:</b>  These are not available to regular users and handles.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplLocale','configuration','  <!- Locale Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Location, Location, Location -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Location Management</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Remove an existing locale?</td>\r\n    </tr>\r\n\r\n    <!- Gummy listing and removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WLOCALE</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- METAR data -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a new locale?</td>\r\n    </tr>\r\n\r\n    <!- Gummy Name -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WNAME</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Locales are a way to allow users to specify their location when playing\r\n     within the realms.   There are two modes in which locales will work the\r\n     first of which (Strict) requires this interface since the locations\r\n     are fixed.<br><br>\r\n\r\n     The other mode will allow the user to specify it as necessary.  In\r\n     both cases the host is required to add the WCHARLOCL macro to the\r\n     RealmPanel template.  Otherwise the functionality will not be forwarded\r\n     onto the user.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMain','configuration','<div class=\"ermain\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplModerator','configuration','  <!- Moderator Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- The ME TOO factor -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Moderator Management</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Revoke existing access?</td>\r\n    </tr>\r\n\r\n    <!- Moderator listing and removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WMODS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Ceate a new moderator -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Assign moderator access to someone?</td>\r\n    </tr>\r\n\r\n    <!- Moderator Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Login name</td>\r\n     <td class=\"fancy_blank\">WLOGIN</td>\r\n    </tr>\r\n\r\n    <!- Gummy Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Roles</td>\r\n     <td class=\"fancy_blank\">WROLES</td>\r\n    </tr>\r\n\r\n    <!- Gummy Name -->\r\n    <tr>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Moderators are people who can have perform limited tasks on the realms\r\n     they have been granted access to.    This allows hosts to hand out tasks\r\n     without loosing outright control over what takes place.   Privileges are\r\n     outlined below:<br><br>\r\n\r\n     <b>(A)rchivist:</b> This allows a moderator to pull post extracts whenever they\r\n     deem it necessary.<br><br>\r\n\r\n     <b>(D)esigner:</b>  Allows a moderator to access various design aspects of the\r\n     sites from template management to font selections.<br><br>\r\n\r\n     <b>(J)ailor:</b> Allows a moderator to ban people at will or control who has\r\n     access to the realm when the access privileges are inversed.<br><br>\r\n\r\n     <b>(S)toryteller:</b>  Controls storytelling aspects like canon handles and\r\n     locale management.<br><br>\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOverview','configuration','  <!- Realm Overview -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- From high above -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm Overview</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Manage options below for MREALM</td>\r\n    </tr>\r\n\r\n    <!- Locale -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Locale Control</td>\r\n     <td class=\"fancy_blank\">WLOCALE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Formatting -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Formatting Options</td>\r\n     <td class=\"fancy_blank\">WHFORMAT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n   <!- Admin features -->\r\nLSTADMIN\r\n\r\n\r\n    <!- Date and times -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Date and Time</td>\r\n    </tr>\r\n\r\n    <!-  Locations -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Location of Stamp</td>\r\n     <td class=\"fancy_blank\">WSTAMP</td>\r\n    </tr>\r\n\r\n    <!- Format -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Format of the Stamp?</td>\r\n     <td class=\"fancy_blank\">WSFORMAT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Languages -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Language Options</td>\r\n    </tr>\r\n\r\n    <!-  Language filter -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Filter out words?</td>\r\n     <td class=\"fancy_blank\">WLANGUAGE</td>\r\n    </tr>\r\n\r\n    <!- Format -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Replace with?</td>\r\n     <td class=\"fancy_blank\">WLFORMAT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Realm Information -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Realm Information</td>\r\n    </tr>\r\n\r\n    <!-  Fonts -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Default Font?</td>\r\n     <td class=\"fancy_blank\">WFONT</td>\r\n    </tr>\r\n\r\n    <!- Genre -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Realm Genre?</td>\r\n     <td class=\"fancy_blank\">WGENRE</td>\r\n    </tr>\r\n\r\n    <!- Rating -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Realm Rating?</td>\r\n     <td class=\"fancy_blank\">WRATE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Image Settings -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Image Settings</td>\r\n    </tr>\r\n\r\n    <!- Height -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Max height?</td>\r\n     <td class=\"fancy_blank\">WHEIGHT</td>\r\n    </tr>\r\n\r\n    <!- Width -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Max width?</td>\r\n     <td class=\"fancy_blank\">WWIDTH</td>\r\n    </tr>\r\n\r\n    <!- Size -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Max file size?</td>\r\n     <td class=\"fancy_blank\">WSIZE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Homepage -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Homepage Link?</td>\r\n    </tr>\r\n\r\n    <!- Widgit -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WHOMEPAGE</td>\r\n    </tr>\r\n\r\n    <!- Webring addition -->\r\nLSTRING\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Description? (50 to 500 Characters)</td>\r\n    </tr>\r\n\r\n    <!- Widgit -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WDESCR</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Archive -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Archiving Email address?</td>\r\n    </tr>\r\n\r\n    <!- Widgit -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WARCHIVE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Administrator Message Boards -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Message board activity goes to?</td>\r\n    </tr>\r\n\r\n    <!- Widgit -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WADMIN</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Message Board -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Alternate message board link?</td>\r\n    </tr>\r\n\r\n    <!- Widgit -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WBOARD</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submit and reset -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     <b>Locale:</b>  Locale allows you to display locations while\r\n      in chat.   In order to use this feature you must have the\r\n      WCHARLOCL macro placed into your Comm Panel with either\r\n      variable or strict set.<br><br>\r\n\r\n     <b>Formatting:</b> This option allows the host to filter out\r\n      excessive HTML formatting from posts themselves.   This will\r\n      effectively prevent HTML from being used at all.<br><br>\r\n\r\n     <b>Access Control:</b>*  Changes the way people can access the\r\n      realm from its default, to a list based invite only and canon\r\n      handle only realms for storylines which require a lot of\r\n      control.<br><br>\r\n\r\n     <b>Banner Ads:</b>*  Handles the display of banner ads within\r\n      realms themselves, including gallery rotations.<br><br>\r\n\r\n     <b>Verified Realms:</b>* Verified realms required that a user\r\n      be first verified as an adult before they can enter the \r\n      realm itself.   The verification method can vary and normally\r\n      realms which employ this feature should not be public.<br><br>\r\n\r\n     <b>Harassment:</b>*  Harassment mode allows the host to\r\n      bombard the users with continual intro pages normally\r\n      shown only when the user enters a realm for the first time.<br><br>\r\n\r\n     <b>Timestamp and Format:</b>  Allows the host to set where the\r\n      date and time stamp will appear on the realm.   The Format\r\n      itself is also soemthing that can be specified using the\r\n      format listed on <a href=\"http://www.postgresql.org/docs/8.1/static/functions-formatting.html#FUNCTIONS-FORMATTING-DATETIME-TABLE\" target=\"_top\" class=\"dark\">this</a>\r\n      document.<br><br>\r\n\r\n     <b>Language Options:</b>  This allows you to enable language\r\n      filtering and additionally which word filtered instances will\r\n      be replaced with. (e.g. Smurf)<br><br>\r\n\r\n     <b>Realm Information:</b> Sets the basics for the realm such as\r\n      default font and the genre/rating the realm will posses.<br><br>\r\n\r\n     <b>Image Information:</b>  Allows a host to control the image\r\n      demensions and size images shown in realm.<br><br>\r\n\r\n     <b>Homepage Link:</b>  Used as part of the Webring built into\r\n      the site itself.    Entering a link, will display sample code\r\n      which can be inserted in the hosts website.<br><br>\r\n\r\n     <b>Description:</b>  The information that a user will see when\r\n      entering a realm or checking it through other various pages\r\n      on the site.<br><br>\r\n\r\n     <b>Archiving:</b>  Every night a complete archive of all posts\r\n      will be sent off to the hosts.  Minus private messages of\r\n      course.<br><br>\r\n\r\n     <b>Board Activity:</b>  When a post is made to the message\r\n      board a copy will be sent to this Email address in order to\r\n      keep a watchful eye.<br><br>\r\n\r\n     <b>Board Alt Link:</b>  If you want to use an alternate\r\n      message board, link to it here and Ethereal Realms will relay\r\n      users there instead.<br><br>\r\n     \r\n\r\n     <b>*</b> All of these options require an administrator to change.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOverviewAdmin','configuration','    <!- Administrative overides -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Administrators Only</td>\r\n    </tr>\r\n\r\n    <!-  Access Control -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Access Control?</td>\r\n     <td class=\"fancy_blank\">WACCESS</td>\r\n    </tr>\r\n\r\n    <!- Banners -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Banner Ads?</td>\r\n     <td class=\"fancy_blank\">WBANNER</td>\r\n    </tr>\r\n\r\n    <!-  Verified realms -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Verified Realm?</td>\r\n     <td class=\"fancy_blank\">WVERIFY</td>\r\n    </tr>\r\n\r\n    <!- Harassment -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Harass with repeating intros?</td>\r\n     <td class=\"fancy_blank\">WHARASS</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOverviewWebring','configuration','    <!- Webring code -->\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Sample code -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Sample code</td>\r\n    </tr>\r\n\r\n    <!- Show sample -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">MSAMPLE</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPicture','configuration','  <!- Picture Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- No nudy pics for you! -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Pictutre Management</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Revoke existing picture bans?</td>\r\n    </tr>\r\n\r\n    <!- Picture ban removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WPICTURES</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Ceate a new moderator -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Ban a new image?</td>\r\n    </tr>\r\n\r\n    <!- Moderator Name -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WLINK</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Picture bans allow a host to ban images and sites based on a per match\r\n     basis.   Simply put any link which matches the first part of the \r\n     banned images cannot be used on the site.<br><br>\r\n\r\n     <b>Note:</b> These images not on a per-realm basis, instead a banned\r\n     image will affect all users.   So be please be responsible when using\r\n     this site.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPoolAccess','configuration','  <!- Access List -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm User Access Control</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select from list below to remove access</td>\r\n    </tr>\r\n\r\n    <!- Title Sections -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUSERS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation Section -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Grant additional access</td>\r\n    </tr>\r\n\r\n    <!- Login name of new banishment -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Login Name</td>\r\n     <td class=\"fancy_blank\">WLOGIN</td>\r\n    </tr>\r\n\r\n    <!- Duration of damnation ->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Duration</td>\r\n     <td class=\"fancy_blank\">WDURATION</td>\r\n    </tr>\r\n\r\n    <!- Action button -->\r\n    <tr> blank\" colspan=\"2\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n  <!- Hidden fields>\r\n  WREASON\r\n\r\n\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Access lists can be a tricky operation.  For one, it would be deadly to remove\r\n     the hosts themselves from the list as it will essentially ban them and prevent\r\n     additional changes to the system.    In order to change this mode of operation\r\n     back to normal modes, it is necessary to have an administrator handle the\r\n     change.<br><br>\r\n\r\n     The duration of access granted is indicative on how many days you place\r\n     on the ban.   However, when banning someone with the duration of zero days the\r\n     effect on the system will be to create a near-permenant ban lasting a few\r\n     thousand years.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPoolBan','configuration','  <!- Banning List -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Banning List</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select from list below to discontinue a ban</td>\r\n    </tr>\r\n\r\n    <!- Title Sections -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUSERS</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation Section -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Banish more souls</td>\r\n    </tr>\r\n\r\n    <!- Login name of new banishment -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Login Name</td>\r\n     <td class=\"fancy_blank\">WLOGIN</td>\r\n    </tr>\r\n\r\n    <!- Duration of damnation ->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Duration</td>\r\n     <td class=\"fancy_blank\">WDURATION</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Reasons for banning -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Reasons for Banning</td>\r\n    </tr>\r\n\r\n    <!- Text area -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WREASON</td>\r\n    </tr>\r\n\r\n    <!- Action button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Banning is a fairly straight forward operation.   Follow the menu to the left\r\n     and the system will automatically handle the details, including removing the\r\n     users from a ban once it has expired.<br><br>\r\n\r\n     The duration of the ban is entirely indicative on how many days you place\r\n     on the ban.   However, when banning someone with the duration of zero days the\r\n     effect on the system will be to create a near-permenant ban lasting a few\r\n     thousand years.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmSelect','configuration','  <!- Realm Selection -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm Selection</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a realm to manage from the list below</td>\r\n    </tr>\r\n\r\n    <!- Title Sections -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WREALMS</td>\r\n     <td class=\"fancy_blank\">WSELECT</td>\r\n    </tr>\r\n   </table>\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This panel will lists all realms to which you have access to.   If no realms\r\n     appear on this list or different realms then you would normally expect, please\r\n     contact that realms host or the site administrator for assistance on the\r\n     matter.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplStart','configuration','  <!- Starting Point -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Have to pick up somewhere -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Since you do not have full supervisory control over this realm it is\r\n     important that you select a link from the list provided which will\r\n     allow you to start managing the realm.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSub','configuration','<div class=\"ersub\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTitle','configuration','<div class=\"ertitle\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWarn','configuration','  <!- Warnings -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Bad dog! Bad! Bad! -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Patron Warnings</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a handle below?</td>\r\n    </tr>\r\n\r\n    <!- Picture ban removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WHANDLES</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WWARN</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Ceate a new moderator -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Warn for the following reason?</td>\r\n    </tr>\r\n\r\n    <!- Moderator Name -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WREASON</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Warning is quick and easy as long as the user is in the realm.  Select\r\n     his or her handle, type in a reason and viola!   As an additional bonus\r\n     all other moderators, hosts and mods will be able to see that the user\r\n     has been warned.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWords','configuration','  <!- Word Filter -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Potty Mouth!! -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Filter out naught words</td>\r\n    </tr>\r\n\r\n    <!- Sub title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Remove a word from the filter</td>\r\n    </tr>\r\n\r\n    <!- Picture ban removal -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WPOTTY</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Ceate a new moderator -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Add a word to the filter?</td>\r\n    </tr>\r\n\r\n    <!- Moderator Name -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WWORD</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">MLINKS</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     The word filter will replace matched words in posts with whatever\r\n     the host desires.    Nothing much to it really, to allow for the\r\n     words remove them from the filter.\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNone','configuration','---- None ----');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtReset','configuration','Reset');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtResetButton','configuration','Reset');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitAddition','configuration','Add');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitAlter','configuration','Alter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitButton','configuration','Submit');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitDelete','configuration','Delete');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitRestore','configuration','Restore');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitView','configuration','Details');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtTopic','configuration','---- New Topic ----');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtWarn','configuration','Warn');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtWarnMsg','configuration','For being a nuisance to public safety...');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkGallery','contrib','/erealms/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkHomepage','contrib','/erealms/config/home.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkManage','contrib','/erealms/config/gallery.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkView','contrib','/erealms/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgCreate','contrib','File(s) were added');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgCreated','contrib','Item was created');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgDelete','contrib','File(s) were removed');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgEdit','contrib','File has been updated');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgError','contrib','An error has occured:');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgExists','contrib','Name already exists');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgFail','contrib','Unable to create file/directory');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgMime','contrib','Invalid MIME type, Images only.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgRemoved','contrib','Item was removed');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgRename','contrib','Selected file has been renamed');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgResize','contrib','Image has been copied and resized');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptComment','contrib','Comments:Ratings:Comments and Ratings:None');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptDisplay','contrib','6:9:12:15:18:24');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPrivacy','contrib','Yes:No');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptRating','contrib','C:C8:G:PG:14+:18+:Adult');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSort','contrib','Alphanumeric:Date and Time:Rating:Manual');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDisplay','contrib','6');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetEditMin','contrib','150');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGenre','contrib','General');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetHEADER','contrib','.HEADER.html');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetHomeRoot','contrib','/home/erealms/www/www/members');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetHomeUrl','contrib','http://members.ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRating','contrib','PG');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetREADME','contrib','.README.html');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetResize','contrib','750');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRoot','contrib','/home/erealms/www/www/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetScript','contrib','http://www.ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSize','contrib','15');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetUpload','contrib','5');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetUrl','contrib','http://gallery.ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagArrowDblDown','contrib','/img/left_ff.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagArrowDblUp','contrib','/img/right_ff.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagArrowDown','contrib','/img/left.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagArrowUp','contrib','/img/right.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagEmail','contrib','Email');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalDeprecate','contrib','[There are no old revisions to remove]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalExpire','contrib','    <tr><td class=\"fancy_sub\" colspan=\"2\">Gallery Creation Disabled for Account</td></tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalLstACL','contrib','    <tr><td>MPUPPET</td><td align=\"center\">WEDITOR</td><td align=\"center\">WJANITOR</td><td align=\"center\">WREVOKE</td></tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalLstImage','contrib','    <tr><td><IMG SRC=\"MLINK\" WIDTH=\"MWIDTH\" HEIGHT=\"MHEIGHT\" BORDER=\"0\"></td><td align=\"center\" valign=\"middle\">WSELECT</td></tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalLstLinks','contrib','    <tr><td><a href=\"MLINK\" target=\"_new\">MNAME</a></td><td>WREVOKE</td></tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHyperlink','contrib','[Hyperlink]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLeechBlank','contrib','[-]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLeechExif','contrib','[E]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLeechFull','contrib','[F]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLeechView','contrib','[V]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel0','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"1\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel1','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"10\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel2','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"20\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel3','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"30\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel4','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"40\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLevel5','contrib','<img src=\"/icons/blank.gif\" border=\"0\" height=\"1\" width=\"50\">&#9702; <a href=\"MLINK\" class=\"dark\">MNAME</a><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNoFiles','contrib','No files in directory');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPrivFalse','contrib','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPrivTrue','contrib','<img src=\"../img/lck.gif\" width=\"50\" height=\"50\" border=\"0\" alt=\"Private\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagSortBtn','contrib','<input type=\"image\" src=\"MLINK\" name=\"MNAME\" value=\"MVAL\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagVerFalse','contrib','&nbsp; <img src=\"../img/nv.gif\" width=\"30\" height=\"30\" align=\"absmiddle\" alt=\"Not Verified\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagVerTrue','contrib','&nbsp; <img src=\"../img/vf.gif\" width=\"30\" height=\"30\" align=\"absmiddle\" alt=\"Verified\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TextNA','contrib','N/A');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAuth','contrib','<!- Site Authentication -->\r\n<div>\r\n <!- Useful buttons ->\r\n <a href=\"/erealms/registration.pl\" class=\"menua\">&#187; Sign Up</a>&nbsp;&nbsp;\r\n <a href=\"/erealms/reset.pl\" class=\"menua\">&#187; Lost Password</a>\r\n <br><br>\r\n\r\n <!- Safety Proceedure -->\r\n MSCRPT\r\n\r\n <!- Outer border -->\r\n <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n  <!- Title field -->\r\n  <div class=\"rowdark\">MTITLE</div>\r\n\r\n  <!- Wrapper Table -->\r\n  <div class=\"erlight\" style=\"width: auto;\">\r\n   <!- Potential Error Message - Add additional formatting in Error Tag->\r\n   MERROR\r\n\r\n   <!- Work Table -->\r\n   <table width=\"98%\">\r\n\r\n    <!- Username -->\r\n    <tr>\r\n     <td><b>Login Name</b></td>\r\n     <td>WUSER</td>\r\n    </tr>\r\n\r\n    <!- Password -->\r\n    <tr>\r\n     <td><b>Password</b></td>\r\n     <td>WPASS</td>\r\n    </tr>\r\n\r\n    <!- Long term cookie -->\r\n    <tr>\r\n     <td>&nbsp;</td>\r\n     <td>WRECL Sign me in automatically.</td>\r\n    </tr>\r\n    <tr>\r\n     <td colspan=\"2\"><hr></td>\r\n    </tr>\r\n\r\n    <!- String based authentication -->\r\n    <tr>\r\n     <td colspan=\"2\">WSECR Disable session-based cookies.<br>(Only use this if your browser cannot support them)</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" height=\"10\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" align=\"right\">WAUTH</td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFileList','contrib','            <li><a href=\"MFLINK\" target=\"_blank\">MFNAME</a></li>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalACL','contrib','  <!- Access control lists -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Access control lists -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Colour spacer -->\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"4\">Gallery Access Control Lists (<i>ACL</i>)</td>\r\n    </tr>\r\n\r\n    <!- Group Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"4\">Manage Access Rights Below</td>\r\n    </tr>\r\n\r\n    <!- Listing header -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><b>Puppet</b></td>\r\n     <td class=\"fancy_blank\" align=\"center\"><b>Editor</b></td>\r\n     <td class=\"fancy_blank\" align=\"center\"><b>Maintenace</b></td>\r\n     <td class=\"fancy_blank\" align=\"center\"><b>Revoke Access</b></td>\r\n    </tr>\r\n\r\n    <!- Display rows -->\r\nLSTACL\r\n\r\n    <!- Update Capability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">&nbsp;</td> \r\n     <td class=\"fancy_blank\" align=\"center\">WUPDATE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"4\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"4\">Grant Access</td>\r\n    </tr>\r\n\r\n    <!- Listing header -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><b>Puppet</b></td>\r\n     <td class=\"fancy_blank\" align=\"center\"><b>Editor</b></td>\r\n     <td class=\"fancy_blank\" align=\"center\"><b>Maintenace</b></td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Active handles and disable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WPUPPET</td>\r\n     <td class=\"fancy_blank\" align=\"center\">WEDITOR</td>\r\n     <td class=\"fancy_blank\" align=\"center\">WJANITOR</td>\r\n     <td class=\"fancy_blank\" align=\"center\">WUPDATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"4\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"4\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Access Control Lists allow you to grant other\'s access to your gallery\r\n     with varying access.    In order to make use of this feature, simply enter\r\n     the puppet name of the user who is to be granted access and select which\r\n     privilege set applies best to them:<br>\r\n     <ul>\r\n      <li><b>Editor:</b> Access allows a user to modify all works in a gallery and\r\n          update the \'News\' and \'Links\' sections of the site.</li>\r\n      <li><b>Maintenance:</b> Unlike an editor, this user will only be able to change\r\n          their own works an no one elses.  These also have the ability to remove\r\n          comments from assigned galleries as they see fit.</li>\r\n     </ul>\r\n\r\n     Access granted is instant and can be removed just as quickly.   Users granted\r\n     access over a gallery do not need to be contributors, instead they will not have\r\n     the ability to create their own galleries.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalDetail','contrib','  <!- Gallery Details for Owners -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gallery Details: MGNAME</td>\r\n    </tr>\r\n\r\n    <!- Work Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">\r\n      <b>Type:</b> MTYPE &#9702;\r\n      <b>Created:</b> MCREATED &#9702;\r\n      <b>Modified:</b> MMODIFIED\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Gallery Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Name of Gallery?</td>\r\n     <td class=\"fancy_blank\">WGNAME</td>\r\n    </tr>\r\n\r\n    <!- Pen Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Pen Name?</td>\r\n     <td class=\"fancy_blank\">WGPEN</td>\r\n    </tr>\r\n\r\n    <!- Rating -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">This Gallery is Rated?</td>\r\n     <td class=\"fancy_blank\">WGRATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Genre -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">For Which Genres?</td>\r\n     <td class=\"fancy_blank\">WGGENRE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Ratings and Comments -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Display Ratings and Comments?</td>\r\n     <td class=\"fancy_blank\">WGCOMMENT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Hide -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Hide From Public?</td>\r\n     <td class=\"fancy_blank\">WGHIDE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Display -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Display How Many?</td>\r\n     <td class=\"fancy_blank\">WGDISPLAY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Sorting Method -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Sorting Method?</td>\r\n     <td class=\"fancy_blank\">WGSORT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Highlighting -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Highlight Which Work?</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WGLIGHT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Description?</td>\r\n    </tr>\r\n\r\n    <!- Description field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WGDESCR</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUPDATE</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGMAIN\" class=\"menub\">Gallery List</a> &#9702;\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Gallery Layer -->\r\n   <div class=\"fancy_layer\">\r\nMLAYERS\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalDetailLayer','contrib','  <!- Gallery Details for Layers -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Layer Details: MNAME</td>\r\n    </tr>\r\n\r\n    <!- Basic Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\">Basic Options Below:</td>\r\n    </tr>\r\n\r\n\r\n    <!- Layer Short Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\" colspan=\"2\">Short Name?</td>\r\n     <td class=\"fancy_blank\">WSHORT</td>\r\n    </tr>\r\n\r\n    <!- PLayer Full Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\" colspan=\"2\">Full Name?</td>\r\n     <td class=\"fancy_blank\">WFULL</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Highlighting -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"3\">Highlight Which Work?</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WLIGHT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"3\">Description</td>\r\n    </tr>\r\n\r\n    <!- Description field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WDESCR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WUPDATE</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Work Management -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"3\">Manage Member Works</td>\r\n    </tr>\r\n\r\n\r\n    <!- List of works in list and not with controls -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><b>Current Layer</b></td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\"><b>Root Layer</b></td>\r\n    </tr>\r\n    <tr> \r\n     <td class=\"fancy_blank\">WARE</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\" align=\"center\">WCONTROL</td>\r\n     <td class=\"fancy_blank\">WNOT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a href=\"LGMAIN\" class=\"menub\">Gallery List</a> &#9702;\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Gallery Layer -->\r\n   <div class=\"fancy_layer\">\r\nMLAYERS\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalDetailLight','contrib','  <!- Gallery Details for Non-Owners -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Users -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gallery Details: MGNAME</td>\r\n    </tr>\r\n\r\n    <!- Work Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">\r\n      <b>Type:</b> MTYPE &#9702;\r\n      <b>Created:</b> MCREATED &#9702;\r\n      <b>Modified:</b> MMODIFIED\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Pen Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Pen Name?</td>\r\n     <td class=\"fancy_blank\">WGPEN</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUPDATE</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGMAIN\" class=\"menub\">Gallery List</a> &#9702;\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Gallery Layer -->\r\n   <div class=\"fancy_layer\">\r\nMLAYERS\r\n   </div>\r\n  </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalInit','contrib','  <!- Gallery Initialization -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Init -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gallery Initialization</td>\r\n    </tr>\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select Gallery Type</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Image galleries -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Image Galleries</td>\r\n    </tr>\r\n\r\nLSTIMAGE\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Text galleries -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Text Galleries</td>\r\n    </tr>\r\n\r\nLSTTEXT\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Selection -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\" align=\"center\">WSELECT</td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Your gallery has not yet been given an identity.  From the list\r\n     on the left hand side, select which gallery will best suit your\r\n     needs.<br><br>\r\n\r\n     Please note that this cannot be changed once accepted.   If you\r\n     see many different variants which suit your needs, please\r\n     consider the use of more then one gallery.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalInitRow','contrib','      <!- Spacer -->\r\n      <tr> \r\n       <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n      </tr>\r\n\r\n      <!- Title and Descriptor -->\r\n      <tr> \r\n       <td class=\"fancy_blank\"><font class=\"stark\">MTITLE</font></td>\r\n       <td class=\"fancy_blank\" align=\"center\" valign=\"middle\" width=\"50\">WSELECT</td>\r\n      </tr>\r\n\r\n      <tr> \r\n       <td class=\"fancy_blank\" colspan=\"2\">MDESCR</td>\r\n      </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalLayers','contrib','    <!- Layer text -->\r\n    <b>Layers</b><br><br>\r\n\r\n    Layers are used to provide additional depth to a normal gallery.\r\n    Effectively allowing you to organize your works according to cities,\r\n    model, theme, genre or whatever suits your needs.<br><br>\r\n\r\n    Select a layer below in order to configure it\'s propreties and\r\n    insert new works.<br><br>\r\n\r\nLSTLAYERS<br><br>\r\n\r\n      \r\n    <div align=\"center\">\r\n     <a href=\"LRESET\" class=\"menub\">Gallery Level</a>\r\n    </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalleryList','contrib','           <!- Contributor portal gallery display -->\r\n           <!- Wrapped in a div -->\r\n           <div class=\"erblank\">\r\n\r\n            <!- Gallery Name and User name -->\r\n            <div class=\"galhead\">\r\n             <a href=\"LVIEW\" target=\"_blank\" class=\"menub\">MGNAME</a>\r\n             <span class=\"white\">by MPNAME<span>\r\n            </div>\r\n\r\n            <div>\r\n             <table width=\"98%\">\r\n              <tr>\r\n\r\n               <!- Genres -->\r\n               <td width=\"100\"><b>Genre(s):</b></td>\r\n               <td>MGENRES</td>\r\n\r\n               <!- Manage works -->\r\n               <td rowspan=\"4\" width=\"65\">\r\n                <a href=\"LMANAGE\" target=\"_blank\" border=\"0\">\r\n                 <img src=\"/img/wrk.gif\" width=\"50\" height=\"50\" border=\"0\" alt=\"Manage Works\" title=\"Manage Works\">\r\n                </a>\r\n               </td>\r\n              </tr>\r\n\r\n              <tr>\r\n               <!- General Rating -->\r\n               <td><b>Rating:</b></td>\r\n               <td>MRATE</td>\r\n              </tr>\r\n\r\n              <tr>\r\n               <!- Work Count -->\r\n               <td><b>Total Works:</b></td>\r\n               <td>MWRKCNT</td>\r\n              </tr>\r\n\r\n              <tr>\r\n               <!- General Rating -->\r\n               <td><b>Last Updated:</b></td>\r\n               <td>MUPDATE</td>\r\n              </tr>\r\n             </table>\r\n            </div>\r\n           </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalLinks','contrib','  <!- Quick Links -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Quick links -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Quick Links</td>\r\n    </tr>\r\n\r\n    <!- Group Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Remove Unwanted Links Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Display rows of links -->\r\nLSTLINKS\r\n\r\n    <!- Update Capability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WDELETE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a New Entry Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation wigets -->\r\n    <!- Link Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Link Name</td>\r\n     <td class=\"fancy_blank\">WNAME</td>\r\n    </tr>\r\n\r\n    <!- Physical Address -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Link Address</td>\r\n     <td class=\"fancy_blank\">WADDRESS</td>\r\n    </tr>\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Quick Links will show up on the main page of your gallery.   Simply\r\n     use the panel on the left to manage all of the links you wish to\r\n     display.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalLstImage','contrib','    <!- Description -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Thumbnail to Display</td>\r\n    </tr>\r\n\r\n    <!- Description bar -->\r\nLSTIMAGE\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalLstText','contrib','    <!- Description -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Main Body of Work</td>\r\n    </tr>\r\n\r\n    <!- Description bar -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WWTEXT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td height=\"15\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Additional Features -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Additional Options</td>\r\n    </tr>\r\n\r\n    <!- Text preservation -->\r\n    <tr class=\"fancy_blank\"> \r\n     <td class=\"fancy_descr\">Preserve Text?</td>\r\n     <td class=\"fancy_blank\">WPRESERVE</td>\r\n    </tr>\r\n\r\n    <!- Archival -->\r\n    WOARCHIVE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalLstTextArchive','contrib','   <!- Base archival options -->\r\n   <tr>\r\n    <td class=\"fancy_descr\">Archive This Version?</td>\r\n    <td class=\"fancy_blank\">WARCHIVE</td>\r\n   </tr>\r\n\r\n   <!- Removal menu -->\r\n   <tr>\r\n    <td class=\"fancy_descr\">Remove This Edition?</td>\r\n    <td class=\"fancy_blank\">WDEPRECATE</td>\r\n   </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalManage','contrib','  <!- Gallery Layer Management -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Layer management -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Layer Management</td>\r\n    </tr>\r\n\r\n\r\n    <!- Layer Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\" Select a Layer Below to Remove</td>\r\n    </tr>\r\n\r\n\r\n    <!- Layer Listing -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WREMLST</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Addition Section-->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a New Layer</td>\r\n    </tr>\r\n\r\n\r\n   <!- Layer Short Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Short Name? (A-Z and _)</td>\r\n     <td class=\"fancy_blank\">WADDWRD</td>\r\n    </tr>\r\n\r\n    <!- Parental watch -->\r\n    <t> \r\n     <td class=\"fancy_descr\">Related to Whom?</td>\r\n     <td class=\"fancy_blank\">WADDLST</td>\r\n    </tr>\r\n\r\n\r\n    <!- Create link -->\r\n    <tr class=\"fancy_blank\"> \r\n     <td colspan=\"2\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"4\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Layers allow you to create divisions into your gallery.  For example,\r\n     this allows a photographic gallery to seperate the works into cities\r\n     or models and grant more freedom on how the works are presented to\r\n     the user.<br><br>\r\n       \r\n     Layers can also carry other layers, up to six depth.   This\r\n     provides you with additional flexibility in the depth and complexity\r\n     of the presentation desired.<br><br>\r\n       \r\n     Management of these layers is handled on the left.    It is important\r\n     to note that while works can be moved from one layer to another that\r\n     functioned is done under the \'Propreties\' section of the site.<br><br>\r\n       \r\n     <b>NOTE:</b>  If you remove a layer which contains works and other\r\n                   layers, then all works contained within will be owned\r\n                   by the root layer.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalNews','contrib','  <!- Quick news -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Quick news -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">News Updates</td>\r\n    </tr>\r\n\r\n    <!- Group Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Type in the Updates Below</td>\r\n    </tr>\r\n\r\n    <!- Text and Submit Buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WNEWS</td>\r\n     <td class=\"fancy_blank\" align=\"center\" valign=\"middle\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGACCS\" class=\"menub\">Access</a> \r\n      <a href=\"LGLAYR\" class=\"menub\">Layers</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Type in the desired news entry to make on your site and it will\r\n     appear on the main page when users enter.    News entries can be\r\n     removed from the main page as well when logged on as yourself.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalPermission','contrib','   <!- Permission Denied -->\r\n   <div class=\"fancy_help\">\r\n    <!- Permission Denied -->\r\n     <b>Access Denied</b><br><br>\r\n\r\n     The area you have attempted to use requires access levels higher\r\n     then those you currently posses.  If you require access to this\r\n     section, please ask the owner of this gallery to continue.<br><br>\r\n\r\n     Select a link below to return to what you were doing\r\n     previously.<br><br>\r\n\r\n     <div align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>&nbsp;\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a>&nbsp;\r\n     </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalSelect','contrib','  <!- Gallery Selection-->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gallery Selection</td>\r\n    </tr>\r\n\r\n    <!- Gallery Listing - Notice Listing-->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Select a Gallery Below</td>\r\n    </tr>\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSELECT</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WCONTROL</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td  class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Creation control -->\r\nMCREATE\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td  class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"right\">[MNOTICE]</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Welcome to the Ethereal Realms management panel!   From this point,\r\n     you will be able to add and remove an number of galleries ranging\r\n     from poetry to snapshot photography.<br><br>\r\n\r\n     Please note, that only contributors who have not expired in access\r\n     will be able to create new galleries.   For those of you gaining\r\n     access through another contributor, you will simply be able to\r\n     select galleries to which you have been granted access.<br><br>\r\n\r\n     Also note that gallery names must be unique.   If the gallery name\r\n     you choose seems to not get created, try a different name.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalSelectCreate','contrib','    <!- New Entry -->\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Create New Entry Below</td>\r\n    </tr>\r\n\r\n    <!- New gallery prompt and button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WNEWGAL</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalWork','contrib','  <!- Work Details -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Work details -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Work Details</td>\r\n    </tr>\r\n\r\n    <!- Group Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">MWNAME &#9702;\r\n      <b>Rated:</b> MRATINGS &#9702;\r\n      <b>Votes:</b> MOLVOTES &#9702;\r\n      <b>Modified:</b> MUPDATED\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Standard options -->\r\n    <!- Work Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Change Title?</td>\r\n     <td class=\"fancy_blank\">WWNAME</td>\r\n    </tr>\r\n\r\n    <!- Updates -->\r\n    <tr class=\"fancy_blank\"> \r\n     <td class=\"fancy_descr\">Notify of Update?</td>\r\n     <td class=\"fancy_blank\">WWNOTIFY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Description -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Description Field</td>\r\n    </tr>\r\n\r\n    <!- Description bar -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WWDESCR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Specific capabilities -->\r\nMUNIQUE\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WUPDATE</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Propreties for works take place at this point.  Simply\r\n     update the information on the left to the desired settings\r\n     and update for the system to recognize the changes.\r\n     <br><br>\r\n\r\n     For owners of image style galleries only an update to this\r\n     section will allow the image to be indexed for the search\r\n     engine.  So choose your descriptions wisely!\r\n   </div>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalWorkList','contrib','  <!- Work Listing -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Work listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Work Listing: MNAME</td>\r\n    </tr>\r\n\r\n    <!- Work Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Select/Remove Works Below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">Status: [MMESSAGE]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Standard Display -->\r\n    <!- Work display and controls -->\r\n    <tr> \r\n     <td>\r\n      <table>\r\n       <tr>\r\n        <!- Full Work Listing--> \r\n        <td>WLISTING</td>\r\n       </tr>\r\n       <tr>\r\n        <!- Manual movement control -->\r\n        <td align=\"center\">MARROWS</td>\r\n       </tr>\r\n      </table>\r\n     </td>\r\n\r\n     <td valign=\"middle\">\r\n      <!- Details, Delete and Confirmation Wigets -->\r\n      WDETAILS\r\n      <br><br>\r\n      WDELETE&nbsp;&nbsp;WCONFIRM\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- New work comissions-->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Create a New Work</td>\r\n    </tr>\r\n\r\n    <!- New Work Name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Name of Work?</td>\r\n     <td class=\"fancy_blank\">WNNAME</td>\r\n    </tr>\r\n\r\n    <!- Specific capabilities -->\r\nMUPLOAD\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Create link -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LGVIEW\" class=\"menub\">Propreties</a>\r\n      <a href=\"LWLIST\" class=\"menub\">Work List</a> &#9702;\r\n      <a href=\"LGNEWS\" class=\"menub\">News</a> \r\n      <a href=\"LGLINK\" class=\"menub\">Links</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_layer\">\r\nMLAYERS\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalWorkUpload','contrib','    <!- Uptional for image galleries only -->\r\n\r\n    <!- Upload field and Leeching capability-->\r\n    <tr> \r\n     <td class=\"fancy_descr\" valign=\"top\">Upload File or Provide Link?\r\n     <td class=\"fancy_blank\">WUPLOAD <div>&nbsp;&nbsp;&nbsp;-or-</div> WLEECH</td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHome','contrib','  <!- Homepage Feature -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Homepages -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Homepage</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Manage Works Below?</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MMESSAGE]</td>\r\n    </tr>\r\n\r\n    <!- Text and Submit Buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSORTED</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WBUTTONS</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Rename ability -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Rename an Existing File?</td>\r\n    </tr>\r\n\r\n    <!- New name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">New Name?</td>\r\n     <td class=\"fancy_blank\">WNEWNAME</td>\r\n    </tr>\r\n\r\n    <!- Submit button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WRENAME</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      Space: MTSIZE &#9702;\r\n      Max: MTMAXM &#9702;\r\n      Files: MTCOUNT\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LMAIN\" class=\"menub\">Main</a> &#9702;\r\n      <a href=\"LLIST\" class=\"menub\">File Listing</a> &#9702;\r\n      <a href=\"LSIZE\" class=\"menub\">Resizing Image</a> &#9702;\r\n      <a href=\"LUPLD\" class=\"menub\">Upload Files</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Here you can edit, remove and rename any files that you have already uploaded.\r\n     Please note, that in order to rename you must have a file selected in the\r\n     area above the rename section.\r\n   </div>\r\n  </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeCreate','contrib','  <!- Homepage Creation -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Homepage creation -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Create a Homepage</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Fill in the Details Below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MMESSAGE]</td>\r\n    </tr>\r\n\r\n    <!- New name -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">New Name?</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n    <!- Submit button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     You do not have homepage space on this site.    Please provide the left-hand\r\n     panel with the desired directory name in order to continue.   Note that if\r\n     this name is already taken, you will have to select another before being able\r\n     to continue.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeEdit','contrib','  <!- Text Edit -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Edit a text file -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Edit a File</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" align=\"left\">Make your Changes Below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MMESSAGE]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Editing text -->\r\n    <tr> \r\n     <td class=\"fancy_blank colspan=\"2\">WEDITOR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Editing text -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSUBMIT</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LMAIN\" class=\"menub\">Main</a> &#9702;\r\n      <a href=\"LLIST\" class=\"menub\">File Listing</a> &#9702;\r\n      <a href=\"LSIZE\" class=\"menub\">Resizing Image</a> &#9702;\r\n      <a href=\"LUPLD\" class=\"menub\">Upload Files</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     To modify a text file, simply alter the contents listed in the\r\n     textarea and submit the changes.    The file will be updated with\r\n     the changes you have done at that time.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeError','contrib','   <!- Error Message -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>An Error has Occured!</b><br><br>\r\n\r\n     MMESSAGE<br><br>\r\n\r\n     MERROR\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeExpire','contrib','   <!- Error Message -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>An Error has Occured!</b><br><br>\r\n\r\n     Your account has expired and as a result you can no longer enter this\r\n     section of the site.    If you wish to correct this, please consider\r\n     making a donation or informing the site administrator in case this\r\n     is an error.\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeListing','contrib','  <!- Homepage File Listing -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- File listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">File listing</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Find a List of all MCOUNT Files Below</td>\r\n    </tr>\r\n\r\n    <!- Title Sections -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><b>File Name</b></td>\r\n     <td class=\"fancy_blank\" align=\"left\"><b>File Size</b></td>\r\n    </tr>\r\n\r\nLSTITEMS\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LMAIN\" class=\"menub\">Main</a> &#9702;\r\n      <a href=\"LLIST\" class=\"menub\">File Listing</a> &#9702;\r\n      <a href=\"LSIZE\" class=\"menub\">Resizing Image</a> &#9702;\r\n      <a href=\"LUPLD\" class=\"menub\">Upload Files</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n  <!- Quick help section -->\r\n  <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This panel is a simple file listing, allowing you to select specific images\r\n     within your homepage.    Clicking on the filename will open a new window\r\n     with the contents within.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeListingItem','contrib','    <!- MNAME Section -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><a href=\"MLINK\" target=\"_new\">MNAME</a></td>\r\n     <td class=\"fancy_blank\" align=\"left\">MBYTES</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeResize','contrib','  <!- Image Resize -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Image Resize -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Image Resize</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Change Image Size Below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MMESSAGE]</td>\r\n    </tr>\r\n\r\n    <!- File listing -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Select a File?</td>\r\n     <td class=\"fancy_blank\">WSORTED</td>\r\n    </tr>\r\n\r\n    <!- Max image size -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Maximum Demension?</td>\r\n     <td class=\"fancy_blank\">WMAX</td>\r\n    </tr>\r\n\r\n    <!- Submit Buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LMAIN\" class=\"menub\">Main</a> &#9702;\r\n      <a href=\"LLIST\" class=\"menub\">File Listing</a> &#9702;\r\n      <a href=\"LSIZE\" class=\"menub\">Resizing Image</a> &#9702;\r\n      <a href=\"LUPLD\" class=\"menub\">Upload Files</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Resizing an image is a snap!   Select the image you wish to resize\r\n     and type in the size this image\'s biggest demension should be \r\n     sized to!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeUpload','contrib','  <!- Image Upload -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Upload images -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Upload Images</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Insert Filenames Below</td>\r\n    </tr>\r\n\r\nLSTITEMS\r\n\r\n    <!- Upload -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WUPLOAD</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a href=\"LMAIN\" class=\"menub\">Main</a> &#9702;\r\n      <a href=\"LLIST\" class=\"menub\">File Listing</a> &#9702;\r\n      <a href=\"LSIZE\" class=\"menub\">Resizing Image</a> &#9702;\r\n      <a href=\"LUPLD\" class=\"menub\">Upload Files</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Upload images, pages and other text material though the left panel.  Simply\r\n     click on the individual \'Browse\' buttons and select a file on your system\r\n     you wish to send over.<br><br>\r\n\r\n     Please note, that while there are numerous upload boxes, it is not necessary\r\n     to fill them all at once.   The system knows how many are filled at any\r\n     given time.\r\n   </div>\r\n  </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplHomeUploadItem','contrib','    <!- File Slow MCOUNT-->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Use File Slot MCOUNT?</td>\r\n     <td class=\"fancy_blank\">WUPLOAD</td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplLeech','contrib',' <!- Leech line item -->\r\n <div align=\"center\">\r\n  <table width=\"80%\">\r\n   <tr>\r\n    <td><b>MNAME</b></td>\r\n    <td width=\"75\" align=\"right\">MSIZE <i>Kb</i></td>\r\n    <td width=\"10\">&nbsp;</td>\r\n    <td width=\"75\" align=\"right\">MTIME <i>Sec</i></td>\r\n    <td width=\"10\">&nbsp;</td>\r\n    <td width=\"30\">MEXIF</td>\r\n    <td width=\"30\">MVIEW</td>\r\n    <td width=\"30\">MFULL</td> \r\n   </tr>\r\n  </table>\r\n </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplLeechFoot','contrib',' <!- Spacer -->\r\n <br><br>\r\n\r\n <div align=\"center\">\r\n  <div class=\"leech_text\" align=\"left\">\r\n   Thank you for your patience!  This script has finished processing the information above. \r\n   Click one of the links below to continue with what you were doing!\r\n \r\n\r\n   <!-- Links -->\r\n   <div align=\"center\">\r\n    <a href=\"LGVIEW\" class=\"menub\">Gallery/Layer Details</a>\r\n    <a href=\"LWLIST\" class=\"menub\">Work Management</a>\r\n   </div>\r\n  </div>\r\n </div>\r\n\r\n <!- Spacer -->\r\n <br><br>\r\n\r\n <!- Copyright -->\r\n <div class=\"leech_bottom\" align=\"center\">\r\n  <span class=\"copy\"><b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n   All works and posts are owned by individual posters</span>\r\n </div>\r\n\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplLeechHead','contrib','<html>\r\n <head>\r\n  <title>Ethereal Realms - Works Leeching</title>\r\n  <META http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Turquoise\">\r\n </head>\r\n\r\n <body>\r\n\r\n <!- Header -->\r\n <div class=\"leech_top\"><img src=\"/img/ttl.gif\" width=\"250\" height=\"46\"></div>\r\n\r\n <div align=\"center\">\r\n  <div class=\"leech_text\" align=\"left\">\r\n   The system is currently processing the link you have provided.  Please note that there\r\n   are many factors that affect how long this process is going to take.   However, be patient\r\n   and shortly you will begin to see a status of images as they are being processed.\r\n   <br><br>\r\n\r\n   Please note that this process may not get all images in one hit.  When this occurs, simply\r\n   submit the link another time and the site will continue where it left off.    This will\r\n   also work for skipped images that may have been missed due to external issues.\r\n   <br><br>\r\n\r\n   As works are leeched from the site you will be given a series of prompts from the script\r\n   telling you what has been done to the image pulled.   Please reference the list below\r\n   for more details:\r\n\r\n   <ul>\r\n    <li>Exif Information - [E] - Information your camera stores when the picture is captured.</li>\r\n    <li>Full View - [F] - The image has been resized for full view as it exceedes system limitations.</li>\r\n    <li>View Size - [V] - As with the above, however restricted to the size for casual browsing.</li>\r\n   </ul>\r\n  </div>\r\n </div>\r\n\r\n <!- Spacer -->\r\n <br><br>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtAbstain','contrib','--');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtCreate','contrib','Create');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDelete','contrib','Remove');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDetails','contrib','Details');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtEdit','contrib','Edit File');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMoveIn','contrib','>>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMoveOut','contrib','<<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNone','contrib','--- None ---');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRename','contrib','Rename');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtResize','contrib','Resize');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSelect','contrib','Select');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtUpdate','contrib','Update');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtUpload','contrib','Upload');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkFAQ','faq','/faq.shtml');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGroupList','faq','       <!- Group MANCHOR quick select -->\r\n       <li><a href=\"MANCHOR\" class=\"dark\">MNAME</a></li>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMaster','faq','  <!- Frequently Asked Questions Master Template -->\r\n  <!- Wrapper table -->\r\n  <table width=\"100%\">\r\n   <tr>\r\n    <td valign=\"top\">\r\n\r\n     <!- Index List and Overview -->\r\n     <!- Table top -->\r\n     <table class=\"fancy\" cellspacing=\"0\" style=\"margin-bottom: 20px;\">\r\n\r\n      <!- Title-->\r\n      <tr> \r\n       <td class=\"fancy_title\">Frequently Asked Questions</td>\r\n      </tr>\r\n\r\n      <!- Sub title and message -->\r\n      <tr> \r\n       <td class=\"fancy_follow\">Question and Answer Overview</td>\r\n      </tr>\r\n\r\n      <!- Generate list -->\r\n      <tr> \r\n       <td class=\"fancy_blank\">\r\nLSTINDEX\r\n       </td>\r\n      </tr>\r\n     </table>\r\n\r\n\r\n     <!- Questions and Answers -->\r\n     <!- Table top -->\r\n     <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n      <!- Title-->\r\n      <tr> \r\n       <td class=\"fancy_title\">Questions and Answers</td>\r\n      </tr>\r\n\r\n\r\n      <!- Spacer -->\r\n      <tr>\r\n       <td class=\"fancy_div\"></td>\r\n      </tr>\r\n\r\n\r\n     <!- List questions and Answers -->\r\nLSTQUESTIONS\r\n\r\n     </table>\r\n\r\n\r\n    <!- New Column -->\r\n    </td>\r\n    <td valign=\"top\">\r\n\r\n\r\n     <!- Quick help section -->\r\n     <div class=\"fancy_help\">\r\n      <!- Quick help text -->\r\n       <b>Quick Help</b><br><br>\r\n   \r\n       Frequently Asked Questions is a section desgined to aid the user in quickly finding\r\n       answers to questions freqently asked to the hosts, administrators or even other users\r\n       on the site itself.     By provinding an easy to reference list it is hoped that\r\n       new users to the site will be better prepared in using the site and enjoy its\r\n       intricacies.<br><br>\r\n\r\n       <!- Display groups -->\r\n       <ul>\r\nLSTGROUPS\r\n       </ul>\r\n\r\n       For quick reference, choose a group of questions which interests you the most from\r\n       above or look at the overview located on the left.\r\n     </div>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuestionGroup','faq','      <!- MNAME group -->\r\n      <tr> \r\n       <td class=\"fancy_sub\">MANCHOR<b>MNAME</b></td>\r\n      </tr>\r\n\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuestionIndex','faq','       <!- MNAME group -->\r\n       <br>\r\n\r\n       <!- Anchor and Name -->\r\n       <span class=\"white\"><b>&#187;<a MANCHOR>MNAME</a></b></span>\r\n\r\n       <!- Use an unordered list -->\r\n       <ul>\r\n        <!- List of all entries -->\r\nLSTINDEX\r\n       </ul>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuestionIndexItem','faq','        <!- MANCHOR -->\r\n        <li><a href=\"MANCHOR\">MQUESTION</a></li>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuestionList','faq','      <!- Question MQUESTION -->\r\n      <tr> \r\n       <td class=\"fancy_blank\">MANCHOR<span class=\"stark\">MQUESTION</span></td>\r\n      </tr>\r\n\r\n      <!- Answer -->\r\n      <tr> \r\n       <td class=\"fancy_blank\">MANSWER</td>\r\n      </tr>\r\n\r\n      <!- Answer -->\r\n      <tr> \r\n       <td class=\"fancy_blank\" align=\"right\">\r\n        <a href=\"/faq.shtml#top\" class=\"menub\">Top</a>\r\n       </td>\r\n      </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQuestionSpacer','faq','      <!- Spacer -->\r\n      <tr>\r\n       <td class=\"fancy_div\"></td>\r\n      </tr>\r\n\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBase','gallery','/erealms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBio','gallery','/erealms/bio.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkGallery','gallery','/erealms/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgComment','gallery','The author or artist of this gallery has opted to disable the ability to comment or rate their gallery.  As a result, the ability to post comments has been disabled.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgListing','gallery','There are no genres that match that type and genres.<br>   Please try another set.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgParam','gallery','Your entry into the Gallery system is invalid.  Please use correct channels in which to navigate.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgRestricted','gallery','You have attempted to enter a restricted area and do not have the proper verification.   Please attempt to access this area through normal channels, or obtain the proper verification.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgSrchResults','gallery','Sorry! Your search did not find any matches, please try a different genre and different keywords in order to generate better results!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgBlank','gallery','/icons/blank.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLayerChild','gallery','child');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLayerParent','gallery','parent');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetMax','gallery','96');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetNil','gallery','N/A');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRestricted','gallery','Adult');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRetrieve','gallery','24');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetRoot','gallery','/home/erealms/www/public_html/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetScript','gallery','http://www.ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetThumbnail','gallery','/icons/blank.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagDelete','gallery','<div style=\"text-align: right;\"><a href=\"MLINK\" class=\"menub\">Remove</a></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalIgnore','gallery','<a href=\"MLINK\"><img src=\"/img/ign.gif\" height=\"50\" width=\"50\" alt=\"Stop Watching\" title=\"Stop Watching\"></a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGalWatch','gallery','<a href=\"MLINK\"><img src=\"/img/wch.gif\" height=\"50\" width=\"50\" border=\"0\" alt=\"Watch this Gallery\" title=\"Watch this Gallery\"></a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGummyDef','gallery','/gummies/1.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagImageFull','gallery','Toggle Full View');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagImageView','gallery','Toggle Normal View');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMapStepDown','gallery','      </ul>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMapStepUp','gallery','      <ul>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNav','gallery','<a href=\"MLINK\" class=\"menub\"><b>MNAME</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavComment','gallery','<b>Post Comment</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavComplete','gallery','<b>View All</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavTarget','gallery','<a href=\"MLINK\" class=\"menub\" target=\"MTARGET\"  onclick=\'window.open(this.href,this.target,settings); return false;\'><b>MNAME</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavView','gallery','<a href=\"MLINK\" class=\"menud\"><b>MNAME</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNewness','gallery','NEW!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPenName','gallery','<a HREF=\"MLINK\" class=\"white\">MNAME</a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPenNameFinalize','gallery',' and ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPenNameSpacer','gallery',', ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPrint','gallery','<a href=\"MLINK\" target=\"_BLANK\"><img src=\"/img/pnt.gif\" border=\"0\" alt=\"View Printable Version\"></A>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRevClose','gallery','</td></tr></table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRevLink','gallery','<p><a href=\"MLINK\">MNAME</a><br></p>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRevNotice','gallery','<br><br><center><b>Revision made on: MDATE</b></center><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRevTitle','gallery','<table border=\"0\" cellpadding=\"5\" cellspacing=\"1\" bgcolor=\"#FFFFFF\" width=\"95%\"><tr><td bgcolor=\"#274F60\"><b><font color=\"#FFFFFF\">Revisions</font></b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTree','gallery','<a href=\"MLINK\">MNAME/</a>&nbsp;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTreeBlank','gallery','Galleries and Expositions');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAuth','gallery','<!- Site Authentication -->\r\n<div>\r\n <!- Useful buttons ->\r\n <a href=\"/erealms/registration.pl\" class=\"menua\">&#187; Sign Up</a>&nbsp;&nbsp;\r\n <a href=\"/erealms/reset.pl\" class=\"menua\">&#187; Lost Password</a>\r\n <br><br>\r\n\r\n <!- Safety Proceedure -->\r\n MSCRPT\r\n\r\n <!- Outer border -->\r\n <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n  <!- Title field -->\r\n  <div class=\"rowdark\">MTITLE</div>\r\n\r\n  <!- Wrapper Table -->\r\n  <div class=\"erlight\" style=\"width: auto;\">\r\n   <!- Potential Error Message - Add additional formatting in Error Tag->\r\n   MERROR\r\n\r\n   <!- Work Table -->\r\n   <table width=\"98%\">\r\n\r\n    <!- Username -->\r\n    <tr>\r\n     <td><b>Login Name</b></td>\r\n     <td>WUSER</td>\r\n    </tr>\r\n\r\n    <!- Password -->\r\n    <tr>\r\n     <td><b>Password</b></td>\r\n     <td>WPASS</td>\r\n    </tr>\r\n\r\n    <!- Long term cookie -->\r\n    <tr>\r\n     <td>&nbsp;</td>\r\n     <td>WRECL Sign me in automatically.</td>\r\n    </tr>\r\n    <tr>\r\n     <td colspan=\"2\"><hr></td>\r\n    </tr>\r\n\r\n    <!- String based authentication -->\r\n    <tr>\r\n     <td colspan=\"2\">WSECR Disable session-based cookies.<br>(Only use this if your browser cannot support them)</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" height=\"10\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" align=\"right\">WAUTH</td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplComment','gallery','     <!- Comments display -->\r\n     <!- Contained within a div -->\r\n     <div class=\"galwrap\" style=\"margin-top: 15px;\">\r\n\r\n      <!- Name and nav -->\r\n      <div class=\"galhead\" style=\"height: 12px\">\r\n       <span style=\"float: left;\"><b>MNAME Comments</b></span>\r\n       <span style=\"float: right;\">MNAV</span>\r\n      </div>\r\n\r\n      <!- Display comments -->\r\n      <div style=\"min-height: 50px;\">\r\nMCOMMENT\r\n      </div>\r\n\r\n      <!- Votes and nav -->\r\n      <div class=\"galfoot\" style=\"height: 12px\">\r\n       <span style=\"float: left;\">MVOTES&nbsp;</span>\r\n       <span style=\"float: right;\">MNAV</span>\r\n      </div>\r\n     </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplCommentList','gallery','        <!- Comment Listing -->\r\n        <div class=\"erlight\" style=\"margin-top: 5px; margin-bottom: 10px;\">\r\n\r\n         <!- Header -->\r\n         <div class=\"rowlight\" style=\"height: 28px\">\r\n          \r\n          <!- From and date -->\r\n          <div style=\"float: left;\">\r\n           <b>From:</b> MPUPPET<br>\r\n           <b>Date:</b> MDATE\r\n\r\n          </div>\r\n\r\n          <!- Gummy -->\r\n          <div style=\"float: right;\">\r\n           <a href=\"MLINK\">\r\n            <img src=\"MGUMMY\" height=\"25\" width=\"25\" alt=\"MNAME\" title=\"MNAME\" style=\"border: 0px;\">\r\n           </a>\r\n          </div>\r\n         </div>\r\n\r\n         <!- Body -->\r\n         <div style=\"margin: 5px;\">MCOMMENT</div>\r\n\r\n         <!- Potential removal -->\r\n         MDELE\r\n        </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplDescription','gallery','<table width=\"100%\" border=\"0\" cellspacing=\"2\" cellpadding=\"3\">\r\n  <tr> \r\n    <td><b><A HREF=\"LGENRE\" class=\"menub\">MGENRE</a> - <b>MCOUNT</b></td>\r\n  </tr>\r\n  <tr> \r\n    <td>MDESCR</td>\r\n  </tr>\r\n  <tr> \r\n    <td>&nbsp;</td>\r\n  </tr>\r\n</table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGallery','gallery','  <!- Gallery Listing -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Galleries Under MGENRE</td>\r\n    </tr>\r\n\r\n    <!- Image galleries -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Location:\r\n      <a href=\"LTYPE\">/</a>&nbsp;\r\n      <a href=\"LSUB\">MSUB/</a>\r\n      <a href=\"LGENRE\">MGENRE/</a>\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Functionality -->\r\n    <tr> \r\n     <!- Nav bar -->\r\n     <td class=\"fancy_sub\">\r\n      LSTNAV\r\n     </td>\r\n\r\n     <!- Sorting capabilities -->\r\n     <td class=\"fancy_sub\" align=\"right\">\r\n      <a href=\"LSNAME\" class=\"menub\">Name</a>\r\n      <a href=\"LSDATE\" class=\"menub\">Date</a>\r\n      <a href=\"LSRATE\" class=\"menub\">Rating</a>\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Gallery listing below -->\r\n    <tr>\r\n     <td colspan=\"2\">\r\nLSTGAL\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Additional Functionality -->\r\n    <tr>\r\n     <!- Nav bar -->\r\n     <td class=\"fancy_sub\">\r\n      LSTNAV\r\n     </td>\r\n\r\n     <!- Searching -->\r\n     <td class=\"fancy_sub\" align=\"right\">\r\n      <a href=\"LSEARCH\" class=\"menub\">Search</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n\r\n   <div class=\"fancy_help\">\r\n    <b>Quick Help</b><br><br>\r\n\r\n     Select a specific gallery within the MGENRE level.    Galleries can be\r\n     additionally sorted by Name, Date and Rating which will allow you to\r\n     quickly determine which galleries are the most popular or have been\r\n     updated recently.<br><br>\r\n\r\n     Please note that sorting by name will cause the galleries to be first\r\n     show which galleries have been recently updated.    Then older galleries\r\n     will be listed alphabetically.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalleryHighlight','gallery','          <td>\r\n           <!- Highighted image -->\r\n           <a href=\"MLINK\">\r\n            <img src=\"LTHUMB\" width=\"100\" height=\"100\"  align=\"middle\" alt=\"Highlighted work\" title=\"Highlighted work\" style=\"margin: 3px; border: 0;\">\r\n           </a>\r\n          </td>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGalleryList','gallery','      <!- MNAME Gallery -->\r\n      <div class=\"galwrap\" style=\"margin-bottom: 25px;\">\r\n\r\n        <!- Title, rating and authors -->\r\n        <div class=\"galhead\">\r\n         <a href=\"MLINK\" class=\"menub\">MNAME</a> (<i>MRATING</i>)\r\n         <b>By</b> MAUTHOR\r\n        </div>\r\n\r\n        <!- Centre management -->\r\n        <table width=\"98%\">\r\n         <tr>\r\n          <!- Highlighting -->\r\nMHLIGHT\r\n\r\n          <!- Description -->\r\n          <td>\r\n           MDESCR\r\n          </td>\r\n         </tr>\r\n        </table>\r\n\r\n        <!- Works, created and updated -->\r\n        <div class=\"galfoot\">\r\n          <b>Works:</b> MCOUNT  &#9702;\r\n          <b>Created:</b> MCREATED  &#9702;\r\n          <b>Updated:</b> MUPDATED\r\n        </div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGenreDescription','gallery','      <!- List item for MGENRE -->\r\n      <!- Spacer -->\r\n      <tr> \r\n        <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n      </tr>\r\n\r\n      <!- Name and Count -->\r\n      <tr> \r\n        <td class=\"fancy_blank\"><a href=\"LGENRE\" class=\"menub\">MGENRE</a></td>\r\n        <td class=\"fancy_blank\" align=\"right\"><b>Galleries:</b> MCOUNT</td>\r\n      </tr>\r\n\r\n      <!- Descriptor -->\r\n      <tr> \r\n        <td class=\"fancy_blank\" colspan=\"2\">MDESCR</td>\r\n      </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGenreSub','gallery','  <!- Genre Sub-Type Listing -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <!- Gallery Init -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">MSUB Genres</td>\r\n    </tr>\r\n\r\n    <!- Image galleries -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Location:\r\n      <a href=\"LTYPE\">/</a>&nbsp;\r\n      <a href=\"LSUB\">MSUB/</a>\r\n     </td>\r\n    </tr>\r\n\r\nLSTSUB\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Searching -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"right\"><a href=\"LSEARCH\" class=\"menub\">Search</a></td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n\r\n   <div class=\"fancy_help\">\r\n    <b>Quick Help</b><br><br>\r\n\r\n     Select a specific entry for MSUB and you will be presented with\r\n     a listing of all galleries pertaining to the desired style.<br><br>\r\n\r\n     Alternatively, you can opt to make use of the search option instead.\r\n     Simply click on the button located to the left in order to search for\r\n     specific works.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGenreType','gallery','  <!- Genre Type Listing -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <!- Gallery Init -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gallery Types</td>\r\n    </tr>\r\n\r\n    <!- Image galleries -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Image Galleries</td>\r\n    </tr>\r\n\r\nLSTIMAGE\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Text galleries -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Text Galleries</td>\r\n    </tr>\r\n\r\nLSTTEXT\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Searching -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"right\"><a href=\"LSEARCH\" class=\"menub\">Search</a></td>\r\n    </tr>\r\n\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n\r\n   <div class=\"fancy_help\">\r\n    <b>Quick Help</b><br><br>\r\n\r\n     Galleries are seperated in various types and sub-types.    In order to\r\n     narrow down your search for galleries and works, please select a type\r\n     which meets your interests.<br><br>\r\n     Alternatively, you can opt to make use of the search option instead.\r\n     Simply click on the button located to the left in order to search for\r\n     specific works.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplImageExif','gallery','         <!- EXIF camera information -->\r\n         <div class=\"erlight\">\r\n          <!- Title row -->\r\n          <div class=\"rowdark\" style=\"text-align: left;\">\r\n           <span class=\"white\" style=\"text-size: 10px;\">Camera Information</span>\r\n          </div>\r\n\r\n          <!- Information row -->\r\n          <div style=\"margin: 3px; text-align: left;\">\r\n           MEXIF\r\n          </div>\r\n         </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplImageIntro','gallery','      <!- MTITLE Gallery Introduction -->\r\n      <!- Wrapped in a div -->\r\n      <div class=\"erlight\" style=\"width: 98%;\">\r\n\r\n        <!- Title, rating and authors -->\r\n        <div class=\"galhead\" style=\"text-align: left;\">\r\n         <span class=\"stark\">\r\n          <b>MTITLE</b> (<i>MRATING</i>)\r\n          <b>By</b> MAUTHOR\r\n         </span>\r\n        </div>\r\n\r\n\r\n        <!- Centre management -->\r\n        <table width=\"98%\">\r\n         <tr>\r\n\r\n          <!- Image -->\r\n          <td>\r\n           <img src=\"MTHUMB\" height=\"150\" width=\"150\" alt=\"MHLIGHT\" title=\"MHLIGHT\" style=\"border: 0px; margin: 3px; vertical-align: middle;\">\r\n          </td>\r\n\r\n          <!- Description -->\r\n          <td>\r\n           MDESCR\r\n          </td>\r\n\r\n          <!- Watch -->\r\n          <td>\r\n           MWATCH\r\n          </td>\r\n\r\n         </tr>\r\n        </table>\r\n\r\n\r\n        <!- Footer -->\r\n        <div class=\"galfoot\" style=\"height: 12px;\">\r\n\r\n          <!- Genre -->\r\n          <span style=\"float: left;\">\r\n           <b>Genre:</b> MGENRE\r\n          </span>\r\n\r\n          <!- Created and updated -->\r\n          <span style=\"float: right;\">\r\n           <b>Created:</b> MCREATED  &#9702;\r\n           <b>Updated:</b> MUPDATED\r\n          </span>\r\n        </div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplImageLayer','gallery','<!- Image  layer entry -->\r\n<!- Nestled in an independant table -->\r\n<div style=\"float: left;\">\r\n <div class=\"MTYPE\" style=\"width: 160px; height: 190px;\">\r\n\r\n  <!- Layer name -->\r\n  <div class=\"rowdark\">\r\n   <a href=\"MLINK\">\r\n    <span class=\"white\" style=\"font-size: 10px\"><b>MNAME</b></span>\r\n   </a>\r\n  </div>\r\n\r\n  <!- Link, Target Window and Image -->\r\n  <div align=\"center\" valign=\"middle\">\r\n   <a href=\"MLINK\">\r\n    <img src=\"MIMAGE\" width=\"150\" height=\"150\" border=\"0\" alt=\"Layer MNAME\" title=\"Layer MNAME\">\r\n   </a>\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplImageList','gallery','<!- Image  work entry -->\r\n<!- Nestled in an independant table -->\r\n<div style=\"float: left;\">\r\n <div class=\"erblank\" style=\"width: 160px; height: 190px;\">\r\n\r\n  <!- Work name -->\r\n  <div class=\"rowdark\">\r\n   <a href=\"MLINK\" target=\"MWINDOW\">\r\n    <span class=\"white\" style=\"font-size: 10px\"><b>MNAME</b> MNEWNESS</span>\r\n   </a>\r\n  </div>\r\n\r\n\r\n  <!- Link, Target Window and Image -->\r\n  <div align=\"center\">\r\n   <a href=\"MLINK\" target=\"MWINDOW\">\r\n    <img src=\"MIMAGE\" width=\"MTHUMB\" height=\"MTHUMB\" border=\"0\" alt=\"MUPDATED (MRATING)\" title=\"MUPDATED  (MRATING)\">\r\n   </a>\r\n  </div>\r\n\r\n  <!- Demensions and size -->\r\n  <div align=\"center\">\r\n   MWIDTHxMHEIGHT MSIZEKB\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplImageWork','gallery','      <!- Work image display -->\r\n      <!- Wrap in a div -->\r\n      <div>\r\n\r\n\r\n       <!- Table will only take up what is necessary -->\r\n       <table>\r\n        <tr>\r\n         <td align=\"center\">\r\n          <!- Toggle ability -->\r\n          <a href=\"LTOGGLE\" class=\"menub\">MTOGGLE</a><br>\r\n\r\n          <!- Image area -->\r\n          <img src=\"LIMAGE\" MWDHT alt=\"MNAME\" title=\"MNAME\" style=\"margin: 5px;\">\r\n\r\n          <!- Additional fields -->\r\n          LSTEXIF\r\n         </td>\r\n        </tr>\r\n       </table>\r\n      </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplListingPri','gallery','<!- Work listing with all the fixings -->\r\n<!- Introduction -->\r\nMINTRO\r\n\r\n<!- Wrap in a table->\r\n<table style=\"width: 98%; border: 1px solid #E3F3FA;\">\r\n\r\n <!- Additional zones -->\r\n <tr>\r\n  <td valign=\"top\" rowspan=\"5\">\r\n   <!- News entries -->\r\nMNEWS\r\n\r\n   <!- Quick news -->\r\nMQUICK\r\n  </td>\r\n </tr>\r\n\r\n <!- Navigation ability -->\r\n <tr>\r\n  <td align=\"center\">  \r\n   MNAV MMAP\r\n  </td>\r\n </tr>\r\n\r\n <!- Listing of all works -->\r\n <tr>\r\n  <td>  \r\nLSTWORKS\r\n  </td>\r\n </tr>\r\n  \r\n <!- Navigation ability -->\r\n <tr>\r\n  <td align=\"center\">  \r\n   MNAV MMAP\r\n  </td>\r\n </tr>\r\n\r\n <!- Comment line -->\r\n <tr>\r\n  <td>  \r\nMCOMMENT\r\n  </td>\r\n </tr>\r\n</table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplListingSec','gallery','<!- Work listing with all the fixings -->\r\n<!- Intro Section -->\r\nMINTRO\r\n\r\n<!- Wrap in a table->\r\n<table style=\"width: 98%; border: 1px solid #E3F3FA;\">\r\n\r\n <!- Navigation ability -->\r\n <tr>\r\n  <td align=\"center\">\r\nMNAV MMAP\r\n  </td>\r\n </tr>\r\n   \r\n\r\n <!- Listing of all works -->\r\n <tr>\r\n  <td>\r\nLSTWORKS\r\n  </td>\r\n </tr>\r\n\r\n <!- Navigation ability -->\r\n <tr>\r\n  <td align=\"center\">\r\nMNAV MMAP\r\n  </td>\r\n </tr>\r\n</table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMain','gallery','<div class=\"ermain\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMap','gallery','  <!- Layer Map Display -->\r\n  <!- Layer listing ->\r\n  <div class=\"erlight\">\r\n   <!- Title -->\r\n   <div class=\"rowdark\">\r\n    MROOT Gallery Map!\r\n   </div>\r\n\r\n   <!- Map holder -->    \r\n   <div style=\"padding: 5px; color: #416F83; font-size: 12px; \">\r\n\r\n    <!- Make use of a unorderd list -->\r\n    <ul>\r\n     <li><a href=\"LROOT\" class=\"dark\"><b>MROOT</b></a></li>\r\n\r\n     <!- The root gallery will always be at the top-->\r\n     <ul>\r\nLSTMAP\r\n     </ul>\r\n    </ul>\r\n\r\n    Authors of galleries have the ability to divide their works into\r\n    various sub-galleries or layers.   The map located above\r\n    allows you to see every layer and how many works are located within.\r\n    Simply click on one of the links to move to that level.<br><br>\r\n\r\n    If at any time you need to reference this document.   Simply click\r\n    on the \'Map\' button located conviently on every page listing works\r\n    for you to view.<br><br>\r\n\r\n    <b>Note:</b>  If you only see one level available, then chances\r\n    are this author has not make use of layers to split up his or her\r\n    works!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMapStep','gallery','         <li><a href=\"MLINK\" class=\"dark\"><b>MNAME</b></a> (MCOUNT)</li>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMsg','gallery','<center>\r\n<table width=500 border=0 cellpadding=3 cellspacing=1 bgcolor=\"#E3F3FA\">\r\n                      <tr> \r\n                        <td height=29 bgcolor=\"#274F60\"><font class=stark><b><img src=\"/img/ero.gif\" width=\"31\" height=\"30\" align=\"absmiddle\">An \r\n                          Error Has Occured!</b></font> </td>\r\n                      </tr>\r\n                      <tr>\r\n                        <td bgcolor=\"#A9C5D1\">MMESSAGE </td>\r\n                      </tr>\r\n                    </table>\r\n</center>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQLinks','gallery','      <!- Quick links handling -->\r\n      <!- Wrapped in a div -->\r\n      <div class=\"erlight\" style=\"width: 200px; margin-top: 23px;\">\r\n\r\n        <!- Title -->\r\n        <div class=\"galhead\">\r\n         <b>Quick Links</b>\r\n        </div>\r\n\r\n        <!- Links entries -->\r\nLSTLINKS\r\n\r\n\r\n        <!- Footer and Expansion -->\r\n        <div class=\"galfoot\" style=\"height: 3px;\">\r\n         &nbsp;\r\n        </div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQLinksEntry','gallery','        <!- Listing -->\r\n        <div style=\"margin: 3px;\">\r\n         &#187; <a href=\"MLINK\" target=\"_blank\" class=\"dark\"><b>MNAME</b></a>\r\n        </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQNews','gallery','      <!- Quick news handling -->\r\n      <!- Wrapped in a div -->\r\n      <div class=\"erlight\" style=\"width: 200px;  margin-top: 23px;\">\r\n\r\n        <!- Title -->\r\n        <div class=\"galhead\">\r\n         <b>News &amp; Updates</b>\r\n        </div>\r\n\r\n        <!- News entries -->\r\nLSTNEWS\r\n\r\n\r\n        <!- Footer and Expansion -->\r\n        <div class=\"galfoot\" style=\"text-align: center;\">\r\n         <a href=\"LNEXP\" class=\"menub\">View All</a>\r\n        </div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplQNewsEntry','gallery','        <!- Listing -->\r\n        <div style=\"margin: 3px;\">\r\n         <!- Date stamp -->\r\n         <div>&#187; <b>MDATE:</b></div>\r\n\r\n         <!- News Entry -->\r\n         <div>MTEXT</div>\r\n\r\n         <!- Removal -->\r\n         MDELL\r\n\r\n         <!- Seperate one from the next ->\r\n         <hr style=\"width: 150px; color: #274F60;\">\r\n        </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSearch','gallery','<!- Main wrapper template -->\r\n<!- Wrap in a table -->\r\n<table style=\"width: 98%\">\r\n <tr>\r\n\r\n <!- Searching row -->\r\n  <td width=\"225\" valign=\"top\">\r\nMSEARCH\r\n  </td>\r\n\r\n  <!- Listing section -->\r\n  <td valign=\"top\">\r\nMBODY\r\n  </td>\r\n </tr>\r\n</table>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSearchBody','gallery','   <!- Body panel -->\r\n   <!- Wrap in a division -->\r\n   <div class=\"erblank\">\r\n\r\n    <!- Navigation bar -->\r\n    <div align=\"center\">\r\nMNAV\r\n    </div>\r\n\r\n\r\n    <!- Listing of works -->\r\n    <div>\r\nLSTWORKS\r\n    </div>\r\n\r\n\r\n    <!- Navigation bar -->\r\n    <div align=\"center\">\r\nMNAV\r\n    </div>\r\n   </div>\r\n\r\n   <!- Simple notice -->\r\n   <div align=\"center\">\r\n    <span class=\"copy\">Results limited to 100 returns</span>\r\n   </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSearchForm','gallery','   <!- Searching -->\r\n   <!- Wrapped within div -->\r\n   <div class=\"erlight\">\r\n\r\n    <!- Title section -->\r\n    <div class=\"rowdark\">\r\n     <span class=\"stark\"><b>Find Works</b></span>\r\n    </div>\r\n\r\n    <!- Genre selection -->\r\n    <div class=\"fancy_blank\">\r\n     <b>Genre &#187;</b> <br>\r\n     WGENRE\r\n    </div>\r\n\r\n    <!- Searching text -->\r\n    <div class=\"fancy_blank\">\r\n     <b>Keywords &#187;</b> <br>\r\n     WTEXT\r\n    </div>\r\n\r\n    <!- Submit button --> \r\n    <div class=\"fancy_blank\" style=\"text-align: right;\"> \r\n     WSEARCH\r\n    </div>\r\n\r\n    <!- Horizontal row -->\r\n    <hr>\r\n\r\n    <!- Quick description -->\r\n    <div class=\"fancy_blank\">\r\n    Select keywords and genres you wish to search through.   The site\r\n    will return a list of appropriate entries ranked by matches and\r\n    then ranked based on the amount of times the keywords appear.\r\n    <br><br>\r\n    Please note that searching through genres which have no indexed\r\n    works will result in an empty return set.    Also note that\r\n    searching through the root genres will results in a search\r\n    through all sub-genres as well for a greater scope!\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSearchNotice','gallery','   <!- Notice panel -->\r\n   <!- Wrap in a div -->\r\n   <div class=\"erblank\" style=\"height: 400px; width: 400px; vertical-align: middle; text-align: center;\">\r\n    MMESSAGE\r\n   </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSrch','gallery','<br>\r\n<table width=500 border=0 cellspacing=0 cellpadding=0>\r\n <tr>\r\n  <td align=\"center\">\r\n   MMESSAGE\r\n  </td>\r\n </tr>\r\n</table>\r\n<br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSub','gallery','<div class=\"ersub\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTextIntro','gallery','      <!- MTITLE Gallery Introduction -->\r\n      <!- Wrapped in a div -->\r\n      <div class=\"erlight\" style=\"width: 98%;\" align=\"center\">\r\n\r\n        <!- Title, rating and authors -->\r\n        <div class=\"galhead\" style=\"text-align: left;\">\r\n         <span class=\"stark\">\r\n          <b>MTITLE</b> (<i>MRATING</i>)\r\n          <b>By</b> MAUTHOR\r\n         </span>\r\n        </div>\r\n\r\n\r\n        <!- Centre management -->\r\n        <div style=\"padding: 5px;\">\r\n         <table width=\"95%\">\r\n          <tr>\r\n\r\n           <!- Description -->\r\n           <td valign=\"middle\">\r\n            MDESCR\r\n           </td>\r\n\r\n           <!- Watching -->\r\n           <td>\r\n             MWATCH\r\n           </td>          \r\n          </tr>\r\n         </table>\r\n        </div>\r\n\r\n        <!- Footer -->\r\n        <div class=\"galfoot\" style=\"height: 12px;\">\r\n\r\n          <!- Genre -->\r\n          <span style=\"float: left;\">\r\n           <b>Genre:</b> MGENRE\r\n          </span>\r\n\r\n          <!- Created and updated -->\r\n          <span style=\"float: right;\">\r\n           <b>Created:</b> MCREATED  &#9702;\r\n           <b>Updated:</b> MUPDATED\r\n          </span>\r\n        </div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTextLayer','gallery','<!- Layer Link for MLAYER -->\r\n<!- A simple link for simple measures -->\r\n<a href=\"MLINK\" class=\"MTYPE\">MNAME</a>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTextList','gallery','<!- Text  work entry -->\r\n<!- Nested for management -->\r\n<div class=\"erblank\" style=\"margin-bottom: 25px;\">\r\n\r\n <!- Work name -->\r\n <div class=\"galhead\">\r\n  <span class=\"white\" style=\"font-size: 10px\">\r\n   <a href=\"MLINK\" target=\"MWINDOW\" class=\"menub\" onclick=\'window.open(this.href,this.target,settings); return false;\'><b>MNAME</b></a> MNEWNESS\r\n  </span>\r\n </div>\r\n\r\n <!- Description -->\r\n <div style=\"margin: 10px;\">\r\n   MDESCR\r\n </div>\r\n\r\n <!- Length and Updated -->\r\n <div class=\"galfoot\" style=\"height: 12px;\">\r\n  <span style=\"float: left;\"><b>Characters:</b> MLENGTH</span>\r\n  <span style=\"float: right;\"><b>Updated:</b> MUPDATED</span>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTextWork','gallery','      <!- Work text display -->\r\n      <table width=\"80%\" border=0 align=\"center\" cellpadding=10 cellspacing=2 bgcolor=\"#274F60\">\r\n       <tr> \r\n\r\n        <!- Display text work -->\r\n        <td align=\"justify\" bgcolor=\"#A9C5D1\">MTEXT</td>\r\n\r\n        <!- Additional features -->\r\n        <td width=\"75\" valign=\"top\" bgcolor=\"#274F60\" align=\"center\">\r\n         <!- Display Revisions -->\r\n         MREVS\r\n\r\n         <!- Allow to print document>\r\n         MPRINT\r\n       </td>\r\n      </tr>\r\n     </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTitle','gallery','<div class=\"ertitle\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVotes','gallery','<b>Rated:</b> MRATINGS &#9702;  <b>Votes:</b> MOLVOTES\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWork','gallery','      <!- Work Display -->\r\n      <!- Wrapped in a div -->\r\n      <div class=\"erlight\">\r\n\r\n        <!- Work name and authors -->\r\n        <div class=\"galhead\">\r\n         <span class=\"stark\">\r\n          MNAME<br>\r\n          By<br>\r\n          MAUTHOR\r\n         </span>\r\n        </div>\r\n\r\n\r\n        <!- Centre management -->\r\n        <div align=\"center\">\r\n\r\n         <!- Table cheat -->\r\n         <table width=\"95%\">\r\n          <tr>\r\n\r\n           <!- Left Prev -->\r\n           <td>\r\n            <a href=\"LPREV\"><img src=\"/img/bck.gif\" width=\"30\" height=\"26\" border=\"0\"></a>\r\n           </td>\r\n\r\n           <!- Description -->\r\n           <td valign=\"middle\" align=\"center\">\r\n            MDESC\r\n           </td>\r\n\r\n\r\n           <!- Left Next -->\r\n           <td align=\"right\">\r\n            <a href=\"LNEXT\"><img src=\"/img/fwd.gif\" width=\"30\" height=\"26\" border=\"0\"></a>\r\n           </td>\r\n          </tr>\r\n         </table>\r\n        </div>\r\n\r\n        <!- Footer -->\r\n        <div class=\"galfoot\" style=\"height: 12px;\">\r\n\r\n          <!- Genre -->\r\n          <span style=\"float: left; padding: 3px;\">\r\n           <b>MCURR of MTOTAL</b>\r\n          </span>\r\n\r\n          <!- Created and updated -->\r\n          <span style=\"float: right;\">\r\n           <a href=\"LGTOP\" class=\"menub\" target=\"_new\">Return to Gallery</a>\r\n          </span>\r\n        </div>\r\n      </div>\r\n\r\n      <!- Body section -->\r\n      <div class=\"erblank\">\r\n       <!-Work display -->\r\nMWORK\r\n\r\n       <!- Comment display -->\r\nMCOMMENT\r\n      </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWriter','gallery','  <!- Comment Composition -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Init -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\">Write or Comment!</td>\r\n    </tr>\r\n\r\n\r\n    <!- Puppet selection -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">Select a Handle Below?</td> \r\n    </tr>\r\n\r\n    <!- Selection wiget -->\r\n    <tr>\r\n     <td class=\"fancy_blank\">WPUPPET</td> \r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Allow ratings -->\r\nMRATE\r\n\r\n    <!- Allow comments -->\r\nMCOMMENT\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Submission button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <table class=\"fancy_help\">\r\n    <tr>\r\n     <td>\r\n      <!- Quick help text -->\r\n       <b>Quick Help</b><br><br>\r\n\r\n       Comments allow you to leave a message or a rating to the work\r\n       or gallery based on the preference of the author.   If you leave\r\n       the comment field blank only the rating will be recorded\r\n       anonymously.On the other hand, leaving ratings blank will simply\r\n\r\n       record the comment and not change the users score in any way.\r\n     </td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWriterComment','gallery','    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\">&nbsp;</td>\r\n    </tr>\r\n\r\n\r\n    <!- Comment on Work -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">Would you Care to Leave a Comment?</td> \r\n    </tr>\r\n\r\n    <!- Selection wiget -->\r\n    <tr>\r\n     <td class=\"fancy_blank\">WCOMMENT</td> \r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWriterRate','gallery','    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <!- Rate a work -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">How Would you Rate This?</td> \r\n    </tr>\r\n\r\n    <!- Selection wiget -->\r\n    <tr>\r\n     <td class=\"fancy_blank\">WRATING</td> \r\n    </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtAbstain','gallery','--');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDescription','gallery','&nbsp;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtFirst','gallery','<<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtLast','gallery','>>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMap','gallery','Map');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNext','gallery','>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPost','gallery','Comment');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPrev','gallery','<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRate','gallery','Rate');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRecent','gallery','Most Recent');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSearch','gallery','Search');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDisplay','gummy','3');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagListOff','gummy','      </ul>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagListOn','gummy','      <ul>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagListPri','gummy','      <li><a href=\" MLINK\" class=\"menua\">MCLASS</a></li>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagListSec','gummy','       <li><a href=\" MLINK\" class=\"menua\">MIDENT</a></li>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplColBlank','gummy','        <!- This space left blank -->\r\n        <td colspan=\"3\"></td>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplColFilled','gummy','        <!- MNAME Gummy -->\r\n        <td width=\"20\">&nbsp;</td>\r\n        <td width=\"35\"><img src=\"MPATH\"></td>\r\n        <td><b>MNAME</b></td>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPage','gummy','  <!- Homepage Feature -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\" style=\"width: 100%;\">\r\n\r\n   <!- Homepages -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\" style=\"width: 600px;\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Gummy Browser</td>\r\n    </tr>\r\n\r\n    <!- Sub title and message -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Gummies Available Listed Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Listing of all gummies -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">\r\n      <table width=\"100%\">\r\nLSTGUMMY\r\n      </table>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help and Select</b><br><br>\r\n\r\n     Gummies are used to add an additional touch to posts and other comments made\r\n     on various aspects of Ethereal Realms.   Various options and styles are\r\n     available to you and can be selected from the list of genres below.<br><br>\r\n\r\n     Please note that contributor gummies are not available to all users.  These\r\n     are most often granted to those who have donated to the site or have been\r\n     verified as being adults.<br><br>\r\n\r\n     <!- Listing of all groups -->\r\n     <ul>\r\nLSTCLASS\r\n     </ul>\r\n\r\nMWARNING\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRow','gummy','       <!- Begin row -->\r\n       <tr>\r\nMROWS\r\n       </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWarning','gummy','     <!-- Warning Message -->\r\n     These specific gummies listed  can be injected into various parts of the\r\n     site.  Simply use the names below and the system will replace them with\r\n     the corresponding images.\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRoot','gummy','Main');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrLogin','login','<center><b>[Invalid username or bad password]</b></center>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkPortal','login','/erealms/portal.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAreaGeneral','login','Welcome to Ethereal Realms!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagAreaRestricted','login','You have entered a restricted area');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAuth','login','<!- Site Authentication -->\r\n<div>\r\n <!- Useful buttons ->\r\n <a href=\"/erealms/registration.pl\" class=\"menua\">&#187; Sign Up</a>&nbsp;&nbsp;\r\n <a href=\"/erealms/reset.pl\" class=\"menua\">&#187; Lost Password</a>\r\n <br><br>\r\n\r\n <!- Safety Proceedure -->\r\n MSCRPT\r\n\r\n <!- Outer border -->\r\n <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n  <!- Title field -->\r\n  <div class=\"rowdark\">MTITLE</div>\r\n\r\n  <!- Wrapper Table -->\r\n  <div class=\"erlight\" style=\"width: auto;\">\r\n   <!- Potential Error Message - Add additional formatting in Error Tag->\r\n   MERROR\r\n\r\n   <!- Work Table -->\r\n   <table width=\"98%\">\r\n\r\n    <!- Username -->\r\n    <tr>\r\n     <td><b>Login Name</b></td>\r\n     <td>WUSER</td>\r\n    </tr>\r\n\r\n    <!- Password -->\r\n    <tr>\r\n     <td><b>Password</b></td>\r\n     <td>WPASS</td>\r\n    </tr>\r\n\r\n    <!- Long term cookie -->\r\n    <tr>\r\n     <td>&nbsp;</td>\r\n     <td>WRECL Sign me in automatically.</td>\r\n    </tr>\r\n    <tr>\r\n     <td colspan=\"2\"><hr></td>\r\n    </tr>\r\n\r\n    <!- String based authentication -->\r\n    <tr>\r\n     <td colspan=\"2\">WSECR Disable session-based cookies.<br>(Only use this if your browser cannot support them)</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" height=\"10\">&nbsp;</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td colspan=\"2\" align=\"right\">WAUTH</td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitButton','login','Login');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBio','mail','/erealms/bio.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPriColor','mail','MCOLOR');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSecColor','mail','MCOLOR');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagIntEmpty','mail','<div align=\"center\">There are no internal messages!</div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMailDel','mail','<img src=\"/img/r_off.gif\" border=\"0\"  alt=\"Deleted\" title=\"Deleted\" style=\"margin-top: 2px;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMailRead','mail','<img src=\"/img/r_off.gif\" border=\"0\"  alt=\"Read\" title=\"Read\" style=\"margin-top: 2px;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMailSent','mail','<b>Message was sent</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMailUndel','mail','<img src=\"/img/r_on.gif\" border=\"0\" alt=\"Not Deleted\" title=\"Not Deleted\"  style=\"margin-top: 2px;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMailUnread','mail','<img src=\"/img/r_on.gif\" border=\"0\" alt=\"Unread\" title=\"Unread\"  style=\"margin-top: 2px;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMessEmpty','mail','<div align=\"center\">There are no user messages!</div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAttach','mail','    <!- Subject views to pure evil -->\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">User has included images with the message</td>\r\n    </tr>\r\n\r\n    <!- Vanity Shots -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\" align=\"left\">\r\nLSTATTACH   \r\n     </td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAttachList','mail','  <!- Vanity Images Attached -->\r\n  <!- Nestled in an independant table -->\r\n  <div style=\"float: left; margin: 5px;\">\r\n    <!- Link, Target Window and Image -->\r\n    <img src=\"LPATH\" width=\"MWIDTH\" height=\"MHEIGHT\" border=\"0\" alt=\"No. MID\" title=\"No. MID\">\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplCompose','mail','  <!- Mail Composition -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Compose a Message</td>\r\n    </tr>\r\n\r\n    <!- Basic Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Fill in Basics Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Subject -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Subject?</td>\r\n     <td class=\"fancy_blank\">WMSUBJ</td>\r\n    </tr>\r\n\r\n    <!- Message Originator -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">From?</td>\r\n     <td class=\"fancy_blank\">WCHARS</td>\r\n    </tr>\r\n\r\n    <!- Message Destination -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Send To?</td>\r\n     <td class=\"fancy_blank\">WMRCPT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Message Body-->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Message Body</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WMBODY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Possible addition of vanities -->\r\nMVAIN\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submit icons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WMSBMT</td>\r\n     <td class=\"fancy_blank\">WMRSET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"left\">\r\n      <a href=\"LBACK\" class=\"menub\">Return to Listing</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n   \r\n   <!- Original message content -->\r\nMORIG\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Messages can be sent to back and forth to other members of Ethereal Realms.\r\n     Simply fill in the fields on the right and send off, the user will either\r\n     be directly notified through an Email or will notice the new message when\r\n     (s)he returns to the Gateway.<br><br>\r\n\r\n     You can also inject gummies into the posts.    For a list of gummies and\r\n     the proper combination to use to make them appear click on\r\n     <a href=\"/erealms/gummies/inject/\" class=\"dark\" target=\"_new\">this</a>\r\n     link to browse the current list!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplInbox','mail','  <!- Mail Viewer Internal -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Inbox</td>\r\n    </tr>\r\n\r\n    <!- User messages and total -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">User to user messages</td>\r\n     <td class=\"fancy_follow\" align=\"right\">Total: MMTOTAL</td>\r\n    </tr>\r\n\r\n\r\n    <!- List all Mail -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">\r\nLSTMAIL\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- System Noices and Total Messages-->\r\n    <tr>\r\n     <td class=\"fancy_sub\">System Notices</td>\r\n     <td class=\"fancy_sub\" align=\"right\">Total: MITOTAL</td>\r\n    </tr>\r\n\r\n    <!- List Internal Messages -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">\r\nLSTINT\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Remove Ability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\" align=\"right\">WDELE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" align=\"left\">\r\n      <a href=\"LMCOMP\" class=\"menub\">Compose a Message</a>\r\n      <a href=\"LRLOAD\" class=\"menub\">Inbox</a>\r\n      <a href=\"LSWITCH\" class=\"menub\">Sent-Mail</a>\r\n     </td>\r\n\r\n     <!- Notice if mail was sent -->\r\n     <td class=\"fancy_sub\" align=\"right\">[MMSENT]</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This view provides you with the capability to see any and all messages\r\n     which are currently in your Inbox.    These messages are split into two\r\n     groups, the first being for User to User messages and can be replied to\r\n     directly to pursue a thread.<br><br>\r\n\r\n     There are also Internal Notices which are messages that would have\r\n     normally been Emailed to you.   If you preffer Email to this method, please\r\n     check your settings in the User Details section of the Gateway.<br><br>\r\n\r\n     Please also note that mail will expire in time.  Currently this delay is\r\n     set at 30 days.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplIncoming','mail','      <!- User to User Message Line -->\r\n      <!- Use MCOLOR and TagPriColor to alternate rows through various means -->\r\n      <div style=\"height: 20px\">\r\n\r\n       <!- Subject line -->\r\n       <div style=\"width: 200px; float: left; margin-top: 2px;\"><a href=\"LMLINK\" class=\"dark\"><b>MMSUBJ</b></a></div>\r\n\r\n       <!- Originator -->\r\n       <div style=\"width: 150px; float: left; margin-top: 2px;\"><a href=\"LCHBIO\" target=\"_new\" class=\"dark\"><b>MMFROM</b></a></div>\r\n\r\n       <!- Read notice -->\r\n       <div style=\"width: 15px; float: left; margin-top: 2px;\">MMREAD</div>\r\n\r\n       <!- Time message sent -->\r\n       <div style=\"width: 75px; float: left; margin-top: 2px;\"><span class=\"white\">MMTIME</span></div>\r\n\r\n       <!- Remove Message -->\r\n       <div style=\"float: right;\">WDELE</div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplInternal','mail','      <!- Internal Message Line -->\r\n      <!- Use MCOLOR and TagPriColor to alternate rows through various means -->\r\n      <div style=\"height: 20px\">\r\n\r\n       <!- Subject line -->\r\n       <div style=\"width: 350px; float: left; margin-top: 2px;\"><a href=\"LMLINK\" class=\"dark\"><b>MMSUBJ</b></a></div>\r\n\r\n       <!- Read notice -->\r\n       <div style=\"width: 15px; float: left; margin-top: 2px;\">MMREAD</div>\r\n\r\n       <!- Time message sent -->\r\n       <div style=\"width: 75px; float: left; margin-top: 2px;\"><span class=\"white\">MMTIME</span></div>\r\n\r\n       <!- Remove Message -->\r\n       <div style=\"float: right;\">WDELE</div>\r\n      </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMain','mail','<div class=\"ermain\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOriginal','mail','   <!- Original message content -->\r\n   <!- Title-->\r\n   <table class=\"fancy\" cellspacing=\"0\" style=\"margin-top: 45px;\">\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Original Message</td>\r\n    </tr>\r\n\r\n    <!- Clarification -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Body of original message below for reference</td>\r\n     <td class=\"fancy_follow\" align=\"right\">WATTACH</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\">MBODY</td>\r\n    </tr>\r\n\r\n    <!- Clarification -->\r\n    <tr> \r\n     <td class=\"fancy_sub\">Body of original message above for reference</td>\r\n     <td class=\"fancy_sub\" align=\"right\">WATTACH</td>\r\n    </tr>\r\n   </table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOutbox','mail','  <!- Mail Viewer Internal -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Sent-Mail</td>\r\n    </tr>\r\n\r\n    <!- User messages and total -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">User to user Messages</td>\r\n     <td class=\"fancy_follow\" align=\"right\">Total: MMTOTAL</td>\r\n    </tr>\r\n\r\n\r\n    <!- List all Mail -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">\r\nLSTMAIL\r\n     </td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Remove Ability -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\" align=\"right\">WDELE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" align=\"left\">\r\n      <a href=\"LMCOMP\" class=\"menub\">Compose a Message</a>\r\n      <a href=\"LSWITCH\" class=\"menub\">Inbox</a>\r\n      <a href=\"LRLOAD\" class=\"menub\">Sent-Mail</a>\r\n     </td>\r\n\r\n     <!- Notice if mail was sent -->\r\n     <td class=\"fancy_sub\" align=\"right\">[MMSENT]</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This view provides you with the ability to see an archive of all\r\n     messages which you have sent.    It also allows you to see if the\r\n     recipient of your message has read the message and removed it from\r\n     their inbox.<br><br>\r\n\r\n     Please also note that mail will expire in time.  Currently this delay is\r\n     set at 30 days and applies to your sent messages as well.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplOutgoing','mail','      <!- User to User Message Line -->\r\n      <!- Use MCOLOR and TagPriColor to alternate rows through various means -->\r\n      <div style=\"height: 20px\">\r\n\r\n       <!- Subject line -->\r\n       <div style=\"width: 200px; float: left; margin-top: 2px;\"><a href=\"LMLINK\" class=\"dark\"><b>MMSUBJ</b></a></div>\r\n\r\n       <!- Originator -->\r\n       <div style=\"width: 150px; float: left; margin-top: 2px;\"><a href=\"LCHBIO\" target=\"_new\" class=\"dark\"><b>MMRCPT</b></a></div>\r\n\r\n       <!- Read notice -->\r\n       <div style=\"width: 15px; float: left; margin-top: 2px;\">MMREAD</div>\r\n\r\n       <!- Removed notice -->\r\n       <div style=\"width: 15px; float: left; margin-top: 2px;\">MMDEL</div>\r\n\r\n       <!- Time message sent -->\r\n       <div style=\"width: 75px; float: left; margin-top: 2px;\"><span class=\"white\">MMTIME</span></div>\r\n\r\n       <!- Remove Message -->\r\n       <div style=\"float: right;\">WDELE</div>\r\n      </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplReply','mail','  <!- Mail Reply -->\r\n  <!- Spacer -->\r\n  <br><br>\r\n\r\n  <!- Wrapper Div -->\r\n  <div style=\"margin-left: 15px;\">\r\n\r\n   <!- Basic header -->\r\n   <b>MFROM wrote on MDATE:</b><br>\r\n\r\n   <!- Original message contents -->\r\n   <!- May contain more of these replies -->\r\n   MREPLY<br>\r\n   ---\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSub','mail','<div class=\"ersub\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanity','mail','    <!- Vanity thy favourite sin -->\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Include pictures with the Email?</td>\r\n    </tr>\r\n\r\n    <!- Vanity Shots -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\" align=\"left\">\r\nLSTVANITY      \r\n     </td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityList','mail','<!- Vanity Image Selection -->\r\n<!- Nestled in an independant table -->\r\n<div style=\"float: left;\">\r\n <div class=\"erblank\" style=\"width: 105px; height: 130px;\">\r\n\r\n  <!- Link, Target Window and Image -->\r\n  <div align=\"center\" valign=\"middle\" style=\"height: 105px; width: 105px;\">\r\n    <img src=\"LVANITY\" border=\"0\" alt=\"No. MID\" title=\"No. MID\">\r\n  </div>\r\n\r\n  <!- Demensions and size -->\r\n  <div align=\"center\">\r\n   WVANITY\r\n  </div>\r\n </div>\r\n</div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplViewer','mail','  <!- Mail Viewer User to user -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Viewing Message from MMFROM</td>\r\n    </tr>\r\n\r\n    <!- Basic Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Header Details Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Subject -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Subject?</td>\r\n     <td class=\"fancy_blank\">MMSUBJ</td>\r\n    </tr>\r\n\r\n    <!- Message Originator -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">From?</td>\r\n     <td class=\"fancy_blank\">MMFROM</td>\r\n    </tr>\r\n\r\n    <!- Message Destination -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Send To?</td>\r\n     <td class=\"fancy_blank\">MMRCPT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Message Body-->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Message Contents</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">MMBODY</td>\r\n    </tr>\r\n\r\n\r\n   <!- Vain attempt at attachment ->\r\nMVAIN\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submit icons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WMREPL</td>\r\n     <td class=\"fancy_blank\">WMDELE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"left\">\r\n      <a href=\"LBACK\" class=\"menub\">Return to Listing</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This message has been sent by another individual.   If you wish to reply, please\r\n     do so and this message will be appended for reference reasons.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplViewerInt','mail','  <!- Mail Viewer Internal -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery Details - Layers -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Viewing an Internal Message</td>\r\n    </tr>\r\n\r\n    <!- Basic Options -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Header Details Below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Subject -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Subject?</td>\r\n     <td class=\"fancy_blank\">MMSUBJ</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Message Body-->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Message Contents</td>\r\n    </tr>\r\n\r\n    <!- highlight field -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">MMBODY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submit icons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WMDELE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"left\">\r\n      <a href=\"LBACK\" class=\"menub\">Return to Listing</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This message has been sent by Ethereal Realms as a notice.    The contents\r\n     are for reference only and cannot be replied to.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMailDelete','mail','Delete');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMailInvalid','mail','Invalid recipient');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMailReply','mail','Reply');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMailReset','mail','Clear');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMailSend','mail','Send');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubject','mail','(No Subject)');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkVote','poll','http://www.ethereal-realms.org/erealms/poll.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgInvalid','poll','The vote you have placed, is using an option that is not available in that poll.   Please try voting again using normal means.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgMissing','poll','This poll does not exist or has not been specified.  It may have been removed from the system or information is missing to continue.   Please try again using normal means.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgVote','poll','Your vote has been submitted!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplGenerate','poll','  <!- Ethereal Realms Polling -->\r\n  <!- Form -->\r\n  WSTARTFORM\r\n\r\n  <!- Wrapper div -->\r\n  <div align=\"center\">\r\n\r\n   <!- Poll table -->\r\n   <table class=\"POLLHEAD\" style=\"width: 150px;\">\r\n\r\n    <!- Header -->\r\n    <tr class=\"POLLNAME\">\r\n     <td>MNAME</td>\r\n    </tr>\r\n \r\n    <!- Body -->\r\n    <tr class=\"POLLBODY\">\r\n     <td>\r\n      <!- Question itself -->\r\n      MQUESTION<br><br>\r\n\r\n      <!- Widget -->\r\n      WOPTIONS<br>\r\n\r\n      <!- Submission -->\r\n      <div align=\"center\">\r\n       <!- Voting -->\r\n       WVOTE<br>\r\n\r\n       <!- Results list -->\r\n       <a href=\"LRESULTS\" target=\"blank\" class=\"POLL\">Results</a>\r\n      </div>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n  </div>\r\n\r\n  <!- End Form -->\r\n  WENDFORM\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMsg','poll','  <!- Error in Poll -->\r\n  <!- Outer border -->\r\n  <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n   <!- Title field -->\r\n   <div class=\"rowdark\">An Error Has Occured!</div>\r\n\r\n   <!- Wrapper Table -->\r\n   <div class=\"erlight\" style=\"width: auto; text-align: left;\">\r\n    MMESSAGE\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPoll','poll','  <!- Ethereal Realms Polling -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Ethereal Realms Polling -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">MTITLE</td>\r\n    </tr>\r\n\r\n    <!- More defined question -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">MQUESTION</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Full results list -->\r\nLSTRESULTS\r\n\r\n\r\n    <!- Final status -->\r\n    <tr>\r\n     <td class=\"fancy_sub\">MTOTAL Total Votes</td>\r\n     <td class=\"fancy_sub\" align=\"right\">[MNOTICE]</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick Help -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n    <b>Quick Help</b><br><br>\r\n\r\n     Don\'t complain about lack of options. You\'ve got to pick a few\r\n     when you do multiple choice. Those are the breaks.<br><br>\r\n\r\n     This whole thing is wildly inaccurate. Rounding errors, ballot\r\n     stuffers, dynamic IPs, firewalls. If you\'re using these numbers\r\n     to do anything important, you\'re insane.\r\n    </ul>\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplResult','poll','    <!- Results option - OPTION -->\r\n    <tr>\r\n\r\n     <!- Options list -->\r\n     <td class=\"fancy_Descr\">\r\n      MOPTION\r\n     </td>\r\n\r\n     <!- Results bar and percentages -->\r\n     <td class=\"fancy_blank\" valign=\"middle\">\r\n      <div class=\"ertitle\" style=\"width: MSPACERpx;\">&nbsp;</div> MVOTES votes / MPERCENT%\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtVote','poll','Submit Vote');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBio','portal','/erealms/bio.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBoard','portal','/erealms/board');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkForum','portal','/erealms/board/system');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkNews','portal','/erealms/weblog.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkQuickLink','portal','http://www.ethereal-realms.org/erealms/go');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLnkGen','portal','<a MLINK class=\"menub\">MTITLE</a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNewness','portal','<b>NEW!</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNewsNIL','portal','There are no recent news items to display<br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmError','portal','<tr><td colspan=\"2\">[MNAME]</td></tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmForum','portal','<A HREF=\"MLINK\" target=\"_blank\"><img src=/img/fm.gif border=\"0\" alt=\"Realm Forum\" title=\"Realm Forum\"></A>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHomeExists','portal','<A HREF=\"MLINK\" target=\"_blank\"><img src=/img/hp.gif border=\"0\" alt=\"Realm Homepage\" title=\"Realm Homepage\"></A>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmHomeMissing','portal','  ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmPublic','portal','&nbsp;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagRealmVerified','portal','<img src=\"/img/tk.gif\" border=\"0\" alt=\"This is a verified realm\" title=\"This is a verified realm\" align=\"absmiddle\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplAdminSect','portal','      <!- Administrative Section -->\r\n      <a href=\"/erealms/admin/system.plGENPARAM\" class=\"menub\" target=\"GenSystem\">System</a>\r\n      <a href=\"/erealms/admin/swho.plGENPARAM\" class=\"menub\" target=\"GenSWho\" GENJSCODE>System Who</a>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplForumItem','portal','            <a href=\"LTOPIC\" target=\"MTOPIC\" LJSTGT><b>MTOPIC</b></a> (MPOSTS)<br>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplNewsItem','portal','      <!- News Item MTITLE -->\r\n      <b>Title:</b> <a class=\"white\" href=LTOPC>[MTOPIC]</a> <a class=\"white\" href=LPOST target=_new>MTITLE</a><br>\r\n      <b>By:</b> <a class=\"white\" href=LBIO target=_new>MNAME</a> on <font class=\"date\">MDATE</font><br><br>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPuppetItem','portal','WPUPPET');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPuppetTitle','portal','<b>MNAME</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmDescription','portal','          <!- Display description and initiate -->\r\n          <script language=\"Javascript\">\r\n           <!--\r\n\r\n            // Legacy method\r\n            // returnWidget();\r\n\r\n            // Direct method\r\n            document.write(\'<div align=\"center\" style=\"margin-bottom: 20px;\"><table><tr><td class=\"JSDESCR\"><layer id=\"legacy\" style=\"color: #FFFFFF;\"></layer><div id=\"modern\" style=\"color: #FFFFFF;\"></div></td></tr></table></div>\');\r\n\r\n            // Select the first realm\r\n            activateWidget();\r\n           // -->\r\n          </script>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmItem','portal','             <tr>\r\n              <td width=\"15\" align=\"center\"  valign=\"middle\" bgcolor=\"#5C8799\"><img src=\"/img/r_off.gif\" CSSID></td>\r\n              <td bgcolor=\"#5C8799\" valign=\"middle\">JLNKO<b>MNAME</b>JLNKC&nbsp; MVERI</td>\r\n              <td width=\"45\" align=\"center\" bgcolor=\"#5C8799\">MGENR</td>\r\n              <td width=\"30\" align=\"center\" bgcolor=\"#A9C5D1\"><font class=\"white\">MRATE</font></td>\r\n              <td width=\"20\" align=\"center\" bgcolor=\"#A9C5D1\">MHOME</td>\r\n              <td width=\"20\" align=\"center\" bgcolor=\"#A9C5D1\">MFORM</td>\r\n              <td width=\"20\" align=\"center\" bgcolor=\"#A9C5D1\">MPERS</td>\r\n             </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmModern','portal','            <!- Hidden field for JS use -->\r\n            WHIDDEN\r\n\r\n            <!- Display of modern realm items -->\r\n            <script  language=\"Javascript\">\r\n             <!-- \r\n              // Display complete widget\r\n              document.write(\'<table width=\"360\" border=\"0\" align=\"center\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#E3F3FA\">\');\r\nLSTMODERN\r\n\r\n              document.write(\'</table>\');\r\n             // -->\r\n            </script>\r\n\r\n\r\n            <!- Display of legacy realm items -->\r\n            <noscript>\r\nLSTORIGINAL\r\n\r\n             <div align=\"center\">[Javascript is not enabled in your browser, please login with Javascript disabled]</div>   \r\n            </noscript>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRealmSelect','portal','              // MNAME\r\n              document.write(\'MROWS\');');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplStatic','portal','  <!- Static Realm Page Handling -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Realms Listing -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Realm Listing</td>\r\n    </tr>\r\n\r\n\r\n    <!- Layer Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Listing of Webring Participating Realms Below</td>\r\n    </tr>\r\n\r\n    <!- Layer Listing -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">\r\n      For ease of management only realms which are members of the webring are included\r\n      in this list.   This allows any realm listed to be link one realm to the other\r\n      without leaving any gaps in the ring.\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- List all realms -->\r\nLSTREALMS\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <!- List all links -->\r\nLSTLINKS\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Please note that not all realms are on this list, private realms for example will \r\n     not be listed as they have no permanent existence on the site.    Certain public \r\n     realms will also not be listed as they may not wish to be part of the webring \r\n     group or simply not have a homepage yet to link their users to.<br><br>\r\n\r\n     Also note, that in some cases a realm may appear on this list that you cannot\r\n     access directly.   In the case of an adult realm, you would need to be verified\r\n     as an adult before being able to continue.    In addition, certain realms are\r\n     called hybrids having the capabilities of a public realm, but remain unlisted\r\n     from the Gateway.    These can be entered by typing in their name explicitly \r\n     as a Private Realm.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplStaticGenre','portal','    <!- Genre titles -->\r\n    <!- Addition Section-->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\"><a MANCHOR></a>MTITLE</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplStaticListing','portal','    <!- Realm Listing - MTITLE -->\r\n    <tr> \r\n     <!- Realm Name and Rating -->\r\n     <td class=\"fancy_blank\">\r\n      <a href=\"MLINK\" target=\"_new\" class=\"white\"><b>MTITLE</b></a> (MRATING)\r\n     </td>\r\n\r\n     <!- Homepage, forums and realm links -->\r\n     <td class=\"fancy_blank\" align=\"right\">\r\n      <a href=\"MHOME\"  target=\"_new\"><img src=\"/img/hp.gif\" alt=\"Homepage\" border=0></a> \r\n      <a href=\"MBOARD\" target=\"_new\"><img src=\"/img/fm.gif\" alt=\"Message boards\" border=0></a> \r\n      <a href=\"MLINK\"  target=\"_new\"><img src=\"/img/pl.gif\" alt=\"Play\" border=0></a>\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <t> \r\n     <td class=\"fancy_blank\" colspan=\"2\">MDESCR</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSub','portal','<div class=\"ersub\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSuperSect','portal','      <!- Supervisory/Administrative Section -->\r\n      <a href=\"/erealms/config/realm.plGENPARAM\" class=\"menub\" target=\"GenRealms\" GENJSCODE>Realms</a>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplTitle','portal','<div class=\"ertitle\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVerifiedSect','portal','      <!- Contributor Section -->\r\n      <a href=\"/erealms/contrib.plGENPARAM\" class=\"menub\" target=\"GenContrib\">Contributors</a>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWeather','portal','  <!- Weather management table -->\r\n  <table class=\"FC_TABLE\">\r\n   <tr> \r\n    <td class=\"FC_TITLE\" colspan=\"2\">Weather Forecast</td>\r\n   </tr>\r\n   <tr> \r\n    <td class=\"FC_INFO\" colspan=\"2\">MFORECAST</td>\r\n   </tr>\r\n   <tr>\r\n     <td class=\"FC_FIELD\">Temperature</td>\r\n     <td class=\"FC_ENTRY\">MC_TEMPC - MF_TEMPF</td>\r\n   </tr>\r\n   <tr>\r\n     <td class=\"FC_FIELD\">Wind Direction</td>\r\n     <td class=\"FC_ENTRY\">MWIND_DIR_ENG</td>\r\n   <tr>\r\n     <td class=\"FC_FIELD\">Wind Speed</td>\r\n     <td class=\"FC_ENTRY\">MWIND_KPHKph - MWIND_MPHMph</td>\r\n   </tr>\r\n   <tr>\r\n     <td class=\"FC_FIELD\">Dew Point</td>\r\n     <td class=\"FC_ENTRY\">MC_DEWC - MF_DEWF</td>\r\n   </tr>\r\n   <tr>\r\n     <td class=\"FC_FIELD\">Visibility</td>\r\n     <td class=\"FC_ENTRY\">MVIS_KILOKm - MVIS_MILEMi</td>\r\n   </tr>\r\n</table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDefault','portal','Default');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmitRealms','portal','Enter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtUnavail','portal','0');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBio','realm','/erealms/bio.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkBoard','realm','/erealms/board.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkIgnore','realm','/erealms/config/ignore.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkMail','realm','/erealms/mail.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkOffline','realm','/erealms/offline.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkPortal','realm','/erealms/portal.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkPuppet','realm','/erealms/config/puppet.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkRealm','realm','/erealms/realm.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptDiceTypes','realm','2:4:6:8:10:12:14:16:20:24:26:30:100');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetActive','realm','600');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetElapse','realm','1800');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGummyDefault','realm','/gummies/1.gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPost','realm','Refresh');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetStreamSize','realm','200000');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeout','realm','1800');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTruncate','realm','40');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagEmail','realm','[Email]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHeadDice','realm','Dice Roll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHeadPrivate','realm','Private Message');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHeadSystem','realm','System Wide Announcement');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagHyperlink','realm','[Hyperlink]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLinkSystem','realm','<center><b>[All Realms]</b></center>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLnkIgnore','realm','<font class=\"imgline\">[Ignored]</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLnkImage','realm','<font class=\"imgline\">[Image]</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMulti','realm','(Multiple Recipients)');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNav','realm','<a href=\"MLINK\" class=\"nav\"><b>MNAME</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostFont','realm','<font size=\"MSIZE\" color=\"MCOLOR\" face=\"MFACE\">MPOST</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostLink','realm','<a href=\"MLINK\" target=\"MTARGET\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostLocale','realm','<b>~~ MLOCL ~~</b><br>MPOST');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostTagline','realm','<font class=\"tagline\">(MNAME)</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostTime','realm','<font class=\"date\">MNAME</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostTitle','realm','<font class=\"title\">MNAME</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPostTopline','realm','<font class=\"topline\">MNAME</font>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPuppetPMFrom','realm','From:');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPuppetPMRealm','realm','Room:');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPuppetPMSep','realm','&#9702;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPuppetPMTo','realm','To:');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTitleWho','realm','<u>Who\'s On?</u>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTotal','realm','<b> TOTAL : </b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplContact','realm','<table width=\"100%\" border=0 cellspacing=0 cellpadding=0>\r\n <tr>\r\n  <td>\r\n   &nbsp;MTITLE\r\n  </td>\r\n </tr>\r\n</table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplInitial','realm',' <!- Notices -->\r\n <!- Encapsulate and define -->\r\n <div align=\"center\">\r\n  <div class=\"notice\">\r\n  \r\n   <!- Header -->\r\n   <div class=\"notice_head\">\r\n    This stream is being terminated!\r\n   </div>\r\n\r\n   <!- Body -->\r\n   <div class=\"notice_foot\">\r\n    For those making use of Stream or Auto-Scolling modes, your streams will end shortly \r\n    after seeing this post.    In order to restart the stream, simply press on the\r\n    \'Refresh\' button found below.<br><br>\r\n\r\n    It is recommended however, that you wait a few moments before attempting to do\r\n    so.   This will allow for the servers to be properly restarted and reduce your \r\n    chance of errors.<br><br>\r\n\r\n    If any errors appear restart after the streams reset and persist, please report\r\n    them to the <a href=\"mailto:council@ethereal-realms.org\" class=\"a\">Council</a>.\r\n   </div>\r\n  </div>\r\n </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplMain','realm','<div class=\"ermain\">MTITLE</b></div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPost','realm','<div align=\"center\">\r\n <table class=\"MPCLASS\">\r\nMNOTICE\r\n  <tr>\r\n   <td>\r\n    <!- Image --> \r\n    MIMAGE\r\n    <!-Gummy, Title and Tagline w/ Comment delimted -->\r\n    MCMTHEAD MGUMMY MTITLE MTAGLN MCMTPOST\r\n    <!- Spacer -->\r\n    <BR><BR>\r\n    <!- Post -->\r\n    MPOST\r\n   </td>\r\n  </tr>\r\nMNOTICE\r\n </table>\r\n</div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPostHeader','realm','  <!- Notice bars -->\r\n  <tr>\r\n   <td class=\"MSCLASS\">MNOTICE</td>\r\n  </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplWho','realm','<center><a href=\"MLINK\" target=\"_blank\">- <b>Log on and Play</b> -</a></center>\r\n<br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceAction','realm','Action/Comments:');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceBotch','realm','Botched roll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceBtch','realm','Botch');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceDiff','realm','Diff');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceDrop','realm','Dropped');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceFail','realm','Failed');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceFailRoll','realm','Failed roll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceHigh','realm','highest');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceIndividual','realm',' Individual');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceLow','realm','lowest');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceMax','realm','Max');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceRoll','realm','ROLL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceSuccess','realm','Successful');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDiceSuccessRoll','realm','Successful roll(s)');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtEndStream','realm','Streams will be reset!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtFirst','realm','<<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtLast','realm','>>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtLocale','realm','None');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNext','realm','>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNone','realm','---- None ----');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPost','realm','Post');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPrev','realm','<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRealmEnter','realm','Enter Realm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRemote','realm','Save Posts');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtResetButton','realm','Clear');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRoll','realm','Roll');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtScrollback','realm','Scroll Back');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSpelling','realm','Check spelling');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtStream','realm','End stream');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSystem','realm','---- System Wide ----');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtTransfer','realm','Transfer back');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocRSSNews','system','/home/erealms/www/public_html/rss/news.rss');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocRSSPortal','system','/home/erealms/www/public_html/rss/portal.rss');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocRSSWho','system','/home/erealms/www/public_html/rss/realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocRSSWorks','system','/home/erealms/www/public_html/rss/works.rss');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocScriptConf','system','http://www.ethereal-realms.org/erealms/confirmation.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocScriptHub','system','http://www.ethereal-realms.org/realms.shtml');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocScriptNews','system','http://www.ethereal-realms.org/erealms/weblog.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocScriptPortal','system','http://www.ethereal-realms.org/erealms/portal.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LocTemp','system','/tmp');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBannedAddress','system','banned@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBannedDefault','system','No reason(s) given.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBannedName','system','Banning Archives');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBaseDir','system','/home/erealms/www/public_html/gallery');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBoardName','system','Ethereal Realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetBoardPrefix','system','[Board]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDescription','system','A community of realms where role play and chat come together ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetExport','system','/usr/bin/htmldoc');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetExportOpt','system','--datadir /usr/share/htmldoc --color --continuous --links --size letter --right 1cm --left 1cm --footer /.d --header .t.  --permissions print --permissions no-annotate --permissions no-copy --permissions no-modify --no-embedfonts --encryption --outfile');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGalleryPrefix','system','[Gallery] Comment on:  ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGeoIP2Location','system','/home/erealms/www/Ethereal/db/geo/ip2location.dat');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGeoMaxMind','system','/home/erealms/www/Ethereal/db/geo/maxmind.dat');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetGoogleMaps','system','ABQIAAAA7ySr91JcKRwzuisH5HwsdhThWuuUbha1AL2hFH4Bok8kYzZoghSjdVc0hu4DvBLQIor6SFMuxYCSFw');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgBackground','system','transparent');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgFull','system','1024');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgQuality','system','90');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgType','system','gif');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetImgView','system','640');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetInfoContactAddress','system','webmaster@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetInfoContactName','system','Webmaster');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetInfoServer','system','Ethereal Realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLeechMax','system','100');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPerm','system','0777');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalDescripion','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalForum','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalNews','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalNewsItems','system','0');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalPuppet','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetPortalRealm','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSenderAddress','system','no-reply@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSenderName','system','Ethereal Realms');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSendmail','system','/usr/sbin/sendmail -t');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSpelAddr','system','localhost');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSpelLoc','system','/usr/bin/ispell -a');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSpelNil','system','No matches found');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSpelPort','system','7000');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSubmissionAddress','system','submissions@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetSubmissionName','system','Submissions');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetThumbnail','system','150');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutMail','system','30');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutOffline','system','14');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutPuppet','system','150');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutPuppeteer','system','90');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutRealm','system','1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetTimeoutRegister','system','7');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetUrl','system','http://www.ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetVersion','system','4.1.0');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('AdminFooter','template','     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('AdminHeader','template','<html>\r\n <head>\r\n  <title>Ethereal Realms - Administrative Area</title>\r\n\r\n  <meta name=\"classification\"     content=\"Gallery, Chat, Perl\">\r\n  <meta name=\"Description\"        content=\"A Perl/CGI image/prose gallery and real-time chat system\">\r\n  <meta name=\"keywords\"           content=\"Perl, CGI, gallery, chat, Ethereal, realms, image, prose, photo\">\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Administrative Area</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('BoardAdmin','template','Subject : MSUBJ\r\nBy      : MFROM on MDATE\r\nIn      : MROOM on MTOPC\r\n\r\nMessage :\r\n--------------------------------------------------------------------------------\r\n\r\nMMESG\r\n\r\n\r\n--------------------------------------------------------------------------------\r\n\r\nMMAIL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('BoardNotice','template','The message below is in reponse to a post that you have made previously\r\nto the MROOM message board:\r\n\r\nSubject : MSUBJ\r\nBy      : MFROM on MDATE\r\nTopic   : MTOPC\r\n\r\n\r\nMMESG\r\n\r\n\r\nIf you wish to respond to the post.  You can use the link below to enter\r\nthe boards and make a response to the appropriate thread:\r\n\r\nMLINK\r\n\r\nIf you have any questions on the matter. Feel free to contact us using\r\nthe Email addresses provided below.  We will be sure to get back to you\r\nas quickly as possible.\r\n\r\nMMAIL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ContribFooter','template','     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ContribHeader','template','<html>\r\n <head>\r\n  <title>Ethereal Realms - Contributors Area</title>\r\n\r\n  <meta name=\"classification\"     content=\"Gallery, Chat, Perl\">\r\n  <meta name=\"Description\"        content=\"A Perl/CGI image/prose gallery and real-time chat system\">\r\n  <meta name=\"keywords\"           content=\"Perl, CGI, gallery, chat, Ethereal, realms, image, prose, photo\">\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Contributors Area</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ContribPortal','template','<html>\r\n <head>\r\n  <title>Ethereal Realms -  Contributor Portal for MGENNAME</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Contributor Portal for MGENNAME</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n      <!- Wrap in a table -->\r\n      <table width=\"98%\" border=\"0\" cellpadding=\"3\" cellspacing=\"1\" style=\"background-color: #A9C5D1;\">\r\n       <tr>\r\n\r\n        <!- Username and Verification status -->\r\n        <td valign=\"middle\" style=\"background-color: #5C8799;\">\r\n          <!- Verification status -->\r\n          MGENVERIFY\r\n\r\n          <!- Name, login and Email -->\r\n          <span class=\"stark\"><b>Contributor Portal for MGENNAME &#9702; MGENUSER &#9702; <a href=\"mailto:MGENEMAIL\">MGENEMAIL</a></b></span>\r\n        </td>\r\n\r\n        <td valign=\"middle\" style=\"background-color: 5C8799;\">\r\n         <span class=\"stark\">Expires: MGENEXPIRE</span>\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Information panes -->\r\n       <tr> \r\n        <td valign=\"top\" bgcolor=\"88A9B8\">\r\n\r\n\r\n         <!- Gallery display -->\r\n         <div class=\"erblank\">\r\n\r\n          <!- Header -->\r\n          <div class=\"galhead\"><b>Gallery Listing</b></div>\r\n\r\n          <!- List all pertinent galleries -->\r\n          <div style=\"padding: 5px;\">\r\nLSTGAL\r\n\r\n          </div>\r\n\r\n          <!- Footer w/ series of links-->\r\n          <div class=\"galfoot\" style=\"text-align: center;\">\r\n           <a href=\"MGALMANAGE\" class=\"menub\" target=\"_new\">Create Gallery</a> &#9702;\r\n           <a href=\"MGALVIEW\"   class=\"menub\" target=\"_new\">Browse Gallery</a> &#9702;\r\n           <a href=\"/erealms/gallery/searchLGENPARAM\" class=\"menub\" target=\"_new\">Search Gallery</a>\r\n          </div>\r\n\r\n         </div>\r\n        </td>\r\n\r\n\r\n        <td width=\"200\">\r\n\r\n         <!- Navigation tools -->\r\n         <div class=\"erdark\">\r\n\r\n          <!- Links to the portal, details and homepage -->\r\n           <div class=\"navcontainer\">\r\n            <ul>\r\n            <li><a href=\"/erealms/gate.plLGENPARAM\" target=\"_blank\">Main Portal</a></li>\r\n            <li><a href=\"/erealms/config/puppeteer.plLGENPARAM\" target=\"_blank\">Change Details</a></li>\r\n            <li><a href=\"/erealms/config/home.plLGENPARAM\" target=\"_blank\">Manage Homepage</a></li>\r\n           </ul>\r\n          </div>\r\n         </div>\r\n\r\n\r\n         <!- Homepage Information -->\r\n         <div class=\"ermedium\">\r\n          <table>\r\n           <!- Homepage folder -->\r\n           <tr>\r\n            <td><b>Folder:</b></td>\r\n            <td>MHPHOME</td>\r\n           </tr>\r\n\r\n           <!- Homepage files -->\r\n           <tr>\r\n            <td><b>Files:</b></td>\r\n            <td>MHPCOUNT</td>\r\n           </tr>\r\n\r\n           <!- Space max -->\r\n           <tr>\r\n            <td><b>Available:</b></td>\r\n            <td>MHPLIMIT</td>\r\n           </tr>\r\n\r\n           <!- Space left -->\r\n           <tr>\r\n            <td><b>Remaining:</b></td>\r\n            <td>MHPAVAIL</td>\r\n           </tr>\r\n          </table>\r\n         </div>\r\n\r\n         <div class=\"ermedium\">\r\n          <div class=\"navcontainer\"\r\n           <ul>\r\n            <!- File listing -->\r\nLSTHPFILES\r\n           </ul>\r\n          </div>\r\n         </div>\r\n        </td>\r\n       </tr>\r\n      </table>\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryChapter','template','<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\r\n<html>\r\n <head>\r\n  <meta http-equiv=\"content-type\"content=\"text/html; charset=ISO-8859-1\">\r\n  <title>MTITLE</title>\r\n  <meta name=\"author\" content=\"MAUTHOR\">\r\n </head>\r\n\r\n <body>\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">MTITLE</td>\r\n    <td align=\"right\">MDATE</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n <br>\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"justify\">MBODY</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n <br>\r\n <br>\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">Copyright MAUTHOR</td>\r\n    <td align=\"right\">All rights reserved</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n\r\n </body>\r\n</html>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryCover','template','<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\r\n<html>\r\n <head>\r\n  <meta http-equiv=\"content-type\"content=\"text/html; charset=ISO-8859-1\">\r\n  <title>MGNAME</title>\r\n  <meta name=\"author\" content=\"MAUTHOR\">\r\n </head>\r\n\r\n <body>\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">Copyright MAUTHOR</td>\r\n    <td align=\"right\">All rights reserved</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n <br>\r\n <br>\r\n\r\n  <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" align=\"left\">\r\n  <tbody>\r\n    <tr>\r\n      <td align=\"Center\">\r\n       <big style=\"font-weight: bold;\"><big><big>MGNAME</big></big></big>\r\n       <br><br>\r\n       <a href=\"http://www.ethereal-realms.org\">\r\n        <img src=\"/var/www/webroot/htdocs/img/logo-publish.gif\" title=\"Ethereal Realms\" alt=\"Ethereal Realms\" border=\"0\" width=\"484\" height=\"480\">\r\n       </a>\r\n       <br><br>\r\n       <big style=\"font-weight: bold;\"><big><big>By MAUTHOR</big></big></big>\r\n     </td>\r\n    </tr>\r\n  </tbody>\r\n </table>\r\n\r\n <br>\r\n <br>\r\n\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\">\r\n  <tbody>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\" rowspan=\"1\" colspan=\"2\">\r\n       <big><big><span style=\"font-weight: bold;\">Quick Links</span></big></big>\r\n      </td>\r\n    </tr>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\">\r\n       <span style=\"font-weight: bold;\">Ethereal Realms</span>\r\n      </td>\r\n      <td style=\"vertical-align: top;\">\r\n       <a href=\"http://www.ethereal-realms.org\">http://www.ethereal-realms.org</a>\r\n      </td>\r\n    </tr>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\">\r\n       <span style=\"font-weight: bold;\">MGNAME</span>\r\n      </td>\r\n      <td style=\"vertical-align: top;\">\r\n       <a href=\"http://www.ethereal-realms.org/erealms/gallery/view/MGID/\">http://www.ethereal-realms.org/erealms/gallery/view/MGID/</a>\r\n      </td>\r\n    </tr>\r\n   </tbody>\r\n  </table>\r\n\r\n <br>\r\n <br>\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">Copyright MAUTHOR</td>\r\n    <td align=\"right\">All rights reserved</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n\r\n </body>\r\n</html>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryExif','template','<span class=\"exiftag\">Make:</span> <span class=\"exifval\">MMAKE</span><br>\r\n<span class=\"exiftag\">Model:</span> <span class=\"exifval\">MMODEL</span><br>\r\n<span class=\"exiftag\">Shutter Speed:</span> <span class=\"exifval\">MEXPOSURE second(s)</span><br>\r\n<span class=\"exiftag\">F Number:</span> <span class=\"exifval\">F/MFNUMBER</span><br>\r\n<span class=\"exiftag\">Focal Length:</span> <span class=\"exifval\">MFOCAL</span><br>\r\n<span class=\"exiftag\">Date Picture Taken:</span> <span class=\"exifval\">MCREATE</span><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryExport','template','<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\r\n<html>\r\n <head>\r\n  <meta http-equiv=\"content-type\"content=\"text/html; charset=ISO-8859-1\">\r\n  <title>MTITLE</title>\r\n  <meta name=\"author\" content=\"MAUTHOR\">\r\n </head>\r\n\r\n <body>\r\n  <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" align=\"left\">\r\n  <tbody>\r\n    <tr>\r\n      <td valign=\"middle\" width=\"100%\">\r\n        <big style=\"font-weight: bold;\"><big><big>MTITLE</big></big></big><br>\r\n        By MAUTHOR\r\n      </td>\r\n      <td>\r\n       <a href=\"http://www.ethereal-realms.org\">\r\n        <img src=\"/var/www/webroot/htdocs/img/logo-export.gif\" title=\"Ethereal Realms\" alt=\"Ethereal Realms\" border=\"0\" width=\"160\" height=\"160\">\r\n       </a>\r\n     </td>\r\n    </tr>\r\n  </tbody>\r\n </table>\r\n\r\n <br>\r\n\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">Copyright MAUTHOR</td>\r\n    <td align=\"right\">All rights reserved</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n\r\n <br>\r\n <div align=\"justify\">\r\n  MBODY\r\n </div>\r\n <br>\r\n\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\" bgcolor=\"#999999\">\r\n  <tbody>\r\n   <tr>\r\n    <td align=\"left\">Copyright MAUTHOR</td>\r\n    <td align=\"right\">All rights reserved</td>\r\n   </tr>\r\n  </tbody>\r\n </table>\r\n\r\n<br>\r\n<br>\r\n\r\n <table cellpadding=\"2\" cellspacing=\"2\" border=\"0\" width=\"100%\">\r\n  <tbody>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\" rowspan=\"1\" colspan=\"2\">\r\n       <big><big><span style=\"font-weight: bold;\">Quick Links</span></big></big>\r\n      </td>\r\n    </tr>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\">\r\n       <span style=\"font-weight: bold;\">Ethereal Realms</span>\r\n      </td>\r\n      <td style=\"vertical-align: top;\">\r\n       <a href=\"http://www.ethereal-realms.org\">http://www.ethereal-realms.org</a>\r\n      </td>\r\n    </tr>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\">\r\n       <span style=\"font-weight: bold;\">MGNAME</span>\r\n      </td>\r\n      <td style=\"vertical-align: top;\">\r\n       <a href=\"http://www.ethereal-realms.org/erealms/gallery/view/MGID/\">http://www.ethereal-realms.org/erealms/gallery/view/MGID/</a>\r\n      </td>\r\n    </tr>\r\n    <tr>\r\n      <td style=\"vertical-align: top;\">\r\n       <span style=\"font-weight: bold;\">MGWORK</span><br>\r\n      </td>\r\n      <td style=\"vertical-align: top;\">\r\n       <a href=\"http://www.ethereal-realms.org/erealms/gallery/view/MGID/MWID\">http://www.ethereal-realms.org/erealms/gallery/view/MGID/MWID</a>\r\n      </td>\r\n     </tr>\r\n   </tbody>\r\n  </table>\r\n </body>\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryFooter','template','\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryHeader','template','<html>\r\n <head>\r\n  <title>Ethereal Realms</title>\r\n\r\n  <meta name=\"classification\"     content=\"Gallery, Chat, Perl\">\r\n  <meta name=\"Description\"        content=\"A Perl/CGI image/prose gallery and real-time chat system\">\r\n  <meta name=\"keywords\"           content=\"Perl, CGI, gallery, chat, Ethereal, realms, image, prose, photo\">\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n  <!- Menu non-javascript specific popups -->\r\n  <script language=\"Javascript\">\r\n   <!--\r\n    // Set size below default if need be\r\n    var height = (screen.height < 535) ?  screen.availHeight : 535;\r\n    var width  = (screen.width  < 735) ?  screen.availWidth  : 735;\r\n\r\n    // Build string\r\n    var settings = \'width=\'+width+\',height=\'+height+\',fullscreen=no,resizable=yes,status=yes,scrollbars=yes,toolbars=no\';\r\n\r\n    // -->\r\n  </script>\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; MTREE</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GalleryNotice','template','By      : MFROM on MDATE\r\nOn      : MWORK\r\n\r\nComment :\r\n--------------------------------------------------------------------------------\r\n\r\nMMESG\r\n\r\n\r\n--------------------------------------------------------------------------------\r\n\r\nMMAIL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('GallerySearch','template','<table width=\"400\" border=\"0\" align=\"center\" cellpadding=\"3\" cellspacing=\"1\" bgcolor=\"#E3F3FA\">\r\n                    <tr bgcolor=\"#274F60\"> \r\n                      <td colspan=\"3\"><font class=stark><b>Search Through Galleries</b></font></td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td bgcolor=\"#A9C5D1\">Search for</td>\r\n                      <td>&#187; </td>\r\n                      <td>WSRCHTYPE</td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td bgcolor=\"#A9C5D1\">Search by</td>\r\n                      <td>&#187; </td>\r\n                      <td>WSRCHFILD</td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td bgcolor=\"#A9C5D1\">Genre</td>\r\n                      <td>&#187; </td>\r\n                      <td>WSRCHGNRE</td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td bgcolor=\"#A9C5D1\">Sort by</td>\r\n                      <td>&#187; </td>\r\n                      <td>WSRCHSORT</td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td height=\"1\" colspan=\"3\" bgcolor=\"#274F60\"></td>\r\n                    </tr>\r\n                    <tr> \r\n                      <td bgcolor=\"#A9C5D1\">Search Site</td>\r\n                      <td colspan=\"2\">WSRCHTEXT</td>\r\n                    </tr>\r\n                    <tr align=\"right\" bgcolor=\"#A9C5D1\"> \r\n                      <td colspan=\"3\">WSRCHSMBT</td>\r\n                    </tr>\r\n                  </table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('HomeHeader','template','<body topmargin=\"0\" bottommargin=\"0\" leftmargin=\"0\" rightmargin=\"0\" bgcolor=\"#1E1C3A\" text=\"#FFFFFF\" link=\"#FFFFFF\" vlink=\"#CCCCCC\" alink=\"#CCCCCC\">\r\n\r\n<table width=\"100%\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\r\n  <tr valign=\"top\">\r\n     <td align=\"left\">\r\n      <center><a href=\"http://www.ethereal-realms.org/\" target=\"_blank\"><img src=\"http://www.ethereal-realms.org/img/index.jpg\" width=\"600\" height=\"145\" border=\"0\"></a></center>\r\n    </td>\r\n  </tr>\r\n</table>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('HomeReadme','template','<table width=\"100%\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\">\r\n  <tr valign=\"top\">\r\n    <td align=\"left\">\r\n     <center><font size=\"2\" face=\"Arial, Helvetica, sans-serif\"><b>Copyright 1999-2004 Ethereal Realms</b><br>\r\n     All page contents are owned by the individual host/hostess</font></center>\r\n    </td>\r\n  </tr>\r\n</table>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailBanned','template','FULLNAME (USERNAME) you have been banned from ROOMNAME on SERVERNAME until the ban is lifted on BANDATE.    This ban is at the realm level and is for the following reason(s):\r\n\r\n  BANREASON\r\n\r\nIt is important to note that any attempt to circumvent this ban may result in permanent removal from Ethereal Realms. The Council recommends you refer to the Acceptable Use Policy you agreed to when registering your account with Ethereal Realms.\r\n\r\nhttp://www.ethereal-realms.org/aup.html\r\n\r\nIf you have questions regarding your ban, contact the hosts of ROOMNAME.  \r\n\r\nThis is a system message.  Do not reply to this email.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailEmailer','template','\r\n--\r\n\r\nEthereal Realms - Gateway to the Imagination');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailGallery','template','You are being notified of an update for:\r\nMWNAME\r\nMDESCR\r\n\r\nWhich can be found by following the link below. \r\nIf there is no hyperlink to click, please cut and paste the link displayed into your browser window and press enter.\r\n\r\nLWORKA\r\n\r\nThis work was created by MANAME, in the gallery, MGNAME. \r\nWhich is found by following the link below.\r\n\r\nLGALLA\r\n\r\nto view other galleries -\r\nhttp://www.ethereal-realms.org/erealms/gallery/?USER=\r\n\r\nto search for a particular gallery -\r\nhttp://www.ethereal-realms.org/erealms/gallery/search/?USER=');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailInvitation','template','Welcome FULLNAME to SERVERNAME\r\n\r\nThis message is sent primarily to verify the authenticity of the Email\r\naddress you provided during registration.   If you have \r\nreceived this Email in error, simply do not reply or read further and\r\nno other attempts (on the part of the system) will be made.\r\n\r\nTo complete registration point your browser to the following URL:\r\n\r\n(( CONFADDR ))\r\n\r\nand use the following code as required.\r\n\r\n{{ CONFCODE }}\r\n\r\nAlternatively, you can save a bit of time by simply clicking on the link below.  Note due to certain mail clients this link may not work.\r\n\r\n{{ AUTHSTRING }}\r\n\r\n\r\nIn case you cannot find your way back to the Portal then please follow \r\nthe link below:\r\n\r\nPORTAL\r\n\r\nShould you require any assistance, feel free to enter the main help \r\ndocuments available at the top of every page, or follow the link below.\r\nThere you will find all you need to know in order to register, create\r\npuppets, and make use of the realms.\r\n\r\nhttp://www.ethereal-realms.org/help.html\r\n\r\n\r\nNOTE: Logins without proper registration are not possible.  If you \r\nhave problems send a message to the address listed below.  Please \r\ninclude the original Email so we can better determine what has\r\nhappened.\r\n\r\nRETURNEMAIL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailNotice','template','This is addressed to FULLNAME\r\nFrom SERVERNAME\r\n\r\nYou have received a message from ORIGIN concerning the subject:\r\nSUBJECT\r\n\r\nAs a result, you are invited to read what he/she  has composed.   In order \r\nto so, please click on the link below.   If there is no link below, or \r\nit has been altered when you receive the message simply copy what is between \r\nthe parentheses and place it in the location bar of your browser.\r\n\r\n\r\n(( AUTHSTRING ))\r\n\r\nThis message will be held for thirty days, then removed as per normal \r\nprocedure.  Should you have any questions  on the matter, please feel \r\nfree to send a message to the address below:\r\n\r\nRETURNEMAIL');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailOffline','template','MFROM Puppet who sent it\r\nMMAIL Generic signature for questions\r\nMROOM Room post originated from\r\nMPOST Extract of post');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailPosts','template','As per your request in checking the \'save posts\' box in the REALM comm panel, you have received an Email containing the logs extracted from REALM on DATE. If you have received this in Error, simply reply to this Email and inform us of this fact.\r\n\r\nINSTRUCTIONS:\r\n\r\nThe file is compressed using the Zip format, which can be handled directly using products such as WinZip (http://www.winzip.com) for Windows based platforms or MacZip (http://www.haase-online.de/dirk/maczip/) for those using MacOS .\r\n\r\nOnce the file is extracted, you only need to drop the file into an open browser window for it to be read.   The posts will look the same as the way you see posts displayed in realm, changing these settings requires you to change the settings at login time, or through the User Details panel.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailReset','template','MNAME,\r\n\r\nYou are receiving this email because someone has requested a new \r\npassword be generated for the account: MUSER.  If this email was \r\nsent in error, please contact the Council of Ethereal Realms.\r\n\r\nThe account details are now as follows:\r\n\r\nUsername: MUSER\r\nPassword: MPASS\r\n\r\nYour new password may be changed via the User Details link found near \r\nthe top right of your portal. We recommend changing it at your earliest \r\nconvenience, to something you will easily remember.\r\n\r\n----------\r\nCouncil of Ethereal Realms\r\ncouncil@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MailVerified','template','Thank you FULLNAME \r\n For registering to SERVERNAME\r\n\r\nRegistration for Ethereal Realms is now complete. You can log in at\r\nhttp://www.ethereal-realms.org/erealms/gate.pl\r\nRemember your user name and password. All passwords are encrypted and\r\nunretrievable.  However for reference, your username and Email address\r\nwhich you have registered will be listed below:\r\n\r\n  Username : LOGINNAME\r\n  Email    : EMAIL\r\n  Hostname : HOSTNAME\r\n\r\nNote: If you should ever loose your password please make use of this link \r\nto correct this: http://www.ethereal-realms.org/erealms/reset.pl \r\n\r\n                                                ----\r\n\r\nWe hope you enjoy Ethereal Realms and will return often.\r\n\r\nTo make your journey through the realms easier here is a list of\r\nvaluable links\r\n\r\nfor access to our main page -\r\nhttp://www.ethereal-realms.org/\r\n\r\nfor assistance in navigating -\r\nhttp://www.ethereal-realms.org/help.html\r\n\r\nfor communication with others -\r\nhttp://www.ethereal-realms.org/erealms/board\r\n                     and\r\nhttp://www.ethereal-realms.org/erealms/board/system\r\n\r\nto assist with the operation of this site -\r\nhttp://www.ethereal-realms.org/erealms/donate.pl\r\n\r\nIf you have any questions or comments please email the\r\ncouncil@ethereal-realms.org');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SuperFooter','template','     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SuperHeader','template','<html>\r\n <head>\r\n  <title>Ethereal Realms - Supervisory Area</title>\r\n\r\n  <meta name=\"classification\"     content=\"Gallery, Chat, Perl\">\r\n  <meta name=\"Description\"        content=\"A Perl/CGI image/prose gallery and real-time chat system\">\r\n  <meta name=\"keywords\"           content=\"Perl, CGI, gallery, chat, Ethereal, realms, image, prose, photo\">\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Supervisory Area</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebCanon','template','<b>NOTE</b>: This realm relies on source handles in order to participate.   If you do not already have a source handle with the host, then please be sure to have one before attempting to enter.   For information on contacting the host, please consult the splash page on the right hand side.');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebDescription','template','  <!- Description handling intelligence -->\r\n  <script language=\"JavaScript\" src=\"/js/descr.js\" type=\"text/javascript\"></script>\r\n  <script language=\"Javascript\">\r\n   <!--\r\n\r\n   // Will format and create the content\r\n   function createContent(cur)\r\n   {\r\n     // Assign description\r\n     switch (cur)\r\n     {\r\n       MDESCRCASE\r\n       default:\r\n        mes = \'No description available!\';\r\n     } \r\n\r\n     // Concatenate and prepare\r\n     mes = \'<FONT CLASS=spec><B>\' + cur + \'</B> - <B>\' + gre + \':</B> (\' + rat + \') \' + mes + \'<FONT>\';\r\n\r\n     // Display and see\r\n     showContent(mes);\r\n   } \r\n\r\n   // -->\r\n  </script>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebFooter','template','     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebHeader','template','<html>\r\n <head>\r\n  <title>Ethereal Realms - Gateway to the Imagination</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Main Area</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebJavascript','template','  <!- Menu non-javascript specific popups -->\r\n  <script language=\"Javascript\">\r\n   <!--\r\n    // Set size below default if need be\r\n    var height = (screen.height < 535) ?  screen.availHeight : 535;\r\n    var width  = (screen.width  < 735) ?  screen.availWidth  : 735;\r\n\r\n    // Build string\r\n    var settings = \'width=\'+width+\',height=\'+height+\',fullscreen=no,resizable=yes,status=yes,scrollbars=yes,toolbars=no\';\r\n\r\n    // -->\r\n  </script>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebNotice','template','\r\n <!- Notices -->\r\n <!- Encapsulate and define -->\r\n <div class=\"notice\" align=\"center\">\r\n  \r\n  <!- Header -->\r\n  <div class=\"notice_head\">\r\n   MDESCR\r\n  </div>\r\n\r\n  <!- Body -->\r\n  <div class=\"notice_foot\">\r\n   For those making use of Stream or Auto-Scolling modes, your streams will end shortly \r\n   after seeing this post.    In order to restart the stream, simply press on the\r\n   \'Refresh\' button found below.<br><br>\r\n\r\n   It is recommended however, that you wait a few moments before attempting to do\r\n   so.   This will allow for the servers to be properly restarted and reduce your \r\n   chance of errors.<br><br>\r\n\r\n   If any errors appear restart after the streams reset and persist, please report\r\n   them to the <a href=\"mailto:council@ethereal-realms.org\" class=\"a\">Council</a>.\r\n  </div>\r\n </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebPortal','template','<html>\r\n <head>\r\n  <title>Ethereal Realms - Gateway to the Imagination</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n\r\n  <!- General Javascript with Linking Capabilities-->\r\nMJAVASCRIPT\r\n\r\n  <!- Description Handling -->\r\nMDESCRIPTION\r\n\r\n </head>\r\n <body>\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Embarcation Point</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n\r\n   <!- Additional Embeded Sections -->\r\n   <tr>\r\n    <td valign=\"top\" align=\"right\">\r\n\r\n      <!- Base Icons -->\r\n      <a href=\"/erealms/config/puppeteer.plGENPARAM\" class=\"menub\" target=\"GenUser\" GENJSCODE>User Details</a>\r\n      <a href=\"/erealms/galleryGENPARAM\" class=\"menub\" target=\"GenGallery\">Galleries</a> \r\n      <a href=\"/erealms/social/searchGENPARAM\" class=\"menub\" target=\"GenSocial\">Social</a> \r\n      <a href=\"/erealms/post/who.plGENPARAM\" class=\"menub\" target=\"GenWho\" GENJSCODE>Who\'s On</a>\r\nMVERSECT\r\nMSUPSECT\r\nMADMSECT\r\n    </td>\r\n   </tr>\r\n\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n\r\n       <!- Additional Embeded Sections -->\r\n       <div align=\"right\">\r\n\r\n       <!- Start Form -->\r\n       FRMOPEN\r\n\r\n\r\n       <!- Main Table -->\r\n       <table height=\"100%\" border=\"0\" align=\"center\" cellpadding=\"10\" cellspacing=\"10\">\r\n\r\n        <!- Potential errors -->\r\n        MERRMSG\r\n\r\n\r\n        <!- First Column -->\r\n        <tr>\r\n         <td align=\"left\" valign=\"top\" width=\"300\">\r\n\r\n\r\n          <!- Mail Services -->\r\n          <div class=\"erblank\" style=\"width: 250px; margin-bottom: 20px; margin-top: 0px;\">\r\n           \r\n           <!- Title section -->\r\n           <div class=\"rowportal\" style=\"height: 18px;\">\r\n            <span style=\"float: right;\"><b>Internal Messaging</b></span>\r\n            <span style=\"float: left;\"><a href=\"/erealms/mail.plGENPARAM\" target=\"GenMail\" GENJSCODE><img src=\"/img/go.gif\" border=\"0\" alt=\"Goto internal mail!\" title=\"Goto internal mail!\"></a></span>\r\n           </div>\r\n\r\n           <!- Body -->\r\n           <div class=\"erportal\">\r\n            <span class=\"white\"><b>Total:</b> MMAILCOUNT</span><br>\r\n            <span class=\"white\"><b>Unread:</b> MMAILUNREAD</span>\r\n           </div>\r\n          </div>\r\n\r\n\r\n\r\n          <!- News Services -->\r\n          <div class=\"erblank\" style=\"width: 250px; margin-bottom: 20px; margin-top: 0px;\">\r\n           \r\n           <!- Title section -->\r\n           <div class=\"rowportal\" style=\"height: 18px;\">\r\n            <span style=\"float: right;\"><b>MNEWSRECENT News and Updates!</b></span>\r\n            <span style=\"float: left;\"><a href=\"/erealms/weblog.pl\" target=\"GenNews\" GENJSCODE><img src=\"/img/go.gif\" border=\"0\" alt=\"Goto news and updates!\" title=\"Goto news and updates!\"></a></span>\r\n           </div>\r\n\r\n           <!- Body -->\r\n           <div class=\"erportal\">\r\nLSTNEWS\r\n           </div>\r\n           <div  class=\"erportal\" align=\"right\"><b>MNEWSCOUNT Items</b></div>\r\n          </div>\r\n\r\n\r\n\r\n          <!- Forums -->\r\n          <div class=\"erblank\" style=\"width: 250px; margin-bottom: 20px; margin-top: 0px;\">\r\n           \r\n           <!- Title section -->\r\n           <div class=\"rowportal\" style=\"height: 18px;\">\r\n            <span style=\"float: right;\"><b>Site Forums</b></span>\r\n            <span style=\"float: left;\"><a href=\"/erealms/board/systemGENPARAM\" target=\"GenForum\" GENJSCODE><img src=\"/img/go.gif\" border=\"0\" alt=\"Goto site forums!\" title=\"Goto site forums!\"></a></span>\r\n           </div>\r\n\r\n           <!- Body -->\r\n           <div class=\"erportal\">\r\nLSTFORUM\r\n           </div>\r\n          </div>\r\n\r\n\r\n\r\n          <!- Rotations -->\r\n          <div style=\"width: 250px;\" align=\"center\">\r\nMROTSECT\r\n          </div>\r\n\r\n\r\n         <!- Linear definition -->\r\n         <!- Second Column -->\r\n         </td>\r\n         <td valign=\"top\" align\"center\">\r\n\r\n\r\n\r\n         <!- Realm entrances -->\r\n         <!- Puppet Selection -->\r\n         <div style=\"width: 380px; height: 50px; margin-bottom: 10px;\">\r\n\r\n           <!- Title section -->\r\n           <div class=\"ertitle\" style=\"margin-bottom: 3px;\"><b>Select a Puppet?</b></div>\r\n\r\n           <!- Body -->\r\n           <!- Puppet List -->\r\n           <div style=\"float: left\">LSTPUPPETS</div>\r\n\r\n           <!- Puppet Management Link -->\r\n           <div style=\"float: right\"><a href=\"/erealms/config/puppet.plGENPARAM\" target=\"GenPuppet\" GENJSCODE><img src=\"/img/gears.gif\" border=\"0\" alt=\"Manage\" title=\"Manage puppets and handles\"></a></div>\r\n         </div>\r\n\r\n\r\n         <!-- Realm Selection -->\r\n         <div style=\"width: 380px; margin-bottom: 10px;\">\r\n\r\n           <!- Title section -->\r\n           <div class=\"ertitle\" style=\"margin-bottom: 3px;\"><b>Select a Realm?</b></div>\r\n\r\n           <div>\r\nLSTREALMS\r\n           </div>\r\n          </div>\r\n\r\n\r\n\r\n          <!- Offline -->\r\n          <div style=\"height: 15px; margin-bottom: 10px\">\r\n           <div class=\"ertitle\" style=\"width: 175px; float: left;\"><b>Take this Offline?</b></div>\r\n           <div style=\"margin-left: 5px; float: left;\">WROFFLINE</div>\r\n          </div>\r\n\r\n\r\n          <!- Private Realms -->\r\n          <div style=\"height: 15px; margin-bottom: 10px\">\r\n           <div class=\"ertitle\" style=\"width: 175px; float: left;\"><b>Private Realm?</b></div>\r\n           <div  style=\"margin-left: 5px; float: left;\">WPRIVREALM</div>\r\n          </div>\r\n\r\n\r\n          <!- Submit -->\r\n          <div style=\"margin-bottom: 10px\">WSUBMIT</div>\r\n\r\n\r\n          <!- Display widget -->\r\n          MDISPLAY\r\n\r\n\r\n          <!- Disable automated login -->\r\n          <div style=\"float: right\"> <a href=\"/erealms/portal.plGENPARAM&USER_FORGET=True\"><img src=\"/img/key.gif\" border=\"0\" alt=\"Forget\" title=\"Disable automated logins\"></a></div>\r\n\r\n \r\n          <!- Close encompassing table -->\r\n         </td>\r\n        </tr>\r\n       </table>\r\n\r\n       <!- Close Form -->\r\n       FRMCLOSE\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebRing','template','<!- Ethereal Realms Webring -- Internal Realm Webring -->\r\n<!- Start Webring ->\r\n<div align=\"center\">\r\n <!- Replacable Image -->\r\n <img src=\"http://www.ethereal-realms.org/img/banner/banner1.gif\" alt=\"Ethereal Realms Webring\" title=\"Ethereal Realms Webring\">\r\n\r\n <!- Spacer -->\r\n <br>\r\n\r\n <!- Links to random, listing, next and prev -->\r\n <a href=\"http://www.ethereal-realms.org/erealms/ring/MREALM/rand\" target=\"_parent\">Random</a> &#9702;\r\n <a href=\"http://www.ethereal-realms.org/realms.shtml\" target=\"_New\">Realms</a> &#9702;\r\n <a href=\"http://www.ethereal-realms.org/erealms/ring/MREALM/next\" target=\"_parent\">Next</a> &#9702;\r\n <a href=\"http://www.ethereal-realms.org/erealms/ring/MREALM/prev\" target=\"_parent\">Previous</a>\r\n</div>\r\n<!- End Webring ->');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('WebStream','template','<br>\r\n<center>\r\n<table border=\"0\" width=500 cellspacing=\"5\" cellpadding=\"5\" align=\"center\" bgcolor=black>\r\n  <tr bgcolor=\"80B4D8\"> \r\n    <td><img src=\"/pic/em.jpg\" width=\"30\" height=\"30\" align=\"absmiddle\"> \r\n      <b><font face=\"Times New Roman, Times, serif\" size=\"2\" color=000000>MDESCR</font></b>\r\n    </td>\r\n  </tr>\r\n  <tr bgcolor=\"204068\"> \r\n    <td>\r\n     <font color=\"#88B4D8\" face=\"Times New Roman, Times, serif\" size=\"2\"><p>For those \r\n      making use of Stream or Auto-Scolling modes, your streams will end shortly after\r\n      seeing this post.    In order to restart the stream, simply press on the \'Refresh\'\r\n      button found below.</p>\r\n\r\n      <p>It is recommended however, that you wait a few moments before attempting to do\r\n       so.   This will allow for the servers to be properly restarted and reduce your \r\n       chance of errors.</p>\r\n\r\n      <p>If any errors appear restart after the streams reset and persist, please report\r\n       them to the <a href=\"mailto:council@ethereal-realms.org\" class=\"a\">Council</a>.</p></font>\r\n    </td>\r\n  </tr>\r\n</table>\r\n<center>\r\n<br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrEmail','user','Email addresses do not match/already in use');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrFullName','user','Full name is invalid');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrHandle','user','Handle is invalid or already in use');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrPassword','user','Invalid Password');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrSuccess','user','Updated');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('ErrUsername','user','Invalid Username or already in use');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkPortal','user','/erealms/gate.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkVanity','user','http://www.ethereal-realms.org/vanity');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgClone','user','<b>Target(s) Cloned</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgCount','user','<b>Must select at least one handle</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgCreate','user','<b>Puppet created</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgDeleteFail','user','<b>Puppet could not be removed</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgDeletePass','user','<b>Puppet removed</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgExists','user','<b>Puppet name already exists or is too short</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgPupPrintout','user','The Quick Brown Fox Jumped Over The Lazy Dog');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgRstFail','user','<b>Invalid username or error during reset</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgRstPass','user','<b>A new password has been generated and mailed out to MMAIL</b>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgSocialError','user','<br><br><b>Error:</b> Some information you provided are invalid.  Please try again!<br><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgSocialUpdate','user','<br><br><b>Note:</b> Social Profile updated<br><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptChatPref','user','Basic chat:Framed chat:Streaming chat:Auto-Scrolling');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptClone','user','Tag:Title:Tag & Title');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptFormat','user','Full formating:No images:Limited formating');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptIgnore','user','Single:Global:Picture:Taglines and Titles:Highlight');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptJavascript','user','Use Javacript:No Javascript');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptMailer','user','Keep on Site:Send to Email');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalBirthDay','user','1:2:3:4:5:6:7:8:9:10:11:12:13:14:15:16:17:18:19:20:21:21:23:24:25:26:27:28:29:30:31:1');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalBirthMonth','user','Jan:Feb:Mar:Apr:May:Jun:Jul:Aug:Sep:Oct:Nov:Dec:Jan');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalBodyType','user','No Comment:Thin:Athletic:Average:Few Extre Pounds: Big and Tall:Average');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalEthnicity','user','African:African American:Asian:Caucasian:European:Hispanic:Indian:Middle Eastern:Native American:Mixed Race:Other:African');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalEyeColour','user','Blue:Brown:Green:Gray:Hazel:Blue');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalGender','user','Male:Female:Male');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalHairColour','user','Black:Blond:Brown:Red:Gray:Bald:Mixed Colour:Blond');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPhysicalHeight','user','Short:Medium:Tall:Medium');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptPrivacy','user','Yes block them:No I want them:Allow them globally');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptScope','user','Yes:No');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialChildrenHave','user','Yes:No:Shared Custody:Other:No');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialChildrenWant','user','Yes:No:Open:Open');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialLooking','user','Hang Out:Short Term:Chat:Long-Term:Photo Exchange:Dating:Friends:Intimate Encounter:Activity Partner:Other:Friends');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialMarital','user','Single:Married:Divorced:Widowed:Seperated:Dating:Single');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialReligion','user','Agnostic:Athiest:Buddhist:Christian:Hindu:Islamic:Jewish:Pagan:Wiccan:Other:Other');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSocialSeeking','user','Male:Female:Male');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptViceDrink','user','Yes:No:Socially:No');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptViceSmoke','user','Yes:No:Socially:No');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetAbuse','user','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetFormat','user','<script language=\"Javascript\" src=\"/js/format.js\"></script>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLocateLat','user','37.39550');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetLocateLong','user','-122.070');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetVanityLimit','user','10');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetVanityMax','user','300');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetVanityPath','user','/home/erealms/www/public_html/vanity');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetVanityThumb','user','100');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetYear','user','1988');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagContact','user','Contact');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagMail','user','Email');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPass','user','Password');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPref','user','General');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagPupRoomPreview','user','[Preview only enabled when used from a realm]');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagSocial','user','Profile');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagTabbed','user','<a href=\"MLINK\" class=\"menub\">MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagVanity','user','Images');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplFormat','user','    <!- Control Bar - Where Javascript controls abilities -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">\r\n      <img src=\"/img/ctl_MFUNC.gif\">\r\n      <img src=\"/img/ctl_bold.gif\" onClick=\"MFUNC(this, 0);\">\r\n      <img src=\"/img/ctl_italics.gif\" onClick=\"MFUNC(this, 1);\">\r\n      <img src=\"/img/ctl_underline.gif\" onClick=\"MFUNC(this, 2);\">\r\n      <img src=\"/img/ctl_centre.gif\" onClick=\"MFUNC(this, 3);\">\r\n      <img src=\"/img/ctl_sep.gif\"> \r\n      <img src=\"/img/ctl_plus.gif\" onClick=\"MFUNC(this, 4);\">\r\n      <img src=\"/img/ctl_minus.gif\" onClick=\"MFUNC(this, 5);\">\r\n     </td>\r\n    </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplIgnore','user','  <!- Puppet Ignore -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Be anti-social and ignore another user -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Ignore User</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"2\">Ignore a New User?</td>\r\n    </tr>\r\n\r\n\r\n    <!- Ignore user section -->\r\n    <!- Ignore field -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Puppet Name?</td>\r\n     <td class=\"fancy_blank\">WNIGNORE</td>\r\n    </tr>\r\n\r\n    <!- Types of ingore -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Method to Ignore By?</td>\r\n     <td class=\"fancy_blank\">WNTYPES</td>\r\n    </tr>\r\n\r\n    <!- Submission -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WNSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Be nice for a change -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Lift Current Bans?</td>\r\n    </tr>\r\n\r\n    <!- Removal list and button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WIGNORED</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n      If you would like to ignore a user, simply type in their handle and\r\n      select \'Single.\'  If you would like to ignore all of that user\'s\r\n      handles, then select \'Global\' or \'Picture\' to simply ignore the\r\n      associated picture.  After a user has been added to your ignore list,\r\n      you will not see anything they post.<br><br>\r\n\r\n      You can tell which handles are individually ignored, as a \'-\' sign\r\n      will appear by their name, a \'*\' for puppets who\'s images are ignored,\r\n      a \'~\' will denote people you wish to show up with more emphasis and\r\n      which are globally ignored a \'+\' will appear by their name.  For those\r\n      wishing to make another handles tagline and title dissapear a \'%\' \r\n      symbol will be appended instead.\r\n   </div>\r\n  </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupActivity','user','  <!- Puppet Activity -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Acivity Management -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Puppet Activity Management</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"3\">Active Puppets</td>\r\n    </tr>\r\n\r\n\r\n    <!- Active handles and disable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WACTIVE</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WPUPOFF</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- New puppet selection -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Inactive Puppets</td>\r\n    </tr>\r\n\r\n    <!- Inctive handles and enable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WDISABLE</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WPUPON</td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LGROUP class=\"menub\">Puppet Groups</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Activity determines if a puppet is currently being used or not.   One which\r\n     is active will appear on all of your lists and can be played within a realm,\r\n     while inactive handles will remain dormant until called upon:<br><br>\r\n\r\n     Please note that inactive puppets can and will expire if not used for an\r\n     extended period of time.   So if a handle you have suspended months back is\r\n     no longer listed, this probably means the system cleared it for use by\r\n     the general population.\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupClone','user','  <!- Puppet Clone -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Acivity Clone -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Puppet Cloning Vats</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">Select Source and Target(s)</td>\r\n     <td class=\"fancy_sub\" align=\"right\">[MMESSAGE]</td>\r\n    </tr>\r\n\r\n    <!- Active handles and disable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WPUPPET</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WCLONE</td>\r\n     <td class=\"fancy_blank\">WTARGET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n      <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- New puppet selection -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Clone Which Section?</td>\r\n    </tr>\r\n\r\n    <!- Inctive handles and enable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WMODE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LBACK class=menub>Back</a> &#9702;\r\n      <a LGROUP class=menub>Puppet Groups</a> &#9702;\r\n      <a LACTVT class=menub>Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=menub>Export</a>\r\n      <a LIMPRT class=menub>Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Cloning is a task which allows you to copy taglines and titles word for\r\n     word onto another handle.    This feature comes in handy if you wish to\r\n     standardize the look and feel of puppets without doing a manual copy and\r\n     paste.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupConfig','user','  <!- Puppet Details -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet details -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Puppet Details</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"2\">Details for MNAME</td>\r\n    </tr>\r\n\r\n\r\n    <!- Image Information -->\r\n    <!- Image link -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Image Link</td>\r\n     <td class=\"fancy_blank\">WPUPIMG</td>\r\n    </tr>\r\n\r\n    <!- Image Demensions -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Demensions</td>\r\n     <td class=\"fancy_blank\">MIMGWIDTH x MIMGHEIGHT</td>\r\n    </tr>\r\n\r\n    <!- Image Size -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Image Size</td>\r\n     <td class=\"fancy_blank\">MIMGSIZEKB</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Homepage and Gummy -->\r\n    <!- Homepage -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Homepage</td>\r\n     <td class=\"fancy_blank\">WPUPBIO</td>\r\n    </tr>\r\n\r\n    <!- Gummy -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Gummy Image [<a href=\"/erealms/gummies\" target=\"_new\">?</a>]</td>\r\n     <td class=\"fancy_blank\">WPUPGUMMY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td  class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Checkboxes -->\r\n    <!- Active-->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Puppet is Active?</td>\r\n     <td class=\"fancy_blank\">WPUPACTV</td>\r\n    </tr>\r\n\r\n    <!- Default -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Puppet is Default?</td>\r\n     <td class=\"fancy_blank\">WPUPDEF</td>\r\n    </tr>\r\n\r\n    <!- Gummy -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Display Contact Info?</td>\r\n     <td class=\"fancy_blank\">WPUPDIS</td>\r\n    </tr>\r\n\r\n    <!- Preview -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Preview in Realm?</td>\r\n     <td class=\"fancy_blank\">WPUPPREV</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title Bar-->\r\nMPUPTITLEB\r\n\r\n    <!- Title wiget -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WPUPTITLE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Tagline bar -->\r\nMPUPTAGB\r\n\r\n    <!- Tagline  wiget -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WPUPTAG</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Inctive handles and enable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr > \r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"center\">\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LGROUP class=\"menub\">Puppet Groups</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Here you can configure all of the details if your puppet.   If you have\r\n     opted to enable to use of Javascript on the site, you will also have\r\n     panels designed to speed up the use of HTML within the Tag and Title\r\n     lines.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupExport','user','  <!- Puppet Export -->\r\n  <!- Wrapper div -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet details -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Puppet Export</td>\r\n    </tr>\r\n\r\n    <!-Export Window -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\">Select the text below and copy it into a file for later use.</td>\r\n    </tr>\r\n\r\n    <!- Create new group and create button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WPUPEXPORT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr > \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\" >\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LGROUP class=\"menub\">Puppet Groups</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Export allows you to make a backup of all your puppets to prevent loss\r\n     in case of failure on the servers.   This feature can also be used to\r\n     transfer the handles from one user to another or even to another site if\r\n     they support such a feature.<br><br>\r\n\r\n     To export, simply copy the text in the window on the left and paste it\r\n     into a notepad document.    Save it as a plain text file and keep it in\r\n     a secure location!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupGroups','user','  <!- Puppet Groups - Main -->\r\n  <!- Wrapper Table-->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet groups -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\"><b>Puppet Grouping</td>\r\n     <td class=\"fancy_title\" colspan=\"2\" align=\"right\">[MCURRENT]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Group Listing -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\" align=\"center\">MGROUPS</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"3\">Move Puppets In/Out of Groups</td>\r\n    </tr>\r\n\r\n    <!- Active handles and disable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WNOT</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WCTRL</td>\r\n     <td class=\"fancy_blank\">WARE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Remove Current Group -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Remove Current Group</td>\r\n    </tr>\r\n\r\n    <!- Current group and remove button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><font class=\"white\">MCURRENT</font></td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">&nbsp</td>\r\n     <td class=\"fancy_blank\">WDELETE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Create Current Group -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Create a New Group</td>\r\n    </tr>\r\n\r\n    <!- Create new group and create button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\"><font class=\"white\">WGROUP</font></td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">&nbsp</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr > \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Puppet groups allows you to organize your handles within a series\r\n     of groups.    This in return can allow you to use only that group\r\n     within realms, cutting down on the amount of handles you have to\r\n     play with in times of need.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupGroupsN','user','  <!- Puppet Groups - New - Appears only if no groups exit-->\r\n  <!- Wrapper Table-->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet groups -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Puppet Grouping</td>\r\n    </tr>\r\n\r\n    <!- Create Current Group -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\">Create a New Group</td>\r\n    </tr>\r\n\r\n    <!- Create new group and create button -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WGROUP</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">&nbsp</td>\r\n     <td class=\"fancy_blank\">WCREATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n      <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Puppet groups allows you to organize your handles within a series\r\n     of groups.    This in return can allow you to use only that group\r\n     within realms, cutting down on the amount of handles you have to\r\n     play with in times of need.\r\n   </div>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupImport','user','  <!- Puppet Import-->\r\n  <!- Wrapper Table-->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet Import -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Puppet Import</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"3\">Paste Text Into Box Blow</td>\r\n    </tr>\r\n\r\n\r\n    <!- Active handles and disable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WPUPIMPORT</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\" align=\"center\">\r\n      Create Duplicates?<br><br>WPUPUNIQUE\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Inctive handles and enable buttons -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"1\">WPUPSUBMIT</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WPUPRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Links -->\r\n    <tr > \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LBACK class=\"menub\">Back</a> &#9702;\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LGROUP class=\"menub\">Puppet Groups</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Import Results -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\" align=\"center\">LSTIMPORT</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Export allows you to make a backup of all your puppets to prevent loss\r\n     in case of failure on the servers.   This feature can also be used to\r\n     transfer the handles from one user to another or even to another site if\r\n     they support such a feature.<br><br>\r\n\r\n     To import, simply copy the text you grabbed previously from the export\r\n     page and copy it into here.   The system will then handle the rest!\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplPupList','user','  <!- Puppet Listing -->\r\n  <!- Wrapper Table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Puppet listing -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title and Puppet totals -->\r\n    <tr> \r\n     <td class=\"fancy_title\">Puppet Listing</td>\r\n     <td class=\"fancy_title\" colspan=\"2\" align=\"right\">Total Puppets - MCOUNT</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">Details / Delete</td>\r\n     <td class=\"fancy_follow\" colspan=\"2\" align=\"right\">[MSTATS]</td>\r\n    </tr>\r\n\r\n    <!- Listing and Viewing -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" rowspan=\"2\">WLIST</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WVIEW</td>\r\n    </tr>\r\n\r\n    <!- Confirmation and delete -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WDELE&nbsp;&nbsp;WCONF</td>\r\n    </tr>\r\n\r\n\r\n    <!- New puppet selection -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Create New Puppet</td>\r\n    </tr>\r\n\r\n    <!- New puppet wiget -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Puppet Name?</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WNEWC</td>\r\n    </tr>\r\n\r\n    <!- Ability to clone -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Clone Which Puppet?</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WCLNE</td>\r\n    </tr>\r\n\r\n    <!- Submit button -->\r\n    <tr>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WMAKE</td>\r\n    </tr>\r\n\r\n    <!- Links -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\" align=\"center\">\r\n      <a LCLONE class=\"menub\">Clone & Copy</a> &#9702;\r\n      <a LGROUP class=\"menub\">Puppet Groups</a> &#9702;\r\n      <a LACTVT class=\"menub\">Puppet Activity</a> &#9702;\r\n      <a LEXPRT class=\"menub\">Export</a>\r\n      <a LIMPRT class=\"menub\">Import</a>\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Welcome to the Puppet Selection List!  From this point, you can\r\n     add, remove and modify any handle under your control.<br><br>\r\n\r\n     In order to clone when creating a new puppet, make sure that you\r\n     have a puppet selected in the \'Details / Delete\' section of the\r\n     panel.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRegAccepted','user',' <!- Registration Acceptance -->\r\n <!- Outer border -->\r\n <div class=\"ermedium\" style=\"width: 325px;\">\r\n\r\n  <!- Title field -->\r\n  <div class=\"rowdark\">Welcome to Ethereal Realms!</div>\r\n\r\n  <!- Wrapper Table -->\r\n  <div class=\"erlight\" style=\"width: auto; text-align: left;\">\r\n   Your registration is complete and you are now free to access Ethereal\r\n   Realms via the <a href=\"/erealms/gate.pl\" class=\"dark\">Gateway</a>. We\r\n   recommend bookmarking this link for future use.<br><br>\r\n\r\n   The <a href=\"/erealms/gate.pl\" class=\"dark\">Gateway</a> is your gateway\r\n   to the Realms. There you will have access to:<br><br>\r\n\r\n   <ul>\r\n    <li>Basic, framed, or Streaming chat</li>\r\n    <li>Public and Private Realms</li>\r\n    <li>Puppet configuration</li>\r\n    <li>User configuration</li>\r\n    <li>Internal Email</li>\r\n    <li>Homepage/Image and Gallery hosting</li>\r\n    <li>Message boards</li>\r\n   </ul>\r\n\r\n   Should you at any time require assistance,\r\n   <a href=\"/faq.html\" target=\"_new\" class=\"dark\">help section</a> are\r\n   available to you at the top of every page.   There you will find all\r\n   you need to know in order to register, create puppets, and make use\r\n   of the realms.<br>\r\n  </div>\r\n </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRegConf','user','  <!- Registration Confirmation page -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Confirmation Table -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Confirm User Registration</td>\r\n    </tr>\r\n\r\n    <!- Additional text -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Complete the Following to Confirm</td>\r\n    </tr>\r\n\r\n    <!- Login Name -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Login Name</td>\r\n     <td class=\"fancy_blank\">WLOGIN [A-Z0-9]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Confirmation Code -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Confirmation Code</td>\r\n     <td class=\"fancy_blank\">WCONFC [A-Z0-9]</td>\r\n    </tr>\r\n\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submission -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WSBMIT</td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Quick Help -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n      Please fill in all areas below with the information received from your\r\n      registration Email.  Your application will then be confirmed for validity\r\n      and will be processed in the order in which it was received.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRegGather','user','  <!- Registration Information page -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Information Table -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr>\r\n     <td class=\"fancy_title\" colspan=\"3\">User Registration</td>\r\n    </tr>\r\n\r\n    <!- Additional text -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">Fill in the Form Below?</td>\r\n     <td class=\"fancy_follow\" colspan=\"2\" align=\"right\">[MERRORMSG]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Login Name -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Login Name</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WUSERNAME [A-Z0-9]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Full name -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Full Name***</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WFULLNAME</td>\r\n    </tr>\r\n\r\n    <!- Handle name -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Screen Name****</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WCHARNAME</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Initial Email Address -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Email Address</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WEMAILONE</td>\r\n    </tr>\r\n\r\n    <!- Confirmation Email Address -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Email Address</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WEMAILTWO (Repeat)</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Initial Password -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Password<i>*</i></td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WUPASSONE</td>\r\n    </tr>\r\n\r\n    <!- Confirmation Email Address -->\r\n    <tr>\r\n     <td class=\"fancy_Descr\">Password<i>*</i></td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WUPASSTWO (Repeat)</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n    <!- Titles -->\r\n    <tr>\r\n     <td class=\"fancy_Sub\">Javascript<i>**</i></td>\r\n     <td class=\"fancy_Sub\">Chatting<i>**</i></td>\r\n     <td class=\"fancy_Sub\">Formatting<i>**</i></td>\r\n    </tr>\r\n\r\n    <!- Widgets in order above -->\r\n    <tr>\r\n     <td class=\"fancy_Blank\">WRADJAVAS</td>\r\n     <td class=\"fancy_Blank\">WRADCHATP</td>\r\n     <td class=\"fancy_Blank\">WRADFORMT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr>\r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Submission -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"3\">WSUBMIT</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick Help -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n    <b>Quick Help</b><br><br>\r\n\r\n    Please fill in all areas below with the information requested.  Your application\r\n    will be processed in the order in which it was received.  Once Ethereal Realms\r\n    has processed the information an Email will be sent to you in order to confirm its\r\n    validity.<br><br>\r\n\r\n    <b>*</b> Passwords are encrypted and cannot be retrieved.<br>\r\n    <b>**</b> These settings can be adjusted later on if necessary.<br>\r\n    <b>***</b> This information is not shown to the public.<br>\r\n    <b>****</b> This will be what people will initially see you as when using the site.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplRegPolicy','user','  <!- Acceptable Use Policy -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Policies and Directives -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\">Acceptable Use Policy</td>\r\n    </tr>\r\n\r\n    <!- ARTICLE I - DEFINITIONS -->\r\n    <tr>\r\n     <td class=\"fancy_follow\">ARTICLE I - DEFINITIONS</td>\r\n    </tr>\r\n\r\n    <!- Body -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" align=\"justify\">\r\n      <p>&quot;Agreement&quot; means this Agreement, including an \r\n        understanding and acceptance of this and all of the following\r\n        articles as listed within this document.</p>\r\n\r\n      <p>&quot;Confirmation&quot; means the acceptance of the agreement\r\n        between the Chatter and Ethereal, which may  be enforced from\r\n        the time of acceptance of this agreement.</p>\r\n\r\n      <p>&quot;Ethereal&quot; means the hosting service for \r\n        the chatting system. Which includes but is not limited \r\n        to, chatting, posting on message board, the hosting \r\n        pages, images and/or galleries on it\'s severs.</p>\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\"></td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- ARTICLE II - CONDUCT  -->\r\n    <tr>\r\n     <td class=\"fancy_sub\">ARTICLE II - CONDUCT</td>\r\n    </tr>\r\n\r\n    <!- Body -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" align=\"justify\">\r\n      <p>1. Ethereal, while being itself under the jurisdiction \r\n        of Canadian law, strives to not only enforce laws which \r\n        apply directly under it, but maintains a strict code \r\n        of conduct to which all chatters, hosts, and members \r\n        of council are bound. Failure to comply with any and \r\n        all of the following points may result in immediate \r\n        and irrevocable banning from Ethereal, which is dependent \r\n        on the severity of the infraction itself.</p>\r\n\r\n      <p>2. The practice, discussion and/or advocation of illegal \r\n        activities will not be tolerated while on Ethereal. \r\n        This includes, but is not limited to, and any all computer \r\n        crimes/vandalism related to computer crimes that fall \r\n        under Canadian law;</p>\r\n\r\n      <blockquote>\r\n       <p>a. The proliferation or discussion of child pornography \r\n         and transmittance of any and all pornographic materials \r\n         to minors;</p>\r\n\r\n       <p>b. The creation of material involving scenes that would \r\n         be considered pedophilic in nature, will not be tolerated. \r\n         This includes and but is not limited to:</p>\r\n\r\n       <blockquote>\r\n\r\n        <p>1) Scenes which place a character below the age of \r\n          concent, in sexual relations with a character of adult \r\n          age. With the exclusion of the historically accurate \r\n          instances where such acts would have been socially acceptable.</p>\r\n        <p>2) Any scenes which is referred to as pedophilic in \r\n          nature by Canadian laws.</p>\r\n       </blockquote>\r\n\r\n       <p>c. The discrimination/harassment of any groups and/or \r\n         individuals based of race, creed, beliefs, sex or as \r\n         defined in the Canadian criminal code of law will not \r\n         be tolerated and will result in immediate termination \r\n         of the chatters account.</p>\r\n      </blockquote>\r\n\r\n      <p>3. Recruiting, meaning the act of leading other chatters \r\n        to other realms and/or systems during their tenure on \r\n        Ethereal Realms is only allowed under explicit permission \r\n        from the host(s) of the affected realm. Without any \r\n        such permission, the hosts of said realm and the council \r\n        can take it upon themselves to ban offending users at \r\n        room or system level depending on the severity of the \r\n        infraction.</p>\r\n\r\n      <p>4. The circumvention of bans, through the creation \r\n        of additional accounts or by violation of terms outlined \r\n        in Article II (CONDUCT) second paragraph, will result \r\n        in the permanent, immediate and unconditional banning \r\n        from Ethereal. The chatter will also accept that these \r\n        procedures come without the ben');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplReset','user','  <!- User Password Reset -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- User Password Reset -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Password Reset</td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_follow\" colspan=\"2\">Provide a Username Below and Reset</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Username -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Username</td>\r\n     <td class=\"fancy_blank\">WUSERNAME [A-Z0-9]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Reset -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WRESET</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Status line -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\" align=\"right\">[MMESS]</td>\r\n    </tr>\r\n   </table>\r\n\r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     This script will allow you to reset the password to your account\r\n     given the username.  Simply fill in the form on the left-hand\r\n     side and the system will conduct the rest.<br><br>\r\n\r\n     <b>Note:</b> Ethereal Realms will send an Email to the address\r\n     which is registered under your account.   If that Email is out\r\n     of date or no longer active you may not get the new password.\r\n     In this case, send out an Email to the \r\n     <a href=\"mailto:council@ethereal-realms.org\" class=\"dark\">Council</a>.<br><br>\r\n\r\n     It is highly recommended that you change your username after you have\r\n     received the password and logged on, since it will reduce the chances\r\n     of the password being forgotten.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocial','user','  <!- Social Profile -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Social Profile</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Catch Phrase</td>\r\n    </tr>\r\n\r\n    <!- Catch Phrase -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSIPHRASE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Physical Traits</td>\r\n    </tr>\r\n\r\n\r\n    <!- Gender -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Gender</td>\r\n     <td class=\"fancy_blank\">WSPGENDER</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Birth Date of Individual -->\r\n    <!- Gender -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Birth Day</td>\r\n     <td class=\"fancy_blank\">WSPBDAY</td>\r\n    </tr>\r\n\r\n    <!- Month -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Birth Month</td>\r\n     <td class=\"fancy_blank\">WSPBMONTH</td>\r\n    </tr>\r\n\r\n    <!- Year -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Birth Year</td>\r\n     <td class=\"fancy_blank\">WSPBYEAR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Height -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Height</td>\r\n     <td class=\"fancy_blank\">WSPHEIGHT</td>\r\n    </tr>\r\n\r\n    <!- Body Type -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Body Type</td>\r\n     <td class=\"fancy_blank\">WSPBODY</td>\r\n    </tr>\r\n\r\n    <!- Eye Colour -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Eye Colour</td>\r\n     <td class=\"fancy_blank\">WSPEYES</td>\r\n    </tr>\r\n\r\n    <!- Hair Colour -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Hair Colour</td>\r\n     <td class=\"fancy_blank\">WSPHAIR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Height -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Ethnicity</td>\r\n     <td class=\"fancy_blank\">WSPETHNIC</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Social Aspects</td>\r\n    </tr>\r\n\r\n\r\n    <!- Looking for Socially -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Looking For</td>\r\n     <td class=\"fancy_blank\">WSSLOOKING</td>\r\n    </tr>\r\n\r\n    <!- Seeking Gender -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Seeking</td>\r\n     <td class=\"fancy_blank\">WSSSEEKING</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Looking for Socially -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Youngest</td>\r\n     <td class=\"fancy_blank\">WSSAGEMIN</td>\r\n    </tr>\r\n\r\n    <!- Seeking Gender -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Oldest</td>\r\n     <td class=\"fancy_blank\">WSSAGEMAX</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Marital Status -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Marital Status</td>\r\n     <td class=\"fancy_blank\">WSSMARITAL</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Children -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Have Children</td>\r\n     <td class=\"fancy_blank\">WSSHCHILD</td>\r\n    </tr>\r\n\r\n    <!- Babies -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Want CHildren</td>\r\n     <td class=\"fancy_blank\">WSSWCHILD</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Religion-->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Profession</td>\r\n     <td class=\"fancy_blank\">WSSWORK</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Religion-->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Religion/Beliefs</td>\r\n     <td class=\"fancy_blank\">WSSRELIGION</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Vices</td>\r\n    </tr>\r\n\r\n\r\n    <!- Smoker -->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Smoke</td>\r\n     <td class=\"fancy_blank\">WSVSMOKE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Drinker-->\r\n    <tr>\r\n     <td class=\"fancy_descr\">Drink</td>\r\n     <td class=\"fancy_blank\">WSVDRINK</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Interests</td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSSINTEREST</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Describe Yourself</td>\r\n    </tr>\r\n\r\n    <!- Description -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSIDESCR</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Ideas for a First Date</td>\r\n    </tr>\r\n\r\n    <!- First Date -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSIDATE</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Your profile is very important when it comes to making contact\r\n     with other members of the site.    It allows users to gain more\r\n     insight on who you are, so its important to present yourself\r\n     in the best light possible.<br><br>\r\n\r\n     For ease of use, the form has been split into various sections\r\n     designed to cover specific facts of your profile.    The sections\r\n     are outlined below:<br><br>\r\n\r\n     <b>Catch Phrase</b>:  This is simply a quick phrase used to \r\n      summarize who you are and may be looking for.   This could also\r\n      be viewed as a pick up line.<br><br>\r\n\r\n     <b>Physical Traits</b>:  These questions revolve around the\r\n      physical aspects of yourself.   Generally these are outside\r\n      of your direct control.<br><br>\r\n\r\n     <b>Physical Traits</b>:  These questions revolve around social\r\n      aspects of your life and can range from your beleifs to your\r\n      profession.<br><br>\r\n\r\n     <b>Vices</b>:  A cute term to describe habits which can be\r\n      viewed differently based on cultural and personal beliefs.<br><br>\r\n\r\n     <b>Interests</b>:  Hobbies or things that interest you can be\r\n      put into here.  Please use a comma in between to seperate the\r\n      items.<br><br>\r\n\r\n     <b>Describe Yourself</b>:  Use this field to describe yourself\r\n      as much as possible.    This is your chance to be heared.<br><br>\r\n\r\n     <b>Ideas for a First Date</b>:  Show how much of a romantic you\r\n      are or present your view of what a good first date would be.<br><br>\r\n\r\n     <b>Note:</b> If you need to change your location, please click on the\r\n       icon below to change those settings.<br><br>\r\n\r\n     <div align=\"center\">\r\n      <a href=\"LLOCATE\" class=\"dark\">\r\n       <img src=\"/img/geo_sm.jpg\" width=\"30\" height=\"30\" style=\"border: 1px solid #E3F3FA;\">\r\n      </a>\r\n     </div>\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialConfirm','user','  <!- Social Confirmation / Location pinpoit -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Confirmations -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Confirm your Location</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"3\">Fill in the blanks below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Country -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">City</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WCITY</td>\r\n    </tr>\r\n\r\n    <!- Region -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Region</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WREGION</td>\r\n    </tr>\r\n\r\n    <!- Country -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Country</td>\r\n     <td class=\"fancy_blank\" colspan=\"2\">WCOUNTRY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Geocoding -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">Physical Location</td>\r\n    </tr>\r\n\r\n    <!- Latitude -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Latitude</td>\r\n     <td class=\"fancy_blank\">MLAT</td>\r\n\r\n     <!- Link to google maps -->\r\n     <td class=\"fancy_blank\" rowspan=\"2\" valign=\"middle\" align=\"right\">\r\n      <a href=\"LGEO\"><img src=\"/img/geo.jpg\" width=\"100\" height=\"100\" style=\"border: 2px solid #E3F3FA;\"></a>\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Longitude -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Longitude</td>\r\n     <td class=\"fancy_blank\">MLON</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"3\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"3\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     If this is the first time you have used this panel, then the\r\n     site will do its best to try to locate where you are.   We\r\n     understand that this may be wildly innacurate, so please change\r\n     the details to match your need.<br><br>\r\n\r\n     In order to improve the performance of your searches, please\r\n     also click on the link next to the Latitude and Longitude.   This\r\n     will provide you with a way of specifying exactly where you are \r\n     and your searches for people near to you will be more accurate as\r\n     a result.\r\n\r\n     <!- Error message -->\r\n     MMESSAGE\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialLocate','user','<html>\r\n <head>\r\n  <title>Ethereal Realms - Gateway to the Imagination</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n  <!- Google Maps API -->\r\n  <script src=\"http://maps.google.com/maps?file=api&amp;v=2&amp;key=MGMKEY\" type=\"text/javascript\"></script>\r\n\r\n  <!- Additional Definitions -->\r\n  <script src=\"/js/geo.js\" type=\"text/javascript\"></script>\r\n\r\n  <!- Additional details -->\r\n  <script type=\"text/javascript\">\r\n\r\n    //<![CDATA[\r\n\r\n    // Load function specific for this application\r\n    function load() {\r\n      if (GBrowserIsCompatible()) {\r\n\r\n        // Create instance\r\n        var map = new GMap2(document.getElementById(\"map\"));\r\n\r\n\r\n        // Map controls\r\n        // Pan and Zoom\r\n        map.addControl(new GLargeMapControl());\r\n\r\n        // Quick overview section\r\n        map.addControl(new GOverviewMapControl());\r\n\r\n        // Ethereal Realms specific control\r\n        map.addControl(new erControl());\r\n\r\n\r\n        // Centre map\r\n        map.setCenter(new GLatLng(MSLAT, MSLON), 13);\r\n\r\n\r\n\r\n        // Event handlers\r\n        // Handling of clicks on markers\r\n        GEvent.addListener(map, \"click\", function(marker, point) {\r\n          if (marker) {\r\n\r\n            // Change current marker\r\n            if (erCurrent != null) {\r\n              // Have to remove first\r\n              map.removeOverlay(erCurrent);\r\n\r\n              // Re-create with changed colour\r\n              map.addOverlay(new GMarker(erPoint, erPasvIcon));\r\n            }\r\n\r\n            // Fetch new point\r\n            erPoint = marker.getPoint();\r\n\r\n            // Remove the current changed state\r\n            map.removeOverlay(marker);\r\n\r\n \r\n            // New current\r\n            erCurrent = new GMarker(erPoint, erActvIcon);\r\n\r\n            // Add overlay to make person comfortable\r\n            map.addOverlay(erCurrent);\r\n          }\r\n        });\r\n      }\r\n    }\r\n\r\n    //]]>\r\n  </script>\r\n </head>\r\n\r\n <body onload=\"load()\" onunload=\"GUnload()\">\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Find where you are</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n      <!- Testing feature -->\r\n      WSTRFORM\r\n       \r\n\r\n       <!- These are specific to the code -->\r\n       <input type=\"hidden\" name=\"GEOLAT\" value=\"\">\r\n       <input type=\"hidden\" name=\"GEOLON\" value=\"\">\r\n      WENDFORM\r\n\r\n\r\n      <!- Google Maps -->\r\n      <!- Wrapper div -->\r\n      <div class=\"fancy_holder\">\r\n\r\n       <!- Puppet details -->\r\n       <!- Table definition -->\r\n       <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n        <!- Title -->\r\n        <tr> \r\n         <td class=\"fancy_title\">Where are you?</td>\r\n        </tr>\r\n\r\n        <!-Export Window -->\r\n        <tr> \r\n         <td class=\"fancy_follow\">Use the map below to locate where you live?</td>\r\n        </tr>\r\n\r\n\r\n        <!- Spacer -->\r\n        <tr> \r\n         <td class=\"fancy_div\"></td>\r\n        </tr>\r\n\r\n\r\n        <!- Display Google Maps Interface -->\r\n        <tr> \r\n         <td class=\"fancy_blank\" align=\"center\">\r\n          <!- All goes within a nice and neat div -->\r\n          <div id=\"map\" style=\"width: 480px; height: 320px\"></div>\r\n         </td>\r\n        </tr>\r\n\r\n\r\n        <!- Spacer -->\r\n        <tr> \r\n         <td class=\"fancy_div\"></td>\r\n        </tr>\r\n\r\n\r\n        <!- Links -->\r\n        <tr> \r\n         <td class=\"fancy_sub\">\r\n          MLINKS\r\n         </td>\r\n        </tr>\r\n       </table>\r\n\r\n       <!- Quick help section -->\r\n       <div class=\"fancy_help\">\r\n        <!- Quick help text -->\r\n         <b>Quick Help</b><br><br>\r\n\r\n         Ethereal Realms makes use of Google Maps in order to pinpoint your location.\r\n         All of the key fuctionality of maps works as expected, except that\r\n         additional buttons have been added in order to track your location with\r\n         more precision.<br><br>\r\n\r\n         This information is not publicly available, however it is used in \r\n         conjunction with search.  These searches will be able to narrow down other\r\n         users in your area, so precision and honesty will only aid you in finding\r\n         someone else!<br><br>\r\n\r\n         Remember that double click with the mouse will center the screen on the\r\n         location.    Use the \'Set\' key to add a marker that can be used to find\r\n         the approrpriate co-ordinates.   You can have multiple markers and the one\r\n         currently in a light red will always be active.<br><br>\r\n\r\n         Once your satisfied, click on the \'Select\' button and the system will\r\n         handle the rest!\r\n       </div>\r\n      </div>\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserContact','user','  <!- User Configuration Contacts -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Contact Information</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Provide as much information as you see fit below:</td>\r\n    </tr>\r\n\r\n\r\n    <!- Generate complete list -->\r\nLSTITEM\r\n\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n     <td class=\"fancy_blank\">WRESET</td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Contact information is used by the system when displaying your \r\n     biographical information.   All of the information you provide\r\n     is entirely optional and can even be disabled on a per Puppet\r\n     basis in order to maintain more privacy.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserContactItem','user','    <!- Entry -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">MNAME</td>\r\n     <td class=\"fancy_blank\">WCONTROL</td>\r\n    </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserContactType','user','    <!- Spacer -->\r\n    <tr> \r\n     <td  class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Title Section -->\r\n    <tr> \r\n     <td  class=\"fancy_sub\" colspan=\"2\">MNAME</td>\r\n    </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserMail','user','  <!- Email Changes -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Change your Email Address</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Fill in the blanks below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MPASS]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Old for Safety -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Password</td>\r\n     <td class=\"fancy_blank\">WPOLD</td>\r\n    </tr>\r\n\r\n    <!- Email Addy -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Email Address</td>\r\n     <td class=\"fancy_blank\">WEMAIL</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Your Email address is important for getting notices, updates and\r\n     other correspondence from the site.     Even post extracts will\r\n     require a valid Email address, so make sure that its kept up to\r\n     date!<br><br>\r\n\r\n     <b>Note:</b>For the purpose of safety, you will be required to type\r\n      in your old password in order to change it.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserPass','user','  <!- Password Changes -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Change your Password</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\">Fill in the blanks below</td>\r\n     <td class=\"fancy_follow\" align=\"right\">[MPASS]</td>\r\n    </tr>\r\n\r\n\r\n    <!- Old for Safety -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Old Password</td>\r\n     <td class=\"fancy_blank\">WPOLD</td>\r\n    </tr>\r\n\r\n    <!- New for Change -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">New Password</td>\r\n     <td class=\"fancy_blank\">WPNEW</td>\r\n    </tr>\r\n\r\n    <!- Catch all errors -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Repeat Above</td>\r\n     <td class=\"fancy_blank\">WPSEC</td>\r\n    </tr>\r\n\r\n\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"center\">MLINKS</td>\r\n     </td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     Your password is the key to your account on Ethereal Realms, as a\r\n     result you may wish to make sure that no one else knows the\r\n     password to prevent abuse.   If you feel someone else may very well\r\n     know the password, then we strongly urge you to change it using\r\n     this form.<br><br>\r\n\r\n     <b>Note:</b>For the purpose of safety, you will be required to type\r\n      in your old password in order to change it.\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserPref','user','  <!- Preferences -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Gallery selection -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Manage your Settings</td>\r\n    </tr>\r\n\r\n    <!- Features -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Chatting Features</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Javascript Features?</td>\r\n     <td class=\"fancy_blank\">WJAVA</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Chatting Options -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Chatting Interface?</td>\r\n     <td class=\"fancy_blank\">WCHAT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Post Formatting -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Formatting of Posts?</td>\r\n     <td class=\"fancy_blank\">WFORMAT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <!- Privacy Features -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Kill Private Messages?</td>\r\n     <td class=\"fancy_blank\">WPRIVACY</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- General -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">General</td>\r\n    </tr>\r\n\r\n    <!- Email Settings -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Where to send mail?</td>\r\n     <td class=\"fancy_blank\">WMAILER</td>\r\n    </tr>\r\n\r\n\r\n    <!- Potential host additions -->\r\nLSTHOST\r\n\r\n\r\n    <!- Listing and Control wigets -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"2\">WSUBMIT</td>\r\n    </tr>\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"2\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     <b>Javascript Options:</b> Disables additional features which are\r\n      normally available on the site.   Such as autoscrolling, descriptive\r\n      realm selection and formatting for handles.<br><br>\r\n\r\n     <b>Chatting Interface:</b> Changes how the system presents posts to you\r\n      with basic being self contained to one page and onto streaming which\r\n      presents you with posts as they become available.<br><br>\r\n\r\n     <b>Formatting Posts:</b> Normally posts come with all of the bells and\r\n      whistles enabled.   This allows you to cut them down a bit if you\r\n      find things too busy to your liking.<br><br>\r\n\r\n     <b>Private Messaging:</b> This allows private messages to be dealt\r\n      with according to your preferences.<br><br>\r\n\r\n     <b>Sending Mail:</b> Send you messages through Email or drop it off\r\n      into your Internal Mail inbox.  The choice is yours!\r\n\r\n   </div>\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplUserPrefHost','user','    <!- Host specific -->\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"2\"></td>\r\n    </tr>\r\n\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"2\">Hosting / Moderative Features</td>\r\n    </tr>\r\n\r\n    <!- Email Settings -->\r\n    <tr> \r\n     <td class=\"fancy_descr\">Ignore users in realm?</td>\r\n     <td class=\"fancy_blank\">WIGNORE</td>\r\n    </tr>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanity','user','  <!- Vanity listing and changes -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n\r\n   <!- Vanity thy favourite sin -->\r\n   <!- Table top -->\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"6\">Personal Pictures</td>\r\n    </tr>\r\n\r\n    <!- Ease their concious -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"6\">Currently uploaded images are below</td>\r\n    </tr>\r\n\r\n    <!- Update things accordingly -->\r\nMCURRENT\r\n\r\n\r\n\r\n    <!- Uploads -->\r\nWUPLOAD\r\n\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"6\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Status -->\r\n    <tr> \r\n     <td class=\"fancy_sub\"  colspan=\"6\" align=\"center\">MLINKS</td>\r\n    <tr> \r\n   </table>\r\n \r\n\r\n   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <!- Quick help text -->\r\n     <b>Quick Help</b><br><br>\r\n\r\n     You can upload images though this interface.  Once uploaded, you\r\n     will be able to manage minor details of these images, set your\r\n     preferences and use them in various aspects of the social\r\n     network.\r\n   </div>\r\n  </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityCurrent','user','    <!- Current Listing -->\r\n    <!- Helpful guide -->\r\n    <tr>\r\n     <td class=\"fancy_blank\"></td>\r\n     <td class=\"fancy_blank\"><b>IMG</b></td>\r\n     <td class=\"fancy_blank\">&nbsp;</td>\r\n     <td class=\"fancy_blank\"><b>Public</b></td>\r\n     <td class=\"fancy_blank\"><b>Vote</b></td>\r\n     <td class=\"fancy_blank\"><b>Delete</b></td>\r\n    </tr>\r\nLSTCURRENT\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"6\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Uploads -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"6\">Set as default image</td>\r\n    </tr>\r\n\r\n    <!- Radio List -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"5\">WDEFAULT</td>\r\n     <td class=\"fancy_blank\">WUPDATE</td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityListing','user','    <!- List of MID -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" align=\"center\" valign=\"middle\" style=\"width: 40px;\"><b>MNUM</b></td>\r\n     <td class=\"fancy_blank\" valign=\"middle\" style=\"height: 110px;\"><img src=\"LTHUMB\" alt=\"MSCORE w/ MVOTES\" title=\"MSCORE w/ MVOTES\"></td>\r\n     <td class=\"fancy_blank\" style=\"width: 40px;\">&nbsp;</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WPUBLIC</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WVOTE</td>\r\n     <td class=\"fancy_blank\" valign=\"middle\">WDELETE</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityUpload','user','    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"6\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Uploads -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"6\">Upload a new image</td>\r\n    </tr>\r\n\r\n    <!- Upload section -->\r\n    <tr> \r\n     <td class=\"fancy_blank\" colspan=\"5\">WUPLOAD</td>\r\n     <td class=\"fancy_blank\">WSUBMIT</td>\r\n    </tr>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtAccept','user','Accept');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtActive','user','Active');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtAddition','user','Insert');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtBack','user','Back');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtChange','user','Change');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtClone','user','>>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtConfirm','user','Confirm');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtDelete','user','Delete');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMoveIn','user','>>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtMoveOut','user','<<');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNone','user','---- None ----');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtRegister','user','Register');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtReset','user','Reset');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubmit','user','Alter');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSuspend','user','Suspend');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtUpload','user','Upload');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtView','user','View');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkMail','vanity','/erealms/mail.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('LnkVanity','vanity','/erealms/vanity.pl');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('MsgErrorEmpty','vanity','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSearchDistance','vanity','5:10:25:50:100:150:200');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('OptSearchRestrict','vanity','All Inclusive:To Region:To City');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDisplay','vanity','25');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('SetDisplayMax','vanity','250');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGeoLackofVanity','vanity','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagGeoVanity','vanity','<img src=\\"MIMAGE\\" alt=\\"User\\" title=\\"user\\"><br>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagInterestsList','vanity','MNAME');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagInterestsNone','vanity','None');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagInterestsSep','vanity',',&nbsp;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonRFoe','vanity','<img src=\"/img/rel_red.jpg\"   width=\"30\" height=\"30\" alt=\"Foe\"       title=\"Foe\"       style=\"border: none;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonRFriend','vanity','<img src=\"/img/rel_blue.jpg\"  width=\"30\" height=\"30\" alt=\"Friend\"    title=\"Friend\"    style=\"border: none;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonRInitial','vanity','<img src=\"/img/rel_trans.jpg\" width=\"30\" height=\"30\" alt=\"Initial\"   title=\"Initial\"   style=\"border: none;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonRNeutral','vanity','<img src=\"/img/rel_grey.jpg\"  width=\"30\" height=\"30\" alt=\"Neutral\"   title=\"Neutral\"   style=\"border: none;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonSNil','vanity','<img src=\"/img/mail_none.gif\" alt=\"No mai sent or received!l\"   title=\"No mail sent or received!\"   style=\"border: 1px solid #A9C5D1;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonSOwner','vanity','<img src=\"/img/mail_sent.gif\" alt=\"You sent this person mail!\" title=\"You sent this person mail!\" style=\"border: 1px solid #A9C5D1;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagLiasonSTarget','vanity','<img src=\"/img/mail_rcvd.gif\" alt=\"Person sent you mail!\" title=\"Person sent you mail!\" style=\"border: 1px solid #A9C5D1;\">');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNav','vanity','<a href=\"MLINK\" class=\"menub\">MNAME</a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavDis','vanity','<a href=\"MLINK\" class=\"menub\"><b>MCOUNT</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagNavVis','vanity','<a href=\"MLINK\" class=\"menud\"><b>MCOUNT</b></a> ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagSocialLackofVanity','vanity','<a href=\"MLINK\"><img src=\"/img/outline.gif\" alt=\"No Picture\" title=\"No Picture\" style=\"padding: 3px; border: none;\"></a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TagSocialVanity','vanity','<a href=\"MLINK\"><img src=\"MIMAGE\" alt=\"User\" title=\"User\"  style=\"padding: 3px; border: none;\"></a>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplErrorEmpty','vanity','   <!- Error Message - No results -->\r\n   <div class=\"fancy_help\" style=\"float: none;\">\r\n    <!- Quick help text -->\r\n     <b>No valid returns</b><br><br>\r\n     We are sorry but your search has turned up no one\r\n     perhaps you should widen the gap in your search or\r\n     change the settings with which you are looking.\r\n   </div>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplErrorInvalid','vanity','   <!- Error Message - Attempted access to a non-existent profile -->\r\n   <div class=\"fancy_help\" style=\"float: none;\">\r\n    <!- Quick help text -->\r\n     <b>Does not exist</b><br><br>\r\n     The profile you have attempted to access does not exist.  If\r\n     you have by chance bookmarked this profile previously, then\r\n     the user is most probably no longer making use of this\r\n     service.<br><br>\r\n\r\n     We are sorry for any inconvenience that this may have caused\r\n     you.   For additional questions, feel free to contact the\r\n     administrators of the site or click on the FAQ link located\r\n     in the top part of the page.     \r\n   </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplErrorProfile','vanity','   <!- Error Message - No valid profile -->\r\n   <div class=\"fancy_help\" style=\"float: none;\">\r\n    <!- Quick help text -->\r\n     <b>No valid profile</b><br><br>\r\n     You have not yet established a valid profile with the\r\n     site and as a result you cannot search through the \r\n     current list of profiles.   Please remedy this by \r\n     creating a profile through the \'User Details\' section\r\n     of the portal prior to attempting this again.    \r\n   </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocial','vanity','<html>\r\n <head>\r\n  <title>Ethereal Realms - MPUPPETNAME - MINTROCATCHPHRASE</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n  <!- General Javascript with Linking Capabilities-->\r\n  <!- Menu non-javascript specific popups -->\r\n  <script language=\"Javascript\">\r\n   <!--\r\n    // Set size below default if need be\r\n    var height = (screen.height < 535) ?  screen.availHeight : 535;\r\n    var width  = (screen.width  < 735) ?  screen.availWidth  : 735;\r\n\r\n    // Build string\r\n    var settings = \'width=\'+width+\',height=\'+height+\',fullscreen=no,resizable=yes,status=yes,scrollbars=yes,toolbars=no\';\r\n\r\n    // -->\r\n  </script>\r\n </head>\r\n\r\n <body>\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; MPUPPETNAME</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n      <!- Wrap in a table -->\r\n      <table width=\"98%\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\" style=\"background-color: #88A9B8; border: 1px solid #E3F3FA;\">\r\n\r\n       <!- Top Bar -->\r\n       <tr>\r\n        <!- Location and list the users catch phrase -->\r\n        <!- Name, login and Email -->\r\n        <td style=\"height: 37px; background-color: #274F60; border-bottom: 1px solid #E3F3FA;\" valign=\"middle\">\r\n          &nbsp;<span class=\"stark\" style=\"margin-top: 5px;\"><b>MLOCATECITY, MLOCATEREGION, MLOCATECOUNTRY - MINTROCATCHPHRASE</b></span>\r\n        </td>\r\n\r\n        <!- IFF status -->\r\n        <td style=\"height: 37px; background-color: #274F60; border-bottom: 1px solid #E3F3FA;\" align=\"right\">\r\n         <a href=\"LLIASONRELATION\">MLIASONRELATION</a>\r\n        </td>\r\n       </tr>\r\n\r\n\r\n       <!- Information Display -->\r\n       <tr> \r\n        <td valign=\"top\" colspan=\"2\">\r\n\r\n         <!- Picture only if required -->\r\nMVANITYDEF\r\n\r\n         <!- Physical Details-->\r\n         <div class=\"erblank\" style=\"padding: 5px; width: 300px;\">\r\n\r\n          <b>Height:</b> MPHYSICALHEIGHT<br>\r\n          <b>Body Type:</b> MPHYSICALBODYTYPE<br>\r\n          <b>Eye Colour:</b> MPHYSICALEYECOLOUR<br>\r\n          <b>Hair Colour:</b> MPHYSICALHAIRCOLOUR<br>\r\n          <b>Ethnicity:</b> MPHYSICALETHNICITY<br>\r\n         </div>\r\n\r\n         <!- Mystical Voodoo ->\r\n         <div class=\"erblank\" style=\"padding: 5px; width: 300px;\">\r\n          <b>Age:</b> MPHYSICALAGE<br>\r\n          <b>Sign:</b> MASTROSIGN<br>\r\n          <b>Animal:</b> MASTROANIMAL<br>\r\n          <b>Element:</b> MASTROELEMENT<br>\r\n         </div>\r\n\r\n         <!- Social elements -->\r\n         <div class=\"erblank\" style=\"padding: 5px; width: 300px;\">\r\n          <b>Looking for:</b> MSOCIALLOOKING<br>\r\n          <b>Seeking:</b> MSOCIALSEEKING<br>\r\n          <b>Profession:</b> MSOCIALPROFESSION<br>\r\n          <b>Religion:</b> MSOCIALRELIGION<br>\r\n          <b>Have Children:</b> MSOCIALCHILDRENHAVE<br>\r\n          <b>Want Children:</b> MSOCIALCHILDRENWANT<br>\r\n         </div>\r\n\r\n         <!- Vices -->\r\n         <div class=\"erblank\" style=\"padding: 5px; width: 300px;\">\r\n          <b>Smoke:</b> MVICESMOKE<br>\r\n          <b>Drink:</b> MVICEDRINK<br>\r\n         </div>\r\n\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Row of Vanity shots -->\r\n       <tr>\r\n        <td colspan=\"2\">\r\n         <!- Yay more vanity -->\r\n         <div class=\"erblank\" style=\"border: none;\">\r\n          <!- Additional Header -->\r\n          <div class=\"galhead\" style=\"border: 1px solid #E3F3FA;\"><b>Additional Pictures</b></div>\r\n\r\n          <!- Let them show here -->\r\n          <div style=\"padding: 5px;\">\r\nMVANITYSUB\r\n          </div>\r\n         </div>\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Interests Section -->\r\n       <tr>\r\n        <td colspan=\"2\">\r\n         <!- What interests a person -->\r\n         <div class=\"erblank\" style=\"border: none;\">\r\n          <!- Additional Header -->\r\n          <div class=\"galhead\" style=\"border: 1px solid #E3F3FA;\"><b>Interests</b></div>\r\n\r\n          <!- Let them show here -->\r\n          <div style=\"padding: 5px;\">\r\nMSOCIALINTERESTS\r\n          </div>\r\n         </div>\r\n        </td>\r\n       </tr>\r\n\r\n       <!- Introduction -->\r\n       <tr>\r\n        <td colspan=\"2\">\r\n         <div class=\"erblank\">\r\n\r\n          <!- Header -->\r\n          <div class=\"galhead\"><b>Introduction</b></div>\r\n\r\n          <!- The Intro goes here -->\r\n          <div style=\"padding: 5px;\">\r\n           MINTRODESCRIPTION\r\n          </div>\r\n         </div>\r\n\r\n\r\n         <!- Interests Section -->\r\n         <div class=\"erblank\">\r\n\r\n          <!- Header -->\r\n          <div class=\"galhead\"><b>Ideas for a First Date</b></div>\r\n\r\n          <!- The Intro goes here -->\r\n          <div style=\"padding: 5px;\">\r\n           MINTROFIRSTDATE\r\n          </div>\r\n         </div>\r\n        </td>\r\n       </tr>\r\n\r\n\r\n       <!- Mail Habituality -->\r\n       <tr>\r\n        <td colspan=\"2\" align=\"center\">\r\n         <!- Display Friends -->\r\n         <b>MPUPPETNAME has MLIASONFRIENDS friend(s)!</b><br><br>\r\n\r\n\r\n         <!- Contact options and mail link -->\r\n         <a href=\"LLIASONMAIL\" target=\"mail\"  ONCLICK=\'window.open(this.href,this.target,settings); return false\'>MLIASONSOURCE</a>\r\n        </td>\r\n       </tr>\r\n      </table>\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialError','vanity','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialGeo','vanity','<html>\r\n <head>\r\n  <title>Ethereal Realms - Geographical Map</title>\r\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">\r\n  <link rel=\"stylesheet\" type=\"text/css\" href=\"/css/main.css\" title=\"Ethereal\">\r\n\r\n  <!- Google Maps API -->\r\n  <script src=\"http://maps.google.com/maps?file=api&amp;v=2&amp;key=MGMKEY\" type=\"text/javascript\"></script>\r\n\r\n  <!- Additional Definitions -->\r\n  <script src=\"/js/geo.js\" type=\"text/javascript\"></script>\r\n\r\n  <!- Additional details -->\r\n  <script type=\"text/javascript\">\r\n\r\n    //<![CDATA[\r\n\r\n    // Load function specific for this application\r\n    function load() {\r\n      if (GBrowserIsCompatible()) {\r\n\r\n        // Create instance\r\n        var map = new GMap2(document.getElementById(\"map\"));\r\n\r\n\r\n        // Map controls\r\n        // Pan and Zoom\r\n        map.addControl(new GLargeMapControl());\r\n\r\n        // Quick overview section\r\n        map.addControl(new GOverviewMapControl());\r\n\r\n        // Map type switch\r\n        map.addControl(new GMapTypeControl());\r\n\r\n        // Centre map\r\n        map.setCenter(new GLatLng(MSLAT, MSLON), 13);\r\n\r\n        // Creates a marker at the given point with the given number label\r\n        function createMarker(uLat, uLon, uDescr) {\r\n          var uLoc = new GLatLng(uLat, uLon);\r\n          var mrkUser = new GMarker(uLoc);\r\n          GEvent.addListener(mrkUser, \"click\", function() {\r\n            mrkUser.openInfoWindowHtml(uDescr);\r\n          });\r\n          return mrkUser;\r\n        }\r\n\r\n\r\n        // List of markers\r\nLSTRES\r\n      }\r\n    }\r\n\r\n    //]]>\r\n  </script>\r\n </head>\r\n\r\n <body onload=\"load()\" onunload=\"GUnload()\">\r\n\r\n  <!-- Wrapper table -->\r\n  <table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" style=\"width: 100%; height: 100%;\">\r\n   <tr>\r\n\r\n   <!-- Header -->\r\n\r\n    <td class=\"header\">\r\n    <!-- Introduction -->\r\n     <span class=\"header_left\">\r\n      <img src=\"/img/ttl.gif\" width=\"250\" height=\"46\" alt=\"Ethereal Realms\" class=\"header_image\">      \r\n      <span class=\"title\" style=\"margin-left: 15px\">&#187; Users near you!</span>\r\n     </span>\r\n\r\n     <!-- Complimentery links -->\r\n     <span class=\"header_right\">\r\n\r\n      <a href=\"/faq.shtml\"><img src=\"/img/faq.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Help\" title=\"Help\"></a>\r\n      <a href=\"/map.html\"><img src=\"/img/map.gif\" width=\"30\" height=\"30\" border=\"0\" alt=\"Site Map\" title=\"Site Map\"></a>\r\n     </span>\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <td style=\"height: 100%;\">\r\n\r\n     <!-- Begin work area -->\r\n     <div class=\"work\" align=\"center\">\r\n\r\n      <!- Google Maps -->\r\n      <!- Wrapper div -->\r\n      <div class=\"fancy_holder\">\r\n\r\n       <!- Puppet details -->\r\n       <!- Table definition -->\r\n       <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n        <!- Title -->\r\n        <tr> \r\n         <td class=\"fancy_title\">User search?</td>\r\n        </tr>\r\n\r\n        <!-Export Window -->\r\n        <tr> \r\n         <td class=\"fancy_follow\">People who near you?</td>\r\n        </tr>\r\n\r\n\r\n        <!- Spacer -->\r\n        <tr> \r\n         <td class=\"fancy_div\"></td>\r\n        </tr>\r\n\r\n\r\n        <!- Display Google Maps Interface -->\r\n        <tr> \r\n         <td class=\"fancy_blank\" align=\"center\">\r\n          <!- All goes within a nice and neat div -->\r\n          <div id=\"map\" style=\"width: 480px; height: 320px\"></div>\r\n         </td>\r\n        </tr>\r\n\r\n\r\n        <!- Spacer -->\r\n        <tr> \r\n         <td class=\"fancy_div\"></td>\r\n        </tr>\r\n\r\n\r\n        <!- Links -->\r\n        <tr> \r\n         <td class=\"fancy_sub\">\r\n          MLINKS\r\n         </td>\r\n        </tr>\r\n       </table>\r\n\r\n       <!- Quick help section -->\r\n       <div class=\"fancy_help\">\r\n        <!- Quick help text -->\r\n         <b>Quick Help</b><br><br>\r\n\r\n         This section allows you to visually see people who are near to\r\n         you.  However, it is important to note that their physical\r\n         location is neither comfirmed or accurate since the site will\r\n         purposfully randomize the last few digets for privacy reasons.\r\n       </div>\r\n      </div>\r\n\r\n     </div>\r\n     <!-- End work area -->\r\n\r\n    </td>\r\n   </tr>\r\n   <tr>\r\n    <!-- Copyright -->\r\n\r\n    <td class=\"footer\">\r\n     <span class=\"copy\">\r\n      <b>Copyright 1999-2006 Ethereal Realms</b><br>\r\n      All works and posts are owned by individual posters\r\n     </span>\r\n    </td>\r\n   </tr>\r\n  </table>\r\n </body>\r\n\r\n</html>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialGeoList','vanity','        // Entry for MPUPPETNAME\r\n        map.addOverlay(createMarker(MLAT, MLON, \"MVANITY<b>MINTROCATCHPHRASE</b><br><a href=\\"MLINK\\" target=\\"view\\" class=\\"dark\\">MPUPPETNAME</a><br>Is a MPHYSICALAGE year old MPHYSICALGENDER<br>Looking for MSOCIALSEEKING<br>Seeking MSOCIALLOOKING \"));\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialInterests','vanity','         <!- Interest Item -->\r\n         <div style=\"width: 150px; float: left;\"><a href=\"MLINK\" class=\"dark\">MNAME</a></div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialSearch','vanity','   <!- Searching Wrapper -->\r\n   <!- Table definition -->\r\n   <table class=\"fancy\" cellspacing=\"0\" style=\"width: 725px; float: none;\">\r\n\r\n    <!- Title and descriptor -->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"3\">Find users near you!</td>\r\n    </tr>\r\n\r\n    <!- Search away -->\r\nMSEARCH\r\n\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n\r\n    <!- Nav bar -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">\r\nLSTNAV MVISUAL\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n   <!- List results -->\r\nLSTRES\r\n\r\n\r\n    <!- Nav bar -->\r\n    <tr> \r\n     <td class=\"fancy_sub\" colspan=\"3\">\r\nLSTNAV MVISUAL\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialSearchBar','vanity','    <!- Search away -->\r\n    <tr>\r\n     <td colspan=\"3\">\r\n\r\n      <!- Wrap it up -->\r\n      <table width=\"500\">\r\n       <tr>\r\n        <!- Range -->\r\n        <td class=\"fancy_descr\">Search range in Kilometers?</td>\r\n        <td class=\"fancy_blank\">WSRNG</td>\r\n\r\n        <!- Submission -->\r\n        <td class=\"fancy_blank rowspan=\"2\" align=\"center\" valign=\"middle\">WSEARCH</td>\r\n       </tr>\r\n\r\n\r\n       <tr>\r\n        <!- Range Restrictions -->\r\n        <td class=\"fancy_descr\">Limit searches to?</td>\r\n        <td class=\"fancy_blank\">WSRES</td>\r\n       </tr>\r\n      </table>\r\n     </td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialSearchList','vanity','    <!- Matched entry list -->\r\n    <tr> \r\n     <!- First division -->\r\n     <td class=\"fancy_blank\" style=\"border-left: 1px solid #E3F3FA; border-top: 1px solid #E3F3FA; border-bottom: 1px solid #E3F3FA;\">\r\n      <div style=\"padding: 3px; text-align: left; vertical-align: top;\">\r\n       <!- Puppet Name -->\r\n       <a href=\"LMAIN\" class=\"menua\">MPUPPETNAME</a><br>\r\n\r\n       <!- Age and Gender -->\r\n       Is a MPHYSICALAGE year old MPHYSICALGENDER<br><br>\r\n\r\n       <!- Seeking and Looking -->\r\n       <b>Looking for</b> MSOCIALSEEKING<br>\r\n       <b>Seeking</b> MSOCIALLOOKING\r\n      </div>\r\n     </td>\r\n\r\n\r\n     <!- Second has more meat -->\r\n     <td class=\"fancy_blank\" style=\"border-top: 1px solid #E3F3FA; border-bottom: 1px solid #E3F3FA;\">\r\n      <div style=\"padding: 3px; text-align: left; vertical-align: top;\">\r\n       <!- Catch Phase -->\r\n       <span class=\"stark\"><b>MINTROCATCHPHRASE</b></span><br>\r\n\r\n       <!- Description and Interests -->\r\n       MINTRODESCRIPTION<br><b>Similiar Interests:</b> LSTINTERESTS<br><br>\r\n\r\n       <!- Location Information -->\r\n       <b>MLOCATECITY, MLOCATEREGION, MLOCATECOUNTRY</b>\r\n      </div>\r\n     </td>\r\n\r\n\r\n     <!- Vanity section -->\r\n     <td class=\"fancy_blank\" style=\"border-right: 1px solid #E3F3FA; border-top: 1px solid #E3F3FA; border-bottom: 1px solid #E3F3FA;\" align=\"center\">\r\n      <!- Display vanity shot -->\r\n      MVANITY\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Spacer -->\r\n    <tr> \r\n     <td class=\"fancy_div\" colspan=\"3\"></td>\r\n    </tr>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialVanityDef','vanity','         <!- Main Picture -->\r\n         <div style=\"float: right; padding: 5px;\">\r\n          <a href=\"MLINK\" target=\"vanity\" ONCLICK=\'window.open(this.href,this.target,settings); return false\'>\r\n           <img src=\"MIMG\" width=\"MWIDTH\" height=\"MHEIGHT\" alt=\"MPUPPETNAME\" title=\"MPUPPETNAME\" border=\"0\"> \r\n          </a>\r\n         </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialVanitySub','vanity','         <!- Sub pictures -->\r\n         <div style=\"width: 105px; height: 105px; float: left;\" valign=\"middle\" align=\"center\">\r\n          <a href=\"MLINK\" target=\"vanity\" ONCLICK=\'window.open(this.href,this.target,settings); return false\'>\r\n           <img src=\"MIMG\" alt=\"MPUPPETNAME\" title=\"MPUPPETNAME\" border=\"0\"> \r\n          </a>\r\n         </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplSocialWarn','vanity','');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanity','vanity','  <!- User image viewer -->\r\n  <!- Wrapper table -->\r\n  <div class=\"fancy_holder\">\r\n   <table class=\"fancy\" cellspacing=\"0\">\r\n\r\n    <!- Colour spacer -->\r\n    <!- Title-->\r\n    <tr> \r\n     <td class=\"fancy_title\" colspan=\"2\">Viewing images for MDEFAULT</td>\r\n    </tr>\r\n\r\n    <!- Additional Description -->\r\n    <tr> \r\n     <td class=\"fancy_follow\" colspan=\"2\">Currently selected image below</td>\r\n    </tr>\r\n\r\n\r\n    <!- Image itself -->\r\n    <tr>\r\n     <td class=\"fancy_blank\" colspan=\"2\" height=\"325\" valign=\"middle\" align=\"center\">\r\n      <!- Submit user to torment of seeing this picture -->\r\nMVANITY\r\n     </td>\r\n    </tr>\r\n\r\n    <!- Navigation -->\r\n    <tr>\r\n     <td class=\"fancy_sub\" colspan=\"2\">\r\nLSTNAV\r\n     </td>\r\n    </tr>\r\n   </table>\r\n\r\n   <!- Variable content -->\r\nMVOTES\r\n  </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityDisplay','vanity','      <!- Display physical image -->\r\n      <IMG SRC=\"LIMAGE\" WIDTH=\"MWIDTH\" HEIGHT=\"MHEIGHT\" ALT=\"Displaying image MID\" TITLE=\"Displaying imageMID\">\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes01','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level One -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height:  30px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes02','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n\r\n    <!- Display Level Two -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height:  60px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes03','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Three -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 90px;   float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes04','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n\r\n    <!- Display Level Four -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 120px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes05','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Five-->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 150px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes06','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Six -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 180px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes07','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Seven-->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 210px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes08','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Eight -->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 240px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes09','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Nine-->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 270px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityRes10','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Results</b><br><br>\r\n\r\n    This user has reached a score of <b>MLEVEL</b> over a total\r\n    of <b>MCOUNT</b> votes;<br><br>\r\n\r\n    <!- Display Level Ten-->\r\n    <div stlyle=\"height: 310px;\" align=\"center\" valign=\"bottom\">\r\n     <div class=\"vainmild\" style=\"height: 30px;  float: left;\">NOT!</div>\r\n     <div class=\"vainmid\" style=\"height: 300px;  float: left;\">PIC!</div>\r\n     <div class=\"vainhot\" style=\"height: 300px;  float: left;\">HOT!</div>\r\n    </div>\r\n   </div>\r\n\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityResNil','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n     <b>Quick Help</b><br><br>\r\n\r\n\r\n     Viewing a users specific images is a snap!   Simply click on the\r\n     numbers below to show a new image, moving back and forth is just\r\n     a click away.<br><br>\r\n\r\n     If the user allows for voting on a certain image then you will be\r\n     shown a voting screen.  After you have placed your vote the results\r\n     will appear.\r\n   </div>\r\n ');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TmplVanityVote','vanity','   <!- Quick help section -->\r\n   <div class=\"fancy_help\">\r\n    <b>Place your vote!</b><br><br>\r\n\r\n    <!- Voting begins ->\r\n    WFRMSTART\r\n\r\n    <!- Display voting choices -->\r\n    WLEVEL\r\n\r\n    <!- Spacer -->\r\n    <br><br>\r\n\r\n    <!- Place your bets here -->\r\n    WVOTE\r\n\r\n    <!- Form Ends -->\r\n    WFRMEND\r\n\r\n    <!- Spacer -->\r\n    <br><br>\r\n\r\n    Simply select the appropriate level of interest in this picture\r\n    and click on the \'Vote\' button to have the system record your\r\n    choice.  All votes are anonymous to the user getting the votes.\r\n   </div>\r\n');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtFirst','vanity','&lt;&lt;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtLast','vanity','&gt;&gt;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNext','vanity','&gt;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNoDescr','vanity','No description available!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtNoIntro','vanity','No catch phrase!');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtPrev','vanity','&lt;');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtReturn','vanity','Return');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSearch','vanity','Search');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSearchDef','vanity','50');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtSubject','vanity','Your profile');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtVisual','vanity','Visual');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('TxtVote','vanity','Vote');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1000','vcodes','System: Autenthication successful to the system through: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1001','vcodes','System: Autenthication failure to the system against: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1100','vcodes','User: Puppeteer password was reset: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1101','vcodes','User: Addition of Puppet: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1102','vcodes','User: Removal of Puppet: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1103','vcodes','User: Email password was changed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1104','vcodes','User: Addition of gallery: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1105','vcodes','User: Removal of gallery: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('1200','vcodes','User: Creation of realm: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2001','vcodes','User: Addition of puppeteer to the banned list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2002','vcodes','User: Removal of puppeteer to the banned list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2004','vcodes','User: Removal of cannon handle: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2005','vcodes','User: Addition of moderator: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2007','vcodes','User: Warning of user: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2100','vcodes','Board: Message and all children were purged: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2101','vcodes','Board: Topic was added to board: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2102','vcodes','Board: Topic was removed from board: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2103','vcodes','Board: Topic description was changed for board: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2201','vcodes','Realm: Removal of locale: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2202','vcodes','Realm: Topic was removed from board: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2203','vcodes','Realm: Realm information was changed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2204','vcodes','Realm: Realm information was reset: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2205','vcodes','Realm: Addition of word to the restriction list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2206','vcodes','Realm: Removal of word to the restriction list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2207','vcodes','Realm: Addition of picture to the restriction list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2208','vcodes','Realm: Removal of picture to the restriction list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2209','vcodes','Realm: Change to ICAO station: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2210','vcodes','Realm: Change of font settings: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2211','vcodes','Realm: Addition of gummy: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2212','vcodes','Realm: Removal of gummy: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2213','vcodes','Realm: Addition of Feed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2214','vcodes','Realm: Removal of Feed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('2215','vcodes','Realm: Modification of Feed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9000','vcodes','User: Addition of ban from the system of puppeteer: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9001','vcodes','User: Puppeteer information was changed: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9002','vcodes','User: Addition of puppeteer to the supervisory list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9003','vcodes','User: Removal of puppeteer to the supervisory list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9004','vcodes','User: Cross reference of user conducted: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9005','vcodes','User: Change in homepage time span: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9006','vcodes','User: Removal of user from system: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9100','vcodes','Realm: Addition of font: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9101','vcodes','Realm: Removal of font: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9104','vcodes','Realm: Addition of realm: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9105','vcodes','Realm: Removal of realm: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9106','vcodes','Realm: Change of public status to: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9107','vcodes','Realm: Supervisor stripped of privileges: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9200','vcodes','Profile: Addition of contact: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9201','vcodes','Profile: Removal of contact: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9202','vcodes','Profile: Addition of gummy: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9203','vcodes','Profile: Removal of gummy: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9300','vcodes','System: Document was altered: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9302','vcodes','System: Tag altered: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9303','vcodes','System: Addition of post to the weblog: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9304','vcodes','System: Removal of post to the weblog: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9305','vcodes','System: Addition of genre: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9306','vcodes','System: Removal of genre: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9307','vcodes','System: Update of genre: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9308','vcodes','System: Removal of poll: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9309','vcodes','System: Update of poll: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9310','vcodes','System: Removal of poll questopm: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9311','vcodes','System: Update of poll question: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9312','vcodes','System: Addition of word to censure list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9313','vcodes','System: Removal of word to censure list: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9314','vcodes','System: Access of Auditing records: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9315','vcodes','System: Addition of rotation: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9316','vcodes','System: Removal of rotation: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9317','vcodes','System: Update of rotation: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9318','vcodes','System: Addition of question: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9319','vcodes','System: Removal of question: MCODE');
INSERT INTO ethereal.Tag (TagName,TagType,TagData) VALUES('9320','vcodes','System: Update of question: MCODE');
UPDATE ethereal.Tag SET TagData='4.0.0' WHERE TagName='SetVersion' AND TagType='system'